@@ -12,6 +12,7 @@
 namespace Symfony\Bridge\Doctrine;
 
 use Doctrine\Persistence\AbstractManagerRegistry;
+use ProxyManager\Proxy\GhostObjectInterface;
 use ProxyManager\Proxy\LazyLoadingInterface;
 use Symfony\Bridge\ProxyManager\LazyProxy\Instantiator\RuntimeInstantiator;
 use Symfony\Component\DependencyInjection\Container;
@@ -19,7 +20,7 @@ use Symfony\Component\DependencyInjection\Container;
 /**
  * References Doctrine connections and entity/document managers.
  *
- * @author  Lukas Kahwe Smith <smith@pooteeweet.org>
+ * @author Lukas Kahwe Smith <smith@pooteeweet.org>
  */
 abstract class ManagerRegistry extends AbstractManagerRegistry
 {
@@ -53,6 +54,9 @@ abstract class ManagerRegistry extends AbstractManagerRegistry
         if (!$manager instanceof LazyLoadingInterface) {
             throw new \LogicException('Resetting a non-lazy manager service is not supported. '.(interface_exists(LazyLoadingInterface::class) && class_exists(RuntimeInstantiator::class) ? sprintf('Declare the "%s" service as lazy.', $name) : 'Try running "composer require symfony/proxy-manager-bridge".'));
         }
+        if ($manager instanceof GhostObjectInterface) {
+            throw new \LogicException('Resetting a lazy-ghost-object manager service is not supported.');
+        }
         $manager->setProxyInitializer(\Closure::bind(
             function (&$wrappedInstance, LazyLoadingInterface $manager) use ($name) {
                 if (isset($this->aliases[$name])) {
