@@ -35,7 +35,7 @@ class DoctrineOrmTypeGuesserTest extends TestCase
         $this->assertEquals($expected, $this->getGuesser($classMetadata)->guessType('TestEntity', 'field'));
     }
 
-    public function requiredType()
+    public static function requiredType()
     {
         yield [Types::DATE_IMMUTABLE, new TypeGuess('Symfony\Component\Form\Extension\Core\Type\DateType', ['input' => 'datetime_immutable'], Guess::HIGH_CONFIDENCE)];
         yield [Types::DATE_MUTABLE, new TypeGuess('Symfony\Component\Form\Extension\Core\Type\DateType', [], Guess::HIGH_CONFIDENCE)];
@@ -49,66 +49,63 @@ class DoctrineOrmTypeGuesserTest extends TestCase
         yield [Types::DATETIMETZ_MUTABLE, new TypeGuess('Symfony\Component\Form\Extension\Core\Type\DateTimeType', [], Guess::HIGH_CONFIDENCE)];
     }
 
-    /**
-     * @dataProvider requiredProvider
-     */
-    public function testRequiredGuesser($classMetadata, $expected)
+    public function testRequiredGuesserSimpleFieldNotNullable()
     {
-        $this->assertEquals($expected, $this->getGuesser($classMetadata)->guessRequired('TestEntity', 'field'));
-    }
-
-    public function requiredProvider()
-    {
-        $return = [];
-
-        // Simple field, not nullable
         $classMetadata = $this->createMock(ClassMetadata::class);
         $classMetadata->fieldMappings['field'] = true;
         $classMetadata->expects($this->once())->method('isNullable')->with('field')->willReturn(false);
 
-        $return[] = [$classMetadata, new ValueGuess(true, Guess::HIGH_CONFIDENCE)];
+        $this->assertEquals(new ValueGuess(true, Guess::HIGH_CONFIDENCE), $this->getGuesser($classMetadata)->guessRequired('TestEntity', 'field'));
+    }
 
-        // Simple field, nullable
+    public function testRequiredGuesserSimpleFieldNullable()
+    {
         $classMetadata = $this->createMock(ClassMetadata::class);
         $classMetadata->fieldMappings['field'] = true;
         $classMetadata->expects($this->once())->method('isNullable')->with('field')->willReturn(true);
 
-        $return[] = [$classMetadata, new ValueGuess(false, Guess::MEDIUM_CONFIDENCE)];
+        $this->assertEquals(new ValueGuess(false, Guess::MEDIUM_CONFIDENCE), $this->getGuesser($classMetadata)->guessRequired('TestEntity', 'field'));
+    }
 
-        // One-to-one, nullable (by default)
+    public function testRequiredGuesserOneToOneNullable()
+    {
         $classMetadata = $this->createMock(ClassMetadata::class);
         $classMetadata->expects($this->once())->method('isAssociationWithSingleJoinColumn')->with('field')->willReturn(true);
 
         $mapping = ['joinColumns' => [[]]];
         $classMetadata->expects($this->once())->method('getAssociationMapping')->with('field')->willReturn($mapping);
 
-        $return[] = [$classMetadata, new ValueGuess(false, Guess::HIGH_CONFIDENCE)];
+        $this->assertEquals(new ValueGuess(false, Guess::HIGH_CONFIDENCE), $this->getGuesser($classMetadata)->guessRequired('TestEntity', 'field'));
+    }
 
-        // One-to-one, nullable (explicit)
+    public function testRequiredGuesserOneToOneExplicitNullable()
+    {
         $classMetadata = $this->createMock(ClassMetadata::class);
         $classMetadata->expects($this->once())->method('isAssociationWithSingleJoinColumn')->with('field')->willReturn(true);
 
         $mapping = ['joinColumns' => [['nullable' => true]]];
         $classMetadata->expects($this->once())->method('getAssociationMapping')->with('field')->willReturn($mapping);
 
-        $return[] = [$classMetadata, new ValueGuess(false, Guess::HIGH_CONFIDENCE)];
+        $this->assertEquals(new ValueGuess(false, Guess::HIGH_CONFIDENCE), $this->getGuesser($classMetadata)->guessRequired('TestEntity', 'field'));
+    }
 
-        // One-to-one, not nullable
+    public function testRequiredGuesserOneToOneNotNullable()
+    {
         $classMetadata = $this->createMock(ClassMetadata::class);
         $classMetadata->expects($this->once())->method('isAssociationWithSingleJoinColumn')->with('field')->willReturn(true);
 
         $mapping = ['joinColumns' => [['nullable' => false]]];
         $classMetadata->expects($this->once())->method('getAssociationMapping')->with('field')->willReturn($mapping);
 
-        $return[] = [$classMetadata, new ValueGuess(true, Guess::HIGH_CONFIDENCE)];
+        $this->assertEquals(new ValueGuess(true, Guess::HIGH_CONFIDENCE), $this->getGuesser($classMetadata)->guessRequired('TestEntity', 'field'));
+    }
 
-        // One-to-many, no clue
+    public function testRequiredGuesserOneToMany()
+    {
         $classMetadata = $this->createMock(ClassMetadata::class);
         $classMetadata->expects($this->once())->method('isAssociationWithSingleJoinColumn')->with('field')->willReturn(false);
 
-        $return[] = [$classMetadata, null];
-
-        return $return;
+        $this->assertNull($this->getGuesser($classMetadata)->guessRequired('TestEntity', 'field'));
     }
 
     private function getGuesser(ClassMetadata $classMetadata)
