@@ -11,6 +11,7 @@
 
 namespace Symfony\Bridge\Doctrine\Tests\IdGenerator;
 
+use Doctrine\ORM\EntityManager;
 use Doctrine\ORM\Mapping\Entity;
 use PHPUnit\Framework\TestCase;
 use Symfony\Bridge\Doctrine\IdGenerator\UlidGenerator;
@@ -21,7 +22,7 @@ class UlidGeneratorTest extends TestCase
 {
     public function testUlidCanBeGenerated()
     {
-        $em = new EntityManager();
+        $em = (new \ReflectionClass(EntityManager::class))->newInstanceWithoutConstructor();
         $generator = new UlidGenerator();
         $ulid = $generator->generate($em, new Entity());
 
@@ -35,7 +36,7 @@ class UlidGeneratorTest extends TestCase
     public function testUlidFactory()
     {
         $ulid = new Ulid('00000000000000000000000000');
-        $em = new EntityManager();
+        $em = (new \ReflectionClass(EntityManager::class))->newInstanceWithoutConstructor();
         $factory = $this->createMock(UlidFactory::class);
         $factory->expects($this->any())
             ->method('create')
