@@ -44,7 +44,8 @@ class ManagerRegistryTest extends TestCase
         $registry->resetManager();
 
         $this->assertSame($foo, $container->get('foo'));
-        $this->assertObjectNotHasAttribute('bar', $foo);
+        $this->assertInstanceOf(\stdClass::class, $foo);
+        $this->assertFalse(property_exists($foo, 'bar'));
     }
 
     /**
