@@ -97,7 +97,7 @@ class HttpCodeActivationStrategyTest extends TestCase
         self::assertEquals($expected, $strategy->isHandlerActivated($record));
     }
 
-    public function isActivatedProvider(): array
+    public static function isActivatedProvider(): array
     {
         return [
             ['/test',  ['level' => Logger::ERROR], true],
