@@ -51,7 +51,7 @@ class ClassExistsMock
 
     public static function register($class)
     {
-        $self = \get_called_class();
+        $self = static::class;
 
         $mockedNs = [substr($class, 0, strrpos($class, '\\'))];
         if (0 < strpos($class, '\\Tests\\')) {
