@@ -179,7 +179,7 @@ class ConfigurationTest extends TestCase
         $this->assertTrue($configuration->shouldDisplayStackTrace('interesting'));
     }
 
-    public function provideItCanBeDisabled(): array
+    public static function provideItCanBeDisabled(): array
     {
         return [
             ['disabled', false],
@@ -248,7 +248,7 @@ class ConfigurationTest extends TestCase
         }
     }
 
-    public function provideDataForToleratesForGroup() {
+    public static function provideDataForToleratesForGroup() {
 
         yield 'total threshold not reached' => ['max[total]=1', [
             'unsilenced' => 0,
@@ -482,10 +482,24 @@ class ConfigurationTest extends TestCase
     {
         $filename = $this->createFile();
         chmod($filename, 0444);
-        $this->expectError();
-        $this->expectErrorMessageMatches('/[Ff]ailed to open stream: Permission denied/');
         $configuration = Configuration::fromUrlEncodedString('generateBaseline=true&baselineFile='.urlencode($filename));
-        $configuration->writeBaseline();
+
+        $this->expectException(\ErrorException::class);
+        $this->expectExceptionMessageMatches('/[Ff]ailed to open stream: Permission denied/');
+
+        set_error_handler(static function (int $errno, string $errstr, string $errfile = null, int $errline = null): bool {
+            if ($errno & (E_WARNING | E_WARNING)) {
+                throw new \ErrorException($errstr, 0, $errno, $errfile, $errline);
+            }
+
+            return false;
+        });
+
+        try {
+            $configuration->writeBaseline();
+        } finally {
+            restore_error_handler();
+        }
     }
 
     protected function setUp(): void
