@@ -14,13 +14,14 @@ namespace Symfony\Bridge\Twig\Extension;
 use Symfony\Bridge\Twig\TokenParser\StopwatchTokenParser;
 use Symfony\Component\Stopwatch\Stopwatch;
 use Twig\Extension\AbstractExtension;
+use Twig\TokenParser\TokenParserInterface;
 
 /**
  * Twig extension for the stopwatch helper.
  *
  * @author Wouter J <wouter@wouterj.nl>
  */
-class StopwatchExtension extends AbstractExtension
+final class StopwatchExtension extends AbstractExtension
 {
     private $stopwatch;
     private $enabled;
@@ -31,12 +32,15 @@ class StopwatchExtension extends AbstractExtension
         $this->enabled = $enabled;
     }
 
-    public function getStopwatch()
+    public function getStopwatch(): Stopwatch
     {
         return $this->stopwatch;
     }
 
-    public function getTokenParsers()
+    /**
+     * @return TokenParserInterface[]
+     */
+    public function getTokenParsers(): array
     {
         return [
             /*
@@ -47,9 +51,4 @@ class StopwatchExtension extends AbstractExtension
             new StopwatchTokenParser(null !== $this->stopwatch && $this->enabled),
         ];
     }
-
-    public function getName()
-    {
-        return 'stopwatch';
-    }
 }
