@@ -116,6 +116,10 @@ final class TranslationExtension extends AbstractExtension
                 throw new \TypeError(sprintf('Argument 2 passed to "%s()" must be a locale passed as a string when the message is a "%s", "%s" given.', __METHOD__, TranslatableInterface::class, get_debug_type($arguments)));
             }
 
+            if ($message instanceof TranslatableMessage && '' === $message->getMessage()) {
+                return '';
+            }
+
             return $message->trans($this->getTranslator(), $locale ?? (\is_string($arguments) ? $arguments : null));
         }
 
