@@ -35,6 +35,12 @@ final class WrappedTemplatedEmail
         return $this->message->getTo()[0]->getName();
     }
 
+    /**
+     * @param string      $image       A Twig path to the image file. It's recommended to define
+     *                                 some Twig namespace for email images (e.g. '@email/images/logo.png').
+     * @param string|null $contentType The media type (i.e. MIME type) of the image file (e.g. 'image/png').
+     *                                 Some email clients require this to display embedded images.
+     */
     public function image(string $image, string $contentType = null): string
     {
         $file = $this->twig->getLoader()->getSourceContext($image);
@@ -47,6 +53,13 @@ final class WrappedTemplatedEmail
         return 'cid:'.$image;
     }
 
+    /**
+     * @param string      $file        A Twig path to the file. It's recommended to define
+     *                                 some Twig namespace for email files (e.g. '@email/files/contract.pdf').
+     * @param string|null $name        A custom file name that overrides the original name of the attached file
+     * @param string|null $contentType The media type (i.e. MIME type) of the file (e.g. 'application/pdf').
+     *                                 Some email clients require this to display attached files.
+     */
     public function attach(string $file, string $name = null, string $contentType = null): void
     {
         $file = $this->twig->getLoader()->getSourceContext($file);
@@ -182,7 +195,7 @@ final class WrappedTemplatedEmail
      */
     public function setPriority(int $priority): self
     {
-        $this->message->setPriority($priority);
+        $this->message->priority($priority);
 
         return $this;
     }
