@@ -18,14 +18,14 @@ use Twig\Node\Node;
 /**
  * @author Fabien Potencier <fabien@symfony.com>
  */
-class FormThemeNode extends Node
+final class FormThemeNode extends Node
 {
     public function __construct(Node $form, Node $resources, int $lineno, string $tag = null, bool $only = false)
     {
         parent::__construct(['form' => $form, 'resources' => $resources], ['only' => $only], $lineno, $tag);
     }
 
-    public function compile(Compiler $compiler)
+    public function compile(Compiler $compiler): void
     {
         $compiler
             ->addDebugInfo($this)
