@@ -44,7 +44,7 @@ class CodeExtensionTest extends TestCase
         $this->assertEquals($this->getExtension()->abbrMethod($method), $abbr);
     }
 
-    public function getClassNameProvider(): array
+    public static function getClassNameProvider(): array
     {
         return [
             ['F\Q\N\Foo', '<abbr title="F\Q\N\Foo">Foo</abbr>'],
@@ -52,7 +52,7 @@ class CodeExtensionTest extends TestCase
         ];
     }
 
-    public function getMethodNameProvider(): array
+    public static function getMethodNameProvider(): array
     {
         return [
             ['F\Q\N\Foo::Method', '<abbr title="F\Q\N\Foo">Foo</abbr>::Method()'],
