@@ -19,4 +19,9 @@ class StubTranslator implements TranslatorInterface
     {
         return '[trans]'.strtr($id, $parameters).'[/trans]';
     }
+
+    public function getLocale(): string
+    {
+        return 'en';
+    }
 }
