@@ -51,17 +51,15 @@ class TranslationNodeVisitorTest extends TestCase
         $this->testMessagesExtraction($node, [[$message, TranslationNodeVisitor::UNDEFINED_DOMAIN]]);
     }
 
-    public function getMessagesExtractionTestData()
+    public static function getMessagesExtractionTestData()
     {
         $message = 'new key';
         $domain = 'domain';
 
         return [
             [TwigNodeProvider::getTransFilter($message), [[$message, null]]],
-            [TwigNodeProvider::getTransChoiceFilter($message), [[$message, null]]],
             [TwigNodeProvider::getTransTag($message), [[$message, null]]],
             [TwigNodeProvider::getTransFilter($message, $domain), [[$message, $domain]]],
-            [TwigNodeProvider::getTransChoiceFilter($message, $domain), [[$message, $domain]]],
             [TwigNodeProvider::getTransTag($message, $domain), [[$message, $domain]]],
         ];
     }
