@@ -35,23 +35,20 @@ use Symfony\Component\HttpKernel\KernelInterface;
  */
 class AssetsInstallCommand extends Command
 {
-    const METHOD_COPY = 'copy';
-    const METHOD_ABSOLUTE_SYMLINK = 'absolute symlink';
-    const METHOD_RELATIVE_SYMLINK = 'relative symlink';
+    public const METHOD_COPY = 'copy';
+    public const METHOD_ABSOLUTE_SYMLINK = 'absolute symlink';
+    public const METHOD_RELATIVE_SYMLINK = 'relative symlink';
 
     protected static $defaultName = 'assets:install';
+    protected static $defaultDescription = 'Install bundle\'s web assets under a public directory';
 
     private $filesystem;
     private $projectDir;
 
-    public function __construct(Filesystem $filesystem, string $projectDir = null)
+    public function __construct(Filesystem $filesystem, string $projectDir)
     {
         parent::__construct();
 
-        if (null === $projectDir) {
-            @trigger_error(sprintf('Not passing the project directory to the constructor of %s is deprecated since Symfony 4.3 and will not be supported in 5.0.', __CLASS__), \E_USER_DEPRECATED);
-        }
-
         $this->filesystem = $filesystem;
         $this->projectDir = $projectDir;
     }
@@ -65,10 +62,10 @@ class AssetsInstallCommand extends Command
             ->setDefinition([
                 new InputArgument('target', InputArgument::OPTIONAL, 'The target directory', null),
             ])
-            ->addOption('symlink', null, InputOption::VALUE_NONE, 'Symlinks the assets instead of copying it')
+            ->addOption('symlink', null, InputOption::VALUE_NONE, 'Symlink the assets instead of copying them')
             ->addOption('relative', null, InputOption::VALUE_NONE, 'Make relative symlinks')
             ->addOption('no-cleanup', null, InputOption::VALUE_NONE, 'Do not remove the assets of the bundles that no longer exist')
-            ->setDescription('Installs bundles web assets under a public directory')
+            ->setDescription(self::$defaultDescription)
             ->setHelp(<<<'EOT'
 The <info>%command.name%</info> command installs bundle assets into a given
 directory (e.g. the <comment>public</comment> directory).
@@ -99,8 +96,7 @@ EOT
     {
         /** @var KernelInterface $kernel */
         $kernel = $this->getApplication()->getKernel();
-        $targetArg = rtrim($input->getArgument('target'), '/');
-
+        $targetArg = rtrim($input->getArgument('target') ?? '', '/');
         if (!$targetArg) {
             $targetArg = $this->getPublicDirectory($kernel->getContainer());
         }
@@ -236,7 +232,7 @@ EOT
     /**
      * Creates symbolic link.
      *
-     * @throws IOException if link can not be created
+     * @throws IOException if link cannot be created
      */
     private function symlink(string $originDir, string $targetDir, bool $relative = false)
     {
@@ -278,10 +274,6 @@ EOT
 
         $composerConfig = json_decode(file_get_contents($composerFilePath), true);
 
-        if (isset($composerConfig['extra']['public-dir'])) {
-            return $composerConfig['extra']['public-dir'];
-        }
-
-        return $defaultPublicDir;
+        return $composerConfig['extra']['public-dir'] ?? $defaultPublicDir;
     }
 }
