@@ -24,9 +24,13 @@ use Symfony\Component\Console\Style\SymfonyStyle;
 final class CachePoolListCommand extends Command
 {
     protected static $defaultName = 'cache:pool:list';
+    protected static $defaultDescription = 'List available cache pools';
 
     private $poolNames;
 
+    /**
+     * @param string[] $poolNames
+     */
     public function __construct(array $poolNames)
     {
         parent::__construct();
@@ -40,7 +44,7 @@ final class CachePoolListCommand extends Command
     protected function configure()
     {
         $this
-            ->setDescription('List available cache pools')
+            ->setDescription(self::$defaultDescription)
             ->setHelp(<<<'EOF'
 The <info>%command.name%</info> command lists all available cache pools.
 EOF
@@ -51,12 +55,14 @@ EOF
     /**
      * {@inheritdoc}
      */
-    protected function execute(InputInterface $input, OutputInterface $output)
+    protected function execute(InputInterface $input, OutputInterface $output): int
     {
         $io = new SymfonyStyle($input, $output);
 
         $io->table(['Pool name'], array_map(function ($pool) {
             return [$pool];
         }, $this->poolNames));
+
+        return 0;
     }
 }
