@@ -11,6 +11,7 @@
 
 namespace Symfony\Bundle\FrameworkBundle\DependencyInjection\Compiler;
 
+use Symfony\Bundle\FrameworkBundle\DataCollector\TemplateAwareDataCollectorInterface;
 use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
 use Symfony\Component\DependencyInjection\ContainerBuilder;
 use Symfony\Component\DependencyInjection\Exception\InvalidArgumentException;
@@ -32,16 +33,19 @@ class ProfilerPass implements CompilerPassInterface
         $definition = $container->getDefinition('profiler');
 
         $collectors = new \SplPriorityQueue();
-        $order = PHP_INT_MAX;
+        $order = \PHP_INT_MAX;
         foreach ($container->findTaggedServiceIds('data_collector', true) as $id => $attributes) {
-            $priority = isset($attributes[0]['priority']) ? $attributes[0]['priority'] : 0;
+            $priority = $attributes[0]['priority'] ?? 0;
             $template = null;
 
-            if (isset($attributes[0]['template'])) {
-                if (!isset($attributes[0]['id'])) {
+            $collectorClass = $container->findDefinition($id)->getClass();
+            $isTemplateAware = is_subclass_of($collectorClass, TemplateAwareDataCollectorInterface::class);
+            if (isset($attributes[0]['template']) || $isTemplateAware) {
+                $idForTemplate = $attributes[0]['id'] ?? $collectorClass;
+                if (!$idForTemplate) {
                     throw new InvalidArgumentException(sprintf('Data collector service "%s" must have an id attribute in order to specify a template.', $id));
                 }
-                $template = [$attributes[0]['id'], $attributes[0]['template']];
+                $template = [$idForTemplate, $attributes[0]['template'] ?? $collectorClass::getTemplate()];
             }
 
             $collectors->insert([$id, $template], [$priority, --$order]);
