@@ -11,10 +11,10 @@
 
 namespace Symfony\Bundle\FrameworkBundle\Routing;
 
-use Symfony\Bundle\FrameworkBundle\Controller\ControllerNameParser;
 use Symfony\Component\Config\Exception\LoaderLoadException;
 use Symfony\Component\Config\Loader\DelegatingLoader as BaseDelegatingLoader;
 use Symfony\Component\Config\Loader\LoaderResolverInterface;
+use Symfony\Component\Routing\RouteCollection;
 
 /**
  * DelegatingLoader delegates route loading to other loaders using a loader resolver.
@@ -24,33 +24,18 @@ use Symfony\Component\Config\Loader\LoaderResolverInterface;
  *
  * @author Fabien Potencier <fabien@symfony.com>
  *
- * @final since Symfony 4.4
+ * @final
  */
 class DelegatingLoader extends BaseDelegatingLoader
 {
-    /**
-     * @deprecated since Symfony 4.4
-     */
-    protected $parser;
     private $loading = false;
     private $defaultOptions;
+    private $defaultRequirements;
 
-    /**
-     * @param LoaderResolverInterface $resolver
-     * @param array                   $defaultOptions
-     */
-    public function __construct($resolver, $defaultOptions = [])
+    public function __construct(LoaderResolverInterface $resolver, array $defaultOptions = [], array $defaultRequirements = [])
     {
-        if ($resolver instanceof ControllerNameParser) {
-            @trigger_error(sprintf('Passing a "%s" instance as first argument to "%s()" is deprecated since Symfony 4.4, pass a "%s" instance instead.', ControllerNameParser::class, __METHOD__, LoaderResolverInterface::class), \E_USER_DEPRECATED);
-            $this->parser = $resolver;
-            $resolver = $defaultOptions;
-            $defaultOptions = 2 < \func_num_args() ? func_get_arg(2) : [];
-        } elseif (2 < \func_num_args() && func_get_arg(2) instanceof ControllerNameParser) {
-            $this->parser = func_get_arg(2);
-        }
-
         $this->defaultOptions = $defaultOptions;
+        $this->defaultRequirements = $defaultRequirements;
 
         parent::__construct($resolver);
     }
@@ -58,7 +43,7 @@ class DelegatingLoader extends BaseDelegatingLoader
     /**
      * {@inheritdoc}
      */
-    public function load($resource, $type = null)
+    public function load($resource, string $type = null): RouteCollection
     {
         if ($this->loading) {
             // This can happen if a fatal error occurs in parent::load().
@@ -77,7 +62,7 @@ class DelegatingLoader extends BaseDelegatingLoader
             // - this handles the case and prevents the second fatal error
             //   by triggering an exception beforehand.
 
-            throw new LoaderLoadException($resource, null, null, null, $type);
+            throw new LoaderLoadException($resource, null, 0, null, $type);
         }
         $this->loading = true;
 
@@ -91,26 +76,17 @@ class DelegatingLoader extends BaseDelegatingLoader
             if ($this->defaultOptions) {
                 $route->setOptions($route->getOptions() + $this->defaultOptions);
             }
+            if ($this->defaultRequirements) {
+                $route->setRequirements($route->getRequirements() + $this->defaultRequirements);
+            }
             if (!\is_string($controller = $route->getDefault('_controller'))) {
                 continue;
             }
 
-            if (false !== strpos($controller, '::')) {
+            if (str_contains($controller, '::')) {
                 continue;
             }
 
-            if ($this->parser && 2 === substr_count($controller, ':')) {
-                $deprecatedNotation = $controller;
-
-                try {
-                    $controller = $this->parser->parse($controller, false);
-
-                    @trigger_error(sprintf('Referencing controllers with %s is deprecated since Symfony 4.1, use "%s" instead.', $deprecatedNotation, $controller), \E_USER_DEPRECATED);
-                } catch (\InvalidArgumentException $e) {
-                    // unable to optimize unknown notation
-                }
-            }
-
             $route->setDefault('_controller', $controller);
         }
 
