@@ -80,7 +80,7 @@ abstract class KernelTestCase extends TestCase
 
         $kernel = static::createKernel($options);
         $kernel->boot();
-        self::$kernel = $kernel;
+        static::$kernel = $kernel;
         static::$booted = true;
 
         $container = static::$kernel->getContainer();
