@@ -74,13 +74,13 @@ class CacheClearCommandTest extends TestCase
         $containerRef = new \ReflectionClass($containerClass);
         $containerFile = \dirname($containerRef->getFileName(), 2).'/'.$containerClass.'.php';
         $containerMetaFile = $containerFile.'.meta';
-        $this->kernelRef = new \ReflectionObject($this->kernel);
-        $this->kernelFile = $this->kernelRef->getFileName();
+        $kernelRef = new \ReflectionObject($this->kernel);
+        $kernelFile = $kernelRef->getFileName();
         /** @var ResourceInterface[] $meta */
         $meta = unserialize(file_get_contents($containerMetaFile));
         $found = false;
         foreach ($meta as $resource) {
-            if ((string) $resource === $this->kernelFile) {
+            if ((string) $resource === $kernelFile) {
                 $found = true;
                 break;
             }
