@@ -36,13 +36,6 @@ class TestAppKernel extends Kernel
         $loader->load(__DIR__.\DIRECTORY_SEPARATOR.'config.yml');
     }
 
-    public function setAnnotatedClassCache(array $annotatedClasses)
-    {
-        $annotatedClasses = array_diff($annotatedClasses, ['Symfony\Bundle\WebProfilerBundle\Controller\ExceptionController', 'Symfony\Bundle\TwigBundle\Controller\ExceptionController', 'Symfony\Bundle\TwigBundle\Controller\PreviewErrorController']);
-
-        parent::setAnnotatedClassCache($annotatedClasses);
-    }
-
     protected function build(ContainerBuilder $container)
     {
         $container->register('logger', NullLogger::class);
