@@ -98,7 +98,7 @@ class CachePoolDeleteCommandTest extends TestCase
         $this->assertSame($expectedSuggestions, $suggestions);
     }
 
-    public function provideCompletionSuggestions()
+    public static function provideCompletionSuggestions()
     {
         yield 'pool_name' => [
             ['f'],
