@@ -14,7 +14,6 @@ namespace Symfony\Bundle\FrameworkBundle\Tests\Controller;
 use Psr\Container\ContainerInterface as Psr11ContainerInterface;
 use Psr\Log\LoggerInterface;
 use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
-use Symfony\Bundle\FrameworkBundle\Controller\ControllerNameParser;
 use Symfony\Bundle\FrameworkBundle\Controller\ControllerResolver;
 use Symfony\Component\DependencyInjection\Container;
 use Symfony\Component\DependencyInjection\ContainerAwareInterface;
@@ -49,31 +48,6 @@ class ControllerResolverTest extends ContainerControllerResolverTest
         $this->assertInstanceOf(ContainerInterface::class, $controller->getContainer());
     }
 
-    /**
-     * @group legacy
-     * @expectedDeprecation Referencing controllers with FooBundle:Default:test is deprecated since Symfony 4.1. Use Symfony\Bundle\FrameworkBundle\Tests\Controller\ContainerAwareController::testAction instead.
-     */
-    public function testGetControllerWithBundleNotation()
-    {
-        $shortName = 'FooBundle:Default:test';
-        $parser = $this->createMockParser();
-        $parser->expects($this->once())
-            ->method('parse')
-            ->with($shortName)
-            ->willReturn('Symfony\Bundle\FrameworkBundle\Tests\Controller\ContainerAwareController::testAction')
-        ;
-
-        $resolver = $this->createLegacyControllerResolver(null, null, $parser);
-        $request = Request::create('/');
-        $request->attributes->set('_controller', $shortName);
-
-        $controller = $resolver->getController($request);
-
-        $this->assertInstanceOf(ContainerAwareController::class, $controller[0]);
-        $this->assertInstanceOf(ContainerInterface::class, $controller[0]->getContainer());
-        $this->assertSame('testAction', $controller[1]);
-    }
-
     public function testContainerAwareControllerGetsContainerWhenNotSet()
     {
         class_exists(AbstractControllerTest::class);
@@ -92,12 +66,11 @@ class ControllerResolverTest extends ContainerControllerResolverTest
         $this->assertSame($container, $controller->getContainer());
     }
 
-    /**
-     * @group legacy
-     * @expectedDeprecation Auto-injection of the container for "Symfony\Bundle\FrameworkBundle\Tests\Controller\TestAbstractController" is deprecated since Symfony 4.2. Configure it as a service instead.
-     */
     public function testAbstractControllerGetsContainerWhenNotSet()
     {
+        $this->expectException(\LogicException::class);
+        $this->expectExceptionMessage('"Symfony\\Bundle\\FrameworkBundle\\Tests\\Controller\\TestAbstractController" has no container set, did you forget to define it as a service subscriber?');
+
         class_exists(AbstractControllerTest::class);
 
         $controller = new TestAbstractController(false);
@@ -105,7 +78,7 @@ class ControllerResolverTest extends ContainerControllerResolverTest
         $container = new Container();
         $container->set(TestAbstractController::class, $controller);
 
-        $resolver = $this->createLegacyControllerResolver(null, $container);
+        $resolver = $this->createControllerResolver(null, $container);
 
         $request = Request::create('/');
         $request->attributes->set('_controller', TestAbstractController::class.'::fooAction');
@@ -114,12 +87,11 @@ class ControllerResolverTest extends ContainerControllerResolverTest
         $this->assertSame($container, $controller->setContainer($container));
     }
 
-    /**
-     * @group legacy
-     * @expectedDeprecation Auto-injection of the container for "Symfony\Bundle\FrameworkBundle\Tests\Controller\DummyController" is deprecated since Symfony 4.2. Configure it as a service instead.
-     */
-    public function testAbstractControllerServiceWithFcqnIdGetsContainerWhenNotSet()
+    public function testAbstractControllerServiceWithFqcnIdGetsContainerWhenNotSet()
     {
+        $this->expectException(\LogicException::class);
+        $this->expectExceptionMessage('"Symfony\\Bundle\\FrameworkBundle\\Tests\\Controller\\DummyController" has no container set, did you forget to define it as a service subscriber?');
+
         class_exists(AbstractControllerTest::class);
 
         $controller = new DummyController();
@@ -127,7 +99,7 @@ class ControllerResolverTest extends ContainerControllerResolverTest
         $container = new Container();
         $container->set(DummyController::class, $controller);
 
-        $resolver = $this->createLegacyControllerResolver(null, $container);
+        $resolver = $this->createControllerResolver(null, $container);
 
         $request = Request::create('/');
         $request->attributes->set('_controller', DummyController::class.'::fooAction');
@@ -176,19 +148,6 @@ class ControllerResolverTest extends ContainerControllerResolverTest
         $this->assertSame($controllerContainer, $controller->getContainer());
     }
 
-    protected function createLegacyControllerResolver(LoggerInterface $logger = null, Psr11ContainerInterface $container = null, ControllerNameParser $parser = null)
-    {
-        if (!$parser) {
-            $parser = $this->createMockParser();
-        }
-
-        if (!$container) {
-            $container = $this->createMockContainer();
-        }
-
-        return new ControllerResolver($container, $parser, $logger);
-    }
-
     protected function createControllerResolver(LoggerInterface $logger = null, Psr11ContainerInterface $container = null)
     {
         if (!$container) {
