@@ -43,6 +43,13 @@ class TestServiceContainerRefPassesTest extends TestCase
             ->setPublic(true)
             ->addTag('container.private', ['package' => 'foo/bar', 'version' => '1.42'])
         ;
+        $container->register('Test\soon_private_service_decorated')
+            ->setPublic(true)
+            ->addTag('container.private', ['package' => 'foo/bar', 'version' => '1.42'])
+        ;
+        $container->register('Test\soon_private_service_decorator')
+            ->setDecoratedService('Test\soon_private_service_decorated')
+            ->setArguments(['Test\soon_private_service_decorator.inner']);
 
         $container->register('Test\private_used_shared_service');
         $container->register('Test\private_unused_shared_service');
@@ -55,6 +62,8 @@ class TestServiceContainerRefPassesTest extends TestCase
             'Test\private_used_shared_service' => new ServiceClosureArgument(new Reference('Test\private_used_shared_service')),
             'Test\private_used_non_shared_service' => new ServiceClosureArgument(new Reference('Test\private_used_non_shared_service')),
             'Test\soon_private_service' => new ServiceClosureArgument(new Reference('.container.private.Test\soon_private_service')),
+            'Test\soon_private_service_decorator' => new ServiceClosureArgument(new Reference('.container.private.Test\soon_private_service_decorated')),
+            'Test\soon_private_service_decorated' => new ServiceClosureArgument(new Reference('.container.private.Test\soon_private_service_decorated')),
         ];
 
         $privateServices = $container->getDefinition('test.private_services_locator')->getArgument(0);
