@@ -60,7 +60,7 @@ class ConfigurationTest extends TestCase
         );
     }
 
-    public function getTestInvalidSessionName()
+    public static function getTestInvalidSessionName()
     {
         return [
             ['a.b'],
@@ -113,7 +113,7 @@ class ConfigurationTest extends TestCase
         $this->assertArrayHasKey($packageName, $config['assets']['packages']);
     }
 
-    public function provideValidAssetsPackageNameConfigurationTests()
+    public static function provideValidAssetsPackageNameConfigurationTests()
     {
         return [
             ['foobar'],
@@ -139,7 +139,7 @@ class ConfigurationTest extends TestCase
             ]);
     }
 
-    public function provideInvalidAssetConfigurationTests()
+    public static function provideInvalidAssetConfigurationTests()
     {
         // helper to turn config into embedded package config
         $createPackageConfig = function (array $packageConfig) {
@@ -192,7 +192,7 @@ class ConfigurationTest extends TestCase
         $this->assertEquals($processedConfig, $config['lock']);
     }
 
-    public function provideValidLockConfigurationTests()
+    public static function provideValidLockConfigurationTests()
     {
         yield [null, ['enabled' => true, 'resources' => ['default' => [class_exists(SemaphoreStore::class) && SemaphoreStore::isSupported() ? 'semaphore' : 'flock']]]];
 
