@@ -13,6 +13,11 @@ return static function (ContainerConfigurator $container) {
                 'sender' => 'sender@example.org',
                 'recipients' => ['redirected@example.org', 'redirected1@example.org'],
             ],
+            'headers' => [
+                'from' => 'from@example.org',
+                'bcc' => ['bcc1@example.org', 'bcc2@example.org'],
+                'foo' => 'bar',
+            ],
         ],
     ]);
 };
