@@ -14,6 +14,7 @@ namespace Symfony\Bundle\FrameworkBundle\Tests\DependencyInjection;
 use Symfony\Component\Config\FileLocator;
 use Symfony\Component\DependencyInjection\ContainerBuilder;
 use Symfony\Component\DependencyInjection\Loader\XmlFileLoader;
+use Symfony\Component\RateLimiter\Policy\SlidingWindowLimiter;
 
 class XmlFrameworkExtensionTest extends FrameworkExtensionTestCase
 {
@@ -66,4 +67,11 @@ class XmlFrameworkExtensionTest extends FrameworkExtensionTestCase
             'status_code' => 500,
         ], $configuration[\Symfony\Component\HttpKernel\Exception\ServiceUnavailableHttpException::class]);
     }
+
+    public function testRateLimiter()
+    {
+        $container = $this->createContainerFromFile('rate_limiter');
+
+        $this->assertTrue($container->hasDefinition('limiter.sliding_window'));
+    }
 }
