@@ -100,7 +100,7 @@ class RouterDebugCommandTest extends AbstractWebTestCase
         $this->assertSame($expectedSuggestions, $tester->complete($input));
     }
 
-    public function provideCompletionSuggestions()
+    public static function provideCompletionSuggestions()
     {
         yield 'option --format' => [
             ['--format', ''],
