@@ -28,21 +28,14 @@ class FirewallContext
     private $config;
 
     /**
-     * @param LogoutListener|null $logoutListener
+     * @param iterable<mixed, callable> $listeners
      */
-    public function __construct(iterable $listeners, ExceptionListener $exceptionListener = null, $logoutListener = null, FirewallConfig $config = null)
+    public function __construct(iterable $listeners, ExceptionListener $exceptionListener = null, LogoutListener $logoutListener = null, FirewallConfig $config = null)
     {
         $this->listeners = $listeners;
         $this->exceptionListener = $exceptionListener;
-        if ($logoutListener instanceof FirewallConfig) {
-            $this->config = $logoutListener;
-            @trigger_error(sprintf('Passing an instance of %s as the 3rd argument to "%s()" is deprecated since Symfony 4.2. Pass a %s instance instead.', FirewallConfig::class, __METHOD__, LogoutListener::class), E_USER_DEPRECATED);
-        } elseif (null === $logoutListener || $logoutListener instanceof LogoutListener) {
-            $this->logoutListener = $logoutListener;
-            $this->config = $config;
-        } else {
-            throw new \TypeError(sprintf('Argument 3 passed to %s() must be instance of %s or null, %s given.', __METHOD__, LogoutListener::class, \is_object($logoutListener) ? \get_class($logoutListener) : \gettype($logoutListener)));
-        }
+        $this->logoutListener = $logoutListener;
+        $this->config = $config;
     }
 
     public function getConfig()
@@ -50,6 +43,9 @@ class FirewallContext
         return $this->config;
     }
 
+    /**
+     * @return iterable<mixed, callable>
+     */
     public function getListeners(): iterable
     {
         return $this->listeners;
