@@ -12,12 +12,16 @@
 namespace Symfony\Bundle\SecurityBundle\Tests\DependencyInjection;
 
 use PHPUnit\Framework\TestCase;
+use Symfony\Bridge\PhpUnit\ExpectDeprecationTrait;
 use Symfony\Bundle\SecurityBundle\DependencyInjection\MainConfiguration;
+use Symfony\Bundle\SecurityBundle\DependencyInjection\Security\Factory\AuthenticatorFactoryInterface;
 use Symfony\Component\Config\Definition\Exception\InvalidConfigurationException;
 use Symfony\Component\Config\Definition\Processor;
 
 class MainConfigurationTest extends TestCase
 {
+    use ExpectDeprecationTrait;
+
     /**
      * The minimal, required config needed to not have any required validation
      * issues.
@@ -113,4 +117,46 @@ class MainConfigurationTest extends TestCase
 
         $this->assertEquals('app.henk_checker', $processedConfig['firewalls']['stub']['user_checker']);
     }
+
+    public function testConfigMergeWithAccessDecisionManager()
+    {
+        $config = [
+            'access_decision_manager' => [
+                'strategy' => MainConfiguration::STRATEGY_UNANIMOUS,
+            ],
+        ];
+        $config = array_merge(static::$minimalConfig, $config);
+
+        $config2 = [];
+
+        $processor = new Processor();
+        $configuration = new MainConfiguration([], []);
+        $processedConfig = $processor->processConfiguration($configuration, [$config, $config2]);
+
+        $this->assertSame(MainConfiguration::STRATEGY_UNANIMOUS, $processedConfig['access_decision_manager']['strategy']);
+    }
+
+    public function testFirewalls()
+    {
+        $factory = $this->createMock(AuthenticatorFactoryInterface::class);
+        $factory->expects($this->once())->method('addConfiguration');
+        $factory->method('getKey')->willReturn('key');
+
+        $configuration = new MainConfiguration(['stub' => $factory], []);
+        $configuration->getConfigTreeBuilder();
+    }
+
+    /**
+     * @group legacy
+     */
+    public function testLegacyFirewalls()
+    {
+        $factory = $this->createMock(AuthenticatorFactoryInterface::class);
+        $factory->expects($this->once())->method('addConfiguration');
+
+        $this->expectDeprecation('Since symfony/security-bundle 5.4: Passing an array of arrays as 1st argument to "Symfony\Bundle\SecurityBundle\DependencyInjection\MainConfiguration::__construct" is deprecated, pass a sorted array of factories instead.');
+
+        $configuration = new MainConfiguration(['http_basic' => ['stub' => $factory]], []);
+        $configuration->getConfigTreeBuilder();
+    }
 }
