@@ -86,7 +86,7 @@ class AbstractFactoryTest extends TestCase
         }
     }
 
-    public function getFailureHandlers()
+    public static function getFailureHandlers()
     {
         return [
             [null, true],
@@ -135,7 +135,7 @@ class AbstractFactoryTest extends TestCase
         }
     }
 
-    public function getSuccessHandlers()
+    public static function getSuccessHandlers()
     {
         return [
             [null, true],
