@@ -33,6 +33,12 @@ abstract class AbstractWebTestCase extends BaseWebTestCase
         static::deleteTmpDir();
     }
 
+    public function provideSecuritySystems()
+    {
+        yield [['enable_authenticator_manager' => true]];
+        yield [['enable_authenticator_manager' => false]];
+    }
+
     protected static function deleteTmpDir()
     {
         if (!file_exists($dir = sys_get_temp_dir().'/'.static::getVarDir())) {
@@ -63,7 +69,8 @@ abstract class AbstractWebTestCase extends BaseWebTestCase
             $options['test_case'],
             $options['root_config'] ?? 'config.yml',
             $options['environment'] ?? strtolower(static::getVarDir().$options['test_case']),
-            $options['debug'] ?? false
+            $options['debug'] ?? false,
+            $options['enable_authenticator_manager'] ?? false
         );
     }
 
