@@ -13,7 +13,7 @@ namespace Symfony\Bundle\SecurityBundle\Tests\Functional\Bundle\GuardedBundle;
 
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Security\Core\User\User;
+use Symfony\Component\Security\Core\User\InMemoryUser;
 use Symfony\Component\Security\Core\User\UserInterface;
 use Symfony\Component\Security\Guard\GuardAuthenticatorHandler;
 use Symfony\Component\Security\Guard\Token\PostAuthenticationGuardToken;
@@ -22,7 +22,7 @@ class AuthenticationController
 {
     public function manualLoginAction(GuardAuthenticatorHandler $guardAuthenticatorHandler, Request $request)
     {
-        $guardAuthenticatorHandler->authenticateWithToken(new PostAuthenticationGuardToken(new User('Jane', 'test', ['ROLE_USER']), 'secure', ['ROLE_USER']), $request, 'secure');
+        $guardAuthenticatorHandler->authenticateWithToken(new PostAuthenticationGuardToken(new InMemoryUser('Jane', 'test', ['ROLE_USER']), 'secure', ['ROLE_USER']), $request, 'secure');
 
         return new Response('Logged in.');
     }
@@ -33,6 +33,6 @@ class AuthenticationController
             return new Response('Not logged in.');
         }
 
-        return new Response('Username: '.$user->getUsername());
+        return new Response('Username: '.$user->getUserIdentifier());
     }
 }
