@@ -124,6 +124,7 @@ class CsrfFormLoginTest extends AbstractWebTestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider provideLegacyClientOptions
      */
     public function testLegacyFormLoginAndLogoutWithCsrfTokens($options)
@@ -154,6 +155,7 @@ class CsrfFormLoginTest extends AbstractWebTestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider provideLegacyClientOptions
      */
     public function testLegacyFormLoginWithInvalidCsrfToken($options)
@@ -172,6 +174,7 @@ class CsrfFormLoginTest extends AbstractWebTestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider provideLegacyClientOptions
      */
     public function testFormLegacyLoginWithCustomTargetPath($options)
@@ -193,6 +196,7 @@ class CsrfFormLoginTest extends AbstractWebTestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider provideLegacyClientOptions
      */
     public function testLegacyFormLoginRedirectsToProtectedResourceAfterLogin($options)
@@ -213,13 +217,13 @@ class CsrfFormLoginTest extends AbstractWebTestCase
         $this->assertStringContainsString('You\'re browsing to path "/protected-resource".', $text);
     }
 
-    public function provideClientOptions()
+    public static function provideClientOptions()
     {
         yield [['test_case' => 'CsrfFormLogin', 'root_config' => 'config.yml', 'enable_authenticator_manager' => true]];
         yield [['test_case' => 'CsrfFormLogin', 'root_config' => 'routes_as_path.yml', 'enable_authenticator_manager' => true]];
     }
 
-    public function provideLegacyClientOptions()
+    public static function provideLegacyClientOptions()
     {
         yield [['test_case' => 'CsrfFormLogin', 'root_config' => 'legacy_config.yml', 'enable_authenticator_manager' => false]];
         yield [['test_case' => 'CsrfFormLogin', 'root_config' => 'legacy_routes_as_path.yml', 'enable_authenticator_manager' => false]];
