@@ -36,6 +36,7 @@ class LocalizedRoutesAsPathTest extends AbstractWebTestCase
 
     /**
      * @group issue-32995
+     *
      * @dataProvider getLocalesAndClientConfig
      */
     public function testLoginFailureWithLocalizedFailurePath($locale, array $options)
@@ -75,6 +76,7 @@ class LocalizedRoutesAsPathTest extends AbstractWebTestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider getLegacyLocalesAndClientConfig
      */
     public function testLegacyLoginLogoutProcedure($locale, array $options)
@@ -98,6 +100,7 @@ class LocalizedRoutesAsPathTest extends AbstractWebTestCase
     /**
      * @group issue-32995
      * @group legacy
+     *
      * @dataProvider getLegacyLocalesAndClientConfig
      */
     public function testLegacyLoginFailureWithLocalizedFailurePath($locale, array $options)
@@ -115,6 +118,7 @@ class LocalizedRoutesAsPathTest extends AbstractWebTestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider getLegacyLocalesAndClientConfig
      */
     public function testLegacyAccessRestrictedResource($locale, array $options)
@@ -127,6 +131,7 @@ class LocalizedRoutesAsPathTest extends AbstractWebTestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider getLegacyLocalesAndClientConfig
      */
     public function testLegacyAccessRestrictedResourceWithForward($locale, array $options)
@@ -137,13 +142,13 @@ class LocalizedRoutesAsPathTest extends AbstractWebTestCase
         $this->assertCount(1, $crawler->selectButton('login'), (string) $client->getResponse());
     }
 
-    public function getLocalesAndClientConfig()
+    public static function getLocalesAndClientConfig()
     {
         yield ['en', ['root_config' => 'localized_routes.yml']];
         yield ['de', ['root_config' => 'localized_routes.yml']];
     }
 
-    public function getLegacyLocalesAndClientConfig()
+    public static function getLegacyLocalesAndClientConfig()
     {
         yield ['en', ['root_config' => 'legacy_localized_routes.yml']];
         yield ['de', ['root_config' => 'legacy_localized_routes.yml']];
