@@ -11,9 +11,27 @@
 
 namespace Symfony\Bundle\SecurityBundle\Tests\Functional;
 
+use Symfony\Component\Config\Definition\Exception\InvalidConfigurationException;
+
 class MissingUserProviderTest extends AbstractWebTestCase
 {
     public function testUserProviderIsNeeded()
+    {
+        $client = $this->createClient(['enable_authenticator_manager' => true, 'test_case' => 'MissingUserProvider', 'root_config' => 'config.yml', 'debug' => true]);
+
+        $this->expectException(InvalidConfigurationException::class);
+        $this->expectExceptionMessage('"default" firewall requires a user provider but none was defined');
+
+        $client->request('GET', '/', [], [], [
+            'PHP_AUTH_USER' => 'username',
+            'PHP_AUTH_PW' => 'pa$$word',
+        ]);
+    }
+
+    /**
+     * @group legacy
+     */
+    public function testLegacyUserProviderIsNeeded()
     {
         $client = $this->createClient(['test_case' => 'MissingUserProvider', 'root_config' => 'config.yml', 'debug' => true]);
 
