@@ -141,6 +141,7 @@ class SecurityRoutingIntegrationTest extends AbstractWebTestCase
 
     /**
      * @dataProvider provideLegacyClientOptions
+     *
      * @group legacy
      */
     public function testLegacyRoutingErrorIsNotExposedForProtectedResourceWhenAnonymous(array $options)
@@ -153,6 +154,7 @@ class SecurityRoutingIntegrationTest extends AbstractWebTestCase
 
     /**
      * @dataProvider provideLegacyClientOptions
+     *
      * @group legacy
      */
     public function testLegacyRoutingErrorIsExposedWhenNotProtected(array $options)
@@ -165,6 +167,7 @@ class SecurityRoutingIntegrationTest extends AbstractWebTestCase
 
     /**
      * @dataProvider provideLegacyClientOptions
+     *
      * @group legacy
      */
     public function testLegacyRoutingErrorIsNotExposedForProtectedResourceWhenLoggedInWithInsufficientRights(array $options)
@@ -183,6 +186,7 @@ class SecurityRoutingIntegrationTest extends AbstractWebTestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider provideLegacyClientOptions
      */
     public function testLegacySecurityConfigurationForSingleIPAddress(array $options)
@@ -199,6 +203,7 @@ class SecurityRoutingIntegrationTest extends AbstractWebTestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider provideLegacyClientOptions
      */
     public function testLegacySecurityConfigurationForMultipleIPAddresses(array $options)
@@ -229,6 +234,7 @@ class SecurityRoutingIntegrationTest extends AbstractWebTestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider provideLegacyConfigs
      */
     public function testLegacySecurityConfigurationForExpression(array $options)
@@ -289,25 +295,25 @@ class SecurityRoutingIntegrationTest extends AbstractWebTestCase
         $this->assertEquals(302, $client->getResponse()->getStatusCode());
     }
 
-    public function provideClientOptions()
+    public static function provideClientOptions()
     {
         yield [['test_case' => 'StandardFormLogin', 'root_config' => 'base_config.yml', 'enable_authenticator_manager' => true]];
         yield [['test_case' => 'StandardFormLogin', 'root_config' => 'routes_as_path.yml', 'enable_authenticator_manager' => true]];
     }
 
-    public function provideLegacyClientOptions()
+    public static function provideLegacyClientOptions()
     {
         yield [['test_case' => 'StandardFormLogin', 'root_config' => 'base_config.yml', 'enable_authenticator_manager' => true]];
         yield [['test_case' => 'StandardFormLogin', 'root_config' => 'routes_as_path.yml', 'enable_authenticator_manager' => true]];
     }
 
-    public function provideConfigs()
+    public static function provideConfigs()
     {
         yield [['test_case' => 'StandardFormLogin', 'root_config' => 'base_config.yml']];
         yield [['test_case' => 'StandardFormLogin', 'root_config' => 'routes_as_path.yml']];
     }
 
-    public function provideLegacyConfigs()
+    public static function provideLegacyConfigs()
     {
         yield [['test_case' => 'StandardFormLogin', 'root_config' => 'legacy_config.yml']];
         yield [['test_case' => 'StandardFormLogin', 'root_config' => 'legacy_routes_as_path.yml']];
