@@ -30,7 +30,7 @@ class FirewallMapTest extends TestCase
         $request = new Request();
 
         $map = [];
-        $container = $this->getMockBuilder(Container::class)->getMock();
+        $container = $this->createMock(Container::class);
         $container->expects($this->never())->method('get');
 
         $firewallMap = new FirewallMap($container, $map);
@@ -46,7 +46,7 @@ class FirewallMapTest extends TestCase
         $request->attributes->set(self::ATTRIBUTE_FIREWALL_CONTEXT, 'foo');
 
         $map = [];
-        $container = $this->getMockBuilder(Container::class)->getMock();
+        $container = $this->createMock(Container::class);
         $container->expects($this->never())->method('get');
 
         $firewallMap = new FirewallMap($container, $map);
@@ -60,7 +60,7 @@ class FirewallMapTest extends TestCase
     {
         $request = new Request();
 
-        $firewallContext = $this->getMockBuilder(FirewallContext::class)->disableOriginalConstructor()->getMock();
+        $firewallContext = $this->createMock(FirewallContext::class);
 
         $firewallConfig = new FirewallConfig('main', 'user_checker');
         $firewallContext->expects($this->once())->method('getConfig')->willReturn($firewallConfig);
@@ -68,19 +68,19 @@ class FirewallMapTest extends TestCase
         $listener = function () {};
         $firewallContext->expects($this->once())->method('getListeners')->willReturn([$listener]);
 
-        $exceptionListener = $this->getMockBuilder(ExceptionListener::class)->disableOriginalConstructor()->getMock();
+        $exceptionListener = $this->createMock(ExceptionListener::class);
         $firewallContext->expects($this->once())->method('getExceptionListener')->willReturn($exceptionListener);
 
-        $logoutListener = $this->getMockBuilder(LogoutListener::class)->disableOriginalConstructor()->getMock();
+        $logoutListener = $this->createMock(LogoutListener::class);
         $firewallContext->expects($this->once())->method('getLogoutListener')->willReturn($logoutListener);
 
-        $matcher = $this->getMockBuilder(RequestMatcherInterface::class)->getMock();
+        $matcher = $this->createMock(RequestMatcherInterface::class);
         $matcher->expects($this->once())
             ->method('matches')
             ->with($request)
             ->willReturn(true);
 
-        $container = $this->getMockBuilder(Container::class)->getMock();
+        $container = $this->createMock(Container::class);
         $container->expects($this->exactly(2))->method('get')->willReturn($firewallContext);
 
         $firewallMap = new FirewallMap($container, ['security.firewall.map.context.foo' => $matcher]);
