@@ -12,8 +12,8 @@
 namespace Symfony\Bundle\TwigBundle\CacheWarmer;
 
 use Psr\Container\ContainerInterface;
-use Symfony\Component\DependencyInjection\ServiceSubscriberInterface;
 use Symfony\Component\HttpKernel\CacheWarmer\CacheWarmerInterface;
+use Symfony\Contracts\Service\ServiceSubscriberInterface;
 use Twig\Environment;
 use Twig\Error\Error;
 
@@ -28,7 +28,7 @@ class TemplateCacheWarmer implements CacheWarmerInterface, ServiceSubscriberInte
     private $twig;
     private $iterator;
 
-    public function __construct(ContainerInterface $container, \Traversable $iterator)
+    public function __construct(ContainerInterface $container, iterable $iterator)
     {
         // As this cache warmer is optional, dependencies should be lazy-loaded, that's why a container should be injected.
         $this->container = $container;
@@ -37,21 +37,37 @@ class TemplateCacheWarmer implements CacheWarmerInterface, ServiceSubscriberInte
 
     /**
      * {@inheritdoc}
+     *
+     * @return string[] A list of template files to preload on PHP 7.4+
      */
-    public function warmUp($cacheDir)
+    public function warmUp(string $cacheDir)
     {
         if (null === $this->twig) {
             $this->twig = $this->container->get('twig');
         }
 
+        $files = [];
+
         foreach ($this->iterator as $template) {
             try {
-                $this->twig->loadTemplate($template);
+                $template = $this->twig->load($template);
+
+                if (\is_callable([$template, 'unwrap'])) {
+                    $files[] = (new \ReflectionClass($template->unwrap()))->getFileName();
+                }
             } catch (Error $e) {
-                // problem during compilation, give up
-                // might be a syntax error or a non-Twig template
+                /*
+                 * Problem during compilation, give up for this template (e.g. syntax errors).
+                 * Failing silently here allows to ignore templates that rely on functions that aren't available in
+                 * the current environment. For example, the WebProfilerBundle shouldn't be available in the prod
+                 * environment, but some templates that are never used in prod might rely on functions the bundle provides.
+                 * As we can't detect which templates are "really" important, we try to load all of them and ignore
+                 * errors. Error checks may be performed by calling the lint:twig command.
+                 */
             }
         }
+
+        return $files;
     }
 
     /**
