@@ -15,17 +15,12 @@ use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 use Symfony\Component\HttpKernel\Profiler\Profile;
 use Symfony\Component\HttpKernel\Profiler\Profiler;
 use Twig\Environment;
-use Twig\Error\LoaderError;
-use Twig\Loader\ExistsLoaderInterface;
-use Twig\Loader\SourceContextLoaderInterface;
 
 /**
- * Profiler Templates Manager.
- *
  * @author Fabien Potencier <fabien@symfony.com>
  * @author Artur Wielogórski <wodor@wodor.net>
  *
- * @internal since Symfony 4.4
+ * @internal
  */
 class TemplateManager
 {
@@ -43,13 +38,11 @@ class TemplateManager
     /**
      * Gets the template name for a given panel.
      *
-     * @param string $panel
-     *
      * @return mixed
      *
      * @throws NotFoundHttpException
      */
-    public function getName(Profile $profile, $panel)
+    public function getName(Profile $profile, string $panel)
     {
         $templates = $this->getNames($profile);
 
@@ -63,12 +56,11 @@ class TemplateManager
     /**
      * Gets template names of templates that are present in the viewed profile.
      *
-     * @return array
-     *
      * @throws \UnexpectedValueException
      */
-    public function getNames(Profile $profile)
+    public function getNames(Profile $profile): array
     {
+        $loader = $this->twig->getLoader();
         $templates = [];
 
         foreach ($this->templates as $arguments) {
@@ -82,11 +74,11 @@ class TemplateManager
                 continue;
             }
 
-            if ('.html.twig' === substr($template, -10)) {
+            if (str_ends_with($template, '.html.twig')) {
                 $template = substr($template, 0, -10);
             }
 
-            if (!$this->templateExists($template.'.html.twig', false)) {
+            if (!$loader->exists($template.'.html.twig')) {
                 throw new \UnexpectedValueException(sprintf('The profiler template "%s.html.twig" for data collector "%s" does not exist.', $template, $name));
             }
 
@@ -95,33 +87,4 @@ class TemplateManager
 
         return $templates;
     }
-
-    /**
-     * @deprecated since Symfony 4.4
-     */
-    protected function templateExists($template/*, bool $triggerDeprecation = true */)
-    {
-        if (1 === \func_num_args()) {
-            @trigger_error(sprintf('The "%s()" method is deprecated since Symfony 4.4, use the "exists()" method of the Twig loader instead.', __METHOD__), \E_USER_DEPRECATED);
-        }
-
-        $loader = $this->twig->getLoader();
-
-        if (1 === Environment::MAJOR_VERSION && !$loader instanceof ExistsLoaderInterface) {
-            try {
-                if ($loader instanceof SourceContextLoaderInterface) {
-                    $loader->getSourceContext($template);
-                } else {
-                    $loader->getSource($template);
-                }
-
-                return true;
-            } catch (LoaderError $e) {
-            }
-
-            return false;
-        }
-
-        return $loader->exists($template);
-    }
 }
