@@ -40,7 +40,7 @@ class WebDebugToolbarListenerTest extends TestCase
         $this->assertEquals($expected, $response->getContent());
     }
 
-    public function getInjectToolbarTests()
+    public static function getInjectToolbarTests()
     {
         return [
             ['<html><head></head><body></body></html>', "<html><head></head><body>\nWDT\n</body></html>"],
@@ -134,6 +134,7 @@ class WebDebugToolbarListenerTest extends TestCase
 
     /**
      * @depends testToolbarIsInjected
+     *
      * @dataProvider provideRedirects
      */
     public function testToolbarIsNotInjectedOnRedirection($statusCode)
@@ -148,7 +149,7 @@ class WebDebugToolbarListenerTest extends TestCase
         $this->assertEquals('<html><head></head><body></body></html>', $response->getContent());
     }
 
-    public function provideRedirects()
+    public static function provideRedirects()
     {
         return [
             [301],
