@@ -46,7 +46,7 @@ class Cookie
      * Sets a cookie.
      *
      * @param string      $name         The cookie name
-     * @param string      $value        The value of the cookie
+     * @param string|null $value        The value of the cookie
      * @param string|null $expires      The time the cookie expires
      * @param string|null $path         The path on the server in which the cookie will be available on
      * @param string      $domain       The domain that the cookie is available
@@ -62,7 +62,7 @@ class Cookie
             $this->rawValue = $value;
         } else {
             $this->value = $value;
-            $this->rawValue = rawurlencode($value);
+            $this->rawValue = rawurlencode($value ?? '');
         }
         $this->name = $name;
         $this->path = empty($path) ? '/' : $path;
@@ -121,18 +121,15 @@ class Cookie
     /**
      * Creates a Cookie instance from a Set-Cookie header value.
      *
-     * @param string      $cookie A Set-Cookie header value
-     * @param string|null $url    The base URL
-     *
      * @return static
      *
      * @throws \InvalidArgumentException
      */
-    public static function fromString($cookie, $url = null)
+    public static function fromString(string $cookie, string $url = null)
     {
         $parts = explode(';', $cookie);
 
-        if (false === strpos($parts[0], '=')) {
+        if (!str_contains($parts[0], '=')) {
             throw new \InvalidArgumentException(sprintf('The cookie string "%s" is not valid.', $parts[0]));
         }
 
@@ -225,7 +222,7 @@ class Cookie
     /**
      * Gets the name of the cookie.
      *
-     * @return string The cookie name
+     * @return string
      */
     public function getName()
     {
@@ -235,7 +232,7 @@ class Cookie
     /**
      * Gets the value of the cookie.
      *
-     * @return string The cookie value
+     * @return string
      */
     public function getValue()
     {
@@ -245,7 +242,7 @@ class Cookie
     /**
      * Gets the raw value of the cookie.
      *
-     * @return string The cookie value
+     * @return string
      */
     public function getRawValue()
     {
@@ -255,7 +252,7 @@ class Cookie
     /**
      * Gets the expires time of the cookie.
      *
-     * @return string|null The cookie expires time
+     * @return string|null
      */
     public function getExpiresTime()
     {
@@ -265,7 +262,7 @@ class Cookie
     /**
      * Gets the path of the cookie.
      *
-     * @return string The cookie path
+     * @return string
      */
     public function getPath()
     {
@@ -275,7 +272,7 @@ class Cookie
     /**
      * Gets the domain of the cookie.
      *
-     * @return string The cookie domain
+     * @return string
      */
     public function getDomain()
     {
@@ -285,7 +282,7 @@ class Cookie
     /**
      * Returns the secure flag of the cookie.
      *
-     * @return bool The cookie secure flag
+     * @return bool
      */
     public function isSecure()
     {
@@ -295,7 +292,7 @@ class Cookie
     /**
      * Returns the httponly flag of the cookie.
      *
-     * @return bool The cookie httponly flag
+     * @return bool
      */
     public function isHttpOnly()
     {
@@ -305,7 +302,7 @@ class Cookie
     /**
      * Returns true if the cookie has expired.
      *
-     * @return bool true if the cookie has expired, false otherwise
+     * @return bool
      */
     public function isExpired()
     {
@@ -314,8 +311,6 @@ class Cookie
 
     /**
      * Gets the samesite attribute of the cookie.
-     *
-     * @return string|null The cookie samesite attribute
      */
     public function getSameSite(): ?string
     {
