@@ -47,12 +47,12 @@ class TestHttpClient extends HttpBrowser
         $this->nextResponse = $response;
     }
 
-    public function setNextScript($script)
+    public function setNextScript(string $script)
     {
         $this->nextScript = $script;
     }
 
-    protected function doRequest($request): Response
+    protected function doRequest(object $request): Response
     {
         if (null === $this->nextResponse) {
             return parent::doRequest($request);
@@ -64,7 +64,7 @@ class TestHttpClient extends HttpBrowser
         return $response;
     }
 
-    protected function getScript($request)
+    protected function getScript(object $request)
     {
         $r = new \ReflectionClass(Response::class);
         $path = $r->getFileName();
