@@ -215,7 +215,7 @@ class ChainAdapterTest extends AdapterTestCase
 
         $adapter1 = $this->getMockBuilder(FilesystemAdapter::class)
             ->setConstructorArgs(['', 2])
-            ->setMethods(['save'])
+            ->onlyMethods(['save'])
             ->getMock();
         $adapter1->expects($this->once())
             ->method('save')
@@ -224,7 +224,7 @@ class ChainAdapterTest extends AdapterTestCase
 
         $adapter2 = $this->getMockBuilder(FilesystemAdapter::class)
             ->setConstructorArgs(['', 4])
-            ->setMethods(['save'])
+            ->onlyMethods(['save'])
             ->getMock();
         $adapter2->expects($this->once())
             ->method('save')
