@@ -48,4 +48,29 @@ class PredisAdapterTest extends AbstractRedisAdapterTestCase
         ];
         $this->assertSame($params, $connection->getParameters()->toArray());
     }
+
+    public function testCreateSslConnection()
+    {
+        $redisHost = getenv('REDIS_HOST');
+
+        $redis = RedisAdapter::createConnection('rediss://'.$redisHost.'/1?ssl[verify_peer]=0', ['class' => \Predis\Client::class, 'timeout' => 3]);
+        $this->assertInstanceOf(\Predis\Client::class, $redis);
+
+        $connection = $redis->getConnection();
+        $this->assertInstanceOf(StreamConnection::class, $connection);
+
+        $redisHost = explode(':', $redisHost);
+        $params = [
+            'scheme' => 'tls',
+            'host' => $redisHost[0],
+            'port' => (int) ($redisHost[1] ?? 6379),
+            'ssl' => ['verify_peer' => '0'],
+            'persistent' => 0,
+            'timeout' => 3,
+            'read_write_timeout' => 0,
+            'tcp_nodelay' => true,
+            'database' => '1',
+        ];
+        $this->assertSame($params, $connection->getParameters()->toArray());
+    }
 }
