@@ -11,9 +11,12 @@
 
 namespace Symfony\Component\Cache\Tests\Adapter;
 
+use Psr\Cache\CacheItemPoolInterface;
 use Symfony\Component\Cache\Adapter\RedisTagAwareAdapter;
-use Symfony\Component\Cache\Tests\Traits\TagAwareTestTrait;
 
+/**
+ * @group integration
+ */
 class RedisTagAwareArrayAdapterTest extends RedisArrayAdapterTest
 {
     use TagAwareTestTrait;
@@ -24,8 +27,12 @@ class RedisTagAwareArrayAdapterTest extends RedisArrayAdapterTest
         $this->skippedTests['testTagItemExpiry'] = 'Testing expiration slows down the test suite';
     }
 
-    public function createCachePool($defaultLifetime = 0)
+    public function createCachePool(int $defaultLifetime = 0, string $testMethod = null): CacheItemPoolInterface
     {
+        if ('testClearWithPrefix' === $testMethod && \defined('Redis::SCAN_PREFIX')) {
+            self::$redis->setOption(\Redis::OPT_SCAN, \Redis::SCAN_PREFIX);
+        }
+
         $this->assertInstanceOf(\RedisArray::class, self::$redis);
         $adapter = new RedisTagAwareAdapter(self::$redis, str_replace('\\', '.', __CLASS__), $defaultLifetime);
 
