@@ -58,6 +58,9 @@ class ExampleConfiguration implements ConfigurationInterface
                 ->arrayNode('scalar_prototyped')
                     ->prototype('scalar')->end()
                 ->end()
+                ->variableNode('variable')
+                    ->example(['foo', 'bar'])
+                ->end()
                 ->arrayNode('parameters')
                     ->useAttributeAsKey('name')
                     ->prototype('scalar')->info('Parameter name')->end()
