@@ -13,6 +13,7 @@ namespace Symfony\Component\Console\Tests\Command;
 
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Console\Application;
+use Symfony\Component\Console\Attribute\AsCommand;
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Exception\InvalidOptionException;
 use Symfony\Component\Console\Helper\FormatterHelper;
@@ -123,7 +124,7 @@ class CommandTest extends TestCase
         $command->setName($name);
     }
 
-    public function provideInvalidCommandNames()
+    public static function provideInvalidCommandNames()
     {
         return [
             [''],
@@ -185,7 +186,8 @@ class CommandTest extends TestCase
         $command = new \TestCommand();
         $command->addOption('foo');
         $command->addArgument('bar');
-        $this->assertEquals('namespace:name [--foo] [--] [<bar>]', $command->getSynopsis(), '->getSynopsis() returns the synopsis');
+        $command->addArgument('info');
+        $this->assertEquals('namespace:name [--foo] [--] [<bar> [<info>]]', $command->getSynopsis(), '->getSynopsis() returns the synopsis');
     }
 
     public function testAddGetUsages()
@@ -336,7 +338,7 @@ class CommandTest extends TestCase
         $this->assertEquals('interact called'.\PHP_EOL.'from the code...'.\PHP_EOL, $tester->getDisplay());
     }
 
-    public function getSetCodeBindToClosureTests()
+    public static function getSetCodeBindToClosureTests()
     {
         return [
             [true, 'not bound to the command'],
@@ -404,6 +406,41 @@ class CommandTest extends TestCase
 
         $this->assertEquals('interact called'.\PHP_EOL.'not bound'.\PHP_EOL, $tester->getDisplay());
     }
+
+    /**
+     * @requires PHP 8
+     */
+    public function testCommandAttribute()
+    {
+        $this->assertSame('|foo|f', Php8Command::getDefaultName());
+        $this->assertSame('desc', Php8Command::getDefaultDescription());
+
+        $command = new Php8Command();
+
+        $this->assertSame('foo', $command->getName());
+        $this->assertSame('desc', $command->getDescription());
+        $this->assertTrue($command->isHidden());
+        $this->assertSame(['f'], $command->getAliases());
+    }
+
+    /**
+     * @requires PHP 8
+     */
+    public function testDefaultCommand()
+    {
+        $apl = new Application();
+        $apl->setDefaultCommand(Php8Command::getDefaultName());
+        $property = new \ReflectionProperty($apl, 'defaultCommand');
+        $property->setAccessible(true);
+
+        $this->assertEquals('foo', $property->getValue($apl));
+
+        $apl->setDefaultCommand(Php8Command2::getDefaultName());
+        $property = new \ReflectionProperty($apl, 'defaultCommand');
+        $property->setAccessible(true);
+
+        $this->assertEquals('foo2', $property->getValue($apl));
+    }
 }
 
 // In order to get an unbound closure, we should create it outside a class
@@ -414,3 +451,13 @@ function createClosure()
         $output->writeln($this instanceof Command ? 'bound to the command' : 'not bound to the command');
     };
 }
+
+#[AsCommand(name: 'foo', description: 'desc', hidden: true, aliases: ['f'])]
+class Php8Command extends Command
+{
+}
+
+#[AsCommand(name: 'foo2', description: 'desc2', hidden: true)]
+class Php8Command2 extends Command
+{
+}
