@@ -88,14 +88,6 @@ class OutputFormatterStyleTest extends TestCase
             $this->assertInstanceOf(\InvalidArgumentException::class, $e, '->setOption() throws an \InvalidArgumentException when the option does not exist in the available options');
             $this->assertStringContainsString('Invalid option specified: "foo"', $e->getMessage(), '->setOption() throws an \InvalidArgumentException when the option does not exist in the available options');
         }
-
-        try {
-            $style->unsetOption('foo');
-            $this->fail('->unsetOption() throws an \InvalidArgumentException when the option does not exist in the available options');
-        } catch (\Exception $e) {
-            $this->assertInstanceOf(\InvalidArgumentException::class, $e, '->unsetOption() throws an \InvalidArgumentException when the option does not exist in the available options');
-            $this->assertStringContainsString('Invalid option specified: "foo"', $e->getMessage(), '->unsetOption() throws an \InvalidArgumentException when the option does not exist in the available options');
-        }
     }
 
     public function testHref()
