@@ -61,7 +61,7 @@ class ArgvInputTest extends TestCase
         $this->assertEquals($expectedOptions, $input->getOptions(), $message);
     }
 
-    public function provideOptions()
+    public static function provideOptions()
     {
         return [
             [
@@ -187,7 +187,7 @@ class ArgvInputTest extends TestCase
         ];
     }
 
-    public function provideNegatableOptions()
+    public static function provideNegatableOptions()
     {
         return [
             [
@@ -259,7 +259,7 @@ class ArgvInputTest extends TestCase
         $input->bind($definition);
     }
 
-    public function provideInvalidInput()
+    public static function provideInvalidInput()
     {
         return [
             [
@@ -330,7 +330,7 @@ class ArgvInputTest extends TestCase
         ];
     }
 
-    public function provideInvalidNegatableInput()
+    public static function provideInvalidNegatableInput()
     {
         return [
             [
@@ -516,7 +516,7 @@ class ArgvInputTest extends TestCase
         $this->assertEquals($expected, $input->getParameterOption($key, $default, $onlyParams), '->getParameterOption() returns the expected value');
     }
 
-    public function provideGetParameterOptionValues()
+    public static function provideGetParameterOptionValues()
     {
         return [
             [['app/console', 'foo:bar'], '-e', 'default', false, 'default'],
