@@ -74,7 +74,7 @@ class ArrayInputTest extends TestCase
         $this->assertEquals($expectedOptions, $input->getOptions(), $message);
     }
 
-    public function provideOptions()
+    public static function provideOptions()
     {
         return [
             [
@@ -133,7 +133,7 @@ class ArrayInputTest extends TestCase
         new ArrayInput($parameters, $definition);
     }
 
-    public function provideInvalidInput()
+    public static function provideInvalidInput()
     {
         return [
             [
