@@ -26,7 +26,7 @@ class ConsoleSectionOutputTest extends TestCase
 
     protected function setUp(): void
     {
-        $this->stream = fopen('php://memory', 'r+b', false);
+        $this->stream = fopen('php://memory', 'r+', false);
     }
 
     protected function tearDown(): void
@@ -143,11 +143,11 @@ class ConsoleSectionOutputTest extends TestCase
 
     public function testClearSectionContainingQuestion()
     {
-        $inputStream = fopen('php://memory', 'r+b', false);
+        $inputStream = fopen('php://memory', 'r+', false);
         fwrite($inputStream, "Batman & Robin\n");
         rewind($inputStream);
 
-        $input = $this->getMockBuilder(StreamableInputInterface::class)->getMock();
+        $input = $this->createMock(StreamableInputInterface::class);
         $input->expects($this->once())->method('isInteractive')->willReturn(true);
         $input->expects($this->once())->method('getStream')->willReturn($inputStream);
 
