@@ -69,14 +69,14 @@ class SymfonyStyleTest extends TestCase
         $this->assertStringEqualsFile($outputFilepath, $this->tester->getDisplay(true));
     }
 
-    public function inputInteractiveCommandToOutputFilesProvider()
+    public static function inputInteractiveCommandToOutputFilesProvider()
     {
         $baseDir = __DIR__.'/../Fixtures/Style/SymfonyStyle';
 
         return array_map(null, glob($baseDir.'/command/interactive_command_*.php'), glob($baseDir.'/output/interactive_output_*.txt'));
     }
 
-    public function inputCommandToOutputFilesProvider()
+    public static function inputCommandToOutputFilesProvider()
     {
         $baseDir = __DIR__.'/../Fixtures/Style/SymfonyStyle';
 
@@ -151,7 +151,7 @@ class SymfonyStyleTest extends TestCase
         $style = new SymfonyStyle($input, $output);
 
         $this->expectException(RuntimeException::class);
-        $this->expectDeprecationMessage('Output should be an instance of "Symfony\Component\Console\Output\ConsoleSectionOutput"');
+        $this->expectExceptionMessage('Output should be an instance of "Symfony\Component\Console\Output\ConsoleSectionOutput"');
 
         $style->createTable()->appendRow(['row']);
     }
