@@ -20,6 +20,9 @@ use Symfony\Component\DependencyInjection\Tests\Fixtures\Preload\D;
 use Symfony\Component\DependencyInjection\Tests\Fixtures\Preload\Dummy;
 use Symfony\Component\DependencyInjection\Tests\Fixtures\Preload\DummyWithInterface;
 use Symfony\Component\DependencyInjection\Tests\Fixtures\Preload\E;
+use Symfony\Component\DependencyInjection\Tests\Fixtures\Preload\F;
+use Symfony\Component\DependencyInjection\Tests\Fixtures\Preload\G;
+use Symfony\Component\DependencyInjection\Tests\Fixtures\Preload\IntersectionDummy;
 use Symfony\Component\DependencyInjection\Tests\Fixtures\Preload\UnionDummy;
 
 class PreloaderTest extends TestCase
@@ -72,4 +75,20 @@ class PreloaderTest extends TestCase
         self::assertTrue(class_exists(D::class, false));
         self::assertTrue(class_exists(E::class, false));
     }
+
+    /**
+     * @requires PHP 8.1
+     */
+    public function testPreloadIntersection()
+    {
+        $r = new \ReflectionMethod(Preloader::class, 'doPreload');
+
+        $preloaded = [];
+
+        $r->invokeArgs(null, ['Symfony\Component\DependencyInjection\Tests\Fixtures\Preload\IntersectionDummy', &$preloaded]);
+
+        self::assertTrue(class_exists(IntersectionDummy::class, false));
+        self::assertTrue(class_exists(F::class, false));
+        self::assertTrue(class_exists(G::class, false));
+    }
 }
