@@ -43,7 +43,7 @@ class EnvVarProcessorTest extends TestCase
         $this->assertSame($processed, $result);
     }
 
-    public function validStrings()
+    public static function validStrings()
     {
         return [
             ['hello', 'hello'],
@@ -89,7 +89,7 @@ class EnvVarProcessorTest extends TestCase
         $this->assertSame(!$processed, $result);
     }
 
-    public function validBools()
+    public static function validBools()
     {
         return [
             ['true', true],
@@ -118,7 +118,7 @@ class EnvVarProcessorTest extends TestCase
         $this->assertSame($processed, $result);
     }
 
-    public function validInts()
+    public static function validInts()
     {
         return [
             ['1', 1],
@@ -143,7 +143,7 @@ class EnvVarProcessorTest extends TestCase
         });
     }
 
-    public function invalidInts()
+    public static function invalidInts()
     {
         return [
             ['foo'],
@@ -168,7 +168,7 @@ class EnvVarProcessorTest extends TestCase
         $this->assertSame($processed, $result);
     }
 
-    public function validFloats()
+    public static function validFloats()
     {
         return [
             ['1', 1.0],
@@ -193,7 +193,7 @@ class EnvVarProcessorTest extends TestCase
         });
     }
 
-    public function invalidFloats()
+    public static function invalidFloats()
     {
         return [
             ['foo'],
@@ -218,7 +218,7 @@ class EnvVarProcessorTest extends TestCase
         $this->assertSame($processed, $result);
     }
 
-    public function validConsts()
+    public static function validConsts()
     {
         return [
             ['Symfony\Component\DependencyInjection\Tests\EnvVarProcessorTest::TEST_CONST', self::TEST_CONST],
@@ -242,7 +242,7 @@ class EnvVarProcessorTest extends TestCase
         });
     }
 
-    public function invalidConsts()
+    public static function invalidConsts()
     {
         return [
             ['Symfony\Component\DependencyInjection\Tests\EnvVarProcessorTest::UNDEFINED_CONST'],
@@ -298,7 +298,7 @@ class EnvVarProcessorTest extends TestCase
         $this->assertSame($processed, $result);
     }
 
-    public function validJson()
+    public static function validJson()
     {
         return [
             ['[1]', [1]],
@@ -336,7 +336,7 @@ class EnvVarProcessorTest extends TestCase
         });
     }
 
-    public function otherJsonValues()
+    public static function otherJsonValues()
     {
         return [
             [1],
@@ -387,7 +387,7 @@ class EnvVarProcessorTest extends TestCase
         });
     }
 
-    public function noArrayValues()
+    public static function noArrayValues()
     {
         return [
             [null],
@@ -413,7 +413,7 @@ class EnvVarProcessorTest extends TestCase
         });
     }
 
-    public function invalidArrayValues()
+    public static function invalidArrayValues()
     {
         return [
             [[]],
@@ -436,7 +436,7 @@ class EnvVarProcessorTest extends TestCase
         }));
     }
 
-    public function arrayValues()
+    public static function arrayValues()
     {
         return [
             [['index' => 'password']],
@@ -478,7 +478,7 @@ class EnvVarProcessorTest extends TestCase
         $this->assertSame($processed, $result);
     }
 
-    public function validNullables()
+    public static function validNullables()
     {
         return [
             ['hello', 'hello'],
@@ -533,7 +533,7 @@ class EnvVarProcessorTest extends TestCase
         $this->assertSame($processed, $result);
     }
 
-    public function validResolve()
+    public static function validResolve()
     {
         return [
             ['string', 'string'],
@@ -574,7 +574,7 @@ class EnvVarProcessorTest extends TestCase
         });
     }
 
-    public function notScalarResolve()
+    public static function notScalarResolve()
     {
         return [
             [null],
@@ -634,7 +634,7 @@ class EnvVarProcessorTest extends TestCase
         $this->assertSame($processed, $result);
     }
 
-    public function validCsv()
+    public static function validCsv()
     {
         $complex = <<<'CSV'
 ,"""","foo""","\""",\,foo\
@@ -749,7 +749,7 @@ CSV;
         })['path']);
     }
 
-    public function provideGetEnvUrlPath()
+    public static function provideGetEnvUrlPath()
     {
         return [
             ['', 'https://symfony.com'],
