@@ -13,8 +13,11 @@ namespace Symfony\Component\DependencyInjection\Tests\Fixtures;
 
 class Bar implements BarInterface
 {
-    public function __construct($quz = null, \NonExistent $nonExistent = null, BarInterface $decorated = null, array $foo = [])
+    public $quz;
+
+    public function __construct($quz = null, \NonExistent $nonExistent = null, BarInterface $decorated = null, array $foo = [], iterable $baz = [])
     {
+        $this->quz = $quz;
     }
 
     public static function create(\NonExistent $nonExistent = null, $factory = null)
