@@ -9,8 +9,10 @@ $container = new ContainerBuilder(new ParameterBag([
     'bar' => 'foo is %%foo bar',
     'escape' => '@escapeme',
     'values' => [true, false, null, 0, 1000.3, 'true', 'false', 'null'],
+    'utf-8 valid string' => "\u{021b}\u{1b56}\ttest",
     'binary' => "\xf0\xf0\xf0\xf0",
     'binary-control-char' => "This is a Bell char \x07",
+    'console banner' => "\e[37;44m#StandWith\e[30;43mUkraine\e[0m",
     'null string' => 'null',
     'string of digits' => '123',
     'string of digits prefixed with minus character' => '-123',
