@@ -405,6 +405,35 @@ class EventDispatcherTest extends TestCase
 
         $this->assertTrue($testLoaded);
     }
+
+    /**
+     * @requires PHP 8.1
+     */
+    public function testNamedClosures()
+    {
+        $listener = new TestEventListener();
+
+        $callback1 = \Closure::fromCallable($listener);
+        $callback2 = \Closure::fromCallable($listener);
+        $callback3 = \Closure::fromCallable(new TestEventListener());
+
+        $this->assertNotSame($callback1, $callback2);
+        $this->assertNotSame($callback1, $callback3);
+        $this->assertNotSame($callback2, $callback3);
+        $this->assertTrue($callback1 == $callback2);
+        $this->assertFalse($callback1 == $callback3);
+
+        $this->dispatcher->addListener('foo', $callback1, 3);
+        $this->dispatcher->addListener('foo', $callback2, 2);
+        $this->dispatcher->addListener('foo', $callback3, 1);
+
+        $this->assertSame(3, $this->dispatcher->getListenerPriority('foo', $callback1));
+        $this->assertSame(3, $this->dispatcher->getListenerPriority('foo', $callback2));
+
+        $this->dispatcher->removeListener('foo', $callback1);
+
+        $this->assertSame(['foo' => [$callback3]], $this->dispatcher->getListeners());
+    }
 }
 
 class CallableClass
