@@ -1146,7 +1146,7 @@ class FilesystemTest extends FilesystemTestCase
         $this->assertEquals($expectedPath, $path);
     }
 
-    public function providePathsForMakePathRelative()
+    public static function providePathsForMakePathRelative()
     {
         $paths = [
             ['/var/lib/symfony/src/Symfony/', '/var/lib/symfony/src/Symfony/Component', '../'],
@@ -1434,7 +1434,7 @@ class FilesystemTest extends FilesystemTestCase
         $this->assertEquals($expectedResult, $result);
     }
 
-    public function providePathsForIsAbsolutePath()
+    public static function providePathsForIsAbsolutePath()
     {
         return [
             ['/var/lib', true],
