@@ -34,9 +34,9 @@ interface ChoiceLoaderInterface
      * @param callable|null $value The callable which generates the values
      *                             from choices
      *
-     * @return ChoiceListInterface The loaded choice list
+     * @return ChoiceListInterface
      */
-    public function loadChoiceList($value = null);
+    public function loadChoiceList(callable $value = null);
 
     /**
      * Loads the choices corresponding to the given values.
@@ -52,9 +52,9 @@ interface ChoiceLoaderInterface
      *                              values in this array are ignored
      * @param callable|null $value  The callable generating the choice values
      *
-     * @return array An array of choices
+     * @return array
      */
-    public function loadChoicesForValues(array $values, $value = null);
+    public function loadChoicesForValues(array $values, callable $value = null);
 
     /**
      * Loads the values corresponding to the given choices.
@@ -70,7 +70,7 @@ interface ChoiceLoaderInterface
      *                               this array are ignored
      * @param callable|null $value   The callable generating the choice values
      *
-     * @return string[] An array of choice values
+     * @return string[]
      */
-    public function loadValuesForChoices(array $choices, $value = null);
+    public function loadValuesForChoices(array $choices, callable $value = null);
 }
