@@ -11,6 +11,9 @@
 
 namespace Symfony\Component\Form;
 
+use Symfony\Component\Form\Extension\Core\Type\FormType;
+use Symfony\Component\OptionsResolver\Exception\InvalidOptionsException;
+
 /**
  * Allows creating a form based on a name, a class or a property.
  *
@@ -25,11 +28,11 @@ interface FormFactoryInterface
      *
      * @param mixed $data The initial data
      *
-     * @return FormInterface The form named after the type
+     * @return FormInterface
      *
-     * @throws \Symfony\Component\OptionsResolver\Exception\InvalidOptionsException if any given option is not applicable to the given type
+     * @throws InvalidOptionsException if any given option is not applicable to the given type
      */
-    public function create(string $type = 'Symfony\Component\Form\Extension\Core\Type\FormType', $data = null, array $options = []);
+    public function create(string $type = FormType::class, $data = null, array $options = []);
 
     /**
      * Returns a form.
@@ -38,11 +41,11 @@ interface FormFactoryInterface
      *
      * @param mixed $data The initial data
      *
-     * @return FormInterface The form
+     * @return FormInterface
      *
-     * @throws \Symfony\Component\OptionsResolver\Exception\InvalidOptionsException if any given option is not applicable to the given type
+     * @throws InvalidOptionsException if any given option is not applicable to the given type
      */
-    public function createNamed(string $name, string $type = 'Symfony\Component\Form\Extension\Core\Type\FormType', $data = null, array $options = []);
+    public function createNamed(string $name, string $type = FormType::class, $data = null, array $options = []);
 
     /**
      * Returns a form for a property of a class.
@@ -53,9 +56,9 @@ interface FormFactoryInterface
      * @param string $property The name of the property to guess for
      * @param mixed  $data     The initial data
      *
-     * @return FormInterface The form named after the property
+     * @return FormInterface
      *
-     * @throws \Symfony\Component\OptionsResolver\Exception\InvalidOptionsException if any given option is not applicable to the form type
+     * @throws InvalidOptionsException if any given option is not applicable to the form type
      */
     public function createForProperty(string $class, string $property, $data = null, array $options = []);
 
@@ -64,22 +67,22 @@ interface FormFactoryInterface
      *
      * @param mixed $data The initial data
      *
-     * @return FormBuilderInterface The form builder
+     * @return FormBuilderInterface
      *
-     * @throws \Symfony\Component\OptionsResolver\Exception\InvalidOptionsException if any given option is not applicable to the given type
+     * @throws InvalidOptionsException if any given option is not applicable to the given type
      */
-    public function createBuilder(string $type = 'Symfony\Component\Form\Extension\Core\Type\FormType', $data = null, array $options = []);
+    public function createBuilder(string $type = FormType::class, $data = null, array $options = []);
 
     /**
      * Returns a form builder.
      *
      * @param mixed $data The initial data
      *
-     * @return FormBuilderInterface The form builder
+     * @return FormBuilderInterface
      *
-     * @throws \Symfony\Component\OptionsResolver\Exception\InvalidOptionsException if any given option is not applicable to the given type
+     * @throws InvalidOptionsException if any given option is not applicable to the given type
      */
-    public function createNamedBuilder(string $name, string $type = 'Symfony\Component\Form\Extension\Core\Type\FormType', $data = null, array $options = []);
+    public function createNamedBuilder(string $name, string $type = FormType::class, $data = null, array $options = []);
 
     /**
      * Returns a form builder for a property of a class.
@@ -91,9 +94,9 @@ interface FormFactoryInterface
      * @param string $property The name of the property to guess for
      * @param mixed  $data     The initial data
      *
-     * @return FormBuilderInterface The form builder named after the property
+     * @return FormBuilderInterface
      *
-     * @throws \Symfony\Component\OptionsResolver\Exception\InvalidOptionsException if any given option is not applicable to the form type
+     * @throws InvalidOptionsException if any given option is not applicable to the form type
      */
     public function createBuilderForProperty(string $class, string $property, $data = null, array $options = []);
 }
