@@ -18,9 +18,6 @@ namespace Symfony\Component\Form;
  */
 class SubmitButton extends Button implements ClickableInterface
 {
-    /**
-     * @var bool
-     */
     private $clicked = false;
 
     /**
@@ -34,14 +31,14 @@ class SubmitButton extends Button implements ClickableInterface
     /**
      * Submits data to the button.
      *
-     * @param string|null $submittedData The data
-     * @param bool        $clearMissing  Not used
+     * @param array|string|null $submittedData The data
+     * @param bool              $clearMissing  Not used
      *
      * @return $this
      *
      * @throws Exception\AlreadySubmittedException if the form has already been submitted
      */
-    public function submit($submittedData, $clearMissing = true)
+    public function submit($submittedData, bool $clearMissing = true)
     {
         if ($this->getConfig()->getDisabled()) {
             $this->clicked = false;
