@@ -555,7 +555,7 @@ class CachingFactoryDecoratorTest extends TestCase
         $this->assertEquals(new ChoiceListView(), $view2);
     }
 
-    public function provideSameChoices()
+    public static function provideSameChoices()
     {
         $object = (object) ['foo' => 'bar'];
 
@@ -568,7 +568,7 @@ class CachingFactoryDecoratorTest extends TestCase
         ];
     }
 
-    public function provideDistinguishedChoices()
+    public static function provideDistinguishedChoices()
     {
         return [
             [0, false],
