@@ -15,7 +15,7 @@ use Symfony\Component\Form\Exception\TransformationFailedException;
 use Symfony\Component\Form\Extension\Core\DataTransformer\BaseDateTimeTransformer;
 use Symfony\Component\Form\Extension\Core\DataTransformer\DateTimeToTimestampTransformer;
 
-class DateTimeToTimestampTransformerTest extends BaseDateTimeTransformerTest
+class DateTimeToTimestampTransformerTest extends BaseDateTimeTransformerTestCase
 {
     public function testTransform()
     {
