@@ -31,7 +31,7 @@ class NumberToLocalizedStringTransformerTest extends TestCase
         \Locale::setDefault($this->defaultLocale);
     }
 
-    public function provideTransformations()
+    public static function provideTransformations()
     {
         return [
             [null, '', 'de_AT'],
@@ -59,7 +59,7 @@ class NumberToLocalizedStringTransformerTest extends TestCase
         $this->assertSame($to, $transformer->transform($from));
     }
 
-    public function provideTransformationsWithGrouping()
+    public static function provideTransformationsWithGrouping()
     {
         return [
             [1234.5, '1.234,5', 'de_DE'],
@@ -98,7 +98,7 @@ class NumberToLocalizedStringTransformerTest extends TestCase
         $this->assertEquals('678,92', $transformer->transform(678.916));
     }
 
-    public function transformWithRoundingProvider()
+    public static function transformWithRoundingProvider()
     {
         return [
             // towards positive infinity (1.6 -> 2, -1.6 -> -1)
@@ -273,7 +273,7 @@ class NumberToLocalizedStringTransformerTest extends TestCase
         $this->assertEquals(12345.912, $transformer->reverseTransform('12345,912'));
     }
 
-    public function reverseTransformWithRoundingProvider()
+    public static function reverseTransformWithRoundingProvider()
     {
         return [
             // towards positive infinity (1.6 -> 2, -1.6 -> -1)
@@ -518,7 +518,7 @@ class NumberToLocalizedStringTransformerTest extends TestCase
         $transformer->reverseTransform($nan);
     }
 
-    public function nanRepresentationProvider()
+    public static function nanRepresentationProvider()
     {
         return [
             ['nan'],
