@@ -17,7 +17,7 @@ use Symfony\Component\Form\FormInterface;
 use Symfony\Component\Intl\Util\IntlTestHelper;
 use Symfony\Component\OptionsResolver\Exception\InvalidOptionsException;
 
-class DateTypeTest extends BaseTypeTest
+class DateTypeTest extends BaseTypeTestCase
 {
     public const TESTED_TYPE = 'Symfony\Component\Form\Extension\Core\Type\DateType';
 
@@ -385,7 +385,7 @@ class DateTypeTest extends BaseTypeTest
         $this->assertEquals($pattern, $view->vars['date_pattern']);
     }
 
-    public function provideDateFormats()
+    public static function provideDateFormats()
     {
         return [
             ['dMy', '{{ day }}{{ month }}{{ year }}'],
@@ -900,7 +900,7 @@ class DateTypeTest extends BaseTypeTest
         $this->assertArrayNotHasKey('type', $view->vars);
     }
 
-    public function provideCompoundWidgets()
+    public static function provideCompoundWidgets()
     {
         return [
             ['text'],
@@ -1054,7 +1054,7 @@ class DateTypeTest extends BaseTypeTest
         $this->assertEquals($expectedData, $form->getData());
     }
 
-    public function provideEmptyData()
+    public static function provideEmptyData()
     {
         $expectedData = \DateTime::createFromFormat('Y-m-d H:i:s', '2018-11-11 00:00:00');
         $lazyEmptyData = static function (FormInterface $form) {
