@@ -13,7 +13,7 @@ namespace Symfony\Component\Form\Tests\Extension\Core\Type;
 
 use Symfony\Component\Intl\Util\IntlTestHelper;
 
-class MoneyTypeTest extends BaseTypeTest
+class MoneyTypeTest extends BaseTypeTestCase
 {
     public const TESTED_TYPE = 'Symfony\Component\Form\Extension\Core\Type\MoneyType';
 
