@@ -11,19 +11,20 @@
 
 namespace Symfony\Component\Form\Tests\Extension\DataCollector;
 
-use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
-use Symfony\Component\EventDispatcher\EventDispatcherInterface;
+use Symfony\Component\EventDispatcher\EventDispatcher;
 use Symfony\Component\Form\CallbackTransformer;
-use Symfony\Component\Form\DataMapperInterface;
 use Symfony\Component\Form\Exception\TransformationFailedException;
+use Symfony\Component\Form\Extension\Core\DataMapper\DataMapper;
 use Symfony\Component\Form\Extension\Core\Type\HiddenType;
 use Symfony\Component\Form\Extension\DataCollector\FormDataExtractor;
 use Symfony\Component\Form\FormBuilder;
 use Symfony\Component\Form\FormError;
-use Symfony\Component\Form\FormFactoryInterface;
+use Symfony\Component\Form\FormFactory;
+use Symfony\Component\Form\FormRegistry;
 use Symfony\Component\Form\FormView;
-use Symfony\Component\Form\ResolvedFormTypeInterface;
+use Symfony\Component\Form\ResolvedFormType;
+use Symfony\Component\Form\ResolvedFormTypeFactory;
 use Symfony\Component\Form\Tests\Fixtures\FixedDataTransformer;
 use Symfony\Component\Validator\ConstraintViolation;
 use Symfony\Component\VarDumper\Test\VarDumperTestTrait;
@@ -40,32 +41,15 @@ class FormDataExtractorTest extends TestCase
      */
     private $dataExtractor;
 
-    /**
-     * @var MockObject&EventDispatcherInterface
-     */
-    private $dispatcher;
-
-    /**
-     * @var MockObject&FormFactoryInterface
-     */
-    private $factory;
-
     protected function setUp(): void
     {
         $this->dataExtractor = new FormDataExtractor();
-        $this->dispatcher = $this->createMock(EventDispatcherInterface::class);
-        $this->factory = $this->createMock(FormFactoryInterface::class);
     }
 
     public function testExtractConfiguration()
     {
-        $type = $this->createMock(ResolvedFormTypeInterface::class);
-        $type->expects($this->any())
-            ->method('getInnerType')
-            ->willReturn(new HiddenType());
-
         $form = $this->createBuilder('name')
-            ->setType($type)
+            ->setType(new ResolvedFormType(new HiddenType()))
             ->getForm();
 
         $this->assertSame([
@@ -80,11 +64,6 @@ class FormDataExtractorTest extends TestCase
 
     public function testExtractConfigurationSortsPassedOptions()
     {
-        $type = $this->createMock(ResolvedFormTypeInterface::class);
-        $type->expects($this->any())
-            ->method('getInnerType')
-            ->willReturn(new HiddenType());
-
         $options = [
             'b' => 'foo',
             'a' => 'bar',
@@ -92,7 +71,7 @@ class FormDataExtractorTest extends TestCase
         ];
 
         $form = $this->createBuilder('name')
-            ->setType($type)
+            ->setType(new ResolvedFormType(new HiddenType()))
             // passed options are stored in an attribute by
             // ResolvedTypeDataCollectorProxy
             ->setAttribute('data_collector/passed_options', $options)
@@ -114,11 +93,6 @@ class FormDataExtractorTest extends TestCase
 
     public function testExtractConfigurationSortsResolvedOptions()
     {
-        $type = $this->createMock(ResolvedFormTypeInterface::class);
-        $type->expects($this->any())
-            ->method('getInnerType')
-            ->willReturn(new HiddenType());
-
         $options = [
             'b' => 'foo',
             'a' => 'bar',
@@ -126,7 +100,7 @@ class FormDataExtractorTest extends TestCase
         ];
 
         $form = $this->createBuilder('name', $options)
-            ->setType($type)
+            ->setType(new ResolvedFormType(new HiddenType()))
             ->getForm();
 
         $this->assertSame([
@@ -145,21 +119,16 @@ class FormDataExtractorTest extends TestCase
 
     public function testExtractConfigurationBuildsIdRecursively()
     {
-        $type = $this->createMock(ResolvedFormTypeInterface::class);
-        $type->expects($this->any())
-            ->method('getInnerType')
-            ->willReturn(new HiddenType());
-
         $grandParent = $this->createBuilder('grandParent')
             ->setCompound(true)
-            ->setDataMapper($this->createMock(DataMapperInterface::class))
+            ->setDataMapper(new DataMapper())
             ->getForm();
         $parent = $this->createBuilder('parent')
             ->setCompound(true)
-            ->setDataMapper($this->createMock(DataMapperInterface::class))
+            ->setDataMapper(new DataMapper())
             ->getForm();
         $form = $this->createBuilder('name')
-            ->setType($type)
+            ->setType(new ResolvedFormType(new HiddenType()))
             ->getForm();
 
         $grandParent->add($parent);
@@ -418,6 +387,6 @@ EODUMP
 
     private function createBuilder(string $name, array $options = []): FormBuilder
     {
-        return new FormBuilder($name, null, $this->dispatcher, $this->factory, $options);
+        return new FormBuilder($name, null, new EventDispatcher(), new FormFactory(new FormRegistry([], new ResolvedFormTypeFactory())), $options);
     }
 }
