@@ -25,7 +25,7 @@ class FixedDataTransformer implements DataTransformerInterface
 
     public function transform($value)
     {
-        if (!array_key_exists($value, $this->mapping)) {
+        if (!\array_key_exists($value, $this->mapping)) {
             throw new TransformationFailedException(sprintf('No mapping for value "%s"', $value));
         }
 
