@@ -14,13 +14,12 @@ namespace Symfony\Component\Form\Tests;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Form\FormFactory;
 use Symfony\Component\Form\FormFactoryBuilder;
-use Symfony\Component\Form\FormTypeGuesserInterface;
 use Symfony\Component\Form\Tests\Fixtures\FooType;
+use Symfony\Component\Form\Tests\Fixtures\NullFormTypeGuesser;
 
 class FormFactoryBuilderTest extends TestCase
 {
     private $registry;
-    private $guesser;
     private $type;
 
     protected function setUp(): void
@@ -29,7 +28,6 @@ class FormFactoryBuilderTest extends TestCase
         $this->registry = $factory->getProperty('registry');
         $this->registry->setAccessible(true);
 
-        $this->guesser = $this->createMock(FormTypeGuesserInterface::class);
         $this->type = new FooType();
     }
 
@@ -50,7 +48,7 @@ class FormFactoryBuilderTest extends TestCase
     public function testAddTypeGuesser()
     {
         $factoryBuilder = new FormFactoryBuilder();
-        $factoryBuilder->addTypeGuesser($this->guesser);
+        $factoryBuilder->addTypeGuesser(new NullFormTypeGuesser());
 
         $factory = $factoryBuilder->getFormFactory();
         $registry = $this->registry->getValue($factory);
