@@ -31,6 +31,7 @@ class TranslationFilesTest extends TestCase
 
     /**
      * @dataProvider provideTranslationFiles
+     *
      * @group Legacy
      */
     public function testTranslationFileIsValidWithoutEntityLoader($filePath)
@@ -46,7 +47,7 @@ class TranslationFilesTest extends TestCase
         $this->assertCount(0, $errors, sprintf('"%s" is invalid:%s', $filePath, \PHP_EOL.implode(\PHP_EOL, array_column($errors, 'message'))));
     }
 
-    public function provideTranslationFiles()
+    public static function provideTranslationFiles()
     {
         return array_map(
             function ($filePath) { return (array) $filePath; },
