@@ -15,8 +15,6 @@ use PHPUnit\Framework\TestCase;
 use Symfony\Component\HttpClient\DataCollector\HttpClientDataCollector;
 use Symfony\Component\HttpClient\NativeHttpClient;
 use Symfony\Component\HttpClient\TraceableHttpClient;
-use Symfony\Component\HttpFoundation\Request;
-use Symfony\Component\HttpFoundation\Response;
 use Symfony\Contracts\HttpClient\Test\TestHttpServer;
 
 class HttpClientDataCollectorTest extends TestCase
@@ -50,7 +48,7 @@ class HttpClientDataCollectorTest extends TestCase
         $sut->registerClient('http_client2', $httpClient2);
         $sut->registerClient('http_client3', $httpClient3);
         $this->assertEquals(0, $sut->getRequestCount());
-        $sut->collect(new Request(), new Response());
+        $sut->lateCollect();
         $this->assertEquals(3, $sut->getRequestCount());
     }
 
@@ -79,7 +77,7 @@ class HttpClientDataCollectorTest extends TestCase
         $sut->registerClient('http_client2', $httpClient2);
         $sut->registerClient('http_client3', $httpClient3);
         $this->assertEquals(0, $sut->getErrorCount());
-        $sut->collect(new Request(), new Response());
+        $sut->lateCollect();
         $this->assertEquals(1, $sut->getErrorCount());
     }
 
@@ -108,7 +106,7 @@ class HttpClientDataCollectorTest extends TestCase
         $sut->registerClient('http_client2', $httpClient2);
         $sut->registerClient('http_client3', $httpClient3);
         $this->assertEquals([], $sut->getClients());
-        $sut->collect(new Request(), new Response());
+        $sut->lateCollect();
         $collectedData = $sut->getClients();
         $this->assertEquals(0, $collectedData['http_client1']['error_count']);
         $this->assertEquals(1, $collectedData['http_client2']['error_count']);
@@ -140,7 +138,7 @@ class HttpClientDataCollectorTest extends TestCase
         $sut->registerClient('http_client2', $httpClient2);
         $sut->registerClient('http_client3', $httpClient3);
         $this->assertEquals([], $sut->getClients());
-        $sut->collect(new Request(), new Response());
+        $sut->lateCollect();
         $collectedData = $sut->getClients();
         $this->assertCount(2, $collectedData['http_client1']['traces']);
         $this->assertCount(1, $collectedData['http_client2']['traces']);
@@ -157,7 +155,7 @@ class HttpClientDataCollectorTest extends TestCase
         ]);
         $sut = new HttpClientDataCollector();
         $sut->registerClient('http_client1', $httpClient1);
-        $sut->collect(new Request(), new Response());
+        $sut->lateCollect();
         $collectedData = $sut->getClients();
         $this->assertCount(1, $collectedData['http_client1']['traces']);
         $sut->reset();
