@@ -59,13 +59,9 @@ class RedirectResponseTest extends TestCase
         $this->assertEquals('baz.beep', $response->getTargetUrl());
     }
 
-    public function testSetTargetUrlNull()
-    {
-        $this->expectException(\InvalidArgumentException::class);
-        $response = new RedirectResponse('foo.bar');
-        $response->setTargetUrl(null);
-    }
-
+    /**
+     * @group legacy
+     */
     public function testCreate()
     {
         $response = RedirectResponse::create('foo', 301);
