@@ -23,6 +23,6 @@ class PredisSessionHandlerTest extends AbstractRedisSessionHandlerTestCase
      */
     protected function createRedisClient(string $host): object
     {
-        return new Client(['host' => $host]);
+        return new Client(array_combine(['host', 'port'], explode(':', getenv('REDIS_HOST')) + [1 => 6379]));
     }
 }
