@@ -22,6 +22,7 @@ use Symfony\Component\HttpFoundation\Session\Storage\Handler\StrictSessionHandle
  * @author Simon <simon.chrzanowski@quentic.com>
  *
  * @runTestsInSeparateProcesses
+ *
  * @preserveGlobalState disabled
  */
 class SessionHandlerFactoryTest extends TestCase
@@ -37,7 +38,7 @@ class SessionHandlerFactoryTest extends TestCase
         $this->assertEquals($expectedPath, \ini_get('session.save_path'));
     }
 
-    public function provideConnectionDSN(): array
+    public static function provideConnectionDSN(): array
     {
         $base = sys_get_temp_dir();
 
