@@ -31,7 +31,7 @@ class ChainCacheClearerTest extends TestCase
 
     public function testInjectClearersInConstructor()
     {
-        $clearer = $this->getMockClearer();
+        $clearer = $this->createMock(CacheClearerInterface::class);
         $clearer
             ->expects($this->once())
             ->method('clear');
@@ -39,9 +39,4 @@ class ChainCacheClearerTest extends TestCase
         $chainClearer = new ChainCacheClearer([$clearer]);
         $chainClearer->clear(self::$cacheDir);
     }
-
-    protected function getMockClearer()
-    {
-        return $this->createMock(CacheClearerInterface::class);
-    }
 }
