@@ -14,6 +14,7 @@ namespace Symfony\Component\HttpKernel\Tests\DependencyInjection;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\HttpKernel\DependencyInjection\ServicesResetter;
 use Symfony\Component\HttpKernel\Tests\Fixtures\ClearableService;
+use Symfony\Component\HttpKernel\Tests\Fixtures\MultiResettableService;
 use Symfony\Component\HttpKernel\Tests\Fixtures\ResettableService;
 
 class ServicesResetterTest extends TestCase
@@ -22,6 +23,8 @@ class ServicesResetterTest extends TestCase
     {
         ResettableService::$counter = 0;
         ClearableService::$counter = 0;
+        MultiResettableService::$resetFirstCounter = 0;
+        MultiResettableService::$resetSecondCounter = 0;
     }
 
     public function testResetServices()
@@ -29,14 +32,18 @@ class ServicesResetterTest extends TestCase
         $resetter = new ServicesResetter(new \ArrayIterator([
             'id1' => new ResettableService(),
             'id2' => new ClearableService(),
+            'id3' => new MultiResettableService(),
         ]), [
-            'id1' => 'reset',
-            'id2' => 'clear',
+            'id1' => ['reset'],
+            'id2' => ['clear'],
+            'id3' => ['resetFirst', 'resetSecond'],
         ]);
 
         $resetter->reset();
 
-        $this->assertEquals(1, ResettableService::$counter);
-        $this->assertEquals(1, ClearableService::$counter);
+        $this->assertSame(1, ResettableService::$counter);
+        $this->assertSame(1, ClearableService::$counter);
+        $this->assertSame(1, MultiResettableService::$resetFirstCounter);
+        $this->assertSame(1, MultiResettableService::$resetSecondCounter);
     }
 }
