@@ -16,11 +16,10 @@ use Symfony\Component\EventDispatcher\EventSubscriberInterface;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpKernel\Event\RequestEvent;
 use Symfony\Component\HttpKernel\EventListener\AddRequestFormatsListener;
+use Symfony\Component\HttpKernel\HttpKernelInterface;
 use Symfony\Component\HttpKernel\KernelEvents;
 
 /**
- * Test AddRequestFormatsListener class.
- *
  * @author Gildas Quemener <gildas.quemener@gmail.com>
  */
 class AddRequestFormatsListenerTest extends TestCase
@@ -47,7 +46,7 @@ class AddRequestFormatsListenerTest extends TestCase
 
     public function testRegisteredEvent()
     {
-        $this->assertEquals(
+        $this->assertSame(
             [KernelEvents::REQUEST => ['onKernelRequest', 100]],
             AddRequestFormatsListener::getSubscribedEvents()
         );
@@ -55,8 +54,8 @@ class AddRequestFormatsListenerTest extends TestCase
 
     public function testSetAdditionalFormats()
     {
-        $request = $this->getRequestMock();
-        $event = $this->getRequestEventMock($request);
+        $request = $this->createMock(Request::class);
+        $event = new RequestEvent($this->createMock(HttpKernelInterface::class), $request, HttpKernelInterface::MAIN_REQUEST);
 
         $request->expects($this->once())
             ->method('setFormat')
@@ -64,19 +63,4 @@ class AddRequestFormatsListenerTest extends TestCase
 
         $this->listener->onKernelRequest($event);
     }
-
-    protected function getRequestMock()
-    {
-        return $this->createMock(Request::class);
-    }
-
-    protected function getRequestEventMock(Request $request)
-    {
-        $event = $this->createMock(RequestEvent::class);
-        $event->expects($this->any())
-            ->method('getRequest')
-            ->willReturn($request);
-
-        return $event;
-    }
 }
