@@ -67,7 +67,7 @@ class RouterListenerTest extends TestCase
         $this->assertEquals(str_starts_with($uri, 'https') ? 'https' : 'http', $context->getScheme());
     }
 
-    public function getPortData()
+    public static function getPortData()
     {
         return [
             [80, 443, 'http://localhost/', 80, 443],
@@ -157,7 +157,7 @@ class RouterListenerTest extends TestCase
         $listener->onKernelRequest(new RequestEvent($kernel, $request, HttpKernelInterface::MAIN_REQUEST));
     }
 
-    public function getLoggingParameterData()
+    public static function getLoggingParameterData()
     {
         return [
             [['_route' => 'foo'], 'Matched route "{route}".', ['route' => 'foo', 'route_parameters' => ['_route' => 'foo'], 'request_uri' => 'http://localhost/', 'method' => 'GET']],
