@@ -82,7 +82,7 @@ class SessionListenerTest extends TestCase
         }
     }
 
-    public function provideSessionOptions(): \Generator
+    public static function provideSessionOptions(): \Generator
     {
         if (\PHP_VERSION_ID > 70300) {
             yield 'set_samesite_by_php' => [
@@ -590,6 +590,30 @@ class SessionListenerTest extends TestCase
         $this->assertFalse($response->headers->has(AbstractSessionListener::NO_AUTO_CACHE_CONTROL_HEADER));
     }
 
+    public function testPrivateResponseMaxAgeIsRespectedIfSessionStarted()
+    {
+        $kernel = $this->createMock(HttpKernelInterface::class);
+
+        $session = $this->createMock(Session::class);
+        $session->expects($this->once())->method('getUsageIndex')->willReturn(1);
+        $request = new Request([], [], [], [], [], ['SERVER_PROTOCOL' => 'HTTP/1.0']);
+        $request->setSession($session);
+
+        $response = new Response();
+        $response->headers->set('Cache-Control', 'no-cache');
+        $response->prepare($request);
+
+        $listener = new SessionListener(new Container());
+        $listener->onKernelResponse(new ResponseEvent($kernel, $request, HttpKernelInterface::MAIN_REQUEST, $response));
+
+        $this->assertSame(0, $response->getMaxAge());
+        $this->assertFalse($response->headers->hasCacheControlDirective('public'));
+        $this->assertTrue($response->headers->hasCacheControlDirective('private'));
+        $this->assertTrue($response->headers->hasCacheControlDirective('must-revalidate'));
+        $this->assertLessThanOrEqual(new \DateTimeImmutable('now', new \DateTimeZone('UTC')), new \DateTimeImmutable($response->headers->get('Expires')));
+        $this->assertFalse($response->headers->has(AbstractSessionListener::NO_AUTO_CACHE_CONTROL_HEADER));
+    }
+
     public function testSurrogateMainRequestIsPublic()
     {
         $session = $this->createMock(Session::class);
@@ -667,6 +691,27 @@ class SessionListenerTest extends TestCase
         $subRequest->getSession();
     }
 
+    public function testGetSessionSetsSessionOnMainRequest()
+    {
+        $mainRequest = new Request();
+        $listener = $this->createListener($mainRequest, new NativeSessionStorageFactory());
+
+        $event = new RequestEvent($this->createMock(HttpKernelInterface::class), $mainRequest, HttpKernelInterface::MAIN_REQUEST);
+        $listener->onKernelRequest($event);
+
+        $this->assertFalse($mainRequest->hasSession(true));
+
+        $subRequest = $mainRequest->duplicate();
+
+        $event = new RequestEvent($this->createMock(HttpKernelInterface::class), $subRequest, HttpKernelInterface::SUB_REQUEST);
+        $listener->onKernelRequest($event);
+
+        $session = $subRequest->getSession();
+
+        $this->assertTrue($mainRequest->hasSession(true));
+        $this->assertSame($session, $mainRequest->getSession());
+    }
+
     public function testSessionUsageExceptionIfStatelessAndSessionUsed()
     {
         $session = $this->createMock(Session::class);
