@@ -240,6 +240,7 @@ class ResponseCacheStrategyTest extends TestCase
 
     /**
      * @group time-sensitive
+     *
      * @dataProvider cacheControlMergingProvider
      */
     public function testCacheControlMerging(array $expects, array $master, array $surrogates)
@@ -309,7 +310,7 @@ class ResponseCacheStrategyTest extends TestCase
         }
     }
 
-    public function cacheControlMergingProvider()
+    public static function cacheControlMergingProvider()
     {
         yield 'result is public if all responses are public' => [
             ['private' => false, 'public' => true],
