@@ -361,7 +361,7 @@ class HttpKernelTest extends TestCase
     {
         $request = new Request();
 
-        $stack = $this->getMockBuilder(RequestStack::class)->setMethods(['push', 'pop'])->getMock();
+        $stack = $this->getMockBuilder(RequestStack::class)->onlyMethods(['push', 'pop'])->getMock();
         $stack->expects($this->once())->method('push')->with($this->equalTo($request));
         $stack->expects($this->once())->method('pop');
 
