@@ -148,7 +148,7 @@ class KernelTest extends TestCase
 
     public function testClassCacheIsNotLoadedByDefault()
     {
-        $kernel = $this->getKernel(['initializeBundles', 'doLoadClassCache']);
+        $kernel = $this->getKernel(['initializeBundles'], [], false, ['doLoadClassCache']);
         $kernel->expects($this->never())
             ->method('doLoadClassCache');
 
@@ -182,10 +182,12 @@ class KernelTest extends TestCase
         $bundle = $this->createMock(Bundle::class);
         $bundle->expects($this->exactly(2))
             ->method('setContainer')
-            ->withConsecutive(
-                [$this->isInstanceOf(ContainerInterface::class)],
-                [null]
-            );
+            ->willReturnCallback(function ($container) {
+                if (null !== $container) {
+                    $this->assertInstanceOf(ContainerInterface::class, $container);
+                }
+            })
+        ;
 
         $kernel = $this->getKernel(['getBundles']);
         $kernel->expects($this->any())
@@ -449,7 +451,7 @@ EOF
         // implements TerminableInterface
         $httpKernelMock = $this->getMockBuilder(HttpKernel::class)
             ->disableOriginalConstructor()
-            ->setMethods(['terminate'])
+            ->onlyMethods(['terminate'])
             ->getMock();
 
         $httpKernelMock
@@ -630,7 +632,7 @@ EOF
     {
         $bundle = $this
             ->getMockBuilder(BundleInterface::class)
-            ->setMethods(['getPath', 'getName'])
+            ->onlyMethods(['getPath', 'getName'])
             ->disableOriginalConstructor()
         ;
 
@@ -661,16 +663,21 @@ EOF
      * @param array $methods Additional methods to mock (besides the abstract ones)
      * @param array $bundles Bundles to register
      */
-    protected function getKernel(array $methods = [], array $bundles = [], bool $debug = false): Kernel
+    protected function getKernel(array $methods = [], array $bundles = [], bool $debug = false, array $methodsToAdd = []): Kernel
     {
         $methods[] = 'registerBundles';
 
-        $kernel = $this
+        $kernelMockBuilder = $this
             ->getMockBuilder(KernelForTest::class)
-            ->setMethods($methods)
+            ->onlyMethods($methods)
             ->setConstructorArgs(['test', $debug])
-            ->getMock()
         ;
+
+        if (0 !== \count($methodsToAdd)) {
+            $kernelMockBuilder->addMethods($methodsToAdd);
+        }
+
+        $kernel = $kernelMockBuilder->getMock();
         $kernel->expects($this->any())
             ->method('registerBundles')
             ->willReturn($bundles)
