@@ -31,7 +31,7 @@ final class Countries extends ResourceBundle
      *
      * This list only contains "officially assigned ISO 3166-1 alpha-2" country codes.
      *
-     * @return string[] an array of canonical ISO 3166 alpha-2 country codes
+     * @return string[]
      */
     public static function getCountryCodes(): array
     {
@@ -45,7 +45,7 @@ final class Countries extends ResourceBundle
      *
      * This list only contains "officially assigned ISO 3166-1 alpha-3" country codes.
      *
-     * @return string[] an array of canonical ISO 3166 alpha-3 country codes
+     * @return string[]
      */
     public static function getAlpha3Codes(): array
     {
@@ -107,9 +107,9 @@ final class Countries extends ResourceBundle
     /**
      * Gets the list of country names indexed with alpha2 codes as keys.
      *
-     * @return string[]
+     * @return array<string, string>
      */
-    public static function getNames($displayLocale = null): array
+    public static function getNames(string $displayLocale = null): array
     {
         return self::asort(self::readEntry(['Names'], $displayLocale), $displayLocale);
     }
@@ -119,9 +119,9 @@ final class Countries extends ResourceBundle
      *
      * Same as method getNames, but with alpha3 codes instead of alpha2 codes as keys.
      *
-     * @return string[]
+     * @return array<string, string>
      */
-    public static function getAlpha3Names($displayLocale = null): array
+    public static function getAlpha3Names(string $displayLocale = null): array
     {
         $alpha2Names = self::getNames($displayLocale);
         $alpha3Names = [];
