@@ -68,7 +68,7 @@ return [
         ],
         'AWG' => [
             0 => 'AWG',
-            1 => 'আরুবা গিল্ডার',
+            1 => 'আরুবা ফ্লোরিন',
         ],
         'AZM' => [
             0 => 'AZM',
@@ -132,7 +132,7 @@ return [
         ],
         'BOB' => [
             0 => 'BOB',
-            1 => 'বলিভিয়ানো',
+            1 => 'বলিভিয়ান বলিভিয়ানো',
         ],
         'BOP' => [
             0 => 'BOP',
@@ -412,7 +412,7 @@ return [
         ],
         'GYD' => [
             0 => 'GYD',
-            1 => 'গাইয়েনা ডলার',
+            1 => 'গায়ানিজ ডলার',
         ],
         'HKD' => [
             0 => 'HK$',
@@ -452,7 +452,7 @@ return [
         ],
         'ILS' => [
             0 => '₪',
-            1 => 'ইস্রাইলি নতুন শেকেল',
+            1 => 'ইসরায়েলি নতুন শেকেল',
         ],
         'INR' => [
             0 => '₹',
@@ -500,7 +500,7 @@ return [
         ],
         'KMF' => [
             0 => 'KMF',
-            1 => 'কম্বোরো ফ্রাঙ্ক',
+            1 => 'কমোরিয়ান ফ্রাঙ্ক',
         ],
         'KPW' => [
             0 => 'KPW',
@@ -640,7 +640,7 @@ return [
         ],
         'MWK' => [
             0 => 'MWK',
-            1 => 'মালাউইয়ান কওয়াচ',
+            1 => 'মালাউইয়ান কোয়াচা',
         ],
         'MXN' => [
             0 => 'MX$',
@@ -708,7 +708,7 @@ return [
         ],
         'PAB' => [
             0 => 'PAB',
-            1 => 'পানামা বেলবোয়া',
+            1 => 'পানামানিয়ান বালবোয়া',
         ],
         'PEI' => [
             0 => 'PEI',
@@ -836,7 +836,7 @@ return [
         ],
         'SRD' => [
             0 => 'SRD',
-            1 => 'সুরিনাম ডলার',
+            1 => 'সুরিনামিজ ডলার',
         ],
         'SRG' => [
             0 => 'SRG',
