@@ -26,10 +26,6 @@ return [
             0 => 'LVR',
             1 => 'Latvian Rouble',
         ],
-        'PHP' => [
-            0 => '₱',
-            1 => 'Philippine Peso',
-        ],
         'RUB' => [
             0 => 'RUB',
             1 => 'Russian Rouble',
