@@ -4,7 +4,7 @@ return [
     'Names' => [
         'PHP' => [
             0 => '₱',
-            1 => 'Philippine Piso',
+            1 => 'Philippine Peso',
         ],
     ],
 ];
