@@ -2,7 +2,7 @@
 
 return [
     'Names' => [
-        'SLL' => [
+        'SLE' => [
             0 => 'Le',
             1 => 'Sierra Leonean Leone',
         ],
