@@ -898,6 +898,10 @@ return [
             0 => 'SKK',
             1 => 'koroa eslovakiarra',
         ],
+        'SLE' => [
+            0 => 'SLE',
+            1 => 'leone sierraleonar berria',
+        ],
         'SLL' => [
             0 => 'SLL',
             1 => 'leone sierraleonarra',
@@ -1046,6 +1050,10 @@ return [
             0 => 'VEB',
             1 => 'Venezuelako bolivarra (1871–2008)',
         ],
+        'VED' => [
+            0 => 'VED',
+            1 => 'bolivar subiraua',
+        ],
         'VEF' => [
             0 => 'VEF',
             1 => 'Venezuelako bolivarra (2008–2018)',
