@@ -980,7 +980,7 @@ return [
         ],
         'TRY' => [
             0 => 'TRY',
-            1 => '新トルコリラ',
+            1 => 'トルコリラ',
         ],
         'TTD' => [
             0 => 'TTD',
