@@ -124,7 +124,7 @@ return [
         ],
         'BRL' => [
             0 => 'R$',
-            1 => 'برازیٖلین رِیَل',
+            1 => 'برازیٖلی رِیَل',
         ],
         'BRN' => [
             0 => 'BRN',
@@ -196,7 +196,7 @@ return [
         ],
         'CNY' => [
             0 => 'CN¥',
-            1 => 'چینیٖز یَن رِنمِنبی',
+            1 => 'چیٖنی یُوان',
         ],
         'COP' => [
             0 => 'COP',
@@ -292,7 +292,7 @@ return [
         ],
         'GBP' => [
             0 => '£',
-            1 => 'برطٲنوی پاونڑ سٹٔرلِنگ',
+            1 => 'برطٲنوی پوٗنڈ',
         ],
         'GEK' => [
             0 => 'GEK',
@@ -419,7 +419,7 @@ return [
             1 => 'جَرڑینیاہُک دیٖنار',
         ],
         'JPY' => [
-            0 => 'JP¥',
+            0 => '¥',
             1 => 'جاپانُک یَن',
         ],
         'KES' => [
@@ -704,7 +704,7 @@ return [
         ],
         'RUB' => [
             0 => 'RUB',
-            1 => 'رٔشیَن رَبٕل',
+            1 => 'روٗسی رَبٕل',
         ],
         'RUR' => [
             0 => 'RUR',
@@ -847,8 +847,8 @@ return [
             1 => 'اُگاداہُک شِلِنگ',
         ],
         'USD' => [
-            0 => 'US$',
-            1 => 'یوٗ ایس ڈالَر',
+            0 => '$',
+            1 => 'US ڈالر',
         ],
         'USN' => [
             0 => 'USN',
