@@ -420,7 +420,7 @@ return [
         ],
         'NIO' => [
             0 => 'NIO',
-            1 => 'निकाराग्वेचा कोर्डोबा',
+            1 => 'निकाराग्वन कोर्डोबा',
         ],
         'NOK' => [
             0 => 'NOK',
