@@ -124,7 +124,7 @@ return [
         ],
         'CNH' => [
             0 => 'CNH',
-            1 => 'చైనీస్ యూవాన్ (ఆఫ్‌షోర్)',
+            1 => 'చైనీస్ యువాన్ (ఆఫ్‌షోర్)',
         ],
         'CNY' => [
             0 => 'CN¥',
