@@ -316,7 +316,7 @@ return [
         ],
         'DDM' => [
             0 => 'DDM',
-            1 => '东德奥斯特马克',
+            1 => '东德马克',
         ],
         'DEM' => [
             0 => 'DEM',
@@ -400,7 +400,7 @@ return [
         ],
         'GEK' => [
             0 => 'GEK',
-            1 => '乔治亚库蓬拉瑞特',
+            1 => '格鲁吉亚库蓬拉瑞特',
         ],
         'GEL' => [
             0 => 'GEL',
@@ -876,7 +876,7 @@ return [
         ],
         'SDP' => [
             0 => 'SDP',
-            1 => '旧苏丹镑',
+            1 => '苏丹镑 (1957–1998)',
         ],
         'SEK' => [
             0 => 'SEK',
@@ -898,6 +898,10 @@ return [
             0 => 'SKK',
             1 => '斯洛伐克克朗',
         ],
+        'SLE' => [
+            0 => 'SLE',
+            1 => '塞拉利昂新利昂',
+        ],
         'SLL' => [
             0 => 'SLL',
             1 => '塞拉利昂利昂',
@@ -1046,6 +1050,10 @@ return [
             0 => 'VEB',
             1 => '委内瑞拉玻利瓦尔 (1871–2008)',
         ],
+        'VED' => [
+            0 => 'VED',
+            1 => '委内瑞拉主权币',
+        ],
         'VEF' => [
             0 => 'VEF',
             1 => '委内瑞拉玻利瓦尔 (2008–2018)',
