@@ -976,11 +976,11 @@ return [
         ],
         'TRL' => [
             0 => 'TRL',
-            1 => '土耳其里拉',
+            1 => '土耳其里拉 (1922–2005)',
         ],
         'TRY' => [
             0 => 'TRY',
-            1 => '新土耳其里拉',
+            1 => '土耳其里拉',
         ],
         'TTD' => [
             0 => 'TTD',
