@@ -17,14 +17,17 @@ return [
         'am' => 'амхарская',
         'an' => 'арагонская',
         'ang' => 'стараанглійская',
+        'ann' => 'абола',
         'anp' => 'ангіка',
         'ar' => 'арабская',
         'arc' => 'арамейская',
         'arn' => 'мапудунгун',
         'arp' => 'арапаха',
+        'ars' => 'недждыйская арабская',
         'as' => 'асамская',
         'asa' => 'асу',
         'ast' => 'астурыйская',
+        'atj' => 'атыкамек',
         'av' => 'аварская',
         'awa' => 'авадхі',
         'ay' => 'аймара',
@@ -51,6 +54,7 @@ return [
         'bug' => 'бугіс',
         'byn' => 'білен',
         'ca' => 'каталанская',
+        'cay' => 'каюга',
         'ccp' => 'чакма',
         'ce' => 'чачэнская',
         'ceb' => 'себуана',
@@ -60,13 +64,22 @@ return [
         'chk' => 'чуук',
         'chm' => 'мары',
         'cho' => 'чокта',
+        'chp' => 'чыпеваян',
         'chr' => 'чэрокі',
         'chy' => 'шэйен',
         'ckb' => 'цэнтральнакурдская',
+        'clc' => 'чылькатын',
         'co' => 'карсіканская',
         'cop' => 'копцкая',
+        'crg' => 'мічыф',
+        'crj' => 'паўднёва-ўсходняя кры',
+        'crk' => 'раўнінны кры',
+        'crl' => 'паўночна-ўсходняя кры',
+        'crm' => 'муская кры',
+        'crr' => 'каралінская алганкійская',
         'crs' => 'сэсэльва',
         'cs' => 'чэшская',
+        'csw' => 'балотная кры',
         'cu' => 'царкоўнаславянская',
         'cv' => 'чувашская',
         'cy' => 'валійская',
@@ -104,7 +117,9 @@ return [
         'fo' => 'фарэрская',
         'fon' => 'фон',
         'fr' => 'французская',
+        'frc' => 'каджунская французская',
         'fro' => 'старафранцузская',
+        'frr' => 'паўночнафрызская',
         'fur' => 'фрыульская',
         'fy' => 'заходняя фрызская',
         'ga' => 'ірландская',
@@ -123,7 +138,9 @@ return [
         'gv' => 'мэнская',
         'gwi' => 'гуіч’ін',
         'ha' => 'хауса',
+        'hai' => 'хайда',
         'haw' => 'гавайская',
+        'hax' => 'паўднёвая хайда',
         'he' => 'іўрыт',
         'hi' => 'хіндзі',
         'hil' => 'хілігайнон',
@@ -133,6 +150,7 @@ return [
         'ht' => 'гаіцянская крэольская',
         'hu' => 'венгерская',
         'hup' => 'хупа',
+        'hur' => 'халкамелем',
         'hy' => 'армянская',
         'hz' => 'герэра',
         'ia' => 'інтэрлінгва',
@@ -142,6 +160,7 @@ return [
         'ie' => 'інтэрлінгвэ',
         'ig' => 'ігба',
         'ii' => 'сычуаньская йі',
+        'ikt' => 'заходнеканадская інуктытут',
         'ilo' => 'ілакана',
         'inh' => 'інгушская',
         'io' => 'іда',
@@ -163,6 +182,7 @@ return [
         'kde' => 'макондэ',
         'kea' => 'кабувердыяну',
         'kfo' => 'кора',
+        'kgp' => 'каінганг',
         'kha' => 'кхасі',
         'khq' => 'койра чыіні',
         'ki' => 'кікуйю',
@@ -190,6 +210,7 @@ return [
         'kum' => 'кумыцкая',
         'kv' => 'комі',
         'kw' => 'корнская',
+        'kwk' => 'квакіутль',
         'ky' => 'кіргізская',
         'la' => 'лацінская',
         'lad' => 'ладына',
@@ -198,12 +219,15 @@ return [
         'lez' => 'лезгінская',
         'lg' => 'ганда',
         'li' => 'лімбургская',
+        'lil' => 'лілуэт',
         'lkt' => 'лакота',
         'ln' => 'лінгала',
         'lo' => 'лаоская',
         'lol' => 'монга',
+        'lou' => 'луізіянская крэольская',
         'loz' => 'лозі',
         'lrc' => 'паўночная луры',
+        'lsm' => 'саамія',
         'lt' => 'літоўская',
         'lu' => 'луба-катанга',
         'lua' => 'луба-касаі',
@@ -233,6 +257,7 @@ return [
         'ml' => 'малаялам',
         'mn' => 'мангольская',
         'mni' => 'мейтэй',
+        'moe' => 'іну-аймун',
         'moh' => 'мохак',
         'mos' => 'мосі',
         'mr' => 'маратхі',
@@ -270,7 +295,12 @@ return [
         'ny' => 'ньянджа',
         'nyn' => 'ньянколе',
         'oc' => 'аксітанская',
-        'oj' => 'аджыбва',
+        'oj' => 'аджыбвэ',
+        'ojb' => 'паўночна-заходняя аджыбвэ',
+        'ojc' => 'цэнтральная аджыбвэ',
+        'ojs' => 'оджы-кры',
+        'ojw' => 'заходняя аджыбвэ',
+        'oka' => 'аканаган',
         'om' => 'арома',
         'or' => 'орыя',
         'os' => 'асецінская',
@@ -282,7 +312,9 @@ return [
         'pcm' => 'нігерыйскі піджын',
         'peo' => 'стараперсідская',
         'phn' => 'фінікійская',
+        'pis' => 'саламонскі піджын',
         'pl' => 'польская',
+        'pqm' => 'малесіт-пасамакуоды',
         'prg' => 'пруская',
         'pro' => 'стараправансальская',
         'ps' => 'пушту',
@@ -324,6 +356,7 @@ return [
         'si' => 'сінгальская',
         'sk' => 'славацкая',
         'sl' => 'славенская',
+        'slh' => 'паўднёвая лушуцыд',
         'sm' => 'самоа',
         'sma' => 'паўднёвасаамская',
         'smj' => 'луле-саамская',
@@ -338,6 +371,7 @@ return [
         'ss' => 'суаці',
         'ssy' => 'саха',
         'st' => 'сесута',
+        'str' => 'стрэйтс саліш',
         'su' => 'сунда',
         'suk' => 'сукума',
         'sux' => 'шумерская',
@@ -346,23 +380,29 @@ return [
         'swb' => 'каморская',
         'syr' => 'сірыйская',
         'ta' => 'тамільская',
+        'tce' => 'паўднёвая тутчонэ',
         'te' => 'тэлугу',
         'tem' => 'тэмнэ',
         'teo' => 'тэсо',
         'tet' => 'тэтум',
         'tg' => 'таджыкская',
+        'tgx' => 'тагіш',
         'th' => 'тайская',
+        'tht' => 'тальтан',
         'ti' => 'тыгрынья',
         'tig' => 'тыгрэ',
         'tk' => 'туркменская',
         'tlh' => 'клінган',
+        'tli' => 'тлінгіт',
         'tn' => 'тсвана',
         'to' => 'танганская',
+        'tok' => 'такіпона',
         'tpi' => 'ток-пісін',
         'tr' => 'турэцкая',
         'trv' => 'тарока',
         'ts' => 'тсонга',
         'tt' => 'татарская',
+        'ttm' => 'паўночная тутчонэ',
         'tum' => 'тумбука',
         'tvl' => 'тувалу',
         'twq' => 'тасаўак',
@@ -386,6 +426,7 @@ return [
         'war' => 'варай',
         'wbp' => 'варлпіры',
         'wo' => 'валоф',
+        'wuu' => 'ву',
         'xal' => 'калмыцкая',
         'xh' => 'коса',
         'xog' => 'сога',
@@ -393,6 +434,7 @@ return [
         'ybb' => 'йемба',
         'yi' => 'ідыш',
         'yo' => 'ёруба',
+        'yrl' => 'ньенгату',
         'yue' => 'кантонскі дыялект кітайскай',
         'zap' => 'сапатэк',
         'zgh' => 'стандартная мараканская тамазіхт',
