@@ -20,15 +20,18 @@ return [
         'am' => 'амхарски',
         'an' => 'арагонежански',
         'ang' => 'староенглески',
+        'ann' => 'оболо',
         'anp' => 'ангика',
         'ar' => 'арапски',
         'arc' => 'армајски',
         'arn' => 'ароканијски',
         'arp' => 'арапахо',
+        'ars' => 'најди арапски',
         'arw' => 'аравак',
         'as' => 'асемијски',
         'asa' => 'асу',
         'ast' => 'астуријски',
+        'atj' => 'атикамекв',
         'av' => 'аварски',
         'awa' => 'авадхи',
         'ay' => 'ајмара',
@@ -60,6 +63,7 @@ return [
         'ca' => 'каталонски',
         'cad' => 'кадо',
         'car' => 'карипски',
+        'cay' => 'Кајуга',
         'cch' => 'атсамски',
         'ccp' => 'чакма',
         'ce' => 'чеченски',
@@ -76,12 +80,20 @@ return [
         'chr' => 'чероки',
         'chy' => 'чејенски',
         'ckb' => 'централнокурдски',
+        'clc' => 'Чилкотин',
         'co' => 'корзикански',
         'cop' => 'коптски',
         'cr' => 'кри',
+        'crg' => 'мичиф',
         'crh' => 'кримеански турски',
+        'crj' => 'јужноисточни кре',
+        'crk' => 'равничарски кре',
+        'crl' => 'сјеверно источни кре',
+        'crm' => 'мосе кре',
+        'crr' => 'алгонкуански за Каролину',
         'cs' => 'чешки',
         'csb' => 'кашубијански',
+        'csw' => 'свампи кре',
         'cu' => 'старославенски',
         'cv' => 'чувашки',
         'cy' => 'велшки',
@@ -103,6 +115,7 @@ return [
         'dyo' => 'јола-фоњи',
         'dyu' => 'ђула',
         'dz' => 'џонга',
+        'dzg' => 'дазага',
         'ebu' => 'ембу',
         'ee' => 'еве',
         'efi' => 'ефикски',
@@ -127,6 +140,7 @@ return [
         'fo' => 'фарски',
         'fon' => 'фон',
         'fr' => 'француски',
+        'frc' => 'кајунски француски',
         'frm' => 'средњи француски',
         'fro' => 'старофранцуски',
         'frr' => 'северно-фризијски',
@@ -157,6 +171,7 @@ return [
         'ha' => 'хауса',
         'hai' => 'хаида',
         'haw' => 'хавајски',
+        'hax' => 'јужни хаида',
         'he' => 'хебрејски',
         'hi' => 'хинди',
         'hil' => 'хилигајнон',
@@ -168,15 +183,18 @@ return [
         'ht' => 'хаићански креолски',
         'hu' => 'мађарски',
         'hup' => 'хупа',
+        'hur' => 'халкомелем',
         'hy' => 'јерменски',
         'hz' => 'хереро',
         'ia' => 'интерлингва',
         'iba' => 'ибан',
+        'ibb' => 'ибибио',
         'id' => 'индонежански',
         'ie' => 'међујезички',
         'ig' => 'игбо',
         'ii' => 'сечуан ји',
         'ik' => 'унупиак',
+        'ikt' => 'западно канадски инуктитут',
         'ilo' => 'илоко',
         'inh' => 'ингвишки',
         'io' => 'идо',
@@ -203,6 +221,7 @@ return [
         'kea' => 'кабовердијански креолски',
         'kfo' => 'коро',
         'kg' => 'конго',
+        'kgp' => 'каинганг',
         'kha' => 'каси',
         'kho' => 'котанешки',
         'khq' => 'којра чини',
@@ -232,6 +251,7 @@ return [
         'kut' => 'кутенаи',
         'kv' => 'коми',
         'kw' => 'корнишки',
+        'kwk' => 'кваквала',
         'ky' => 'киргиски',
         'la' => 'латински',
         'lad' => 'ладино',
@@ -242,12 +262,16 @@ return [
         'lez' => 'лезгиан',
         'lg' => 'ганда',
         'li' => 'лимбургиш',
+        'lij' => 'линуриан',
+        'lil' => 'лилоет',
         'lkt' => 'лакота',
         'ln' => 'лингала',
         'lo' => 'лаоски',
         'lol' => 'монго',
+        'lou' => 'луизиански креолски',
         'loz' => 'лози',
         'lrc' => 'сјеверни лури',
+        'lsm' => 'самиа',
         'lt' => 'литвански',
         'lu' => 'луба-катанга',
         'lua' => 'луба-лулуа',
@@ -281,6 +305,7 @@ return [
         'mn' => 'монголски',
         'mnc' => 'манчу',
         'mni' => 'манипури',
+        'moe' => 'иму-аимун',
         'moh' => 'махавски',
         'mos' => 'моси',
         'mr' => 'марати',
@@ -324,6 +349,11 @@ return [
         'nzi' => 'нзима',
         'oc' => 'провансалски',
         'oj' => 'ојибва',
+        'ojb' => 'сјеверозападни ојибва',
+        'ojc' => 'Централни обијва',
+        'ojs' => 'оји-кре',
+        'ojw' => 'западни ојибва',
+        'oka' => 'оканаган',
         'om' => 'оромо',
         'or' => 'одија',
         'os' => 'осетски',
@@ -335,11 +365,14 @@ return [
         'pam' => 'пампанга',
         'pap' => 'папиаменто',
         'pau' => 'палауански',
+        'pcm' => 'нигеријски пидгин',
         'peo' => 'староперсијски',
         'phn' => 'феничански',
         'pi' => 'пали',
+        'pis' => 'пијин',
         'pl' => 'пољски',
         'pon' => 'понпејски',
+        'pqm' => 'малисет-шасамкуоди',
         'prg' => 'пруски',
         'pro' => 'старопровансалски',
         'ps' => 'паштунски',
@@ -348,6 +381,7 @@ return [
         'raj' => 'рађастани',
         'rap' => 'рапануи',
         'rar' => 'раротонган',
+        'rhg' => 'рохимгја',
         'rm' => 'рето-романски',
         'rn' => 'рунди',
         'ro' => 'румунски',
@@ -364,6 +398,7 @@ return [
         'saq' => 'самбуру',
         'sas' => 'сасак',
         'sat' => 'сантали',
+        'sba' => 'нгамбеј',
         'sbp' => 'сангу',
         'sc' => 'сардињаски',
         'scn' => 'сицилијански',
@@ -382,6 +417,7 @@ return [
         'sid' => 'сидамо',
         'sk' => 'словачки',
         'sl' => 'словенски',
+        'slh' => 'јужни лушотсед',
         'sm' => 'самоански',
         'sma' => 'јужни сами',
         'smj' => 'луле сами',
@@ -397,6 +433,7 @@ return [
         'srr' => 'серер',
         'ss' => 'свати',
         'st' => 'сесото',
+        'str' => 'страитс салиш',
         'su' => 'сундански',
         'suk' => 'сукума',
         'sus' => 'сусу',
@@ -407,13 +444,16 @@ return [
         'syc' => 'класични сиријски',
         'syr' => 'сиријски',
         'ta' => 'тамилски',
+        'tce' => 'јужни тутчоне',
         'te' => 'телугу',
         'tem' => 'тимне',
         'teo' => 'тесо',
         'ter' => 'терено',
         'tet' => 'тетум',
         'tg' => 'таџички',
+        'tgx' => 'тагиш',
         'th' => 'тајландски',
+        'tht' => 'талтан',
         'ti' => 'тигриња',
         'tig' => 'тигре',
         'tiv' => 'тив',
@@ -426,11 +466,14 @@ return [
         'tn' => 'тсвана',
         'to' => 'тонга',
         'tog' => 'њаса тонга',
+        'tok' => 'токи пона',
         'tpi' => 'ток писин',
         'tr' => 'турски',
+        'trv' => 'тароко',
         'ts' => 'тсонга',
         'tsi' => 'тсимшиан',
         'tt' => 'татарски',
+        'ttm' => 'сјеверни тутчоне',
         'tum' => 'тумбука',
         'tvl' => 'тувалу',
         'tw' => 'тви',
@@ -447,6 +490,7 @@ return [
         'uz' => 'узбечки',
         'vai' => 'ваи',
         've' => 'венда',
+        'vec' => 'венецијански',
         'vi' => 'вијетнамски',
         'vo' => 'волапук',
         'vot' => 'вотски',
@@ -457,14 +501,17 @@ return [
         'war' => 'варај',
         'was' => 'вашо',
         'wo' => 'волоф',
+        'wuu' => 'ву кинески',
         'xal' => 'калмик',
         'xh' => 'коса',
         'xog' => 'сога',
         'yao' => 'јао',
         'yap' => 'јапешки',
         'yav' => 'јангбен',
+        'ybb' => 'јемба',
         'yi' => 'јидиш',
         'yo' => 'јоруба',
+        'yrl' => 'ненгату',
         'yue' => 'кантонски',
         'za' => 'жуанг',
         'zap' => 'запотечки',
@@ -482,5 +529,6 @@ return [
         'nl_BE' => 'фламански',
         'ro_MD' => 'молдавски',
         'zh_Hans' => 'кинески (поједностављен)',
+        'zh_Hant' => 'кинески (традиционални)',
     ],
 ];
