@@ -22,6 +22,7 @@ return [
         'am' => 'amhàric',
         'an' => 'aragonès',
         'ang' => 'anglès antic',
+        'ann' => 'obolo',
         'anp' => 'angika',
         'ar' => 'àrab',
         'arc' => 'arameu',
@@ -35,6 +36,7 @@ return [
         'asa' => 'pare',
         'ase' => 'llengua de signes americana',
         'ast' => 'asturià',
+        'atj' => 'atacama',
         'av' => 'àvar',
         'awa' => 'awadhi',
         'ay' => 'aimara',
@@ -94,13 +96,21 @@ return [
         'chr' => 'cherokee',
         'chy' => 'xeiene',
         'ckb' => 'kurd central',
+        'clc' => 'chilcotin',
         'co' => 'cors',
         'cop' => 'copte',
         'cr' => 'cree',
+        'crg' => 'michif',
         'crh' => 'tàtar de Crimea',
+        'crj' => 'cree sud-oriental',
+        'crk' => 'cree de la plana',
+        'crl' => 'cree nord-oriental',
+        'crm' => 'moose cree',
+        'crr' => 'algonquí de Carolina',
         'crs' => 'francès crioll de les Seychelles',
         'cs' => 'txec',
         'csb' => 'caixubi',
+        'csw' => 'swampy cree',
         'cu' => 'eslau eclesiàstic',
         'cv' => 'txuvaix',
         'cy' => 'gal·lès',
@@ -186,6 +196,7 @@ return [
         'hai' => 'haida',
         'hak' => 'xinès hakka',
         'haw' => 'hawaià',
+        'hax' => 'haida meridional',
         'he' => 'hebreu',
         'hi' => 'hindi',
         'hif' => 'hindi de Fiji',
@@ -199,6 +210,7 @@ return [
         'ht' => 'crioll d’Haití',
         'hu' => 'hongarès',
         'hup' => 'hupa',
+        'hur' => 'halkomelem',
         'hy' => 'armeni',
         'hz' => 'herero',
         'ia' => 'interlingua',
@@ -209,6 +221,7 @@ return [
         'ig' => 'igbo',
         'ii' => 'yi sichuan',
         'ik' => 'inupiak',
+        'ikt' => 'inuktitut occidental canadenc',
         'ilo' => 'ilocano',
         'inh' => 'ingúix',
         'io' => 'ido',
@@ -270,6 +283,7 @@ return [
         'kut' => 'kutenai',
         'kv' => 'komi',
         'kw' => 'còrnic',
+        'kwk' => 'kwak’wala',
         'ky' => 'kirguís',
         'la' => 'llatí',
         'lad' => 'judeocastellà',
@@ -281,6 +295,7 @@ return [
         'lg' => 'ganda',
         'li' => 'limburguès',
         'lij' => 'lígur',
+        'lil' => 'lillooet',
         'lkt' => 'lakota',
         'lmo' => 'llombard',
         'ln' => 'lingala',
@@ -289,6 +304,7 @@ return [
         'lou' => 'crioll francès de Louisiana',
         'loz' => 'lozi',
         'lrc' => 'luri septentrional',
+        'lsm' => 'saamia',
         'lt' => 'lituà',
         'lu' => 'luba katanga',
         'lua' => 'luba-lulua',
@@ -326,6 +342,7 @@ return [
         'mn' => 'mongol',
         'mnc' => 'manxú',
         'mni' => 'manipurí',
+        'moe' => 'innu-aimun',
         'moh' => 'mohawk',
         'mos' => 'moore',
         'mr' => 'marathi',
@@ -373,6 +390,11 @@ return [
         'nzi' => 'nzema',
         'oc' => 'occità',
         'oj' => 'ojibwa',
+        'ojb' => 'ojibwa septentrional',
+        'ojc' => 'ojibwa central',
+        'ojs' => 'oji-cree',
+        'ojw' => 'ojibwa occidental',
+        'oka' => 'okanagà',
         'om' => 'oromo',
         'or' => 'oriya',
         'os' => 'osseta',
@@ -391,10 +413,12 @@ return [
         'pfl' => 'alemany palatí',
         'phn' => 'fenici',
         'pi' => 'pali',
+        'pis' => 'pidgin',
         'pl' => 'polonès',
         'pms' => 'piemontès',
         'pnt' => 'pòntic',
         'pon' => 'ponapeà',
+        'pqm' => 'maliseet-passamaquoddy',
         'prg' => 'prussià',
         'pro' => 'provençal antic',
         'ps' => 'paixtu',
@@ -445,6 +469,7 @@ return [
         'sid' => 'sidamo',
         'sk' => 'eslovac',
         'sl' => 'eslovè',
+        'slh' => 'lushootseed meridional',
         'sm' => 'samoà',
         'sma' => 'sami meridional',
         'smj' => 'sami lule',
@@ -461,6 +486,7 @@ return [
         'ss' => 'swazi',
         'ssy' => 'saho',
         'st' => 'sotho meridional',
+        'str' => 'straits salish',
         'su' => 'sondanès',
         'suk' => 'sukuma',
         'sus' => 'susú',
@@ -472,13 +498,16 @@ return [
         'syr' => 'siríac',
         'szl' => 'silesià',
         'ta' => 'tàmil',
+        'tce' => 'tutxone meridional',
         'te' => 'telugu',
         'tem' => 'temne',
         'teo' => 'teso',
         'ter' => 'terena',
         'tet' => 'tètum',
         'tg' => 'tadjik',
+        'tgx' => 'tagish',
         'th' => 'tai',
+        'tht' => 'tahltà',
         'ti' => 'tigrinya',
         'tig' => 'tigre',
         'tiv' => 'tiv',
@@ -493,12 +522,14 @@ return [
         'tn' => 'setswana',
         'to' => 'tongalès',
         'tog' => 'tonga',
+        'tok' => 'toki pona',
         'tpi' => 'tok pisin',
         'tr' => 'turc',
         'trv' => 'taroko',
         'ts' => 'tsonga',
         'tsi' => 'tsimshià',
         'tt' => 'tàtar',
+        'ttm' => 'tutxone septentrional',
         'ttt' => 'tat meridional',
         'tum' => 'tumbuka',
         'tvl' => 'tuvaluà',
@@ -541,6 +572,7 @@ return [
         'ybb' => 'yemba',
         'yi' => 'ídix',
         'yo' => 'ioruba',
+        'yrl' => 'nheengatú',
         'yue' => 'cantonès',
         'za' => 'zhuang',
         'zap' => 'zapoteca',
