@@ -23,6 +23,7 @@ return [
         'am' => 'Amharisch',
         'an' => 'Aragonesisch',
         'ang' => 'Altenglisch',
+        'ann' => 'Obolo',
         'anp' => 'Angika',
         'ar' => 'Arabisch',
         'arc' => 'Aramäisch',
@@ -38,6 +39,7 @@ return [
         'asa' => 'Asu',
         'ase' => 'Amerikanische Gebärdensprache',
         'ast' => 'Asturisch',
+        'atj' => 'Atikamekw',
         'av' => 'Awarisch',
         'avk' => 'Kotava',
         'awa' => 'Awadhi',
@@ -103,14 +105,22 @@ return [
         'chr' => 'Cherokee',
         'chy' => 'Cheyenne',
         'ckb' => 'Zentralkurdisch',
+        'clc' => 'Chilcotin',
         'co' => 'Korsisch',
         'cop' => 'Koptisch',
         'cps' => 'Capiznon',
         'cr' => 'Cree',
+        'crg' => 'Michif',
         'crh' => 'Krimtatarisch',
+        'crj' => 'Südost-Cree',
+        'crk' => 'Plains-Cree',
+        'crl' => 'Northern East Cree',
+        'crm' => 'Moose Cree',
+        'crr' => 'Carolina-Algonkin',
         'crs' => 'Seychellenkreol',
         'cs' => 'Tschechisch',
         'csb' => 'Kaschubisch',
+        'csw' => 'Swampy Cree',
         'cu' => 'Kirchenslawisch',
         'cv' => 'Tschuwaschisch',
         'cy' => 'Walisisch',
@@ -202,6 +212,7 @@ return [
         'hai' => 'Haida',
         'hak' => 'Hakka',
         'haw' => 'Hawaiisch',
+        'hax' => 'Süd-Haida',
         'he' => 'Hebräisch',
         'hi' => 'Hindi',
         'hif' => 'Fidschi-Hindi',
@@ -215,6 +226,7 @@ return [
         'ht' => 'Haiti-Kreolisch',
         'hu' => 'Ungarisch',
         'hup' => 'Hupa',
+        'hur' => 'Halkomelem',
         'hy' => 'Armenisch',
         'hz' => 'Herero',
         'ia' => 'Interlingua',
@@ -225,6 +237,7 @@ return [
         'ig' => 'Igbo',
         'ii' => 'Yi',
         'ik' => 'Inupiak',
+        'ikt' => 'Westkanadisches Inuktitut',
         'ilo' => 'Ilokano',
         'inh' => 'Inguschisch',
         'io' => 'Ido',
@@ -291,6 +304,7 @@ return [
         'kut' => 'Kutenai',
         'kv' => 'Komi',
         'kw' => 'Kornisch',
+        'kwk' => 'Kwakʼwala',
         'ky' => 'Kirgisisch',
         'la' => 'Latein',
         'lad' => 'Ladino',
@@ -303,6 +317,7 @@ return [
         'lg' => 'Ganda',
         'li' => 'Limburgisch',
         'lij' => 'Ligurisch',
+        'lil' => 'Lillooet',
         'liv' => 'Livisch',
         'lkt' => 'Lakota',
         'lmo' => 'Lombardisch',
@@ -312,6 +327,7 @@ return [
         'lou' => 'Kreol (Louisiana)',
         'loz' => 'Lozi',
         'lrc' => 'Nördliches Luri',
+        'lsm' => 'Saamia',
         'lt' => 'Litauisch',
         'ltg' => 'Lettgallisch',
         'lu' => 'Luba-Katanga',
@@ -350,6 +366,7 @@ return [
         'mn' => 'Mongolisch',
         'mnc' => 'Mandschurisch',
         'mni' => 'Meithei',
+        'moe' => 'Innu-Aimun',
         'moh' => 'Mohawk',
         'mos' => 'Mossi',
         'mr' => 'Marathi',
@@ -399,6 +416,11 @@ return [
         'nzi' => 'Nzima',
         'oc' => 'Okzitanisch',
         'oj' => 'Ojibwa',
+        'ojb' => 'Nordwest-Ojibwe',
+        'ojc' => 'Zentral-Ojibwe',
+        'ojs' => 'Oji-Cree',
+        'ojw' => 'West-Ojibwe',
+        'oka' => 'Okanagan',
         'om' => 'Oromo',
         'or' => 'Oriya',
         'os' => 'Ossetisch',
@@ -418,10 +440,12 @@ return [
         'pfl' => 'Pfälzisch',
         'phn' => 'Phönizisch',
         'pi' => 'Pali',
+        'pis' => 'Pijin',
         'pl' => 'Polnisch',
         'pms' => 'Piemontesisch',
         'pnt' => 'Pontisch',
         'pon' => 'Ponapeanisch',
+        'pqm' => 'Maliseet-Passamaquoddy',
         'prg' => 'Altpreußisch',
         'pro' => 'Altprovenzalisch',
         'ps' => 'Paschtu',
@@ -480,6 +504,7 @@ return [
         'sid' => 'Sidamo',
         'sk' => 'Slowakisch',
         'sl' => 'Slowenisch',
+        'slh' => 'Süd-Lushootseed',
         'sli' => 'Schlesisch (Niederschlesisch)',
         'sly' => 'Selayar',
         'sm' => 'Samoanisch',
@@ -499,6 +524,7 @@ return [
         'ssy' => 'Saho',
         'st' => 'Süd-Sotho',
         'stq' => 'Saterfriesisch',
+        'str' => 'Straits Salish',
         'su' => 'Sundanesisch',
         'suk' => 'Sukuma',
         'sus' => 'Susu',
@@ -510,6 +536,7 @@ return [
         'syr' => 'Syrisch',
         'szl' => 'Schlesisch (Wasserpolnisch)',
         'ta' => 'Tamil',
+        'tce' => 'Südliches Tutchone',
         'tcy' => 'Tulu',
         'te' => 'Telugu',
         'tem' => 'Temne',
@@ -517,7 +544,9 @@ return [
         'ter' => 'Tereno',
         'tet' => 'Tetum',
         'tg' => 'Tadschikisch',
+        'tgx' => 'Tagish',
         'th' => 'Thailändisch',
+        'tht' => 'Tahltan',
         'ti' => 'Tigrinya',
         'tig' => 'Tigre',
         'tiv' => 'Tiv',
@@ -532,6 +561,7 @@ return [
         'tn' => 'Tswana',
         'to' => 'Tongaisch',
         'tog' => 'Nyasa Tonga',
+        'tok' => 'Toki Pona',
         'tpi' => 'Neumelanesisch',
         'tr' => 'Türkisch',
         'tru' => 'Turoyo',
@@ -540,6 +570,7 @@ return [
         'tsd' => 'Tsakonisch',
         'tsi' => 'Tsimshian',
         'tt' => 'Tatarisch',
+        'ttm' => 'Nördliches Tutchone',
         'ttt' => 'Tatisch',
         'tum' => 'Tumbuka',
         'tvl' => 'Tuvaluisch',
