@@ -20,6 +20,7 @@ return [
         'am' => 'Αμχαρικά',
         'an' => 'Αραγονικά',
         'ang' => 'Παλαιά Αγγλικά',
+        'ann' => 'Ομπόλο',
         'anp' => 'Ανγκικά',
         'ar' => 'Αραβικά',
         'arc' => 'Αραμαϊκά',
@@ -30,6 +31,7 @@ return [
         'as' => 'Ασαμικά',
         'asa' => 'Άσου',
         'ast' => 'Αστουριανά',
+        'atj' => 'Ατικαμέκ',
         'av' => 'Αβαρικά',
         'awa' => 'Αγουαντί',
         'ay' => 'Αϊμάρα',
@@ -86,13 +88,21 @@ return [
         'chr' => 'Τσερόκι',
         'chy' => 'Τσεγιέν',
         'ckb' => 'Κεντρικά Κουρδικά',
+        'clc' => 'Τσιλκότιν',
         'co' => 'Κορσικανικά',
         'cop' => 'Κοπτικά',
         'cr' => 'Κρι',
+        'crg' => 'Μίτσιφ',
         'crh' => 'Τουρκικά Κριμαίας',
+        'crj' => 'Νοτιοανατολικά Κρι',
+        'crk' => 'Κρι πεδιάδας',
+        'crl' => 'Βορειοανατολικά Κρι',
+        'crm' => 'Μους Κρι',
+        'crr' => 'Καρολίνα Αλγκονκιάν',
         'crs' => 'Κρεολικά Γαλλικά Σεϋχελλών',
         'cs' => 'Τσεχικά',
         'csb' => 'Κασούμπιαν',
+        'csw' => 'Κρι Βάλτου',
         'cu' => 'Εκκλησιαστικά Σλαβικά',
         'cv' => 'Τσουβασικά',
         'cy' => 'Ουαλικά',
@@ -171,6 +181,7 @@ return [
         'ha' => 'Χάουσα',
         'hai' => 'Χάιντα',
         'haw' => 'Χαβαϊκά',
+        'hax' => 'Βόρεια Χάιντα',
         'he' => 'Εβραϊκά',
         'hi' => 'Χίντι',
         'hil' => 'Χιλιγκαϊνόν',
@@ -182,6 +193,7 @@ return [
         'ht' => 'Αϊτιανά',
         'hu' => 'Ουγγρικά',
         'hup' => 'Χούπα',
+        'hur' => 'Χαλκομελέμ',
         'hy' => 'Αρμενικά',
         'hz' => 'Χερέρο',
         'ia' => 'Ιντερλίνγκουα',
@@ -192,6 +204,7 @@ return [
         'ig' => 'Ίγκμπο',
         'ii' => 'Σίτσουαν Γι',
         'ik' => 'Ινουπιάκ',
+        'ikt' => 'Ινουκτιτούτ Δυτικού Καναδά',
         'ilo' => 'Ιλόκο',
         'inh' => 'Ινγκούς',
         'io' => 'Ίντο',
@@ -219,6 +232,7 @@ return [
         'kea' => 'Γλώσσα του Πράσινου Ακρωτηρίου',
         'kfo' => 'Κόρο',
         'kg' => 'Κονγκό',
+        'kgp' => 'Κάινγκανγκ',
         'kha' => 'Κάσι',
         'kho' => 'Κοτανικά',
         'khq' => 'Κόιρα Τσίνι',
@@ -249,6 +263,7 @@ return [
         'kut' => 'Κουτενάι',
         'kv' => 'Κόμι',
         'kw' => 'Κορνουαλικά',
+        'kwk' => 'Κουακουάλα',
         'ky' => 'Κιργιζικά',
         'la' => 'Λατινικά',
         'lad' => 'Λαδίνο',
@@ -259,6 +274,7 @@ return [
         'lez' => 'Λεζγκικά',
         'lg' => 'Γκάντα',
         'li' => 'Λιμβουργιανά',
+        'lil' => 'Λιλουέτ',
         'lkt' => 'Λακότα',
         'ln' => 'Λινγκάλα',
         'lo' => 'Λαοτινά',
@@ -266,6 +282,7 @@ return [
         'lou' => 'Κρεολικά (Λουιζιάνα)',
         'loz' => 'Λόζι',
         'lrc' => 'Βόρεια Λούρι',
+        'lsm' => 'Σαάμια',
         'lt' => 'Λιθουανικά',
         'lu' => 'Λούμπα-Κατάνγκα',
         'lua' => 'Λούμπα-Λουλούα',
@@ -301,6 +318,7 @@ return [
         'mn' => 'Μογγολικά',
         'mnc' => 'Μαντσού',
         'mni' => 'Μανιπούρι',
+        'moe' => 'Ινου-αϊμούν',
         'moh' => 'Μοχόκ',
         'mos' => 'Μόσι',
         'mr' => 'Μαραθικά',
@@ -345,6 +363,11 @@ return [
         'nzi' => 'Νζίμα',
         'oc' => 'Οξιτανικά',
         'oj' => 'Οζιβίγουα',
+        'ojb' => 'Βορειοδυτικά Οζιβίγουα',
+        'ojc' => 'Κεντρικά Οτζίμπουα',
+        'ojs' => 'Ότζι-Κρι',
+        'ojw' => 'Δυτικά Οζιβίγουα',
+        'oka' => 'Οκανάγκαν',
         'om' => 'Ορόμο',
         'or' => 'Όντια',
         'os' => 'Οσετικά',
@@ -360,8 +383,10 @@ return [
         'peo' => 'Αρχαία Περσικά',
         'phn' => 'Φοινικικά',
         'pi' => 'Πάλι',
+        'pis' => 'Πιτζίν',
         'pl' => 'Πολωνικά',
         'pon' => 'Πομπηικά',
+        'pqm' => 'Μαλισιτ-Πασσαμακουόντ',
         'prg' => 'Πρωσικά',
         'pro' => 'Παλαιά Προβανσάλ',
         'ps' => 'Πάστο',
@@ -410,6 +435,7 @@ return [
         'sid' => 'Σιντάμο',
         'sk' => 'Σλοβακικά',
         'sl' => 'Σλοβενικά',
+        'slh' => 'Νότια Λάσουτσιντ',
         'sm' => 'Σαμοανά',
         'sma' => 'Νότια Σάμι',
         'smj' => 'Λούλε Σάμι',
@@ -426,6 +452,7 @@ return [
         'ss' => 'Σουάτι',
         'ssy' => 'Σάχο',
         'st' => 'Νότια Σόθο',
+        'str' => 'Στρέιτς Σαλίς',
         'su' => 'Σουνδανικά',
         'suk' => 'Σουκούμα',
         'sus' => 'Σούσου',
@@ -436,13 +463,16 @@ return [
         'syc' => 'Κλασικά Συριακά',
         'syr' => 'Συριακά',
         'ta' => 'Ταμιλικά',
+        'tce' => 'Νότια Τουτσόνε',
         'te' => 'Τελούγκου',
         'tem' => 'Τίμνε',
         'teo' => 'Τέσο',
         'ter' => 'Τερένο',
         'tet' => 'Τέτουμ',
         'tg' => 'Τατζικικά',
+        'tgx' => 'Τατζίς',
         'th' => 'Ταϊλανδικά',
+        'tht' => 'Ταλτάν',
         'ti' => 'Τιγκρινικά',
         'tig' => 'Τίγκρε',
         'tiv' => 'Τιβ',
@@ -455,12 +485,14 @@ return [
         'tn' => 'Τσουάνα',
         'to' => 'Τονγκανικά',
         'tog' => 'Νιάσα Τόνγκα',
+        'tok' => 'Τόκι Πόνα',
         'tpi' => 'Τοκ Πισίν',
         'tr' => 'Τουρκικά',
         'trv' => 'Ταρόκο',
         'ts' => 'Τσόνγκα',
         'tsi' => 'Τσίμσιαν',
         'tt' => 'Ταταρικά',
+        'ttm' => 'Βόρεια Τουτσόνε',
         'tum' => 'Τουμπούκα',
         'tvl' => 'Τουβαλού',
         'tw' => 'Τούι',
@@ -498,6 +530,7 @@ return [
         'ybb' => 'Γιέμπα',
         'yi' => 'Γίντις',
         'yo' => 'Γιορούμπα',
+        'yrl' => 'Νινγκατού',
         'yue' => 'Καντονέζικα',
         'za' => 'Ζουάνγκ',
         'zap' => 'Ζάποτεκ',
@@ -523,6 +556,7 @@ return [
         'fa_AF' => 'Νταρί',
         'fr_CA' => 'Γαλλικά Καναδά',
         'fr_CH' => 'Γαλλικά Ελβετίας',
+        'hi_Latn' => 'Χίντι (Λατινικό)',
         'nds_NL' => 'Κάτω Γερμανικά Ολλανδίας',
         'nl_BE' => 'Φλαμανδικά',
         'pt_BR' => 'Πορτογαλικά Βραζιλίας',
