@@ -23,6 +23,7 @@ return [
         'am' => 'amhara',
         'an' => 'aragoni',
         'ang' => 'vanainglise',
+        'ann' => 'obolo',
         'anp' => 'angika',
         'ar' => 'araabia',
         'arc' => 'aramea',
@@ -30,6 +31,7 @@ return [
         'aro' => 'araona',
         'arp' => 'arapaho',
         'arq' => 'Alžeeria araabia',
+        'ars' => 'Najdi araabia',
         'arw' => 'aravaki',
         'ary' => 'Maroko araabia',
         'arz' => 'Egiptuse araabia',
@@ -37,6 +39,7 @@ return [
         'asa' => 'asu',
         'ase' => 'Ameerika viipekeel',
         'ast' => 'astuuria',
+        'atj' => 'atikameki',
         'av' => 'avaari',
         'awa' => 'avadhi',
         'ay' => 'aimara',
@@ -101,14 +104,22 @@ return [
         'chr' => 'tšerokii',
         'chy' => 'šaieeni',
         'ckb' => 'sorani',
+        'clc' => 'tšilkotini',
         'co' => 'korsika',
         'cop' => 'kopti',
         'cps' => 'kapisnoni',
         'cr' => 'krii',
+        'crg' => 'michifi',
         'crh' => 'krimmitatari',
+        'crj' => 'lõuna-idakrii',
+        'crk' => 'tasandikukrii',
+        'crl' => 'põhja-idakrii',
+        'crm' => 'põdrakrii',
+        'crr' => 'Carolina algonkini',
         'crs' => 'seišelli',
         'cs' => 'tšehhi',
         'csb' => 'kašuubi',
+        'csw' => 'sookrii',
         'cu' => 'kirikuslaavi',
         'cv' => 'tšuvaši',
         'cy' => 'kõmri',
@@ -169,6 +180,7 @@ return [
         'fur' => 'friuuli',
         'fy' => 'läänefriisi',
         'ga' => 'iiri',
+        'gaa' => 'gaa',
         'gag' => 'gagauusi',
         'gan' => 'kani',
         'gay' => 'gajo',
@@ -197,6 +209,7 @@ return [
         'hai' => 'haida',
         'hak' => 'hakka',
         'haw' => 'havai',
+        'hax' => 'lõunahaida',
         'he' => 'heebrea',
         'hi' => 'hindi',
         'hif' => 'Fidži hindi',
@@ -210,6 +223,7 @@ return [
         'ht' => 'haiti',
         'hu' => 'ungari',
         'hup' => 'hupa',
+        'hur' => 'halkomelemi',
         'hy' => 'armeenia',
         'hz' => 'herero',
         'ia' => 'interlingua',
@@ -220,6 +234,7 @@ return [
         'ig' => 'ibo',
         'ii' => 'nuosu',
         'ik' => 'injupiaki',
+        'ikt' => 'Lääne-Kanada inuktituti',
         'ilo' => 'iloko',
         'inh' => 'inguši',
         'io' => 'ido',
@@ -285,6 +300,7 @@ return [
         'kut' => 'kutenai',
         'kv' => 'komi',
         'kw' => 'korni',
+        'kwk' => 'kvakvala',
         'ky' => 'kirgiisi',
         'la' => 'ladina',
         'lad' => 'ladiino',
@@ -296,6 +312,7 @@ return [
         'lg' => 'ganda',
         'li' => 'limburgi',
         'lij' => 'liguuri',
+        'lil' => 'lillueti',
         'liv' => 'liivi',
         'lkt' => 'lakota',
         'lmo' => 'lombardi',
@@ -305,6 +322,7 @@ return [
         'lou' => 'Louisiana kreoolkeel',
         'loz' => 'lozi',
         'lrc' => 'põhjaluri',
+        'lsm' => 'samia',
         'lt' => 'leedu',
         'ltg' => 'latgali',
         'lu' => 'Katanga luba',
@@ -343,6 +361,7 @@ return [
         'mn' => 'mongoli',
         'mnc' => 'mandžu',
         'mni' => 'manipuri',
+        'moe' => 'innu',
         'moh' => 'mohoogi',
         'mos' => 'more',
         'mr' => 'marathi',
@@ -392,6 +411,11 @@ return [
         'nzi' => 'nzima',
         'oc' => 'oksitaani',
         'oj' => 'odžibvei',
+        'ojb' => 'loodeodžibvei',
+        'ojc' => 'keskodžibvei',
+        'ojs' => 'Severni odžibvei',
+        'ojw' => 'lääneodžibvei',
+        'oka' => 'okanagani',
         'om' => 'oromo',
         'or' => 'oria',
         'os' => 'osseedi',
@@ -411,10 +435,12 @@ return [
         'pfl' => 'Pfalzi',
         'phn' => 'foiniikia',
         'pi' => 'paali',
+        'pis' => 'pijini',
         'pl' => 'poola',
         'pms' => 'piemonte',
         'pnt' => 'pontose',
         'pon' => 'poonpei',
+        'pqm' => 'passamakodi',
         'prg' => 'preisi',
         'pro' => 'vanaprovansi',
         'ps' => 'puštu',
@@ -471,6 +497,7 @@ return [
         'sid' => 'sidamo',
         'sk' => 'slovaki',
         'sl' => 'sloveeni',
+        'slh' => 'Lõuna-Puget-Soundi sališi',
         'sli' => 'alamsileesia',
         'sly' => 'selajari',
         'sm' => 'samoa',
@@ -490,6 +517,7 @@ return [
         'ssy' => 'saho',
         'st' => 'lõunasotho',
         'stq' => 'saterfriisi',
+        'str' => 'väinasališi',
         'su' => 'sunda',
         'suk' => 'sukuma',
         'sus' => 'susu',
@@ -501,6 +529,7 @@ return [
         'syr' => 'süüria',
         'szl' => 'sileesia',
         'ta' => 'tamili',
+        'tce' => 'lõunatutšoni',
         'tcy' => 'tulu',
         'te' => 'telugu',
         'tem' => 'temne',
@@ -508,7 +537,9 @@ return [
         'ter' => 'tereno',
         'tet' => 'tetumi',
         'tg' => 'tadžiki',
+        'tgx' => 'tagishi',
         'th' => 'tai',
+        'tht' => 'tahltani',
         'ti' => 'tigrinja',
         'tig' => 'tigree',
         'tiv' => 'tivi',
@@ -523,6 +554,7 @@ return [
         'tn' => 'tsvana',
         'to' => 'tonga',
         'tog' => 'tšitonga',
+        'tok' => 'toki pona',
         'tpi' => 'uusmelaneesia',
         'tr' => 'türgi',
         'tru' => 'turojo',
@@ -531,6 +563,7 @@ return [
         'tsd' => 'tsakoonia',
         'tsi' => 'tsimši',
         'tt' => 'tatari',
+        'ttm' => 'põhjatutšoni',
         'ttt' => 'lõunataadi',
         'tum' => 'tumbuka',
         'tvl' => 'tuvalu',
