@@ -23,6 +23,7 @@ return [
         'am' => 'Amtharais',
         'an' => 'Aragonais',
         'ang' => 'Seann-Bheurla',
+        'ann' => 'Obolo',
         'anp' => 'Angika',
         'ar' => 'Arabais',
         'arc' => 'Aramais',
@@ -30,6 +31,7 @@ return [
         'aro' => 'Araona',
         'arp' => 'Arapaho',
         'arq' => 'Arabais Aildireach',
+        'ars' => 'Arabais Najdi',
         'arw' => 'Arawak',
         'ary' => 'Arabais Mhorocach',
         'arz' => 'Arabais Èipheiteach',
@@ -37,6 +39,7 @@ return [
         'asa' => 'Asu',
         'ase' => 'Cainnt-shanais na h-Aimeireaga',
         'ast' => 'Astùrais',
+        'atj' => 'Atikamekw',
         'av' => 'Avarais',
         'avk' => 'Kotava',
         'awa' => 'Awadhi',
@@ -101,14 +104,22 @@ return [
         'chr' => 'Cherokee',
         'chy' => 'Cheyenne',
         'ckb' => 'Cùrdais Mheadhanach',
+        'clc' => 'Chilcotin',
         'co' => 'Corsais',
         'cop' => 'Coptais',
         'cps' => 'Capiznon',
         'cr' => 'Cree',
+        'crg' => 'Michif',
         'crh' => 'Turcais Chriomach',
+        'crj' => 'Cree Ear-dheasach',
+        'crk' => 'Cree nam Machair',
+        'crl' => 'Cree Ear-thuathach',
+        'crm' => 'Moose Cree',
+        'crr' => 'Algonquianais Charolina',
         'crs' => 'Seiseallais',
         'cs' => 'Seicis',
         'csb' => 'Caisiubais',
+        'csw' => 'Omushkego',
         'cu' => 'Slàbhais na h-Eaglaise',
         'cv' => 'Chuvash',
         'cy' => 'Cuimris',
@@ -199,6 +210,7 @@ return [
         'hai' => 'Haida',
         'hak' => 'Hakka',
         'haw' => 'Cànan Hawai’i',
+        'hax' => 'Haida Dheasach',
         'he' => 'Eabhra',
         'hi' => 'Hindis',
         'hif' => 'Hindis Fhìditheach',
@@ -212,6 +224,7 @@ return [
         'ht' => 'Crìtheol Haidhti',
         'hu' => 'Ungairis',
         'hup' => 'Hupa',
+        'hur' => 'Halkomelem',
         'hy' => 'Airmeinis',
         'hz' => 'Herero',
         'ia' => 'Interlingua',
@@ -222,6 +235,7 @@ return [
         'ig' => 'Igbo',
         'ii' => 'Yi Sichuan',
         'ik' => 'Inupiaq',
+        'ikt' => 'Inuktitut Shiarach Chanada',
         'ilo' => 'Iloko',
         'inh' => 'Ingush',
         'io' => 'Ido',
@@ -285,6 +299,7 @@ return [
         'kut' => 'Kutenai',
         'kv' => 'Komi',
         'kw' => 'Còrnais',
+        'kwk' => 'Kwakʼwala',
         'ky' => 'Cìorgasais',
         'la' => 'Laideann',
         'lad' => 'Ladino',
@@ -297,6 +312,7 @@ return [
         'lg' => 'Ganda',
         'li' => 'Cànan Limburg',
         'lij' => 'Liogùrais',
+        'lil' => 'Lillooet',
         'lkt' => 'Lakhóta',
         'lmo' => 'Lombardais',
         'ln' => 'Lingala',
@@ -305,6 +321,7 @@ return [
         'lou' => 'Crìtheol Louisiana',
         'loz' => 'Lozi',
         'lrc' => 'Luri Thuathach',
+        'lsm' => 'Saamia',
         'lt' => 'Liotuainis',
         'lu' => 'Luba-Katanga',
         'lua' => 'Luba-Lulua',
@@ -342,6 +359,7 @@ return [
         'mn' => 'Mongolais',
         'mnc' => 'Manchu',
         'mni' => 'Manipuri',
+        'moe' => 'Innu-aimun',
         'moh' => 'Mohawk',
         'mos' => 'Mossi',
         'mr' => 'Marathi',
@@ -391,6 +409,11 @@ return [
         'nzi' => 'Nzima',
         'oc' => 'Ogsatanais',
         'oj' => 'Ojibwa',
+        'ojb' => 'Ojibwa Iar-thuathach',
+        'ojc' => 'Ojibwa Mheadhanach',
+        'ojs' => 'Oji-Cree',
+        'ojw' => 'Ojibwa Shiarach',
+        'oka' => 'Okanagan',
         'om' => 'Oromo',
         'or' => 'Odia',
         'os' => 'Ossetic',
@@ -409,9 +432,11 @@ return [
         'peo' => 'Seann-Pheirsis',
         'phn' => 'Phenicis',
         'pi' => 'Pali',
+        'pis' => 'Pijin',
         'pl' => 'Pòlainnis',
         'pms' => 'Piedmontese',
         'pon' => 'Cànan Pohnpei',
+        'pqm' => 'Maliseet-Passamaquoddy',
         'prg' => 'Pruisis',
         'pro' => 'Seann-Phrovençal',
         'ps' => 'Pashto',
@@ -467,6 +492,7 @@ return [
         'sid' => 'Sidamo',
         'sk' => 'Slòbhacais',
         'sl' => 'Slòbhainis',
+        'slh' => 'Lushootseed Dheasach',
         'sly' => 'Selayar',
         'sm' => 'Samothais',
         'sma' => 'Sàmais Dheasach',
@@ -483,6 +509,7 @@ return [
         'ss' => 'Swati',
         'ssy' => 'Saho',
         'st' => 'Sesotho',
+        'str' => 'Salish a’ Chaolais',
         'su' => 'Cànan Sunda',
         'suk' => 'Sukuma',
         'sus' => 'Susu',
@@ -493,6 +520,7 @@ return [
         'syc' => 'Suraidheac Chlasaigeach',
         'syr' => 'Suraidheac',
         'ta' => 'Taimilis',
+        'tce' => 'Tutchone Dheasach',
         'tcy' => 'Tulu',
         'te' => 'Telugu',
         'tem' => 'Timne',
@@ -500,7 +528,9 @@ return [
         'ter' => 'Terêna',
         'tet' => 'Tetum',
         'tg' => 'Taidigis',
+        'tgx' => 'Tagish',
         'th' => 'Cànan nan Tàidh',
+        'tht' => 'Tahltan',
         'ti' => 'Tigrinya',
         'tig' => 'Tigre',
         'tiv' => 'Tiv',
@@ -515,6 +545,7 @@ return [
         'tn' => 'Tswana',
         'to' => 'Tonga',
         'tog' => 'Nyasa Tonga',
+        'tok' => 'Toki Pona',
         'tpi' => 'Tok Pisin',
         'tr' => 'Turcais',
         'tru' => 'Turoyo',
@@ -522,6 +553,7 @@ return [
         'ts' => 'Tsonga',
         'tsi' => 'Tsimshian',
         'tt' => 'Tatarais',
+        'ttm' => 'Tutchone Thuathach',
         'ttt' => 'Tati',
         'tum' => 'Tumbuka',
         'tvl' => 'Tubhalu',
@@ -538,9 +570,10 @@ return [
         'uz' => 'Usbagais',
         'vai' => 'Vai',
         've' => 'Venda',
+        'vec' => 'Bheinisis',
         'vep' => 'Veps',
         'vi' => 'Bhiet-Namais',
-        'vls' => 'Flannrais Siarach',
+        'vls' => 'Flànrais Shiarach',
         'vo' => 'Volapük',
         'vro' => 'Võro',
         'vun' => 'Vunjo',
@@ -588,8 +621,9 @@ return [
         'fa_AF' => 'Dari',
         'fr_CA' => 'Fraingis Chanada',
         'fr_CH' => 'Fraingis Eilbheiseach',
+        'hi_Latn' => 'Hindis (Laideann)',
         'nds_NL' => 'Sagsannais Ìochdarach',
-        'nl_BE' => 'Flannrais',
+        'nl_BE' => 'Flànrais',
         'pt_BR' => 'Portagailis Bhraisileach',
         'pt_PT' => 'Portagailis Eòrpach',
         'ro_MD' => 'Moldobhais',
