@@ -268,6 +268,7 @@ return [
         'li' => 'लिंबर्गिश',
         'lil' => 'लिलोएट',
         'lkt' => 'लैकोटा',
+        'lmo' => 'लॉमबर्ड',
         'ln' => 'लिंगाला',
         'lo' => 'लाओ',
         'lol' => 'मोंगो',
@@ -544,6 +545,7 @@ return [
         'fa_AF' => 'दारी',
         'fr_CA' => 'कनाडाई फ़्रेंच',
         'fr_CH' => 'स्विस फ़्रेंच',
+        'hi_Latn' => 'हिन्दी (लैटिन)',
         'nds_NL' => 'निचली सैक्सन',
         'nl_BE' => 'फ़्लेमिश',
         'pt_BR' => 'ब्राज़ीली पुर्तगाली',
