@@ -19,17 +19,20 @@ return [
         'am' => 'ամհարերեն',
         'an' => 'արագոներեն',
         'ang' => 'հին անգլերեն',
+        'ann' => 'օբոլո',
         'anp' => 'անգիկա',
         'ar' => 'արաբերեն',
         'arc' => 'արամեերեն',
         'arn' => 'մապուչի',
         'arp' => 'արապահո',
         'arq' => 'ալժիրական արաբերեն',
+        'ars' => 'նեջդի արաբերեն',
         'arz' => 'եգիպտական արաբերեն',
         'as' => 'ասամերեն',
         'asa' => 'ասու',
         'ase' => 'ամերիկյան ժեստերի լեզու',
         'ast' => 'աստուրերեն',
+        'atj' => 'աթիկամեկ',
         'av' => 'ավարերեն',
         'awa' => 'ավադհի',
         'ay' => 'այմարա',
@@ -56,6 +59,7 @@ return [
         'bug' => 'բուգիերեն',
         'byn' => 'բիլին',
         'ca' => 'կատալաներեն',
+        'cay' => 'կայուգա',
         'ccp' => 'չակմա',
         'ce' => 'չեչեներեն',
         'ceb' => 'սեբուերեն',
@@ -64,14 +68,23 @@ return [
         'chk' => 'տրուկերեն',
         'chm' => 'մարի',
         'cho' => 'չոկտո',
+        'chp' => 'չիպևայան',
         'chr' => 'չերոկի',
         'chy' => 'շայեն',
         'ckb' => 'սորանի քրդերեն',
+        'clc' => 'չիլկոտիներեն',
         'co' => 'կորսիկերեն',
         'cop' => 'ղպտերեն',
+        'crg' => 'միչիֆ',
         'crh' => 'ղրիմյան թուրքերեն',
+        'crj' => 'հարավ-արևելյան քրի',
+        'crk' => 'հարթավայրերի քրի',
+        'crl' => 'հյուսիս-արևելյան քրի',
+        'crm' => 'մուզ քրի',
+        'crr' => 'կարոլինական ալգոնկիներեն',
         'crs' => 'սեյշելյան խառնակերտ ֆրանսերեն',
         'cs' => 'չեխերեն',
+        'csw' => 'ճահճի քրի',
         'cu' => 'սլավոներեն, եկեղեցական',
         'cv' => 'չուվաշերեն',
         'cy' => 'ուելսերեն',
@@ -85,7 +98,7 @@ return [
         'doi' => 'դոգրի',
         'dsb' => 'ստորին սորբերեն',
         'dua' => 'դուալա',
-        'dv' => 'մալդիվերեն',
+        'dv' => 'դիվեհի',
         'dyo' => 'ջոլա-ֆոնյի',
         'dz' => 'ջոնգքհա',
         'dzg' => 'դազագա',
@@ -110,7 +123,9 @@ return [
         'fo' => 'ֆարյորերեն',
         'fon' => 'ֆոն',
         'fr' => 'ֆրանսերեն',
+        'frc' => 'քաջունական ֆրանսերեն',
         'fro' => 'հին ֆրանսերեն',
+        'frr' => 'հյուսիսային ֆրիզերեն',
         'frs' => 'արևելաֆրիզերեն',
         'fur' => 'ֆրիուլիերեն',
         'fy' => 'արևմտաֆրիզերեն',
@@ -134,7 +149,9 @@ return [
         'gv' => 'մեներեն',
         'gwi' => 'գվիչին',
         'ha' => 'հաուսա',
+        'hai' => 'հայդա',
         'haw' => 'հավայիերեն',
+        'hax' => 'հարավային հայդա',
         'he' => 'եբրայերեն',
         'hi' => 'հինդի',
         'hil' => 'հիլիգայնոն',
@@ -145,6 +162,7 @@ return [
         'ht' => 'խառնակերտ հայիթերեն',
         'hu' => 'հունգարերեն',
         'hup' => 'հուպա',
+        'hur' => 'հալքոմելեմ',
         'hy' => 'հայերեն',
         'hz' => 'հերերո',
         'ia' => 'ինտերլինգուա',
@@ -154,6 +172,7 @@ return [
         'ie' => 'ինտերլինգուե',
         'ig' => 'իգբո',
         'ii' => 'սիչուան',
+        'ikt' => 'արևմտականադական ինուկտիտուտ',
         'ilo' => 'իլոկերեն',
         'inh' => 'ինգուշերեն',
         'io' => 'իդո',
@@ -175,6 +194,7 @@ return [
         'kde' => 'մակոնդե',
         'kea' => 'կաբուվերդերեն',
         'kfo' => 'կորո',
+        'kgp' => 'կաինգան',
         'kha' => 'քասիերեն',
         'khq' => 'կոյրա չինի',
         'ki' => 'կիկույու',
@@ -202,6 +222,7 @@ return [
         'kum' => 'կումիկերեն',
         'kv' => 'կոմիերեն',
         'kw' => 'կոռներեն',
+        'kwk' => 'կվակվալա',
         'ky' => 'ղրղզերեն',
         'la' => 'լատիներեն',
         'lad' => 'լադինո',
@@ -210,11 +231,14 @@ return [
         'lez' => 'լեզգիերեն',
         'lg' => 'գանդա',
         'li' => 'լիմբուրգերեն',
+        'lil' => 'լիլուետ',
         'lkt' => 'լակոտա',
         'ln' => 'լինգալա',
         'lo' => 'լաոսերեն',
+        'lou' => 'լուիզիանական կրեոլերեն',
         'loz' => 'լոզի',
         'lrc' => 'հյուսիսային լուրիերեն',
+        'lsm' => 'սաամերեն',
         'lt' => 'լիտվերեն',
         'lu' => 'լուբա-կատանգա',
         'lua' => 'լուբա-լուլուա',
@@ -243,6 +267,7 @@ return [
         'ml' => 'մալայալամ',
         'mn' => 'մոնղոլերեն',
         'mni' => 'մանիպուրի',
+        'moe' => 'իննու-այմուն',
         'moh' => 'մոհավք',
         'mos' => 'մոսսի',
         'mr' => 'մարաթի',
@@ -250,7 +275,7 @@ return [
         'ms' => 'մալայերեն',
         'mt' => 'մալթայերեն',
         'mua' => 'մունդանգ',
-        'mus' => 'կրիկ',
+        'mus' => 'մասքոջի',
         'mwl' => 'միրանդերեն',
         'my' => 'բիրմայերեն',
         'myv' => 'էրզյա',
@@ -282,6 +307,11 @@ return [
         'nyn' => 'նյանկոլե',
         'oc' => 'օքսիտաներեն',
         'oj' => 'օջիբվա',
+        'ojb' => 'հյուսիս-արևմտյան օջիբվե',
+        'ojc' => 'կենտրոնական օջիբվե',
+        'ojs' => 'օջի քրի',
+        'ojw' => 'արևմտյան օջիբվե',
+        'oka' => 'օկանագան',
         'om' => 'օրոմո',
         'or' => 'օրիյա',
         'os' => 'օսերեն',
@@ -294,17 +324,19 @@ return [
         'pap' => 'պապյամենտո',
         'pau' => 'պալաուերեն',
         'pcd' => 'պիկարդերեն',
-        'pcm' => 'նիգերյան կրեոլերեն',
+        'pcm' => 'նիգերիական փիջին',
         'pdc' => 'փենսիլվանական գերմաներեն',
         'pdt' => 'պլատագերմաներեն',
         'peo' => 'հին պարսկերեն',
         'pfl' => 'պալատինյան գերմաներեն',
         'phn' => 'փյունիկերեն',
         'pi' => 'պալի',
+        'pis' => 'փիջին',
         'pl' => 'լեհերեն',
         'pms' => 'պիեմոնտերեն',
         'pnt' => 'պոնտերեն',
         'pon' => 'պոնպեերեն',
+        'pqm' => 'մալեսիտ-պասամակվոդի',
         'prg' => 'պրուսերեն',
         'pro' => 'հին պրովանսերեն',
         'ps' => 'փուշթու',
@@ -315,7 +347,7 @@ return [
         'rap' => 'ռապանուի',
         'rar' => 'ռարոտոնգաներեն',
         'rgn' => 'ռոմանիոլերեն',
-        'rhg' => 'Ռոհինջա',
+        'rhg' => 'ռոհինջա',
         'rif' => 'ռիֆերեն',
         'rm' => 'ռոմանշերեն',
         'rn' => 'ռունդի',
@@ -352,6 +384,7 @@ return [
         'si' => 'սինհալերեն',
         'sk' => 'սլովակերեն',
         'sl' => 'սլովեներեն',
+        'slh' => 'հարավային լուշուցիդ',
         'sm' => 'սամոաերեն',
         'sma' => 'հարավային սաամի',
         'smj' => 'լուլե սաամի',
@@ -366,6 +399,7 @@ return [
         'ss' => 'սվազերեն',
         'ssy' => 'սահոերեն',
         'st' => 'հարավային սոթո',
+        'str' => 'սթրեյթս սալիշերեն',
         'su' => 'սունդաներեն',
         'suk' => 'սուկումա',
         'sv' => 'շվեդերեն',
@@ -373,6 +407,7 @@ return [
         'swb' => 'կոմորերեն',
         'syr' => 'ասորերեն',
         'ta' => 'թամիլերեն',
+        'tce' => 'հարավային թուտչոնե',
         'tcy' => 'տուլու',
         'te' => 'թելուգու',
         'tem' => 'տեմնե',
@@ -380,7 +415,9 @@ return [
         'ter' => 'տերենո',
         'tet' => 'տետում',
         'tg' => 'տաջիկերեն',
+        'tgx' => 'թագիշ',
         'th' => 'թայերեն',
+        'tht' => 'թալթան',
         'ti' => 'տիգրինյա',
         'tig' => 'տիգրե',
         'tiv' => 'տիվերեն',
@@ -394,6 +431,7 @@ return [
         'tmh' => 'տամաշեկ',
         'tn' => 'ցվանա',
         'to' => 'տոնգերեն',
+        'tok' => 'տոկիպոնա',
         'tpi' => 'տոկ փիսին',
         'tr' => 'թուրքերեն',
         'tru' => 'տուրոյո',
@@ -402,6 +440,7 @@ return [
         'tsd' => 'ցակոներեն',
         'tsi' => 'ցիմշյան',
         'tt' => 'թաթարերեն',
+        'ttm' => 'հյուսիսային թուտչոնե',
         'tum' => 'տումբուկա',
         'tvl' => 'թուվալուերեն',
         'tw' => 'տուի',
@@ -443,6 +482,7 @@ return [
         'ybb' => 'եմբա',
         'yi' => 'իդիշ',
         'yo' => 'յորուբա',
+        'yrl' => 'նինգաթու',
         'yue' => 'կանտոներեն',
         'za' => 'ժուանգ',
         'zap' => 'սապոտեկերեն',
@@ -468,6 +508,7 @@ return [
         'fa_AF' => 'դարի',
         'fr_CA' => 'կանադական ֆրանսերեն',
         'fr_CH' => 'շվեյցարական ֆրանսերեն',
+        'hi_Latn' => 'հինդի (լատինական)',
         'nds_NL' => 'ստորին սաքսոներեն',
         'nl_BE' => 'ֆլամանդերեն',
         'pt_BR' => 'բրազիլական պորտուգալերեն',
@@ -475,6 +516,6 @@ return [
         'ro_MD' => 'մոլդովերեն',
         'sw_CD' => 'կոնգոյի սուահիլի',
         'zh_Hans' => 'պարզեցված չինարեն',
-        'zh_Hant' => 'չինարեն, ավանդական',
+        'zh_Hant' => 'ավանդական չինարեն',
     ],
 ];
