@@ -14,8 +14,5 @@ return [
         'zh' => 'ꍏꇩꉙ',
     ],
     'LocalizedNames' => [
-        'pt_BR' => 'ꀠꑟꁍꄨꑸꉙ',
-        'zh_Hans' => 'ꈝꐯꍏꇩꉙ',
-        'zh_Hant' => 'ꀎꋏꍏꇩꉙ',
     ],
 ];
