@@ -23,6 +23,7 @@ return [
         'am' => 'amarico',
         'an' => 'aragonese',
         'ang' => 'inglese antico',
+        'ann' => 'obolo',
         'anp' => 'angika',
         'ar' => 'arabo',
         'arc' => 'aramaico',
@@ -38,6 +39,7 @@ return [
         'asa' => 'asu',
         'ase' => 'lingua dei segni americana',
         'ast' => 'asturiano',
+        'atj' => 'atikamekw',
         'av' => 'avaro',
         'avk' => 'kotava',
         'awa' => 'awadhi',
@@ -103,14 +105,22 @@ return [
         'chr' => 'cherokee',
         'chy' => 'cheyenne',
         'ckb' => 'curdo sorani',
+        'clc' => 'chilcotin',
         'co' => 'corso',
         'cop' => 'copto',
         'cps' => 'capiznon',
         'cr' => 'cree',
+        'crg' => 'métchif',
         'crh' => 'turco crimeo',
+        'crj' => 'cree sud-orientale',
+        'crk' => 'cree delle pianure',
+        'crl' => 'cree nord-orientale',
+        'crm' => 'cree moose',
+        'crr' => 'algonchino della Carolina',
         'crs' => 'creolo delle Seychelles',
         'cs' => 'ceco',
         'csb' => 'kashubian',
+        'csw' => 'cree delle paludi',
         'cu' => 'slavo ecclesiastico',
         'cv' => 'ciuvascio',
         'cy' => 'gallese',
@@ -201,6 +211,7 @@ return [
         'hai' => 'haida',
         'hak' => 'hakka',
         'haw' => 'hawaiano',
+        'hax' => 'haida meridionale',
         'he' => 'ebraico',
         'hi' => 'hindi',
         'hif' => 'hindi figiano',
@@ -214,6 +225,7 @@ return [
         'ht' => 'creolo haitiano',
         'hu' => 'ungherese',
         'hup' => 'hupa',
+        'hur' => 'halkomelem',
         'hy' => 'armeno',
         'hz' => 'herero',
         'ia' => 'interlingua',
@@ -224,6 +236,7 @@ return [
         'ig' => 'igbo',
         'ii' => 'sichuan yi',
         'ik' => 'inupiak',
+        'ikt' => 'inuktitut canadese occidentale',
         'ilo' => 'ilocano',
         'inh' => 'ingush',
         'io' => 'ido',
@@ -244,7 +257,7 @@ return [
         'kaa' => 'kara-kalpak',
         'kab' => 'cabilo',
         'kac' => 'kachin',
-        'kaj' => 'kai',
+        'kaj' => 'jju',
         'kam' => 'kamba',
         'kaw' => 'kawi',
         'kbd' => 'cabardino',
@@ -287,6 +300,7 @@ return [
         'kut' => 'kutenai',
         'kv' => 'komi',
         'kw' => 'cornico',
+        'kwk' => 'kwakʼwala',
         'ky' => 'kirghiso',
         'la' => 'latino',
         'lad' => 'giudeo-spagnolo',
@@ -299,6 +313,7 @@ return [
         'lg' => 'ganda',
         'li' => 'limburghese',
         'lij' => 'ligure',
+        'lil' => 'lillooet',
         'liv' => 'livone',
         'lkt' => 'lakota',
         'lmo' => 'lombardo',
@@ -308,6 +323,7 @@ return [
         'lou' => 'creolo della Louisiana',
         'loz' => 'lozi',
         'lrc' => 'luri settentrionale',
+        'lsm' => 'samia',
         'lt' => 'lituano',
         'ltg' => 'letgallo',
         'lu' => 'luba-katanga',
@@ -346,6 +362,7 @@ return [
         'mn' => 'mongolo',
         'mnc' => 'manchu',
         'mni' => 'manipuri',
+        'moe' => 'innu-aimun',
         'moh' => 'mohawk',
         'mos' => 'mossi',
         'mr' => 'marathi',
@@ -395,6 +412,11 @@ return [
         'nzi' => 'nzima',
         'oc' => 'occitano',
         'oj' => 'ojibwa',
+        'ojb' => 'ojibwe nord-occidentale',
+        'ojc' => 'ojibwe centrale',
+        'ojs' => 'oji-cree',
+        'ojw' => 'ojibwe occidentale',
+        'oka' => 'okanagan',
         'om' => 'oromo',
         'or' => 'odia',
         'os' => 'ossetico',
@@ -413,10 +435,12 @@ return [
         'pfl' => 'tedesco palatino',
         'phn' => 'fenicio',
         'pi' => 'pali',
+        'pis' => 'pijin',
         'pl' => 'polacco',
         'pms' => 'piemontese',
         'pnt' => 'pontico',
         'pon' => 'ponape',
+        'pqm' => 'malecite-passamaquoddy',
         'prg' => 'prussiano',
         'pro' => 'provenzale antico',
         'ps' => 'pashto',
@@ -475,6 +499,7 @@ return [
         'sid' => 'sidamo',
         'sk' => 'slovacco',
         'sl' => 'sloveno',
+        'slh' => 'lushootseed meridionale',
         'sli' => 'tedesco slesiano',
         'sly' => 'selayar',
         'sm' => 'samoano',
@@ -494,6 +519,7 @@ return [
         'ssy' => 'saho',
         'st' => 'sotho del sud',
         'stq' => 'saterfriesisch',
+        'str' => 'salish straits',
         'su' => 'sundanese',
         'suk' => 'sukuma',
         'sus' => 'susu',
@@ -505,6 +531,7 @@ return [
         'syr' => 'siriaco',
         'szl' => 'slesiano',
         'ta' => 'tamil',
+        'tce' => 'tutchone meridionale',
         'tcy' => 'tulu',
         'te' => 'telugu',
         'tem' => 'temne',
@@ -512,7 +539,9 @@ return [
         'ter' => 'tereno',
         'tet' => 'tetum',
         'tg' => 'tagico',
-        'th' => 'thai',
+        'tgx' => 'tagish',
+        'th' => 'thailandese',
+        'tht' => 'tahltan',
         'ti' => 'tigrino',
         'tig' => 'tigre',
         'tiv' => 'tiv',
@@ -527,6 +556,7 @@ return [
         'tn' => 'tswana',
         'to' => 'tongano',
         'tog' => 'nyasa del Tonga',
+        'tok' => 'toki pona',
         'tpi' => 'tok pisin',
         'tr' => 'turco',
         'tru' => 'turoyo',
@@ -535,6 +565,7 @@ return [
         'tsd' => 'zaconico',
         'tsi' => 'tsimshian',
         'tt' => 'tataro',
+        'ttm' => 'tutchone settentrionale',
         'ttt' => 'tat islamico',
         'tum' => 'tumbuka',
         'tvl' => 'tuvalu',
