@@ -19,15 +19,18 @@ return [
         'am' => 'ამჰარული',
         'an' => 'არაგონული',
         'ang' => 'ძველი ინგლისური',
+        'ann' => 'ობოლო',
         'anp' => 'ანგიკა',
         'ar' => 'არაბული',
         'arc' => 'არამეული',
         'arn' => 'მაპუდუნგუნი',
         'arp' => 'არაპაჰო',
+        'ars' => 'ნაჯის არაბული',
         'arw' => 'არავაკი',
         'as' => 'ასამური',
         'asa' => 'ასუ',
         'ast' => 'ასტურიული',
+        'atj' => 'ატიკამეკი',
         'av' => 'ხუნძური',
         'awa' => 'ავადი',
         'ay' => 'აიმარა',
@@ -73,13 +76,21 @@ return [
         'chr' => 'ჩეროკი',
         'chy' => 'ჩეიენი',
         'ckb' => 'ცენტრალური ქურთული',
+        'clc' => 'ჩილკოტინი',
         'co' => 'კორსიკული',
         'cop' => 'კოპტური',
         'cr' => 'კრი',
+        'crg' => 'მიჩიფი',
         'crh' => 'ყირიმულ-თურქული',
+        'crj' => 'სამხრეთ-აღმოსავლეთის კრი',
+        'crk' => 'დაბლობის კრი',
+        'crl' => 'ჩრდილო-აღმოსავლეთის კრი',
+        'crm' => 'მუსური კრი',
+        'crr' => 'კაროლინური ალგონკინი',
         'crs' => 'სესელვა-კრეოლური ფრანგული',
         'cs' => 'ჩეხური',
         'csb' => 'კაშუბური',
+        'csw' => 'ჭაობის კრი',
         'cu' => 'საეკლესიო სლავური',
         'cv' => 'ჩუვაშური',
         'cy' => 'უელსური',
@@ -123,6 +134,7 @@ return [
         'fo' => 'ფარერული',
         'fon' => 'ფონი',
         'fr' => 'ფრანგული',
+        'frc' => 'კაჟუნური ფრანგული',
         'frm' => 'საშუალო ფრანგული',
         'fro' => 'ძველი ფრანგული',
         'frr' => 'ჩრდილოფრიზიული',
@@ -150,7 +162,9 @@ return [
         'gv' => 'მენური',
         'gwi' => 'გვიჩინი',
         'ha' => 'ჰაუსა',
+        'hai' => 'ჰაიდა',
         'haw' => 'ჰავაიური',
+        'hax' => 'სამხრეთული ჰაიდა',
         'he' => 'ებრაული',
         'hi' => 'ჰინდი',
         'hil' => 'ჰილიგაინონი',
@@ -161,6 +175,7 @@ return [
         'ht' => 'ჰაიტიური კრეოლი',
         'hu' => 'უნგრული',
         'hup' => 'ჰუპა',
+        'hur' => 'ჰალკომელემი',
         'hy' => 'სომხური',
         'hz' => 'ჰერერო',
         'ia' => 'ინტერლინგუალური',
@@ -170,6 +185,7 @@ return [
         'ie' => 'ინტერლინგი',
         'ig' => 'იგბო',
         'ii' => 'სიჩუანის ი',
+        'ikt' => 'დასავლეთ-კანადური ინუკტიტუტი',
         'ilo' => 'ილოკო',
         'inh' => 'ინგუშური',
         'io' => 'იდო',
@@ -195,6 +211,7 @@ return [
         'kea' => 'კაბუვერდიანუ',
         'kfo' => 'კორო',
         'kg' => 'კონგო',
+        'kgp' => 'კაინგანგი',
         'kha' => 'ხასი',
         'khq' => 'კოირა-ჩიინი',
         'ki' => 'კიკუიუ',
@@ -224,6 +241,7 @@ return [
         'kut' => 'კუტენაი',
         'kv' => 'კომი',
         'kw' => 'კორნული',
+        'kwk' => 'კვაკვალა',
         'ky' => 'ყირგიზული',
         'la' => 'ლათინური',
         'lad' => 'ლადინო',
@@ -234,12 +252,15 @@ return [
         'lez' => 'ლეზგიური',
         'lg' => 'განდა',
         'li' => 'ლიმბურგული',
+        'lil' => 'ლილიეტი',
         'lkt' => 'ლაკოტა',
         'ln' => 'ლინგალა',
         'lo' => 'ლაოსური',
         'lol' => 'მონგო',
+        'lou' => 'ლუიზიანას კრეოლური',
         'loz' => 'ლოზი',
         'lrc' => 'ჩრდილოეთ ლური',
+        'lsm' => 'სამია',
         'lt' => 'ლიეტუვური',
         'lu' => 'ლუბა-კატანგა',
         'lua' => 'ლუბა-ლულუა',
@@ -273,6 +294,7 @@ return [
         'mn' => 'მონღოლური',
         'mnc' => 'მანჯურიული',
         'mni' => 'მანიპური',
+        'moe' => 'ინუ-აიმუნი',
         'moh' => 'მოჰაუკური',
         'mos' => 'მოსი',
         'mr' => 'მარათჰი',
@@ -317,6 +339,11 @@ return [
         'nzi' => 'ნზიმა',
         'oc' => 'ოქსიტანური',
         'oj' => 'ოჯიბვე',
+        'ojb' => 'ჩრდილო-დასავლეთის ოჯიბვა',
+        'ojc' => 'ცენტრალური ოჯიბვე',
+        'ojs' => 'ოჯი-კრი',
+        'ojw' => 'დასავლეთის ოჯიბვა',
+        'oka' => 'ოკანაგანი',
         'om' => 'ორომო',
         'or' => 'ორია',
         'os' => 'ოსური',
@@ -330,7 +357,9 @@ return [
         'peo' => 'ძველი სპარსული',
         'phn' => 'ფინიკიური',
         'pi' => 'პალი',
+        'pis' => 'პიჯინი',
         'pl' => 'პოლონური',
+        'pqm' => 'მალისეტ-პასამაკვოდი',
         'prg' => 'პრუსიული',
         'pro' => 'ძველი პროვანსული',
         'ps' => 'პუშტუ',
@@ -377,6 +406,7 @@ return [
         'si' => 'სინჰალური',
         'sk' => 'სლოვაკური',
         'sl' => 'სლოვენური',
+        'slh' => 'სამხრეთული ლუშუციდი',
         'sm' => 'სამოა',
         'sma' => 'სამხრეთსამური',
         'smj' => 'ლულე-საამური',
@@ -391,6 +421,7 @@ return [
         'ss' => 'სუატი',
         'ssy' => 'საჰო',
         'st' => 'სამხრეთ სოთოს ენა',
+        'str' => 'სტრეიტს სალიში',
         'su' => 'სუნდური',
         'suk' => 'სუკუმა',
         'sux' => 'შუმერული',
@@ -400,23 +431,29 @@ return [
         'syc' => 'კლასიკური სირიული',
         'syr' => 'სირიული',
         'ta' => 'ტამილური',
+        'tce' => 'სამხრეთ ტუჩონი',
         'te' => 'ტელუგუ',
         'tem' => 'ტინმე',
         'teo' => 'ტესო',
         'tet' => 'ტეტუმი',
         'tg' => 'ტაჯიკური',
-        'th' => 'ტაი',
+        'tgx' => 'ტაგიში',
+        'th' => 'ტაილანდური',
+        'tht' => 'ტალტანი',
         'ti' => 'ტიგრინია',
         'tig' => 'თიგრე',
         'tk' => 'თურქმენული',
         'tlh' => 'კლინგონი',
+        'tli' => 'ტლინგიტი',
         'tn' => 'ტსვანა',
         'to' => 'ტონგანური',
+        'tok' => 'ტოკი-პონა',
         'tpi' => 'ტოკ-პისინი',
         'tr' => 'თურქული',
         'trv' => 'ტაროკო',
         'ts' => 'ტსონგა',
         'tt' => 'თათრული',
+        'ttm' => 'ჩრდილოეთ ტუჩონი',
         'tum' => 'ტუმბუკა',
         'tvl' => 'ტუვალუ',
         'tw' => 'თუი',
@@ -442,6 +479,7 @@ return [
         'war' => 'ვარაი',
         'wbp' => 'ვალპირი',
         'wo' => 'ვოლოფური',
+        'wuu' => 'ვუ',
         'xal' => 'ყალმუხური',
         'xh' => 'ქჰოსა',
         'xog' => 'სოგა',
@@ -449,6 +487,7 @@ return [
         'ybb' => 'იემბა',
         'yi' => 'იდიში',
         'yo' => 'იორუბა',
+        'yrl' => 'ნენგატუ',
         'yue' => 'კანტონური',
         'zbl' => 'ბლისსიმბოლოები',
         'zen' => 'ზენაგა',
