@@ -16,13 +16,16 @@ return [
         'alt' => 'អាល់តៃខាងត្បូង',
         'am' => 'អាំហារិក',
         'an' => 'អារ៉ាហ្គោន',
+        'ann' => 'អូបូឡូ',
         'anp' => 'អាហ្គីកា',
         'ar' => 'អារ៉ាប់',
         'arn' => 'ម៉ាពូឈី',
         'arp' => 'អារ៉ាប៉ាហូ',
+        'ars' => 'អារ៉ាប់ណាឌី',
         'as' => 'អាសាមីស',
         'asa' => 'អាស៊ូ',
         'ast' => 'អាស្ទូរី',
+        'atj' => 'អាទិកាម៉េក',
         'av' => 'អាវ៉ារីក',
         'awa' => 'អាវ៉ាឌី',
         'ay' => 'អីម៉ារ៉ា',
@@ -48,6 +51,7 @@ return [
         'bug' => 'ប៊ុកហ្គី',
         'byn' => 'ប្ល៊ីន',
         'ca' => 'កាតាឡាន',
+        'cay' => 'ខាយូហ្កា',
         'ccp' => 'ចាក់ម៉ា',
         'ce' => 'ឈីឆេន',
         'ceb' => 'ស៊ីប៊ូអាណូ',
@@ -56,12 +60,21 @@ return [
         'chk' => 'ឈូគី',
         'chm' => 'ម៉ារី',
         'cho' => 'ឆុកតាវ',
+        'chp' => 'ឈីប៉េវ៉ាយអិន',
         'chr' => 'ឆេរូគី',
         'chy' => 'ឈីយីនី',
         'ckb' => 'ឃើដភាគកណ្តាល',
+        'clc' => 'ឈីលកូទីន',
         'co' => 'កូស៊ីខាន',
+        'crg' => 'មីឈីហ្វ',
+        'crj' => 'គ្រីខាងកើត​ប៉ែកខាងត្បូង',
+        'crk' => 'គ្រីតំបន់វាលរាប',
+        'crl' => 'គ្រីខាងកើត​ប៉ែកខាងជើង',
+        'crm' => 'មូសគ្រី',
+        'crr' => 'អាល់ហ្គនខ្វៀន ខារ៉ូលីណា',
         'crs' => 'សេសេលវ៉ាគ្រីអូល (បារាំង)',
         'cs' => 'ឆែក',
+        'csw' => 'គ្រីតំបន់ភក់ល្បាប់',
         'cu' => 'ឈើជស្លាវិក',
         'cv' => 'ឈូវ៉ាស',
         'cy' => 'វេល',
@@ -98,6 +111,8 @@ return [
         'fo' => 'ហ្វារូស',
         'fon' => 'ហ្វ៊ុន',
         'fr' => 'បារាំង',
+        'frc' => 'បារាំងកាហ្សង់',
+        'frr' => 'ហ្វ្រ៊ីសៀន​ខាងជើង',
         'fur' => 'ហ៊្វ្រូលាន',
         'fy' => 'ហ្វ្រីស៊ានខាងលិច',
         'ga' => 'អៀរឡង់',
@@ -115,7 +130,9 @@ return [
         'gv' => 'មេន',
         'gwi' => 'ហ្គីចឈីន',
         'ha' => 'ហូសា',
+        'hai' => 'ហៃដា',
         'haw' => 'ហាវ៉ៃ',
+        'hax' => 'ហៃដាខាងត្បូង',
         'he' => 'ហេប្រឺ',
         'hi' => 'ហិណ្ឌី',
         'hil' => 'ហ៊ីលីហ្គេណុន',
@@ -125,6 +142,7 @@ return [
         'ht' => 'ហៃទី',
         'hu' => 'ហុងគ្រី',
         'hup' => 'ហ៊ូប៉ា',
+        'hur' => 'ហាល់កូម៉េឡេម',
         'hy' => 'អាមេនី',
         'hz' => 'ហឺរីរ៉ូ',
         'ia' => 'អ៊ីនធើលីង',
@@ -133,6 +151,7 @@ return [
         'id' => 'ឥណ្ឌូណេស៊ី',
         'ig' => 'អ៊ីកបូ',
         'ii' => 'ស៊ីឈាន់យី',
+        'ikt' => 'អ៊ីនុកទីទុត​កាណាដា​ប៉ែកខាងលិច',
         'ilo' => 'អ៊ីឡូកូ',
         'inh' => 'អ៊ិនហ្គូស',
         'io' => 'អ៊ីដូ',
@@ -154,6 +173,7 @@ return [
         'kde' => 'ម៉ាកូនដេ',
         'kea' => 'កាប៊ូវឺឌៀនូ',
         'kfo' => 'គូរូ',
+        'kgp' => 'ខាងហ្កេង',
         'kha' => 'កាស៊ី',
         'khq' => 'គុយរ៉ាឈីនី',
         'ki' => 'គីគូយូ',
@@ -181,6 +201,7 @@ return [
         'kum' => 'គូមីគ',
         'kv' => 'កូមី',
         'kw' => 'កូនីស',
+        'kwk' => 'ក្វាក់វ៉ាឡា',
         'ky' => '​កៀហ្ស៊ីស',
         'la' => 'ឡាតំាង',
         'lad' => 'ឡាឌីណូ',
@@ -189,11 +210,15 @@ return [
         'lez' => 'ឡេសហ្គី',
         'lg' => 'ហ្កាន់ដា',
         'li' => 'លីមប៊ូស',
+        'lij' => 'លីគូរី',
+        'lil' => 'លីលលូអេត',
         'lkt' => 'ឡាកូតា',
         'ln' => 'លីនកាឡា',
         'lo' => 'ឡាវ',
+        'lou' => 'ក្រេអូល លូអ៊ីស៊ីអាណា',
         'loz' => 'ឡូហ្ស៊ី',
         'lrc' => 'លូរីខាងជើង',
+        'lsm' => 'សាមៀ',
         'lt' => 'លីទុយអានី',
         'lu' => 'លូបាកាតានហ្គា',
         'lua' => 'លូបាលូឡា',
@@ -222,6 +247,7 @@ return [
         'ml' => 'ម៉ាឡាយ៉ាឡាម',
         'mn' => 'ម៉ុងហ្គោលី',
         'mni' => 'ម៉ានីពូរី',
+        'moe' => 'អ៊ីននូអៃមុន',
         'moh' => 'ម៊ូហាគ',
         'mos' => 'មូស៊ី',
         'mr' => 'ម៉ារ៉ាធី',
@@ -258,6 +284,11 @@ return [
         'ny' => 'ណានចា',
         'nyn' => 'ណានកូលេ',
         'oc' => 'អូសីតាន់',
+        'ojb' => 'អូជីបវ៉ា​ប៉ែកពាយ័ព្យ',
+        'ojc' => 'អូជីពវ៉ាកណ្ដាល',
+        'ojs' => 'អូជីគ្រី',
+        'ojw' => 'អូជីបវ៉ា​ខាងលិច',
+        'oka' => 'អូកាណាហ្កាន',
         'om' => 'អូរ៉ូម៉ូ',
         'or' => 'អូឌៀ',
         'os' => 'អូស៊ីទិក',
@@ -267,7 +298,9 @@ return [
         'pap' => 'ប៉ាប៉ៃមេនតូ',
         'pau' => 'ប៉ាលូអាន',
         'pcm' => 'ភាសាទំនាក់ទំនងនីហ្សេរីយ៉ា',
+        'pis' => 'ពីជីន',
         'pl' => 'ប៉ូឡូញ',
+        'pqm' => 'ម៉ាលីស៊ីត ប៉ាសាម៉ាខ្វូឌី',
         'prg' => 'ព្រូស៊ាន',
         'ps' => 'បាស្តូ',
         'pt' => 'ព័រទុយហ្គាល់',
@@ -306,6 +339,7 @@ return [
         'si' => 'ស្រីលង្កា',
         'sk' => 'ស្លូវ៉ាគី',
         'sl' => 'ស្លូវ៉ានី',
+        'slh' => 'ឡាស៊ូតស៊ីតខាងត្បូង',
         'sm' => 'សាម័រ',
         'sma' => 'សាមីខាងត្បូង',
         'smj' => 'លូលីសាមី',
@@ -320,6 +354,7 @@ return [
         'ss' => 'ស្វាទី',
         'ssy' => 'សាហូ',
         'st' => 'សូថូខាងត្បូង',
+        'str' => 'សាលីសស្ត្រេតស៍',
         'su' => 'ស៊ូដង់',
         'suk' => 'ស៊ូគូម៉ា',
         'sv' => 'ស៊ុយអែត',
@@ -327,23 +362,29 @@ return [
         'swb' => 'កូម៉ូរី',
         'syr' => 'ស៊ីរី',
         'ta' => 'តាមីល',
+        'tce' => 'ថុចឆុនខាងត្បូង',
         'te' => 'តេលុគុ',
         'tem' => 'ធីមនី',
         'teo' => 'តេសូ',
         'tet' => 'ទីទុំ',
         'tg' => 'តាហ្ស៊ីគ',
+        'tgx' => 'តាហ្គីស',
         'th' => 'ថៃ',
+        'tht' => 'តាល់តាន',
         'ti' => 'ទីហ្គ្រីញ៉ា',
         'tig' => 'ធីហ្គ្រា',
         'tk' => 'តួកម៉េន',
         'tlh' => 'ឃ្លីនហ្គុន',
+        'tli' => 'ថ្លីងហ្គីត',
         'tn' => 'ស្វាណា',
         'to' => 'តុងហ្គា',
+        'tok' => 'តូគីប៉ូណា',
         'tpi' => 'ថុកពីស៊ីន',
         'tr' => 'ទួរគី',
         'trv' => 'តារ៉ូកូ',
         'ts' => 'សុងហ្គា',
         'tt' => 'តាតា',
+        'ttm' => 'ថុចឆុនខាងជើង',
         'tum' => 'ទុមប៊ូកា',
         'tvl' => 'ទូវ៉ាលូ',
         'tw' => 'ទ្វី',
@@ -359,6 +400,7 @@ return [
         'uz' => 'អ៊ូសបេគ',
         'vai' => 'វៃ',
         've' => 'វេនដា',
+        'vec' => 'វេណេតូ',
         'vi' => 'វៀតណាម',
         'vo' => 'វូឡាពូក',
         'vun' => 'វុនចូ',
@@ -368,6 +410,7 @@ return [
         'war' => 'វ៉ារេយ',
         'wbp' => 'វ៉ារីប៉ារី',
         'wo' => 'វូឡុហ្វ',
+        'wuu' => 'អ៊ូចិន',
         'xal' => 'កាលមីគ',
         'xh' => 'ឃសា',
         'xog' => 'សូហ្គា',
@@ -375,6 +418,7 @@ return [
         'ybb' => 'យេមបា',
         'yi' => 'យ៉ីឌីស',
         'yo' => 'យរូបា',
+        'yrl' => 'ញីនហ្កាទូ',
         'yue' => 'កន្តាំង',
         'za' => 'ហ្សួង',
         'zgh' => 'តាម៉ាហ្សៃម៉ារ៉ុកស្តង់ដា',
@@ -385,8 +429,10 @@ return [
     ],
     'LocalizedNames' => [
         'ar_001' => 'អារ៉ាប់ (ស្តង់ដារ)',
+        'de_CH' => 'អាល្លឺម៉ង់ (ស្វ៊ីស)',
         'es_ES' => 'អេស្ប៉ាញ (អ៊ឺរ៉ុប)',
         'fa_AF' => 'ដារី',
+        'fr_CH' => 'បារាំង (ស្វ៊ីស)',
         'nds_NL' => 'ហ្សាក់ស្យុងក្រោម',
         'nl_BE' => 'ផ្លាមីស',
         'pt_BR' => 'ព័រទុយហ្កាល់ (ប្រេស៊ីល)',
