@@ -20,15 +20,18 @@ return [
         'am' => 'ಅಂಹರಿಕ್',
         'an' => 'ಅರಗೊನೀಸ್',
         'ang' => 'ಪ್ರಾಚೀನ ಇಂಗ್ಲೀಷ್',
+        'ann' => 'ಒಬೊಲೊ',
         'anp' => 'ಆಂಗಿಕಾ',
         'ar' => 'ಅರೇಬಿಕ್',
         'arc' => 'ಅರಾಮಿಕ್',
         'arn' => 'ಮಪುಚೆ',
         'arp' => 'ಅರಪಾಹೋ',
+        'ars' => 'ನ್ಯಾಜ್ಡಿ ಅರೇಬಿಕ್',
         'arw' => 'ಅರಾವಾಕ್',
         'as' => 'ಅಸ್ಸಾಮೀಸ್',
         'asa' => 'ಅಸು',
         'ast' => 'ಆಸ್ಟುರಿಯನ್',
+        'atj' => 'ಅತಿಕಮೆಕ್',
         'av' => 'ಅವರಿಕ್',
         'awa' => 'ಅವಧಿ',
         'ay' => 'ಅಯ್ಮಾರಾ',
@@ -61,6 +64,7 @@ return [
         'ca' => 'ಕೆಟಲಾನ್',
         'cad' => 'ಕ್ಯಾಡ್ಡೋ',
         'car' => 'ಕಾರಿಬ್',
+        'cay' => 'ಕಯುಗಾ',
         'cch' => 'ಅಟ್ಸಮ್',
         'ccp' => 'ಚಕ್ಮಾ',
         'ce' => 'ಚಚೆನ್',
@@ -77,13 +81,21 @@ return [
         'chr' => 'ಚೆರೋಕಿ',
         'chy' => 'ಚೀಯೆನ್ನೇ',
         'ckb' => 'ಮಧ್ಯ ಕುರ್ದಿಶ್',
+        'clc' => 'ಚಿಲ್ಕೋಟಿನ್',
         'co' => 'ಕೋರ್ಸಿಕನ್',
         'cop' => 'ಕೊಪ್ಟಿಕ್',
         'cr' => 'ಕ್ರೀ',
+        'crg' => 'ಮಿಚಿಫ್',
         'crh' => 'ಕ್ರಿಮೀಯನ್ ಟರ್ಕಿಷ್',
+        'crj' => 'ದಕ್ಷಿಣ ಪೂರ್ವ ಕ್ರೀ',
+        'crk' => 'ಪ್ಲೇನ್ಸ್ ಕ್ರೀ',
+        'crl' => 'ಉತ್ತರ ಪೂರ್ವ ಕ್ರೀ',
+        'crm' => 'ಮೂಸ್ ಕ್ರೀ',
+        'crr' => 'ಕೆರೊಲಿನಾ ಅಲ್ಗೊಂಕ್ವಿಯನ್',
         'crs' => 'ಸೆಸೆಲ್ವಾ ಕ್ರಯೋಲ್ ಫ್ರೆಂಚ್',
         'cs' => 'ಜೆಕ್',
         'csb' => 'ಕಶುಬಿಯನ್',
+        'csw' => 'ಸ್ವಾಂಪಿ ಕ್ರೀ',
         'cu' => 'ಚರ್ಚ್ ಸ್ಲಾವಿಕ್',
         'cv' => 'ಚುವಾಶ್',
         'cy' => 'ವೆಲ್ಶ್',
@@ -164,6 +176,7 @@ return [
         'hai' => 'ಹೈಡಾ',
         'hak' => 'ಹಕ್',
         'haw' => 'ಹವಾಯಿಯನ್',
+        'hax' => 'ದಕ್ಷಿಣ ಹೈಡಾ',
         'he' => 'ಹೀಬ್ರೂ',
         'hi' => 'ಹಿಂದಿ',
         'hil' => 'ಹಿಲಿಗೇನನ್',
@@ -176,6 +189,7 @@ return [
         'ht' => 'ಹೈಟಿಯನ್ ಕ್ರಿಯೋಲಿ',
         'hu' => 'ಹಂಗೇರಿಯನ್',
         'hup' => 'ಹೂಪಾ',
+        'hur' => 'ಹಾಲ್ಕೊಮೆಲೆಮ್',
         'hy' => 'ಅರ್ಮೇನಿಯನ್',
         'hz' => 'ಹೆರೆರೊ',
         'ia' => 'ಇಂಟರ್‌ಲಿಂಗ್ವಾ',
@@ -186,6 +200,7 @@ return [
         'ig' => 'ಇಗ್ಬೊ',
         'ii' => 'ಸಿಚುಅನ್ ಯಿ',
         'ik' => 'ಇನುಪಿಯಾಕ್',
+        'ikt' => 'ಪಶ್ಚಿಮ ಕೆನಡಿಯನ್ ಇನುಕ್ಟಿಟುಟ್',
         'ilo' => 'ಇಲ್ಲಿಕೋ',
         'inh' => 'ಇಂಗುಷ್',
         'io' => 'ಇಡೊ',
@@ -212,6 +227,7 @@ return [
         'kea' => 'ಕಬುವೆರ್ಡಿಯನು',
         'kfo' => 'ಕೋರೋ',
         'kg' => 'ಕಾಂಗೋ',
+        'kgp' => 'ಕೈಗಂಗ್',
         'kha' => 'ಖಾಸಿ',
         'kho' => 'ಖೋಟಾನೀಸ್',
         'khq' => 'ಕೊಯ್ರ ಚೀನಿ',
@@ -242,6 +258,7 @@ return [
         'kut' => 'ಕುಟೇನಾಯ್',
         'kv' => 'ಕೋಮಿ',
         'kw' => 'ಕಾರ್ನಿಷ್',
+        'kwk' => 'ಕ್ವಾಕ್‌ವಾಲಾ',
         'ky' => 'ಕಿರ್ಗಿಜ್',
         'la' => 'ಲ್ಯಾಟಿನ್',
         'lad' => 'ಲ್ಯಾಡಿನೋ',
@@ -252,6 +269,7 @@ return [
         'lez' => 'ಲೆಜ್ಘಿಯನ್',
         'lg' => 'ಗಾಂಡಾ',
         'li' => 'ಲಿಂಬರ್ಗಿಶ್',
+        'lil' => 'ಲಿಲ್ಲೂವೆಟ್',
         'lkt' => 'ಲಕೊಟ',
         'ln' => 'ಲಿಂಗಾಲ',
         'lo' => 'ಲಾವೋ',
@@ -259,6 +277,7 @@ return [
         'lou' => 'ಲೂಯಿಸಿಯಾನ ಕ್ರಿಯೋಲ್',
         'loz' => 'ಲೋಝಿ',
         'lrc' => 'ಉತ್ತರ ಲೂರಿ',
+        'lsm' => 'ಸಾಮಿಯಾ',
         'lt' => 'ಲಿಥುವೇನಿಯನ್',
         'lu' => 'ಲೂಬಾ-ಕಟಾಂಗಾ',
         'lua' => 'ಲುಬ-ಲುಲಾ',
@@ -292,6 +311,7 @@ return [
         'mn' => 'ಮಂಗೋಲಿಯನ್',
         'mnc' => 'ಮಂಚು',
         'mni' => 'ಮಣಿಪುರಿ',
+        'moe' => 'ಇನ್ನು-ಐಮುನ್',
         'moh' => 'ಮೊಹಾವ್ಕ್',
         'mos' => 'ಮೊಸ್ಸಿ',
         'mr' => 'ಮರಾಠಿ',
@@ -336,6 +356,11 @@ return [
         'nzi' => 'ಜೀಮಾ',
         'oc' => 'ಒಸಿಟನ್',
         'oj' => 'ಒಜಿಬ್ವಾ',
+        'ojb' => 'ವಾಯುವ್ಯ ಓಜಿಬ್ವಾ',
+        'ojc' => 'ಮಧ್ಯ ಓಜಿಬ್ವಾ',
+        'ojs' => 'ಓಜಿ-ಕ್ರೀ',
+        'ojw' => 'ಪಶ್ಚಿಮ ಓಜಿಬ್ವಾ',
+        'oka' => 'ಒಕನಾಗನ್',
         'om' => 'ಒರೊಮೊ',
         'or' => 'ಒಡಿಯ',
         'os' => 'ಒಸ್ಸೆಟಿಕ್',
@@ -351,8 +376,10 @@ return [
         'peo' => 'ಪ್ರಾಚೀನ ಪರ್ಶಿಯನ್',
         'phn' => 'ಫೀನಿಷಿಯನ್',
         'pi' => 'ಪಾಲಿ',
+        'pis' => 'ಪಿಜಿನ್',
         'pl' => 'ಪೊಲಿಶ್',
         'pon' => 'ಪೋನ್‌‌ಪಿಯನ್',
+        'pqm' => 'ಮ್ಯಾಲಿಸೀಟ್-ಪಸ್ಸಾಮಕ್ವಾಡ್ಡಿ',
         'prg' => 'ಪ್ರಶಿಯನ್',
         'pro' => 'ಪ್ರಾಚೀನ ಪ್ರೊವೆನ್ಶಿಯಲ್',
         'ps' => 'ಪಾಷ್ಟೋ',
@@ -399,6 +426,7 @@ return [
         'sid' => 'ಸಿಡಾಮೋ',
         'sk' => 'ಸ್ಲೋವಾಕ್',
         'sl' => 'ಸ್ಲೋವೇನಿಯನ್',
+        'slh' => 'ದಕ್ಷಿಣ ಲುಶೂಟ್‌ಸೀಡ್',
         'sm' => 'ಸಮೋವನ್',
         'sma' => 'ದಕ್ಷಿಣ ಸಾಮಿ',
         'smj' => 'ಲೂಲ್ ಸಾಮಿ',
@@ -415,6 +443,7 @@ return [
         'ss' => 'ಸ್ವಾತಿ',
         'ssy' => 'ಸಹೊ',
         'st' => 'ದಕ್ಷಿಣ ಸೋಥೋ',
+        'str' => 'ಸ್ಟ್ರೇಟ್ಸ್ ಸೆಲಿಶ್',
         'su' => 'ಸುಂಡಾನೀಸ್',
         'suk' => 'ಸುಕುಮಾ',
         'sus' => 'ಸುಸು',
@@ -425,13 +454,16 @@ return [
         'syc' => 'ಶಾಸ್ತ್ರೀಯ ಸಿರಿಯಕ್',
         'syr' => 'ಸಿರಿಯಾಕ್',
         'ta' => 'ತಮಿಳು',
+        'tce' => 'ದಕ್ಷಿಣ ಟಚ್‌ವನ್',
         'te' => 'ತೆಲುಗು',
         'tem' => 'ಟಿಮ್ನೆ',
         'teo' => 'ಟೆಸೊ',
         'ter' => 'ಟೆರೆನೋ',
         'tet' => 'ಟೇಟಮ್',
         'tg' => 'ತಾಜಿಕ್',
+        'tgx' => 'ಟಾಗಿಶ್',
         'th' => 'ಥಾಯ್',
+        'tht' => 'ಟಾಹ್ಲ್ಟನ್',
         'ti' => 'ಟಿಗ್ರಿನ್ಯಾ',
         'tig' => 'ಟೈಗ್ರೆ',
         'tiv' => 'ಟಿವ್',
@@ -444,12 +476,14 @@ return [
         'tn' => 'ಸ್ವಾನಾ',
         'to' => 'ಟೋಂಗನ್',
         'tog' => 'ನ್ಯಾಸಾ ಟೋಂಗಾ',
+        'tok' => 'ಟೋಕಿ ಪೋನಾ',
         'tpi' => 'ಟೋಕ್ ಪಿಸಿನ್',
         'tr' => 'ಟರ್ಕಿಶ್',
         'trv' => 'ಟರೊಕೊ',
         'ts' => 'ಸೋಂಗಾ',
         'tsi' => 'ಸಿಂಶಿಯನ್',
         'tt' => 'ಟಾಟರ್',
+        'ttm' => 'ಉತ್ತರ ಟಚ್‌ವನ್',
         'tum' => 'ತುಂಬುಕಾ',
         'tvl' => 'ಟುವಾಲು',
         'tw' => 'ಟ್ವಿ',
@@ -477,7 +511,7 @@ return [
         'was' => 'ವಾಷೋ',
         'wbp' => 'ವಾರ್ಲ್‌ಪಿರಿ',
         'wo' => 'ವೋಲೋಫ್',
-        'wuu' => 'ವು',
+        'wuu' => 'ವು ಚೈನೀಸ್',
         'xal' => 'ಕಲ್ಮೈಕ್',
         'xh' => 'ಕ್ಸೋಸ',
         'xog' => 'ಸೊಗ',
@@ -487,6 +521,7 @@ return [
         'ybb' => 'ಯೆಂಬಾ',
         'yi' => 'ಯಿಡ್ಡಿಶ್',
         'yo' => 'ಯೊರುಬಾ',
+        'yrl' => 'ನಿಂಗಾಟು',
         'yue' => 'ಕ್ಯಾಂಟನೀಸ್',
         'za' => 'ಝೂವಾಂಗ್',
         'zap' => 'ಝೋಪೊಟೆಕ್',
