@@ -20,15 +20,18 @@ return [
         'am' => 'ອຳຮາຣິກ',
         'an' => 'ອາຣາໂກເນັດ',
         'ang' => 'ອັງກິດໂບຮານ',
+        'ann' => 'ໂອໂບໂລ',
         'anp' => 'ແອນຈີກາ',
         'ar' => 'ອາຣັບ',
         'arc' => 'ອາລາມິກ',
         'arn' => 'ມາພຸດຊີ',
         'arp' => 'ອາຣາປາໂຮ',
+        'ars' => 'ນາຈດີ ອາຣາບິກ',
         'arw' => 'ອາຣາແວກ',
         'as' => 'ອັສຊາມີສ',
         'asa' => 'ອາຊູ',
         'ast' => 'ອັສຕູຮຽນ',
+        'atj' => 'ອາຕິກາແມກ',
         'av' => 'ອາວາຣິກ',
         'awa' => 'ອາວາຮິ',
         'ay' => 'ອາຍມາລາ',
@@ -85,13 +88,21 @@ return [
         'chr' => 'ຊີໂຣກີ',
         'chy' => 'ຊີເຢນນີ',
         'ckb' => 'ໂຊຣານິ ເຄີດິຊ',
+        'clc' => 'ຊິວໂຄຕິນ',
         'co' => 'ຄໍຊິກາ',
         'cop' => 'ຄອບຕິກ',
         'cr' => 'ຄີ',
+        'crg' => 'ມິຊິຟ',
         'crh' => 'ຄຣີເມນເຕີຄິຊ',
+        'crj' => 'ຄຣີຕາເວັນອອກສ່ຽງໃຕ້',
+        'crk' => 'ເພລນຄຣີ',
+        'crl' => 'ຄຣີຕາເວັນອອກສ່ຽງເໜືອ',
+        'crm' => 'ມູສຄຣີ',
+        'crr' => 'ຄາໂຣລິນາ ອາກອນຄວຽນ',
         'crs' => 'ເຊເຊວາ ໂຄຣດ ຝຣັ່ງ',
         'cs' => 'ເຊກ',
         'csb' => 'ກາຊູບຽນ',
+        'csw' => 'ຊວາມປີຄຣີ',
         'cu' => 'ໂບດສລາວິກ',
         'cv' => 'ຊູວາຊ',
         'cy' => 'ເວວ',
@@ -138,6 +149,7 @@ return [
         'fo' => 'ຟາໂຣສ',
         'fon' => 'ຟອນ',
         'fr' => 'ຝຣັ່ງ',
+        'frc' => 'ຝຣັ່ງເຄຈຸນ',
         'frm' => 'ຟຮັ່ງເສດກາງ',
         'fro' => 'ຟຮັ່ງເສດໂບຮານ',
         'frr' => 'ຟຣີຊຽນເໜືອ',
@@ -169,6 +181,7 @@ return [
         'ha' => 'ເຮົາຊາ',
         'hai' => 'ໄຮດາ',
         'haw' => 'ຮາໄວອຽນ',
+        'hax' => 'ໄຮດາໃຕ້',
         'he' => 'ຮີບຣິວ',
         'hi' => 'ຮິນດິ',
         'hil' => 'ຮິຣິໄກນອນ',
@@ -180,6 +193,7 @@ return [
         'ht' => 'ໄຮຕຽນ',
         'hu' => 'ຮັງກາຣຽນ',
         'hup' => 'ຮູປາ',
+        'hur' => 'ຮາລໂກເມລຽມ',
         'hy' => 'ອາເມນຽນ',
         'hz' => 'ເຮິຮິໂຣ',
         'ia' => 'ອິນເຕີລິງລົວ',
@@ -190,6 +204,7 @@ return [
         'ig' => 'ອິກໂບ',
         'ii' => 'ເສສວນ ອີ',
         'ik' => 'ອິນນູປຽກ',
+        'ikt' => 'ອິນັກທິທັດຄານາດາຕາເວັນຕົກ',
         'ilo' => 'ໄອໂລໂກ',
         'inh' => 'ອິນກັຊ',
         'io' => 'ອີໂດ',
@@ -217,6 +232,7 @@ return [
         'kea' => 'ຄາເວີເດຍນູ',
         'kfo' => 'ໂຄໂລ',
         'kg' => 'ຄອງໂກ',
+        'kgp' => 'ເຄນກັງ',
         'kha' => 'ຄາສິ',
         'kho' => 'ໂຄຕັນ',
         'khq' => 'ຄອຍຣາ ຊິນີ',
@@ -247,6 +263,7 @@ return [
         'kut' => 'ຄູເທໄນ',
         'kv' => 'ໂຄມິ',
         'kw' => 'ຄໍນິຊ',
+        'kwk' => 'ຄວາກຄວາກລາ',
         'ky' => 'ເກຍກີສ',
         'la' => 'ລາຕິນ',
         'lad' => 'ລາດີໂນ',
@@ -257,12 +274,15 @@ return [
         'lez' => 'ລີຊຽນ',
         'lg' => 'ແກນດາ',
         'li' => 'ລິມເບີກີຊ',
+        'lil' => 'ລິນລູເອັດ',
         'lkt' => 'ລາໂກຕາ',
         'ln' => 'ລິງກາລາ',
         'lo' => 'ລາວ',
         'lol' => 'ແມັງໂກ້',
+        'lou' => 'ລຸຍຊີອານນາ ຄຣີໂອນ',
         'loz' => 'ໂລຊິ',
         'lrc' => 'ລູຣິ ທາງຕອນເໜືອ',
+        'lsm' => 'ຊາອາເມຍ',
         'lt' => 'ລິທົວນຽນ',
         'lu' => 'ລູບາ-ຄາຕັງກາ',
         'lua' => 'ລູບາ-ລູລົວ',
@@ -298,6 +318,7 @@ return [
         'mn' => 'ມອງໂກເລຍ',
         'mnc' => 'ແມນຈູ',
         'mni' => 'ມານີພູຣິ',
+        'moe' => 'ອິນນຸໄອມັນ',
         'moh' => 'ໂມຫາ',
         'mos' => 'ມອສຊີ',
         'mr' => 'ມາຣາທີ',
@@ -342,6 +363,11 @@ return [
         'nzi' => 'ນິມາ',
         'oc' => 'ອັອກຊີຕານ',
         'oj' => 'ໂອຈິບວາ',
+        'ojb' => 'ໂອຈິບວາຕາເວັນຕົກສ່ຽງເໜືອ',
+        'ojc' => 'ໂອຈິບວາກາງ',
+        'ojs' => 'ໂອຈິຄຣີ',
+        'ojw' => 'ໂອຈິບວາຕາເວັນຕົກ',
+        'oka' => 'ໂອກະນາກັນ',
         'om' => 'ໂອໂຣໂມ',
         'or' => 'ໂອຣິຢາ',
         'os' => 'ອອດເຊຕິກ',
@@ -357,8 +383,10 @@ return [
         'peo' => 'ເປີເຊຍໂບຮານ',
         'phn' => 'ຟີນີເຊຍ',
         'pi' => 'ປາລີ',
+        'pis' => 'ປິຈິນ',
         'pl' => 'ໂປລິຊ',
         'pon' => 'ພອນເພ',
+        'pqm' => 'ມາລິຊີດ ພາສຊາມາໂຄດດີ',
         'prg' => 'ປຣັສຊຽນ',
         'pro' => 'ໂປວອງຊານໂບຮານ',
         'ps' => 'ປາສໂຕ',
@@ -407,6 +435,7 @@ return [
         'sid' => 'ຊິດາໂມ',
         'sk' => 'ສະໂລແວັກ',
         'sl' => 'ສະໂລເວນຽນ',
+        'slh' => 'ລູຊຸດຊີດໃຕ້',
         'sm' => 'ຊາມົວ',
         'sma' => 'ຊາມິໃຕ້',
         'smj' => 'ລຸນຊາມິ',
@@ -423,6 +452,7 @@ return [
         'ss' => 'ຊຣາຕິ',
         'ssy' => 'ຊາໂຮ',
         'st' => 'ໂຊໂທໃຕ້',
+        'str' => 'ຊ່ອງແຄບເຊລີຊ',
         'su' => 'ຊຸນແດນນີສ',
         'suk' => 'ຊູຄູມ້າ',
         'sus' => 'ຊູຊູ',
@@ -433,13 +463,16 @@ return [
         'syc' => 'ຊີເລຍແບບດັ້ງເດີມ',
         'syr' => 'ຊີເລຍ',
         'ta' => 'ທາມິລ',
+        'tce' => 'ທຸດຊອນໃຕ້',
         'te' => 'ເຕລູກູ',
         'tem' => 'ທີມເນ',
         'teo' => 'ເຕໂຊ',
         'ter' => 'ເຕເລໂນ',
         'tet' => 'ເຕຕູມ',
         'tg' => 'ທາຈິກ',
+        'tgx' => 'ທາກີຊ',
         'th' => 'ໄທ',
+        'tht' => 'ທາວທັນ',
         'ti' => 'ຕິກຣິນຢາ',
         'tig' => 'ໄທກຣີ',
         'tiv' => 'ຕີວ',
@@ -452,12 +485,14 @@ return [
         'tn' => 'ເຕສະວານາ',
         'to' => 'ທອງການ',
         'tog' => 'ນາຍອາຊາຕອງກາ',
+        'tok' => 'ໂທກີໂພນາ',
         'tpi' => 'ທອກພີຊິນ',
         'tr' => 'ເທີຄິຊ',
         'trv' => 'ຕາໂລໂກ',
         'ts' => 'ເຕຊອງກາ',
         'tsi' => 'ຊີມຊີແອນ',
         'tt' => 'ທາທາ',
+        'ttm' => 'ທັດໂຈນເເໜືອ',
         'tum' => 'ຕຳບູກາ',
         'tvl' => 'ຕູວາລູ',
         'tw' => 'ທວີ',
@@ -485,6 +520,7 @@ return [
         'was' => 'ວາໂຊ',
         'wbp' => 'ວາຣພິຣິ',
         'wo' => 'ວໍລອບ',
+        'wuu' => 'ຈີນອູ',
         'xal' => 'ການມິກ',
         'xh' => 'ໂຮຊາ',
         'xog' => 'ໂຊກາ',
@@ -494,6 +530,7 @@ return [
         'ybb' => 'ແຢມບາ',
         'yi' => 'ຢິວ',
         'yo' => 'ໂຢຣູບາ',
+        'yrl' => 'ນີນກາຕູ',
         'yue' => 'ກວາງຕຸ້ງ',
         'za' => 'ຊວາງ',
         'zap' => 'ຊາໂປແຕບ',
@@ -509,15 +546,12 @@ return [
         'ar_001' => 'ອາຣາບິກມາດຕະຖານສະໄໝໃໝ່',
         'de_AT' => 'ເຢຍລະມັນ (ໂອສຕຣິດ)',
         'de_CH' => 'ສະວິສ ໄຮ ເຈີແມນ',
-        'en_AU' => 'ອັງກິດ (ໂອດສະຕາລີ)',
-        'en_CA' => 'ອັງກິດແຄນາດາ',
         'en_GB' => 'ອັງກິດ (ບຣິດທິຊ)',
         'en_US' => 'ອັງກິດ (ອາເມລິກັນ)',
         'es_419' => 'ລາຕິນ ອາເມຣິກັນ ສະແປນນິຊ',
         'es_ES' => 'ສະເປັນ ຢຸໂຣບ',
         'es_MX' => 'ເມັກຊິກັນ ສະແປນນິຊ',
         'fa_AF' => 'ດາຣີ',
-        'fr_CA' => 'ຟລັງ(ການາດາ)',
         'fr_CH' => 'ຝຣັ່ງ (ສວິສ)',
         'nds_NL' => 'ຊາຊອນ ຕອນໄຕ',
         'nl_BE' => 'ຟລີມິຊ',
