@@ -20,15 +20,18 @@ return [
         'am' => 'अम्हारिक',
         'an' => 'अर्गोनीज',
         'ang' => 'पुरातन इंग्रजी',
+        'ann' => 'ओबोलो',
         'anp' => 'अंगिका',
         'ar' => 'अरबी',
         'arc' => 'अ‍ॅरेमाइक',
         'arn' => 'मापुची',
         'arp' => 'आरापाहो',
+        'ars' => 'नजदी अरबी',
         'arw' => 'आरावाक',
         'as' => 'आसामी',
         'asa' => 'असु',
         'ast' => 'अस्तुरियन',
+        'atj' => 'अटिकमेक',
         'av' => 'अ‍ॅव्हेरिक',
         'awa' => 'अवधी',
         'ay' => 'ऐमरा',
@@ -61,6 +64,7 @@ return [
         'ca' => 'कातालान',
         'cad' => 'कॅड्डो',
         'car' => 'कॅरिब',
+        'cay' => 'केयुगा',
         'cch' => 'अत्सम',
         'ccp' => 'चाकमा',
         'ce' => 'चेचेन',
@@ -77,13 +81,21 @@ return [
         'chr' => 'चेरोकी',
         'chy' => 'शेयेन्न',
         'ckb' => 'मध्य कुर्दिश',
+        'clc' => 'चिलकोटिन',
         'co' => 'कॉर्सिकन',
         'cop' => 'कॉप्टिक',
         'cr' => 'क्री',
+        'crg' => 'मिचिफो',
         'crh' => 'क्राइमीन तुर्की',
+        'crj' => 'दक्षिणात्य इस्ट क्री',
+        'crk' => 'प्लेन्स क्री',
+        'crl' => 'नॉर्दर्न ईस्ट क्री',
+        'crm' => 'मूस क्री',
+        'crr' => 'कॅरोलिना अल्गोंक्वियन',
         'crs' => 'सेसेल्वा क्रिओल फ्रेंच',
         'cs' => 'झेक',
         'csb' => 'काशुबियन',
+        'csw' => 'स्वॅम्पी क्री',
         'cu' => 'चर्च स्लाव्हिक',
         'cv' => 'चूवाश',
         'cy' => 'वेल्श',
@@ -164,6 +176,7 @@ return [
         'hai' => 'हैडा',
         'hak' => 'हाक्का चिनी',
         'haw' => 'हवाईयन',
+        'hax' => 'दक्षिणात्य हैडा',
         'he' => 'हिब्रू',
         'hi' => 'हिंदी',
         'hil' => 'हिलीगेनॉन',
@@ -176,6 +189,7 @@ return [
         'ht' => 'हैतीयन क्रेओल',
         'hu' => 'हंगेरियन',
         'hup' => 'हूपा',
+        'hur' => 'हॉल्कमेलम',
         'hy' => 'आर्मेनियन',
         'hz' => 'हरेरो',
         'ia' => 'इंटरलिंग्वा',
@@ -186,6 +200,7 @@ return [
         'ig' => 'ईग्बो',
         'ii' => 'सिचुआन यी',
         'ik' => 'इनूपियाक',
+        'ikt' => 'वेस्टर्न कॅनेडियन इनुकिटुट',
         'ilo' => 'इलोको',
         'inh' => 'इंगुश',
         'io' => 'इडौ',
@@ -212,6 +227,7 @@ return [
         'kea' => 'काबवर्दियानु',
         'kfo' => 'कोरो',
         'kg' => 'काँगो',
+        'kgp' => 'काइंगांग',
         'kha' => 'खासी',
         'kho' => 'खोतानीस',
         'khq' => 'कोयरा चीनी',
@@ -242,6 +258,7 @@ return [
         'kut' => 'कुतेनाई',
         'kv' => 'कोमी',
         'kw' => 'कोर्निश',
+        'kwk' => 'क्वक्क्वाला',
         'ky' => 'किरगीझ',
         'la' => 'लॅटिन',
         'lad' => 'लादीनो',
@@ -252,6 +269,7 @@ return [
         'lez' => 'लेझ्घीयन',
         'lg' => 'गांडा',
         'li' => 'लिंबूर्गिश',
+        'lil' => 'लिलूएट',
         'lkt' => 'लाकोटा',
         'ln' => 'लिंगाला',
         'lo' => 'लाओ',
@@ -259,6 +277,7 @@ return [
         'lou' => 'ल्युसियाना क्रिओल',
         'loz' => 'लोझि',
         'lrc' => 'उत्तरी ल्युरी',
+        'lsm' => 'सामिया',
         'lt' => 'लिथुआनियन',
         'lu' => 'ल्यूबा-कटांगा',
         'lua' => 'लुबा-लुलुआ',
@@ -292,6 +311,7 @@ return [
         'mn' => 'मंगोलियन',
         'mnc' => 'मान्चु',
         'mni' => 'मणिपुरी',
+        'moe' => 'इन्नू-ॲमन',
         'moh' => 'मोहॉक',
         'mos' => 'मोस्सी',
         'mr' => 'मराठी',
@@ -336,6 +356,11 @@ return [
         'nzi' => 'न्झिमा',
         'oc' => 'ऑक्सितान',
         'oj' => 'ओजिब्वा',
+        'ojb' => 'नॉर्थवेस्टर्न ओजिब्वा',
+        'ojc' => 'सेंट्रल ओजिब्वा',
+        'ojs' => 'ओजी-क्री',
+        'ojw' => 'वेस्टर्न ओजिबवा',
+        'oka' => 'ओकनागन',
         'om' => 'ओरोमो',
         'or' => 'उडिया',
         'os' => 'ओस्सेटिक',
@@ -351,8 +376,10 @@ return [
         'peo' => 'पुरातन फारसी',
         'phn' => 'फोनिशियन',
         'pi' => 'पाली',
+        'pis' => 'पिजिन',
         'pl' => 'पोलिश',
         'pon' => 'पोह्नपियन',
+        'pqm' => 'मालीसेट-पासामाक्वाड्डी',
         'prg' => 'प्रुशियन',
         'pro' => 'पुरातन प्रोव्हेन्सल',
         'ps' => 'पश्तो',
@@ -399,6 +426,7 @@ return [
         'sid' => 'सिदामो',
         'sk' => 'स्लोव्हाक',
         'sl' => 'स्लोव्हेनियन',
+        'slh' => 'दक्षिणात्य लुशूटसीड',
         'sm' => 'सामोअन',
         'sma' => 'दक्षिणात्य सामी',
         'smj' => 'ल्युल सामी',
@@ -415,6 +443,7 @@ return [
         'ss' => 'स्वाती',
         'ssy' => 'साहो',
         'st' => 'दक्षिणी सोथो',
+        'str' => 'स्ट्राइट्स सालीश',
         'su' => 'सुंदानीज',
         'suk' => 'सुकुमा',
         'sus' => 'सुसु',
@@ -425,13 +454,16 @@ return [
         'syc' => 'अभिजात सिरियाक',
         'syr' => 'सिरियाक',
         'ta' => 'तामिळ',
+        'tce' => 'दक्षिणात्य टचोन',
         'te' => 'तेलगू',
         'tem' => 'टिम्ने',
         'teo' => 'तेसो',
         'ter' => 'तेरेनो',
         'tet' => 'तेतुम',
         'tg' => 'ताजिक',
+        'tgx' => 'टॅगिश',
         'th' => 'थाई',
+        'tht' => 'तहल्टन',
         'ti' => 'तिग्रिन्या',
         'tig' => 'टाइग्रे',
         'tiv' => 'तिव',
@@ -444,12 +476,14 @@ return [
         'tn' => 'त्स्वाना',
         'to' => 'टोंगन',
         'tog' => 'न्यासा टोन्गा',
+        'tok' => 'टोकि पोना',
         'tpi' => 'टोक पिसिन',
         'tr' => 'तुर्की',
         'trv' => 'तारोको',
         'ts' => 'सोंगा',
         'tsi' => 'सिम्शियन',
         'tt' => 'तातर',
+        'ttm' => 'नॉर्दर्न टचोन',
         'tum' => 'तुम्बुका',
         'tvl' => 'टुवालु',
         'tw' => 'ट्वी',
@@ -487,6 +521,7 @@ return [
         'ybb' => 'येमबा',
         'yi' => 'यिद्दिश',
         'yo' => 'योरुबा',
+        'yrl' => 'न्हेंगाटू',
         'yue' => 'कँटोनीज',
         'za' => 'झुआंग',
         'zap' => 'झेपोटेक',
