@@ -7,7 +7,7 @@ return [
         'ace' => 'အာချေး',
         'ada' => 'ဒန်မဲ',
         'ady' => 'အဒိုင်ဂီ',
-        'af' => 'တောင်အာဖရိက',
+        'af' => 'အာဖရိကန်',
         'agq' => 'အာဂ်ဟိန်း',
         'ain' => 'အိန်နု',
         'ak' => 'အာကန်',
@@ -16,13 +16,16 @@ return [
         'am' => 'အမ်ဟာရစ်ခ်',
         'an' => 'အာရာဂွန်',
         'ang' => 'အင်ဂလို ဆက္ကစွန်',
+        'ann' => 'အိုဘိုလို',
         'anp' => 'အန်ဂီကာ',
         'ar' => 'အာရဗီ',
         'arn' => 'မာပုချီ',
         'arp' => 'အာရာပါဟို',
+        'ars' => 'နာ့ဂျဒီ အာရဗစ်',
         'as' => 'အာသံ',
         'asa' => 'အာစု',
         'ast' => 'အက်စ်တိုးရီးယား',
+        'atj' => 'အာတီကမဲကု',
         'av' => 'အာဗာရစ်ခ်',
         'awa' => 'အာဝါဒီ',
         'ay' => 'အိုင်မာရ',
@@ -48,6 +51,7 @@ return [
         'bug' => 'ဘူဂစ်စ်',
         'byn' => 'ဘလင်',
         'ca' => 'ကတ်တလန်',
+        'cay' => 'ကာယုဂါ',
         'ccp' => 'ချတ်ခ်မာ',
         'ce' => 'ချက်ချန်း',
         'ceb' => 'စီဗူအာနို',
@@ -56,13 +60,22 @@ return [
         'chk' => 'ချူကီးစ်',
         'chm' => 'မာရီ',
         'cho' => 'ချော့တို',
+        'chp' => 'ချီပွေဝိုင်ရန်',
         'chr' => 'ချာရိုကီ',
         'chy' => 'ချေယန်း',
         'ckb' => 'ဗဟိုဒေသသုံး ကဒ်ဘာသာ',
+        'clc' => 'ချီကိုလ်တင်',
         'co' => 'ခိုစီကန်',
         'cr' => 'ခရီး',
+        'crg' => 'မစ်ချစ်ခ်',
+        'crj' => 'တောင်ပိုင်း အရှေ့ခရီ',
+        'crk' => 'ပလိန်းစ် ခရီ',
+        'crl' => 'မြောက်ပိုင်း အရှေ့ခရီ',
+        'crm' => 'မုစ်ခရီး',
+        'crr' => 'ကယ်ရိုလိုင်းနား အယ်လ်ဂွန်းကီယန်',
         'crs' => 'ခရီအိုလီ',
         'cs' => 'ချက်',
+        'csw' => 'ဆွမ်ပီ ခရီ',
         'cu' => 'ချပ်ချ် စလာဗစ်',
         'cv' => 'ချူဗက်ရှ်',
         'cy' => 'ဝေလ',
@@ -103,6 +116,7 @@ return [
         'fo' => 'ဖာရို',
         'fon' => 'ဖော်န်',
         'fr' => 'ပြင်သစ်',
+        'frc' => 'ကေဂျန် ဖရန့်စ်',
         'frm' => 'အလယ်ပိုင်း ပြင်သစ်',
         'fro' => 'ဖရန်စီစ်',
         'frr' => 'မြောက် ဖရီစီရန်',
@@ -126,8 +140,10 @@ return [
         'gv' => 'မန်းဇ်',
         'gwi' => 'ဂွစ်ချင်',
         'ha' => 'ဟာဥစာ',
+        'hai' => 'ဟေဒါ',
         'haw' => 'ဟာဝိုင်ယီ',
-        'he' => 'ဟီးဘရူး',
+        'hax' => 'တောင် ဟိုင်ဒါ',
+        'he' => 'ဟီဘရူး',
         'hi' => 'ဟိန်ဒူ',
         'hil' => 'ဟီလီဂေနွန်',
         'hmn' => 'မုံ',
@@ -136,6 +152,7 @@ return [
         'ht' => 'ဟေတီ',
         'hu' => 'ဟန်ဂေရီ',
         'hup' => 'ဟူပါ',
+        'hur' => 'ဟော့ကမိုလွမ်',
         'hy' => 'အာမေးနီးယား',
         'hz' => 'ဟီရဲရို',
         'ia' => 'အင်တာလင်ဂွါ',
@@ -144,6 +161,7 @@ return [
         'id' => 'အင်ဒိုနီးရှား',
         'ig' => 'အစ္ဂဘို',
         'ii' => 'စီချွမ် ရီ',
+        'ikt' => 'အနောက် ကနေဒီယန် အီနုတီတွတ်',
         'ilo' => 'အီလိုကို',
         'inh' => 'အင်ဂုရှ်',
         'io' => 'အီဒို',
@@ -168,6 +186,7 @@ return [
         'kea' => 'ကဘူဗာဒီအာနူ',
         'kfo' => 'ကိုရို',
         'kg' => 'ကွန်ဂို',
+        'kgp' => 'ကိန်းဂန်',
         'kha' => 'ခါစီ',
         'khq' => 'ကိုရာ ချီအီနီ',
         'ki' => 'ကီကူယူ',
@@ -195,6 +214,7 @@ return [
         'kum' => 'ကွမ်မိုက်',
         'kv' => 'ကိုမီ',
         'kw' => 'ခိုနီရှ်',
+        'kwk' => 'ကွပ်ခ်ဝါလာ',
         'ky' => 'ကာဂျစ်',
         'la' => 'လက်တင်',
         'lad' => 'လာဒီနို',
@@ -203,11 +223,14 @@ return [
         'lez' => 'လက်ဇ်ဂီးယား',
         'lg' => 'ဂန်ဒါ',
         'li' => 'လင်ဘာဂစ်ရှ်',
+        'lil' => 'လာလူးဝစ်တ်',
         'lkt' => 'လာကိုတာ',
         'ln' => 'လင်ဂါလာ',
         'lo' => 'လာအို',
+        'lou' => 'လူဝီဇီယားနား ခရီးယို',
         'loz' => 'လိုဇီ',
         'lrc' => 'မြောက်လူရီ',
+        'lsm' => 'ဆာမိအာ',
         'lt' => 'လစ်သူဝေးနီးယား',
         'lu' => 'လူဘာ-ကတန်ဂါ',
         'lua' => 'လူဘာ-လူလူအာ',
@@ -238,6 +261,7 @@ return [
         'mn' => 'မွန်ဂိုလီးယား',
         'mnc' => 'မန်ချူး',
         'mni' => 'မနိပူရ',
+        'moe' => 'အီနုအေမွန်',
         'moh' => 'မိုဟော့ခ်',
         'mos' => 'မိုစီ',
         'mr' => 'မာရသီ',
@@ -264,7 +288,7 @@ return [
         'nmg' => 'ကွာစီအို',
         'nn' => 'နော်ဝေ နီးနောစ်',
         'nnh' => 'အွန်ရဲဘွန်း',
-        'no' => 'နော်ဝေး',
+        'no' => 'နော်ဝေ',
         'nog' => 'နိုဂိုင်',
         'nqo' => 'အွန်ကို',
         'nr' => 'တောင် အွန်န်ဘီလီ',
@@ -274,6 +298,11 @@ return [
         'ny' => 'နရန်ဂျာ',
         'nyn' => 'နရန်ကိုလီ',
         'oc' => 'အိုစီတန်',
+        'ojb' => 'အိုဂျစ်ဘွာ',
+        'ojc' => 'အိုဂျစ်ဘွေး',
+        'ojs' => 'အိုဂျီခရီ',
+        'ojw' => 'အနောက် အိုဂျီဘွာ',
+        'oka' => 'အိုကနဂန်',
         'om' => 'အိုရိုမို',
         'or' => 'အိုရီရာ',
         'os' => 'အိုဆဲတစ်ခ်',
@@ -285,7 +314,9 @@ return [
         'pcm' => 'နိုင်ဂျီးရီးယား ပစ်ဂျင်',
         'peo' => 'ပါရှန် အဟောင်း',
         'pi' => 'ပါဠိ',
+        'pis' => 'ပီဂျင်',
         'pl' => 'ပိုလန်',
+        'pqm' => 'မလိဇိ ပါစမ်မကွာဒီ',
         'prg' => 'ပရူရှန်',
         'ps' => 'ပက်ရှ်တွန်း',
         'pt' => 'ပေါ်တူဂီ',
@@ -323,6 +354,7 @@ return [
         'si' => 'စင်ဟာလာ',
         'sk' => 'ဆလိုဗက်',
         'sl' => 'ဆလိုဗေးနီးယား',
+        'slh' => 'တောင် လာ့ရှုစတိ',
         'sm' => 'ဆမိုအာ',
         'sma' => 'တောင် ဆာမိ',
         'smj' => 'လူလီ ဆာမိ',
@@ -337,6 +369,7 @@ return [
         'ss' => 'ဆွာဇီလန်',
         'ssy' => 'ဆာဟို',
         'st' => 'တောင်ပိုင်း ဆိုသို',
+        'str' => 'ဆဲလစ်ရှ် ရေလက်ကြား',
         'su' => 'ဆူဒန်',
         'suk' => 'ဆူကူမာ',
         'sv' => 'ဆွီဒင်',
@@ -344,23 +377,29 @@ return [
         'swb' => 'ကိုမိုရီးယန်း',
         'syr' => 'ဆီးရီးယား',
         'ta' => 'တမီးလ်',
+        'tce' => 'တောင် တပ်ချွန်',
         'te' => 'တီလီဂူ',
         'tem' => 'တင်မ်နဲ',
         'teo' => 'တီဆို',
         'tet' => 'တီတွမ်',
         'tg' => 'တာဂျစ်',
+        'tgx' => 'တာဂစ်ရှ်',
         'th' => 'ထိုင်း',
+        'tht' => 'တဟီတန်',
         'ti' => 'တီဂ်ရင်ယာ',
         'tig' => 'တီဂရီ',
         'tk' => 'တာ့ခ်မင်နစ္စတန်',
         'tlh' => 'ကလင်ဂွန်',
+        'tli' => 'တလင်းဂစ်',
         'tn' => 'တီဆဝါနာ',
         'to' => 'တွန်ဂါ',
+        'tok' => 'တိုကီပိုနာ',
         'tpi' => 'တော့ခ် ပိစင်',
         'tr' => 'တူရကီ',
         'trv' => 'တရိုကို',
         'ts' => 'ဆွန်ဂါ',
         'tt' => 'တာတာ',
+        'ttm' => 'မြောက် တပ်ချွန်',
         'tum' => 'တမ်ဘူကာ',
         'tvl' => 'တူဗာလူ',
         'twq' => 'တာဆာဝါချ',
@@ -384,13 +423,15 @@ return [
         'war' => 'ဝါရေး',
         'wbp' => 'ဝေါလ်ပီရီ',
         'wo' => 'ဝူလိုဖ်',
+        'wuu' => 'ဝူ တရုတ်',
         'xal' => 'ကာလ်မိုက်',
         'xh' => 'ဇိုစာ',
         'xog' => 'ဆိုဂါ',
         'yav' => 'ရန်ဘဲန်',
         'ybb' => 'ရမ်ဘာ',
-        'yi' => 'ဂျူး',
+        'yi' => 'ရဟူဒီ',
         'yo' => 'ယိုရူဘာ',
+        'yrl' => 'အန်ဟင်းဂတူ',
         'yue' => 'ကွမ်းတုံ',
         'zgh' => 'မိုရိုကို တမဇိုက်',
         'zh' => 'တရုတ်',
