@@ -16,13 +16,16 @@ return [
         'alt' => 'සතර්න් අල්ටය්',
         'am' => 'ඇම්හාරික්',
         'an' => 'ඇරගොනීස්',
+        'ann' => 'ඔබලෝ',
         'anp' => 'අන්ගික',
         'ar' => 'අරාබි',
         'arn' => 'මපුචෙ',
         'arp' => 'ඇරපහො',
+        'ars' => 'නජ්ඩි අරාබි',
         'as' => 'ඇසෑම්',
         'asa' => 'අසු',
         'ast' => 'ඇස්ටියුරියන්',
+        'atj' => 'ඇටිකමෙක්ව්',
         'av' => 'ඇවරික්',
         'awa' => 'අවදි',
         'ay' => 'අයිමරා',
@@ -48,6 +51,7 @@ return [
         'bug' => 'බුගිනීස්',
         'byn' => 'බ්ලින්',
         'ca' => 'කැටලන්',
+        'cay' => 'කයුගා',
         'ccp' => 'චක්මා',
         'ce' => 'චෙච්නියානු',
         'ceb' => 'සෙබුඅනො',
@@ -56,12 +60,21 @@ return [
         'chk' => 'චූකීස්',
         'chm' => 'මරි',
         'cho' => 'චොක්ටොව්',
+        'chp' => 'චිපෙවියන්',
         'chr' => 'චෙරොකී',
         'chy' => 'චෙයෙන්නෙ',
         'ckb' => 'සොරානි කුර්දිෂ්',
+        'clc' => 'චිල්කොටින්',
         'co' => 'කෝසිකානු',
+        'crg' => 'මිචිෆ්',
+        'crj' => 'දකුණු නැගෙනහිර ක්‍රී',
+        'crk' => 'ප්ලේන්ස් ක්‍රී',
+        'crl' => 'උතුරු නැගෙනහිර ක්‍රී',
+        'crm' => 'මූස් ක්‍රී',
+        'crr' => 'කැරොලිනා ඇල්ගොන්කියන්',
         'crs' => 'සෙසෙල්ව ක්‍රොල් ෆ්‍රෙන්ච්',
         'cs' => 'චෙක්',
+        'csw' => 'මඩ වගුරු ක්‍රී',
         'cu' => 'චර්ච් ස්ලැවික්',
         'cv' => 'චවේෂ්',
         'cy' => 'වෙල්ෂ්',
@@ -98,6 +111,8 @@ return [
         'fo' => 'ෆාරෝස්',
         'fon' => 'ෆොන්',
         'fr' => 'ප්‍රංශ',
+        'frc' => 'කජුන් ප්‍රංශ',
+        'frr' => 'උතුරු ෆ්‍රිසියානු',
         'fur' => 'ෆ්‍රියුලියන්',
         'fy' => 'බටහිර ෆ්‍රිසියානු',
         'ga' => 'අයර්ලන්ත',
@@ -116,8 +131,10 @@ return [
         'gv' => 'මැන්ක්ස්',
         'gwi' => 'ග්විචින්',
         'ha' => 'හෝසා',
+        'hai' => 'හයිඩා',
         'hak' => 'හකා චයිනිස්',
         'haw' => 'හවායි',
+        'hax' => 'දකුණු හයිඩා',
         'he' => 'හීබෲ',
         'hi' => 'හින්දි',
         'hil' => 'හිලිගෙනන්',
@@ -128,6 +145,7 @@ return [
         'ht' => 'හයිටි',
         'hu' => 'හන්ගේරියානු',
         'hup' => 'හුපා',
+        'hur' => 'හල්කොමලෙම්',
         'hy' => 'ආර්මේනියානු',
         'hz' => 'හෙරෙරො',
         'ia' => 'ඉන්ටලින්ගුආ',
@@ -136,6 +154,7 @@ return [
         'id' => 'ඉන්දුනීසියානු',
         'ig' => 'ඉග්බෝ',
         'ii' => 'සිචුආන් යී',
+        'ikt' => 'බටහිර කැනේඩියානු ඉනුක්ටිටුට්',
         'ilo' => 'ඉලොකො',
         'inh' => 'ඉන්ගුෂ්',
         'io' => 'ඉඩො',
@@ -157,6 +176,7 @@ return [
         'kde' => 'මැකොන්ඩ්',
         'kea' => 'කබුවෙර්ඩියානු',
         'kfo' => 'කොරො',
+        'kgp' => 'කයිංගං',
         'kha' => 'ඛසි',
         'khq' => 'කොයිරා චිනි',
         'ki' => 'කිකුයු',
@@ -184,6 +204,7 @@ return [
         'kum' => 'කුමික්',
         'kv' => 'කොමි',
         'kw' => 'කෝනීසියානු',
+        'kwk' => 'ක්වාක්වාලා',
         'ky' => 'කිර්ගිස්',
         'la' => 'ලතින්',
         'lad' => 'ලඩිනො',
@@ -192,11 +213,14 @@ return [
         'lez' => 'ලෙස්ගියන්',
         'lg' => 'ගන්ඩා',
         'li' => 'ලිම්බර්ගිශ්',
+        'lil' => 'ලිලූට්',
         'lkt' => 'ලකොට',
         'ln' => 'ලින්ගලා',
         'lo' => 'ලාඕ',
+        'lou' => 'ලුසියානා ක්‍රියෝල්',
         'loz' => 'ලොසි',
         'lrc' => 'උතුරු ලුරි',
+        'lsm' => 'සාමියා',
         'lt' => 'ලිතුවේනියානු',
         'lu' => 'ලුබා-කටන්ගා',
         'lua' => 'ලුබ-ලුලුඅ',
@@ -225,6 +249,7 @@ return [
         'ml' => 'මලයාලම්',
         'mn' => 'මොංගෝලියානු',
         'mni' => 'මනිපුරි',
+        'moe' => 'ඉනු-අයිමුන්',
         'moh' => 'මොහොව්ක්',
         'mos' => 'මොස්සි',
         'mr' => 'මරාති',
@@ -262,6 +287,11 @@ return [
         'ny' => 'න්යන්ජා',
         'nyn' => 'නයන්කෝලෙ',
         'oc' => 'ඔසිටාන්',
+        'ojb' => 'වයඹ ඔජිබ්වා',
+        'ojc' => 'මධ්‍යම ඔජිබ්වා',
+        'ojs' => 'ඔජි-ක්‍රී',
+        'ojw' => 'බටහිර ඔජිබ්වා',
+        'oka' => 'ඔකනගන්',
         'om' => 'ඔරොමෝ',
         'or' => 'ඔඩියා',
         'os' => 'ඔසිටෙක්',
@@ -271,7 +301,9 @@ return [
         'pap' => 'පපියමෙන්ටො',
         'pau' => 'පලවුවන්',
         'pcm' => 'නෛජීරියන් පෙන්ගින්',
+        'pis' => 'පිජින්',
         'pl' => 'පෝලන්ත',
+        'pqm' => 'මලිසීට්-පස්සමකුඩි',
         'prg' => 'පෘශියන්',
         'ps' => 'පෂ්ටො',
         'pt' => 'පෘතුගීසි',
@@ -309,6 +341,7 @@ return [
         'si' => 'සිංහල',
         'sk' => 'ස්ලෝවැක්',
         'sl' => 'ස්ලෝවේනියානු',
+        'slh' => 'දකුණු ලුෂූට්සීඩ්',
         'sm' => 'සෑමොඅන්',
         'sma' => 'දකුණු සාමි',
         'smj' => 'ලුලේ සාමි',
@@ -323,6 +356,7 @@ return [
         'ss' => 'ස්වති',
         'ssy' => 'සහො',
         'st' => 'සතර්න් සොතො',
+        'str' => 'සාලිෂ්ස මුද්ර සන්ධිය',
         'su' => 'සන්ඩනීසියානු',
         'suk' => 'සුකුමා',
         'sv' => 'ස්වීඩන්',
@@ -330,23 +364,29 @@ return [
         'swb' => 'කොමොරියන්',
         'syr' => 'ස්‍රයෑක්',
         'ta' => 'දෙමළ',
+        'tce' => 'දකුණු ටචෝන්',
         'te' => 'තෙළිඟු',
         'tem' => 'ටිම්නෙ',
         'teo' => 'ටෙසෝ',
         'tet' => 'ටේටම්',
         'tg' => 'ටජික්',
+        'tgx' => 'ටැගිෂ්',
         'th' => 'තායි',
+        'tht' => 'ටැල්ටන්',
         'ti' => 'ටිග්‍රින්යා',
         'tig' => 'ටීග්‍රෙ',
         'tk' => 'ටර්ක්මෙන්',
         'tlh' => 'ක්ලින්ගොන්',
+        'tli' => 'ට්ලින්ගිට්',
         'tn' => 'ස්වනා',
         'to' => 'ටොංගා',
+        'tok' => 'ටෝකි පොනා',
         'tpi' => 'ටොක් පිසින්',
         'tr' => 'තුර්කි',
         'trv' => 'ටරොකො',
         'ts' => 'සොන්ග',
         'tt' => 'ටාටර්',
+        'ttm' => 'උතුරු ටචෝන්',
         'tum' => 'ටුම්බුකා',
         'tvl' => 'ටුවාලු',
         'twq' => 'ටසවාක්',
@@ -378,6 +418,7 @@ return [
         'ybb' => 'යෙම්බා',
         'yi' => 'යිඩිශ්',
         'yo' => 'යොරූබා',
+        'yrl' => 'නොහීඟටු',
         'yue' => 'කැන්ටොනීස්',
         'zgh' => 'සම්මත මොරොක්කෝ ටමසිග්ත්',
         'zh' => 'චීන',
