@@ -20,15 +20,18 @@ return [
         'am' => 'amharščina',
         'an' => 'aragonščina',
         'ang' => 'stara angleščina',
+        'ann' => 'obolo',
         'anp' => 'angikaščina',
         'ar' => 'arabščina',
         'arc' => 'aramejščina',
         'arn' => 'mapudungunščina',
         'arp' => 'arapaščina',
+        'ars' => 'nadždska arabščina',
         'arw' => 'aravaščina',
         'as' => 'asamščina',
         'asa' => 'asujščina',
         'ast' => 'asturijščina',
+        'atj' => 'atikamekwščina',
         'av' => 'avarščina',
         'awa' => 'avadščina',
         'ay' => 'ajmarščina',
@@ -61,6 +64,7 @@ return [
         'ca' => 'katalonščina',
         'cad' => 'kadoščina',
         'car' => 'karibski jezik',
+        'cay' => 'kajuščina',
         'ccp' => 'chakma',
         'ce' => 'čečenščina',
         'ceb' => 'sebuanščina',
@@ -76,13 +80,21 @@ return [
         'chr' => 'čerokeščina',
         'chy' => 'čejenščina',
         'ckb' => 'soranska kurdščina',
+        'clc' => 'čilkotinščina',
         'co' => 'korziščina',
         'cop' => 'koptščina',
         'cr' => 'krijščina',
+        'crg' => 'mičifščina',
         'crh' => 'krimska tatarščina',
+        'crj' => 'jugovzhodna krijščina',
+        'crk' => 'nižinska krijščina',
+        'crl' => 'severovzhodna krijščina',
+        'crm' => 'moose-krijščina',
+        'crr' => 'karolinska algonkinščina',
         'crs' => 'sejšelska francoska kreolščina',
         'cs' => 'češčina',
         'csb' => 'kašubščina',
+        'csw' => 'močvirska krijščina',
         'cu' => 'stara cerkvena slovanščina',
         'cv' => 'čuvaščina',
         'cy' => 'valižanščina',
@@ -161,6 +173,7 @@ return [
         'ha' => 'havščina',
         'hai' => 'haidščina',
         'haw' => 'havajščina',
+        'hax' => 'južna haidščina',
         'he' => 'hebrejščina',
         'hi' => 'hindijščina',
         'hil' => 'hiligajnonščina',
@@ -172,6 +185,7 @@ return [
         'ht' => 'haitijska kreolščina',
         'hu' => 'madžarščina',
         'hup' => 'hupa',
+        'hur' => 'halkomelenščina',
         'hy' => 'armenščina',
         'hz' => 'herero',
         'ia' => 'interlingva',
@@ -182,6 +196,7 @@ return [
         'ig' => 'igboščina',
         'ii' => 'sečuanska jiščina',
         'ik' => 'inupiaščina',
+        'ikt' => 'zahodna kanadska inuktituščina',
         'ilo' => 'ilokanščina',
         'inh' => 'inguščina',
         'io' => 'ido',
@@ -208,6 +223,7 @@ return [
         'kea' => 'zelenortskootoška kreolščina',
         'kfo' => 'koro',
         'kg' => 'kongovščina',
+        'kgp' => 'kaingangščina',
         'kha' => 'kasi',
         'kho' => 'kotanščina',
         'khq' => 'koyra chiini',
@@ -238,6 +254,7 @@ return [
         'kut' => 'kutenajščina',
         'kv' => 'komijščina',
         'kw' => 'kornijščina',
+        'kwk' => 'kvakvala',
         'ky' => 'kirgiščina',
         'la' => 'latinščina',
         'lad' => 'ladinščina',
@@ -248,6 +265,7 @@ return [
         'lez' => 'lezginščina',
         'lg' => 'ganda',
         'li' => 'limburščina',
+        'lil' => 'lilovetščina',
         'lkt' => 'lakotščina',
         'ln' => 'lingala',
         'lo' => 'laoščina',
@@ -255,6 +273,7 @@ return [
         'lou' => 'louisianska kreolščina',
         'loz' => 'lozi',
         'lrc' => 'severna lurijščina',
+        'lsm' => 'saamijščina',
         'lt' => 'litovščina',
         'lu' => 'luba-katanga',
         'lua' => 'luba-lulua',
@@ -288,6 +307,7 @@ return [
         'mn' => 'mongolščina',
         'mnc' => 'mandžurščina',
         'mni' => 'manipurščina',
+        'moe' => 'inuaimunščina',
         'moh' => 'mohoščina',
         'mos' => 'mosijščina',
         'mr' => 'maratščina',
@@ -332,6 +352,11 @@ return [
         'nzi' => 'nzima',
         'oc' => 'okcitanščina',
         'oj' => 'anašinabščina',
+        'ojb' => 'severozahodna očipvejščina',
+        'ojc' => 'osrednja očipvejščina',
+        'ojs' => 'oči-krijščina',
+        'ojw' => 'zahodna očipvejščina',
+        'oka' => 'okanaganščina',
         'om' => 'oromo',
         'or' => 'odijščina',
         'os' => 'osetinščina',
@@ -346,8 +371,10 @@ return [
         'peo' => 'stara perzijščina',
         'phn' => 'feničanščina',
         'pi' => 'palijščina',
+        'pis' => 'pidžin',
         'pl' => 'poljščina',
         'pon' => 'ponpejščina',
+        'pqm' => 'maliseet-passamaquoddščina',
         'prg' => 'stara pruščina',
         'pro' => 'stara provansalščina',
         'ps' => 'paštunščina',
@@ -394,6 +421,7 @@ return [
         'sid' => 'sidamščina',
         'sk' => 'slovaščina',
         'sl' => 'slovenščina',
+        'slh' => 'južna lušucidščina',
         'sm' => 'samoanščina',
         'sma' => 'južna samijščina',
         'smj' => 'luleška samijščina',
@@ -409,6 +437,7 @@ return [
         'ss' => 'svazijščina',
         'ssy' => 'saho',
         'st' => 'sesoto',
+        'str' => 'ožinska sališčina',
         'su' => 'sundanščina',
         'suk' => 'sukuma',
         'sus' => 'susujščina',
@@ -419,12 +448,15 @@ return [
         'syc' => 'klasična sirščina',
         'syr' => 'sirščina',
         'ta' => 'tamilščina',
+        'tce' => 'južna tučonščina',
         'te' => 'telugijščina',
         'tem' => 'temnejščina',
         'teo' => 'teso',
         'tet' => 'tetumščina',
         'tg' => 'tadžiščina',
+        'tgx' => 'tagiščina',
         'th' => 'tajščina',
+        'tht' => 'taltanščina',
         'ti' => 'tigrajščina',
         'tig' => 'tigrejščina',
         'tiv' => 'tivščina',
@@ -437,12 +469,14 @@ return [
         'tn' => 'cvanščina',
         'to' => 'tongščina',
         'tog' => 'malavijska tongščina',
+        'tok' => 'toki pona',
         'tpi' => 'tok pisin',
         'tr' => 'turščina',
         'trv' => 'taroko',
         'ts' => 'congščina',
         'tsi' => 'tsimščina',
         'tt' => 'tatarščina',
+        'ttm' => 'severna tučonščina',
         'tum' => 'tumbukščina',
         'tvl' => 'tuvalujščina',
         'tw' => 'tvi',
@@ -470,6 +504,7 @@ return [
         'was' => 'vašajščina',
         'wbp' => 'varlpirščina',
         'wo' => 'volofščina',
+        'wuu' => 'wu-kitajščina',
         'xal' => 'kalmiščina',
         'xh' => 'koščina',
         'xog' => 'sogščina',
@@ -479,6 +514,7 @@ return [
         'ybb' => 'jembajščina',
         'yi' => 'jidiš',
         'yo' => 'jorubščina',
+        'yrl' => 'nheengatu',
         'yue' => 'kantonščina',
         'zap' => 'zapoteščina',
         'zbl' => 'znakovni jezik Bliss',
