@@ -23,6 +23,7 @@ return [
         'am' => 'amhariska',
         'an' => 'aragonesiska',
         'ang' => 'fornengelska',
+        'ann' => 'obolo',
         'anp' => 'angika',
         'ar' => 'arabiska',
         'arc' => 'arameiska',
@@ -38,6 +39,7 @@ return [
         'asa' => 'asu',
         'ase' => 'amerikanskt teckenspråk',
         'ast' => 'asturiska',
+        'atj' => 'atikamekw',
         'av' => 'avariska',
         'avk' => 'kotava',
         'awa' => 'awadhi',
@@ -103,14 +105,22 @@ return [
         'chr' => 'cherokesiska',
         'chy' => 'cheyenne',
         'ckb' => 'soranisk kurdiska',
+        'clc' => 'chilcotin',
         'co' => 'korsikanska',
         'cop' => 'koptiska',
         'cps' => 'kapisnon',
         'cr' => 'cree',
+        'crg' => 'michif',
         'crh' => 'krimtatariska',
+        'crj' => 'sydostcree',
+        'crk' => 'slättcree',
+        'crl' => 'nordost-cree',
+        'crm' => 'moose cree',
+        'crr' => 'Carolina-algonkinska',
         'crs' => 'seychellisk kreol',
         'cs' => 'tjeckiska',
         'csb' => 'kasjubiska',
+        'csw' => 'träskcree',
         'cu' => 'kyrkslaviska',
         'cv' => 'tjuvasjiska',
         'cy' => 'walesiska',
@@ -202,6 +212,7 @@ return [
         'hai' => 'haida',
         'hak' => 'hakka',
         'haw' => 'hawaiiska',
+        'hax' => 'sydhaida',
         'he' => 'hebreiska',
         'hi' => 'hindi',
         'hif' => 'Fiji-hindi',
@@ -215,6 +226,7 @@ return [
         'ht' => 'haitiska',
         'hu' => 'ungerska',
         'hup' => 'hupa',
+        'hur' => 'halkomelem',
         'hy' => 'armeniska',
         'hz' => 'herero',
         'ia' => 'interlingua',
@@ -225,6 +237,7 @@ return [
         'ig' => 'igbo',
         'ii' => 'szezuan i',
         'ik' => 'inupiak',
+        'ikt' => 'inuktun',
         'ilo' => 'iloko',
         'inh' => 'ingusjiska',
         'io' => 'ido',
@@ -291,6 +304,7 @@ return [
         'kut' => 'kutenaj',
         'kv' => 'kome',
         'kw' => 'korniska',
+        'kwk' => 'kwakʼwala',
         'ky' => 'kirgiziska',
         'la' => 'latin',
         'lad' => 'ladino',
@@ -303,6 +317,7 @@ return [
         'lg' => 'luganda',
         'li' => 'limburgiska',
         'lij' => 'liguriska',
+        'lil' => 'lillooet',
         'liv' => 'livoniska',
         'lkt' => 'lakota',
         'lmo' => 'lombardiska',
@@ -312,6 +327,7 @@ return [
         'lou' => 'louisiana-kreol',
         'loz' => 'lozi',
         'lrc' => 'nordluri',
+        'lsm' => 'saamia',
         'lt' => 'litauiska',
         'ltg' => 'lettgalliska',
         'lu' => 'luba-katanga',
@@ -350,6 +366,7 @@ return [
         'mn' => 'mongoliska',
         'mnc' => 'manchuriska',
         'mni' => 'manipuri',
+        'moe' => 'innu-aimun',
         'moh' => 'mohawk',
         'mos' => 'mossi',
         'mr' => 'marathi',
@@ -399,6 +416,11 @@ return [
         'nzi' => 'nzima',
         'oc' => 'occitanska',
         'oj' => 'odjibwa',
+        'ojb' => 'nordvästojibwa',
+        'ojc' => 'ojibwa',
+        'ojs' => 'oji-cree',
+        'ojw' => 'västojibwe',
+        'oka' => 'okanagan',
         'om' => 'oromo',
         'or' => 'oriya',
         'os' => 'ossetiska',
@@ -418,10 +440,12 @@ return [
         'pfl' => 'Pfalz-tyska',
         'phn' => 'feniciska',
         'pi' => 'pali',
+        'pis' => 'pidginspråk',
         'pl' => 'polska',
         'pms' => 'piemontesiska',
         'pnt' => 'pontiska',
         'pon' => 'pohnpeiska',
+        'pqm' => 'maliseet-passamaquoddy',
         'prg' => 'fornpreussiska',
         'pro' => 'fornprovensalska',
         'ps' => 'afghanska',
@@ -480,6 +504,7 @@ return [
         'sid' => 'sidamo',
         'sk' => 'slovakiska',
         'sl' => 'slovenska',
+        'slh' => 'sydlushootseed',
         'sli' => 'lågsilesiska',
         'sly' => 'selayar',
         'sm' => 'samoanska',
@@ -499,6 +524,7 @@ return [
         'ssy' => 'saho',
         'st' => 'sydsotho',
         'stq' => 'saterfrisiska',
+        'str' => 'sundsalishanska',
         'su' => 'sundanesiska',
         'suk' => 'sukuma',
         'sus' => 'susu',
@@ -510,6 +536,7 @@ return [
         'syr' => 'syriska',
         'szl' => 'silesiska',
         'ta' => 'tamil',
+        'tce' => 'sydtutchone',
         'tcy' => 'tulu',
         'te' => 'telugu',
         'tem' => 'temne',
@@ -517,7 +544,9 @@ return [
         'ter' => 'tereno',
         'tet' => 'tetum',
         'tg' => 'tadzjikiska',
+        'tgx' => 'tagish',
         'th' => 'thailändska',
+        'tht' => 'tahltan',
         'ti' => 'tigrinja',
         'tig' => 'tigré',
         'tiv' => 'tivi',
@@ -532,6 +561,7 @@ return [
         'tn' => 'tswana',
         'to' => 'tonganska',
         'tog' => 'nyasatonganska',
+        'tok' => 'toki pona',
         'tpi' => 'tok pisin',
         'tr' => 'turkiska',
         'tru' => 'turoyo',
@@ -540,6 +570,7 @@ return [
         'tsd' => 'tsakodiska',
         'tsi' => 'tsimshian',
         'tt' => 'tatariska',
+        'ttm' => 'nordtutchone',
         'ttt' => 'muslimsk tatariska',
         'tum' => 'tumbuka',
         'tvl' => 'tuvaluanska',
@@ -611,6 +642,7 @@ return [
         'fa_AF' => 'dari',
         'fr_CA' => 'kanadensisk franska',
         'fr_CH' => 'schweizisk franska',
+        'hi_Latn' => 'hindi (latinsk)',
         'nds_NL' => 'lågsaxiska',
         'nl_BE' => 'flamländska',
         'pt_BR' => 'brasiliansk portugisiska',
