@@ -21,15 +21,18 @@ return [
         'am' => 'அம்ஹாரிக்',
         'an' => 'ஆர்கோனீஸ்',
         'ang' => 'பழைய ஆங்கிலம்',
+        'ann' => 'ஒபோலோ',
         'anp' => 'அங்கிகா',
         'ar' => 'அரபிக்',
         'arc' => 'அராமைக்',
         'arn' => 'மபுச்சே',
         'arp' => 'அரபஹோ',
+        'ars' => 'நஜ்தி அரபிக்',
         'arw' => 'அராவாக்',
         'as' => 'அஸ்ஸாமீஸ்',
         'asa' => 'அசு',
         'ast' => 'அஸ்துரியன்',
+        'atj' => 'அடிகாமேக்வ்',
         'av' => 'அவேரிக்',
         'awa' => 'அவதி',
         'ay' => 'அய்மரா',
@@ -64,6 +67,7 @@ return [
         'ca' => 'கேட்டலான்',
         'cad' => 'கேடோ',
         'car' => 'கரீப்',
+        'cay' => 'கேயுகா',
         'cch' => 'ஆட்சம்',
         'ccp' => 'சக்மா',
         'ce' => 'செச்சென்',
@@ -80,13 +84,21 @@ return [
         'chr' => 'செரோகீ',
         'chy' => 'செயேனி',
         'ckb' => 'மத்திய குர்திஷ்',
+        'clc' => 'சில்கோடின்',
         'co' => 'கார்சிகன்',
         'cop' => 'காப்டிக்',
         'cr' => 'க்ரீ',
+        'crg' => 'மிச்சிஃப்',
         'crh' => 'கிரிமியன் துர்க்கி',
+        'crj' => 'தென்கிழக்கு க்ரீ',
+        'crk' => 'சமவெளி க்ரீ',
+        'crl' => 'வடகிழக்கு க்ரீ',
+        'crm' => 'மூஸ் க்ரீ',
+        'crr' => 'கரோலினா அல்கோன்குயன்',
         'crs' => 'செசெல்வா க்ரெயோல் பிரெஞ்சு',
         'cs' => 'செக்',
         'csb' => 'கஷுபியன்',
+        'csw' => 'சதுப்பு நில க்ரீ',
         'cu' => 'சர்ச் ஸ்லாவிக்',
         'cv' => 'சுவாஷ்',
         'cy' => 'வேல்ஷ்',
@@ -167,6 +179,7 @@ return [
         'hai' => 'ஹைடா',
         'hak' => 'ஹக்கா சீனம்',
         'haw' => 'ஹவாயியன்',
+        'hax' => 'தெற்கு ஹைடா',
         'he' => 'ஹீப்ரூ',
         'hi' => 'இந்தி',
         'hif' => 'ஃபிஜி இந்தி',
@@ -180,6 +193,7 @@ return [
         'ht' => 'ஹைத்தியன் க்ரியோலி',
         'hu' => 'ஹங்கேரியன்',
         'hup' => 'ஹுபா',
+        'hur' => 'ஹல்கோமெலம்',
         'hy' => 'ஆர்மேனியன்',
         'hz' => 'ஹெரேரோ',
         'ia' => 'இன்டர்லிங்வா',
@@ -190,6 +204,7 @@ return [
         'ig' => 'இக்போ',
         'ii' => 'சிசுவான் ஈ',
         'ik' => 'இனுபியாக்',
+        'ikt' => 'மேற்கு கனடிய இனுக்டிடுட்',
         'ilo' => 'இலோகோ',
         'inh' => 'இங்குஷ்',
         'io' => 'இடோ',
@@ -216,6 +231,7 @@ return [
         'kea' => 'கபுவெர்தியானு',
         'kfo' => 'கோரோ',
         'kg' => 'காங்கோ',
+        'kgp' => 'கைன்கேங்',
         'kha' => 'காஸி',
         'kho' => 'கோதானீஸ்',
         'khq' => 'கொய்ரா சீனீ',
@@ -242,10 +258,11 @@ return [
         'ksf' => 'பாஃபியா',
         'ksh' => 'கொலோக்னியன்',
         'ku' => 'குர்திஷ்',
-        'kum' => 'கும்இக்',
+        'kum' => 'கும்யிக்',
         'kut' => 'குடேனை',
         'kv' => 'கொமி',
         'kw' => 'கார்னிஷ்',
+        'kwk' => 'குவாக்வாலா',
         'ky' => 'கிர்கிஸ்',
         'la' => 'லத்தின்',
         'lad' => 'லடினோ',
@@ -256,13 +273,16 @@ return [
         'lez' => 'லெஜ்ஜியன்',
         'lg' => 'கான்டா',
         'li' => 'லிம்பர்கிஷ்',
+        'lil' => 'லில்லூயிட்',
         'lkt' => 'லகோடா',
+        'lmo' => 'லொம்பார்டு',
         'ln' => 'லிங்காலா',
         'lo' => 'லாவோ',
         'lol' => 'மோங்கோ',
         'lou' => 'லூசியானா க்ரயோல்',
         'loz' => 'லோசி',
         'lrc' => 'வடக்கு லுரி',
+        'lsm' => 'சாமியா',
         'lt' => 'லிதுவேனியன்',
         'lu' => 'லுபா-கடாங்கா',
         'lua' => 'லுபா-லுலுலா',
@@ -296,6 +316,7 @@ return [
         'mn' => 'மங்கோலியன்',
         'mnc' => 'மன்சூ',
         'mni' => 'மணிப்புரி',
+        'moe' => 'இன்னு-ஐமுன்',
         'moh' => 'மொஹாக்',
         'mos' => 'மோஸ்ஸி',
         'mr' => 'மராத்தி',
@@ -340,6 +361,11 @@ return [
         'nzi' => 'நிஜ்மா',
         'oc' => 'ஒக்கிடன்',
         'oj' => 'ஒஜிப்வா',
+        'ojb' => 'வடமேற்கு ஓஜிப்வா',
+        'ojc' => 'மத்திய ஓஜிப்வா',
+        'ojs' => 'ஓஜி-க்ரீ',
+        'ojw' => 'மேற்கு ஓஜிப்வா',
+        'oka' => 'ஒகானகன்',
         'om' => 'ஒரோமோ',
         'or' => 'ஒடியா',
         'os' => 'ஒசெட்டிக்',
@@ -356,12 +382,14 @@ return [
         'peo' => 'பழைய பெர்ஷியன்',
         'phn' => 'ஃபொனிஷியன்',
         'pi' => 'பாலி',
+        'pis' => 'பிஜின்',
         'pl' => 'போலிஷ்',
         'pon' => 'ஃபோன்பெயென்',
+        'pqm' => 'மலிசீட்-பஸ்ஸமகுவாடி',
         'prg' => 'பிரஷ்யன்',
         'pro' => 'பழைய ப்ரோவென்சால்',
         'ps' => 'பஷ்தோ',
-        'pt' => 'போர்ச்சுக்கீஸ்',
+        'pt' => 'போர்ச்சுகீஸ்',
         'qu' => 'க்வெச்சுவா',
         'quc' => 'கீசீ',
         'raj' => 'ராஜஸ்தானி',
@@ -405,6 +433,7 @@ return [
         'sid' => 'சிடாமோ',
         'sk' => 'ஸ்லோவாக்',
         'sl' => 'ஸ்லோவேனியன்',
+        'slh' => 'தெற்கு லுஷூட்சீட்',
         'sm' => 'சமோவான்',
         'sma' => 'தெற்கு சமி',
         'smj' => 'லுலே சமி',
@@ -421,6 +450,7 @@ return [
         'ss' => 'ஸ்வாடீ',
         'ssy' => 'சஹோ',
         'st' => 'தெற்கு ஸோதோ',
+        'str' => 'ஸ்ட்ரெய்ட்ஸ் சாலிஷ்',
         'su' => 'சுண்டானீஸ்',
         'suk' => 'சுகுமா',
         'sus' => 'சுசு',
@@ -431,13 +461,16 @@ return [
         'syc' => 'பாரம்பரிய சிரியாக்',
         'syr' => 'சிரியாக்',
         'ta' => 'தமிழ்',
+        'tce' => 'தெற்கு டட்சோன்',
         'te' => 'தெலுங்கு',
         'tem' => 'டிம்னே',
         'teo' => 'டெசோ',
         'ter' => 'டெரெனோ',
         'tet' => 'டெடும்',
         'tg' => 'தஜிக்',
+        'tgx' => 'தகிஷ்',
         'th' => 'தாய்',
+        'tht' => 'தால்டன்',
         'ti' => 'டிக்ரின்யா',
         'tig' => 'டைக்ரே',
         'tiv' => 'டிவ்',
@@ -450,12 +483,14 @@ return [
         'tn' => 'ஸ்வானா',
         'to' => 'டோங்கான்',
         'tog' => 'நயாசா டோங்கா',
+        'tok' => 'டோக்கி போனா',
         'tpi' => 'டோக் பிஸின்',
         'tr' => 'துருக்கிஷ்',
         'trv' => 'தரோகோ',
         'ts' => 'ஸோங்கா',
         'tsi' => 'ட்ஸிம்ஷியன்',
         'tt' => 'டாடர்',
+        'ttm' => 'வடக்கு டட்சோன்',
         'tum' => 'தும்புகா',
         'tvl' => 'டுவாலு',
         'tw' => 'ட்வி',
@@ -493,6 +528,7 @@ return [
         'ybb' => 'யெம்பா',
         'yi' => 'யெட்டிஷ்',
         'yo' => 'யோருபா',
+        'yrl' => 'நஹீன்கட்டு',
         'yue' => 'காண்டோனீஸ்',
         'za' => 'ஜுவாங்',
         'zap' => 'ஜாபோடெக்',
