@@ -23,6 +23,7 @@ return [
         'am' => 'lea fakaʻameliki',
         'an' => 'lea fakaʻalakoni',
         'ang' => 'lea fakapālangi-motuʻa',
+        'ann' => 'lea fakaʻopolo',
         'anp' => 'lea fakaʻangika',
         'ar' => 'lea fakaʻalepea',
         'arc' => 'lea fakaʻalāmiti',
@@ -30,6 +31,7 @@ return [
         'aro' => 'lea fakaʻalaona',
         'arp' => 'lea fakaʻalapaho',
         'arq' => 'lea fakaʻalepea-ʻaisilia',
+        'ars' => 'lea fakaʻalepea-nāsiti',
         'arw' => 'lea fakaʻalauaki',
         'ary' => 'lea fakaʻalepea-moloko',
         'arz' => 'lea fakaʻalepea-ʻisipite',
@@ -37,6 +39,7 @@ return [
         'asa' => 'lea fakaʻasu',
         'ase' => 'lea fakaʻilonga-ʻamelika',
         'ast' => 'lea fakaʻasitūlia',
+        'atj' => 'lea fakaʻatikameku',
         'av' => 'lea fakaʻavaliki',
         'avk' => 'lea fakakotava',
         'awa' => 'lea fakaʻauati',
@@ -102,14 +105,22 @@ return [
         'chr' => 'lea fakaselokī',
         'chy' => 'lea fakaseiene',
         'ckb' => 'lea fakakūtisi-loloto',
+        'clc' => 'lea fakatisilikōtini',
         'co' => 'lea fakakōsika',
         'cop' => 'lea fakakopitika',
         'cps' => 'lea fakakapiseno',
         'cr' => 'lea fakakelī',
+        'crg' => 'lea fakametisifi',
         'crh' => 'lea fakatoake-kilimea',
+        'crj' => 'lea fakakilī-tongahahake',
+        'crk' => 'lea fakakilī-toafa',
+        'crl' => 'lea fakakilī-tokelauhahake',
+        'crm' => 'lea fakamose-kilī',
+        'crr' => 'lea fakaʻalakonikuia-kalolina',
         'crs' => 'lea fakaseselua-falanisē',
         'cs' => 'lea fakaseki',
         'csb' => 'lea fakakasiupia',
+        'csw' => 'lea fakakilī-ano',
         'cu' => 'lea fakasilavia-fakasiasi',
         'cv' => 'lea fakasuvasa',
         'cy' => 'lea fakauēlesi',
@@ -201,6 +212,7 @@ return [
         'hai' => 'lea fakahaita',
         'hak' => 'lea fakasiaina-haka',
         'haw' => 'lea fakahauaiʻi',
+        'hax' => 'lea fakahaita-tonga',
         'he' => 'lea fakahepelū',
         'hi' => 'lea fakahinitī',
         'hif' => 'lea fakahinitī-fisi',
@@ -214,6 +226,7 @@ return [
         'ht' => 'lea fakahaiti',
         'hu' => 'lea fakahungakalia',
         'hup' => 'lea fakahupa',
+        'hur' => 'lea fakahalikomele',
         'hy' => 'lea fakaʻāmenia',
         'hz' => 'lea fakahelelo',
         'ia' => 'lea fakavahaʻalea',
@@ -224,12 +237,13 @@ return [
         'ig' => 'lea fakaʻikipō',
         'ii' => 'lea fakasisiuani-ī',
         'ik' => 'lea fakaʻinupiaki',
+        'ikt' => 'lea fakaʻinuketītuti-kānata-hihifo',
         'ilo' => 'lea fakaʻiloko',
         'inh' => 'lea fakaʻingusi',
         'io' => 'lea fakaʻito',
         'is' => 'lea fakaʻaisilani',
         'it' => 'lea fakaʻītali',
-        'iu' => 'lea fakaʻinuketituti',
+        'iu' => 'lea fakaʻinuketītuti',
         'izh' => 'lea fakaʻingiliani',
         'ja' => 'lea fakasiapani',
         'jam' => 'lea fakapālangi-samaika',
@@ -290,6 +304,7 @@ return [
         'kut' => 'lea fakakutenai',
         'kv' => 'lea fakakomi',
         'kw' => 'lea fakakoniuali',
+        'kwk' => 'lea fakakuakuala',
         'ky' => 'lea fakakīsisi',
         'la' => 'lea fakalatina',
         'lad' => 'lea fakalatino',
@@ -302,14 +317,17 @@ return [
         'lg' => 'lea fakakanita',
         'li' => 'lea fakalimipūliki',
         'lij' => 'lea fakalikulia',
+        'lil' => 'lea fakalilōeti',
         'liv' => 'lea fakalivonia',
         'lkt' => 'lea fakalakota',
         'lmo' => 'lea fakalomipāti',
         'ln' => 'lea lingikala',
         'lo' => 'lea fakalau',
         'lol' => 'lea fakamongikō',
+        'lou' => 'lea fakaluisiana',
         'loz' => 'lea fakalosi',
         'lrc' => 'lea fakaluli-tokelau',
+        'lsm' => 'lea fakasāmia',
         'lt' => 'lea fakalituania',
         'ltg' => 'lea fakalatakale',
         'lu' => 'lea fakalupa-katanga',
@@ -348,6 +366,7 @@ return [
         'mn' => 'lea fakamongokōlia',
         'mnc' => 'lea fakamanisū',
         'mni' => 'lea fakamanipuli',
+        'moe' => 'lea fakaʻinuʻaimuni',
         'moh' => 'lea fakamohauki',
         'mos' => 'lea fakamosi',
         'mr' => 'lea fakamalati',
@@ -397,8 +416,13 @@ return [
         'nzi' => 'lea fakanesima',
         'oc' => 'lea fakaʻokitane',
         'oj' => 'lea fakaʻosipiuā',
+        'ojb' => 'lea fakaʻosipiuā-tokelauhihifo',
+        'ojc' => 'lea fakaʻosipiuā-loto',
+        'ojs' => 'lea fakakilī-osi',
+        'ojw' => 'lea fakaʻosipiuā-hihifo',
+        'oka' => 'lea faka-ʻokanākani',
         'om' => 'lea fakaʻolomo',
-        'or' => 'lea faka-ʻotia',
+        'or' => 'lea fakaʻotia',
         'os' => 'lea fakaʻosetiki',
         'osa' => 'lea fakaʻosēse',
         'ota' => 'lea fakatoake-ʻotomani',
@@ -416,10 +440,12 @@ return [
         'pfl' => 'lea fakasiamane-palatine',
         'phn' => 'lea fakafoinikia',
         'pi' => 'lea fakapāli',
+        'pis' => 'lea fakapisini',
         'pl' => 'lea fakapolani',
         'pms' => 'lea fakapiemonite',
         'pnt' => 'lea fakaponitiki',
         'pon' => 'lea fakaponapē',
+        'pqm' => 'lea fakamaliseti-pasamakuoti',
         'prg' => 'lea fakapulūsia',
         'pro' => 'lea fakapolovenisi-motuʻa',
         'ps' => 'lea fakapasitō',
@@ -478,6 +504,7 @@ return [
         'sid' => 'lea fakasitamo',
         'sk' => 'lea fakasolāvaki',
         'sl' => 'lea fakasolovenia',
+        'slh' => 'lea fakalusūtisiti',
         'sli' => 'lea fakasilesia-hifo',
         'sly' => 'lea fakaselaiā',
         'sm' => 'lea fakahaʻamoa',
@@ -497,6 +524,7 @@ return [
         'ssy' => 'lea fakasaho',
         'st' => 'lea fakasoto-tonga',
         'stq' => 'lea fakafilisia-satēlani',
+        'str' => 'lea fakasalisi-vahatokelau',
         'su' => 'lea fakasunitā',
         'suk' => 'lea fakasukuma',
         'sus' => 'lea fakasusū',
@@ -508,6 +536,7 @@ return [
         'syr' => 'lea fakasuliāiā',
         'szl' => 'lea fakasilesia',
         'ta' => 'lea fakatamili',
+        'tce' => 'lea fakatutisone-tonga',
         'tcy' => 'lea fakatulu',
         'te' => 'lea fakaʻinitia-teluku',
         'tem' => 'lea fakatimenē',
@@ -515,7 +544,9 @@ return [
         'ter' => 'lea fakateleno',
         'tet' => 'lea fakatetumu',
         'tg' => 'lea fakatāsiki',
+        'tgx' => 'lea fakatākisi',
         'th' => 'lea fakatailani',
+        'tht' => 'lea fakatālitāni',
         'ti' => 'lea fakatikilinia',
         'tig' => 'lea fakatikilē',
         'tiv' => 'lea fakativi',
@@ -530,6 +561,7 @@ return [
         'tn' => 'lea fakatisuana',
         'to' => 'lea fakatonga',
         'tog' => 'lea fakaniasa-tonga',
+        'tok' => 'lea fakatoki-pona',
         'tpi' => 'lea fakatoki-pisini',
         'tr' => 'lea fakatoake',
         'tru' => 'lea fakatuloio',
@@ -538,6 +570,7 @@ return [
         'tsd' => 'lea fakasakōnia',
         'tsi' => 'lea fakatisīmisiani',
         'tt' => 'lea fakatatale',
+        'ttm' => 'lea fakatutisone-tokelau',
         'ttt' => 'lea fakatati-moselemi',
         'tum' => 'lea fakatumepuka',
         'tvl' => 'lea fakatūvalu',
@@ -610,8 +643,6 @@ return [
         'fr_CH' => 'lea fakafalanisē-suisilani',
         'nds_NL' => 'lea fakasakisoni-hifo',
         'nl_BE' => 'lea fakahōlani-pelesiume',
-        'pt_BR' => 'lea fakapotukali-palāsili',
-        'pt_PT' => 'lea fakapotukali-ʻiulope',
         'ro_MD' => 'lea fakamolitāvia',
         'sw_CD' => 'lea fakasuahili-kongikō',
         'zh_Hans' => 'lea fakasiaina-fakafaingofua',
