@@ -13,7 +13,7 @@ return [
         'af' => 'Afrikaanca',
         'afh' => 'Afrihili',
         'agq' => 'Aghem',
-        'ain' => 'Ayni Dili',
+        'ain' => 'Aynuca',
         'ak' => 'Akan',
         'akk' => 'Akad Dili',
         'akz' => 'Alabamaca',
@@ -23,12 +23,13 @@ return [
         'am' => 'Amharca',
         'an' => 'Aragonca',
         'ang' => 'Eski İngilizce',
+        'ann' => 'Obolo dili',
         'anp' => 'Angika',
         'ar' => 'Arapça',
         'arc' => 'Aramice',
         'arn' => 'Mapuçe dili',
         'aro' => 'Araona',
-        'arp' => 'Arapaho Dili',
+        'arp' => 'Arapaho dili',
         'arq' => 'Cezayir Arapçası',
         'ars' => 'Necd Arapçası',
         'arw' => 'Arawak Dili',
@@ -38,7 +39,8 @@ return [
         'asa' => 'Asu',
         'ase' => 'Amerikan İşaret Dili',
         'ast' => 'Asturyasça',
-        'av' => 'Avar Dili',
+        'atj' => 'Atikamekçe',
+        'av' => 'Avar dili',
         'avk' => 'Kotava',
         'awa' => 'Awadhi',
         'ay' => 'Aymara',
@@ -103,14 +105,22 @@ return [
         'chr' => 'Çerokice',
         'chy' => 'Şayence',
         'ckb' => 'Orta Kürtçe',
+        'clc' => 'Çilkotince',
         'co' => 'Korsikaca',
         'cop' => 'Kıptice',
         'cps' => 'Capiznon',
         'cr' => 'Krice',
-        'crh' => 'Kırım Türkçesi',
+        'crg' => 'Michif dili',
+        'crh' => 'Kırım Tatarcası',
+        'crj' => 'Güney Doğu Kricesi',
+        'crk' => 'Ova Kricesi',
+        'crl' => 'Kuzey Doğu Kricesi',
+        'crm' => 'Moose Kricesi',
+        'crr' => 'Carolina Algonkin dili',
         'crs' => 'Seselwa Kreole Fransızcası',
         'cs' => 'Çekçe',
         'csb' => 'Kashubian',
+        'csw' => 'Bataklık Kricesi',
         'cu' => 'Kilise Slavcası',
         'cv' => 'Çuvaşça',
         'cy' => 'Galce',
@@ -202,6 +212,7 @@ return [
         'hai' => 'Haydaca',
         'hak' => 'Hakka Çincesi',
         'haw' => 'Hawaii dili',
+        'hax' => 'Güney Haydaca',
         'he' => 'İbranice',
         'hi' => 'Hintçe',
         'hif' => 'Fiji Hintçesi',
@@ -215,6 +226,7 @@ return [
         'ht' => 'Haiti Kreyolu',
         'hu' => 'Macarca',
         'hup' => 'Hupaca',
+        'hur' => 'Halkomelemce',
         'hy' => 'Ermenice',
         'hz' => 'Herero dili',
         'ia' => 'İnterlingua',
@@ -225,6 +237,7 @@ return [
         'ig' => 'İbo dili',
         'ii' => 'Sichuan Yi',
         'ik' => 'İnyupikçe',
+        'ikt' => 'Batı Kanada İnuktitut dili',
         'ilo' => 'Iloko',
         'inh' => 'İnguşça',
         'io' => 'Ido',
@@ -291,6 +304,7 @@ return [
         'kut' => 'Kutenai dili',
         'kv' => 'Komi',
         'kw' => 'Kernevekçe',
+        'kwk' => 'Kwakʼwala dili',
         'ky' => 'Kırgızca',
         'la' => 'Latince',
         'lad' => 'Ladino',
@@ -303,6 +317,7 @@ return [
         'lg' => 'Ganda',
         'li' => 'Limburgca',
         'lij' => 'Ligurca',
+        'lil' => 'Lillooet dili',
         'liv' => 'Livonca',
         'lkt' => 'Lakotaca',
         'lmo' => 'Lombardça',
@@ -312,6 +327,7 @@ return [
         'lou' => 'Louisiana Kreolcesi',
         'loz' => 'Lozi',
         'lrc' => 'Kuzey Luri',
+        'lsm' => 'Samia dili',
         'lt' => 'Litvanca',
         'ltg' => 'Latgalian',
         'lu' => 'Luba-Katanga',
@@ -350,6 +366,7 @@ return [
         'mn' => 'Moğolca',
         'mnc' => 'Mançurya dili',
         'mni' => 'Manipuri dili',
+        'moe' => 'Doğu İnnucası',
         'moh' => 'Mohavk dili',
         'mos' => 'Mossi',
         'mr' => 'Marathi dili',
@@ -399,6 +416,11 @@ return [
         'nzi' => 'Nzima dili',
         'oc' => 'Oksitan dili',
         'oj' => 'Ojibva dili',
+        'ojb' => 'Kuzeybatı Ojibwe dili',
+        'ojc' => 'Orta Ojibwe dili',
+        'ojs' => 'Anişininice',
+        'ojw' => 'Batı Ojibwe dili',
+        'oka' => 'Okanagan dili',
         'om' => 'Oromo dili',
         'or' => 'Oriya dili',
         'os' => 'Osetçe',
@@ -418,10 +440,12 @@ return [
         'pfl' => 'Palatin Almancası',
         'phn' => 'Fenike dili',
         'pi' => 'Pali',
+        'pis' => 'Pijin dili',
         'pl' => 'Lehçe',
         'pms' => 'Piyemontece',
         'pnt' => 'Kuzeybatı Kafkasya',
         'pon' => 'Pohnpeian',
+        'pqm' => 'Malisetçe-Passamaquoddy',
         'prg' => 'Prusyaca',
         'pro' => 'Eski Provensal',
         'ps' => 'Peştuca',
@@ -480,6 +504,7 @@ return [
         'sid' => 'Sidamo dili',
         'sk' => 'Slovakça',
         'sl' => 'Slovence',
+        'slh' => 'Güney Lushootseed',
         'sli' => 'Aşağı Silezyaca',
         'sly' => 'Selayar',
         'sm' => 'Samoa dili',
@@ -499,6 +524,7 @@ return [
         'ssy' => 'Saho',
         'st' => 'Güney Sotho dili',
         'stq' => 'Saterland Frizcesi',
+        'str' => 'Boğazlar Saliş dili',
         'su' => 'Sunda dili',
         'suk' => 'Sukuma dili',
         'sus' => 'Susu',
@@ -510,6 +536,7 @@ return [
         'syr' => 'Süryanice',
         'szl' => 'Silezyaca',
         'ta' => 'Tamilce',
+        'tce' => 'Güney Tuçoncası',
         'tcy' => 'Tuluca',
         'te' => 'Telugu dili',
         'tem' => 'Timne',
@@ -517,7 +544,9 @@ return [
         'ter' => 'Tereno',
         'tet' => 'Tetum',
         'tg' => 'Tacikçe',
+        'tgx' => 'Tagişçe',
         'th' => 'Tayca',
+        'tht' => 'Tahltanca',
         'ti' => 'Tigrinya dili',
         'tig' => 'Tigre',
         'tiv' => 'Tiv',
@@ -526,12 +555,13 @@ return [
         'tkr' => 'Sahurca',
         'tl' => 'Tagalogca',
         'tlh' => 'Klingonca',
-        'tli' => 'Tlingit',
+        'tli' => 'Tlingitçe',
         'tly' => 'Talışça',
         'tmh' => 'Tamaşek',
         'tn' => 'Setsvana',
         'to' => 'Tonga dili',
         'tog' => 'Nyasa Tonga',
+        'tok' => 'Toki Pona',
         'tpi' => 'Tok Pisin',
         'tr' => 'Türkçe',
         'tru' => 'Turoyo',
@@ -540,6 +570,7 @@ return [
         'tsd' => 'Tsakonca',
         'tsi' => 'Tsimshian',
         'tt' => 'Tatarca',
+        'ttm' => 'Kuzey Tuçoncası',
         'ttt' => 'Tatça',
         'tum' => 'Tumbuka',
         'tvl' => 'Tuvalyanca',
