@@ -21,6 +21,7 @@ return [
         'am' => 'амхарська',
         'an' => 'арагонська',
         'ang' => 'давньоанглійська',
+        'ann' => 'оболо',
         'anp' => 'ангіка',
         'ar' => 'арабська',
         'arc' => 'арамейська',
@@ -34,6 +35,7 @@ return [
         'asa' => 'асу',
         'ase' => 'американська мова рухів',
         'ast' => 'астурійська',
+        'atj' => 'атикамек',
         'av' => 'аварська',
         'awa' => 'авадхі',
         'ay' => 'аймара',
@@ -92,24 +94,32 @@ return [
         'chm' => 'марійська',
         'chn' => 'чинук жаргон',
         'cho' => 'чокто',
-        'chp' => 'чіпевʼян',
+        'chp' => 'чипевʼян',
         'chr' => 'черокі',
         'chy' => 'чейєнн',
         'ckb' => 'центральнокурдська',
+        'clc' => 'чилкотін',
         'co' => 'корсиканська',
         'cop' => 'коптська',
         'cr' => 'крі',
+        'crg' => 'мічиф',
         'crh' => 'кримськотатарська',
+        'crj' => 'південно-східна крі',
+        'crk' => 'рівнинна крі',
+        'crl' => 'північна іст-крі',
+        'crm' => 'муз-крі',
+        'crr' => 'каролінська алгонкінська',
         'crs' => 'сейшельська креольська',
         'cs' => 'чеська',
         'csb' => 'кашубська',
+        'csw' => 'свампі-крі',
         'cu' => 'церковнословʼянська',
         'cv' => 'чуваська',
         'cy' => 'валлійська',
         'da' => 'данська',
         'dak' => 'дакота',
         'dar' => 'даргінська',
-        'dav' => 'таіта',
+        'dav' => 'таїта',
         'de' => 'німецька',
         'del' => 'делаварська',
         'den' => 'слейв',
@@ -120,7 +130,7 @@ return [
         'dsb' => 'нижньолужицька',
         'dua' => 'дуала',
         'dum' => 'середньонідерландська',
-        'dv' => 'дівехі',
+        'dv' => 'дивехі',
         'dyo' => 'дьола-фоні',
         'dyu' => 'діула',
         'dz' => 'дзонг-ке',
@@ -184,6 +194,7 @@ return [
         'hai' => 'хайда',
         'hak' => 'хаккаська',
         'haw' => 'гавайська',
+        'hax' => 'південна гайда',
         'he' => 'іврит',
         'hi' => 'гінді',
         'hil' => 'хілігайнон',
@@ -196,6 +207,7 @@ return [
         'ht' => 'гаїтянська креольська',
         'hu' => 'угорська',
         'hup' => 'хупа',
+        'hur' => 'галкомелем',
         'hy' => 'вірменська',
         'hz' => 'гереро',
         'ia' => 'інтерлінгва',
@@ -206,12 +218,13 @@ return [
         'ig' => 'ігбо',
         'ii' => 'сичуаньська ї',
         'ik' => 'інупіак',
+        'ikt' => 'західноканадська інуктитут',
         'ilo' => 'ілоканська',
         'inh' => 'інгуська',
         'io' => 'ідо',
         'is' => 'ісландська',
         'it' => 'італійська',
-        'iu' => 'інуктітут',
+        'iu' => 'інуктитут',
         'ja' => 'японська',
         'jbo' => 'ложбан',
         'jgo' => 'нгомба',
@@ -233,9 +246,10 @@ return [
         'kea' => 'кабувердіану',
         'kfo' => 'коро',
         'kg' => 'конґолезька',
+        'kgp' => 'кайнґанґ',
         'kha' => 'кхасі',
         'kho' => 'хотаносакська',
-        'khq' => 'койра чіїні',
+        'khq' => 'койра чиїні',
         'ki' => 'кікуйю',
         'kj' => 'кунама',
         'kk' => 'казахська',
@@ -263,9 +277,10 @@ return [
         'kut' => 'кутенаї',
         'kv' => 'комі',
         'kw' => 'корнська',
+        'kwk' => 'кваквала',
         'ky' => 'киргизька',
         'la' => 'латинська',
-        'lad' => 'ладіно',
+        'lad' => 'ладино',
         'lag' => 'лангі',
         'lah' => 'ланда',
         'lam' => 'ламба',
@@ -273,13 +288,17 @@ return [
         'lez' => 'лезгінська',
         'lg' => 'ганда',
         'li' => 'лімбургійська',
+        'lij' => 'лігурійська',
+        'lil' => 'лілуетська',
         'lkt' => 'лакота',
+        'lmo' => 'ломбардська',
         'ln' => 'лінгала',
         'lo' => 'лаоська',
         'lol' => 'монго',
         'lou' => 'луїзіанська креольська',
         'loz' => 'лозі',
         'lrc' => 'північнолурська',
+        'lsm' => 'самія',
         'lt' => 'литовська',
         'lu' => 'луба-катанга',
         'lua' => 'луба-лулуа',
@@ -315,6 +334,7 @@ return [
         'mn' => 'монгольська',
         'mnc' => 'манчжурська',
         'mni' => 'маніпурі',
+        'moe' => 'інну-аймун',
         'moh' => 'магавк',
         'mos' => 'моссі',
         'mr' => 'маратхі',
@@ -361,6 +381,11 @@ return [
         'nzi' => 'нзіма',
         'oc' => 'окситанська',
         'oj' => 'оджібва',
+        'ojb' => 'північно-західна оджибве',
+        'ojc' => 'центральна оджибве',
+        'ojs' => 'оджи-крі',
+        'ojw' => 'західна оджибве',
+        'oka' => 'оканаганська',
         'om' => 'оромо',
         'or' => 'одія',
         'os' => 'осетинська',
@@ -376,8 +401,10 @@ return [
         'peo' => 'давньоперська',
         'phn' => 'фінікійсько-пунічна',
         'pi' => 'палі',
+        'pis' => 'піджин',
         'pl' => 'польська',
         'pon' => 'понапе',
+        'pqm' => 'малесіт-пасамакводі',
         'prg' => 'прусська',
         'pro' => 'давньопровансальська',
         'ps' => 'пушту',
@@ -426,6 +453,7 @@ return [
         'sid' => 'сідамо',
         'sk' => 'словацька',
         'sl' => 'словенська',
+        'slh' => 'південна лушуцид',
         'sm' => 'самоанська',
         'sma' => 'південносаамська',
         'smj' => 'саамська луле',
@@ -439,9 +467,10 @@ return [
         'sr' => 'сербська',
         'srn' => 'сранан тонго',
         'srr' => 'серер',
-        'ss' => 'сісваті',
+        'ss' => 'сисваті',
         'ssy' => 'сахо',
         'st' => 'південна сото',
+        'str' => 'саліська стрейт',
         'su' => 'сунданська',
         'suk' => 'сукума',
         'sus' => 'сусу',
@@ -452,13 +481,16 @@ return [
         'syc' => 'сирійська класична',
         'syr' => 'сирійська',
         'ta' => 'тамільська',
+        'tce' => 'південна тутчон',
         'te' => 'телугу',
         'tem' => 'темне',
         'teo' => 'тесо',
         'ter' => 'терено',
         'tet' => 'тетум',
         'tg' => 'таджицька',
+        'tgx' => 'тагіш',
         'th' => 'тайська',
+        'tht' => 'талтан',
         'ti' => 'тигринья',
         'tig' => 'тигре',
         'tiv' => 'тів',
@@ -471,12 +503,14 @@ return [
         'tn' => 'тсвана',
         'to' => 'тонганська',
         'tog' => 'ньяса тонга',
+        'tok' => 'токі-пона',
         'tpi' => 'ток-пісін',
         'tr' => 'турецька',
         'trv' => 'тароко',
         'ts' => 'тсонга',
         'tsi' => 'цимшиан',
         'tt' => 'татарська',
+        'ttm' => 'північна тутчон',
         'tum' => 'тумбука',
         'tvl' => 'тувалу',
         'tw' => 'тві',
@@ -514,6 +548,7 @@ return [
         'ybb' => 'ємба',
         'yi' => 'їдиш',
         'yo' => 'йоруба',
+        'yrl' => 'ньєнґату',
         'yue' => 'кантонська',
         'za' => 'чжуан',
         'zap' => 'сапотекська',
@@ -528,14 +563,10 @@ return [
     'LocalizedNames' => [
         'ar_001' => 'сучасна стандартна арабська',
         'az_Arab' => 'південноазербайджанська',
-        'de_CH' => 'швейцарська верхньонімецька',
-        'en_US' => 'американська англійська',
         'es_419' => 'латиноамериканська іспанська',
         'es_ES' => 'європейська іспанська',
         'es_MX' => 'мексиканська іспанська',
         'fa_AF' => 'дарі',
-        'fr_CA' => 'канадська французька',
-        'fr_CH' => 'швейцарська французька',
         'nds_NL' => 'нижньосаксонська',
         'nl_BE' => 'фламандська',
         'pt_BR' => 'бразильська португальська',
