@@ -20,6 +20,7 @@ return [
         'am' => '阿姆哈拉语',
         'an' => '阿拉贡语',
         'ang' => '古英语',
+        'ann' => '奥博洛语',
         'anp' => '昂加语',
         'ar' => '阿拉伯语',
         'arc' => '阿拉米语',
@@ -30,6 +31,7 @@ return [
         'as' => '阿萨姆语',
         'asa' => '帕雷语',
         'ast' => '阿斯图里亚斯语',
+        'atj' => '阿提卡米克语',
         'av' => '阿瓦尔语',
         'awa' => '阿瓦德语',
         'ay' => '艾马拉语',
@@ -86,13 +88,21 @@ return [
         'chr' => '切罗基语',
         'chy' => '夏延语',
         'ckb' => '中库尔德语',
+        'clc' => '奇尔科廷语',
         'co' => '科西嘉语',
         'cop' => '科普特语',
-        'cr' => '克里族语',
-        'crh' => '克里米亚土耳其语',
+        'cr' => '克里语',
+        'crg' => '米其芙语',
+        'crh' => '克里米亚鞑靼语',
+        'crj' => '东南部克里语',
+        'crk' => '平原克里语',
+        'crl' => '东北部克里语',
+        'crm' => '穆斯克里语',
+        'crr' => '卡罗莱纳州阿尔冈昆语',
         'crs' => '塞舌尔克里奥尔语',
         'cs' => '捷克语',
         'csb' => '卡舒比语',
+        'csw' => '沼泽克里语',
         'cu' => '教会斯拉夫语',
         'cv' => '楚瓦什语',
         'cy' => '威尔士语',
@@ -173,6 +183,7 @@ return [
         'hai' => '海达语',
         'hak' => '客家语',
         'haw' => '夏威夷语',
+        'hax' => '南海达语',
         'he' => '希伯来语',
         'hi' => '印地语',
         'hil' => '希利盖农语',
@@ -185,6 +196,7 @@ return [
         'ht' => '海地克里奥尔语',
         'hu' => '匈牙利语',
         'hup' => '胡帕语',
+        'hur' => '哈尔魁梅林语',
         'hy' => '亚美尼亚语',
         'hz' => '赫雷罗语',
         'ia' => '国际语',
@@ -195,6 +207,7 @@ return [
         'ig' => '伊博语',
         'ii' => '四川彝语',
         'ik' => '伊努皮克语',
+        'ikt' => '西加拿大因纽特语',
         'ilo' => '伊洛卡诺语',
         'inh' => '印古什语',
         'io' => '伊多语',
@@ -222,6 +235,7 @@ return [
         'kea' => '卡布佛得鲁语',
         'kfo' => '克罗语',
         'kg' => '刚果语',
+        'kgp' => '坎刚语',
         'kha' => '卡西语',
         'kho' => '和田语',
         'khq' => '西桑海语',
@@ -252,16 +266,19 @@ return [
         'kut' => '库特奈语',
         'kv' => '科米语',
         'kw' => '康沃尔语',
+        'kwk' => '夸夸瓦拉语',
         'ky' => '柯尔克孜语',
         'la' => '拉丁语',
         'lad' => '拉迪诺语',
         'lag' => '朗吉语',
-        'lah' => '印度-雅利安语',
+        'lah' => '西旁遮普语',
         'lam' => '兰巴语',
         'lb' => '卢森堡语',
         'lez' => '列兹金语',
         'lg' => '卢干达语',
         'li' => '林堡语',
+        'lij' => '利古里亚语',
+        'lil' => '利洛埃特语',
         'lkt' => '拉科塔语',
         'ln' => '林加拉语',
         'lo' => '老挝语',
@@ -269,6 +286,7 @@ return [
         'lou' => '路易斯安那克里奥尔语',
         'loz' => '洛齐语',
         'lrc' => '北卢尔语',
+        'lsm' => '萨米亚语',
         'lt' => '立陶宛语',
         'lu' => '鲁巴加丹加语',
         'lua' => '卢巴-卢拉语',
@@ -304,6 +322,7 @@ return [
         'mn' => '蒙古语',
         'mnc' => '满语',
         'mni' => '曼尼普尔语',
+        'moe' => '因努埃蒙语',
         'moh' => '摩霍克语',
         'mos' => '莫西语',
         'mr' => '马拉地语',
@@ -349,6 +368,11 @@ return [
         'nzi' => '恩济马语',
         'oc' => '奥克语',
         'oj' => '奥吉布瓦语',
+        'ojb' => '西北部奥吉布瓦语',
+        'ojc' => '中奥吉布瓦语',
+        'ojs' => '欧吉克里语',
+        'ojw' => '西奥吉布瓦语',
+        'oka' => '欧肯那根语',
         'om' => '奥罗莫语',
         'or' => '奥里亚语',
         'os' => '奥塞梯语',
@@ -364,8 +388,10 @@ return [
         'peo' => '古波斯语',
         'phn' => '腓尼基语',
         'pi' => '巴利语',
+        'pis' => '皮京语',
         'pl' => '波兰语',
         'pon' => '波纳佩语',
+        'pqm' => '马利塞-帕萨马科迪语',
         'prg' => '普鲁士语',
         'pro' => '古普罗文斯语',
         'ps' => '普什图语',
@@ -414,6 +440,7 @@ return [
         'sid' => '悉达摩语',
         'sk' => '斯洛伐克语',
         'sl' => '斯洛文尼亚语',
+        'slh' => '南卢舒特种子语',
         'sm' => '萨摩亚语',
         'sma' => '南萨米语',
         'smj' => '吕勒萨米语',
@@ -430,6 +457,7 @@ return [
         'ss' => '斯瓦蒂语',
         'ssy' => '萨霍语',
         'st' => '南索托语',
+        'str' => '海峡萨利希语',
         'su' => '巽他语',
         'suk' => '苏库马语',
         'sus' => '苏苏语',
@@ -440,13 +468,16 @@ return [
         'syc' => '古典叙利亚语',
         'syr' => '叙利亚语',
         'ta' => '泰米尔语',
+        'tce' => '南塔穹语',
         'te' => '泰卢固语',
         'tem' => '泰姆奈语',
         'teo' => '特索语',
         'ter' => '特伦诺语',
         'tet' => '德顿语',
         'tg' => '塔吉克语',
+        'tgx' => '塔吉什语',
         'th' => '泰语',
+        'tht' => '塔尔坦语',
         'ti' => '提格利尼亚语',
         'tig' => '提格雷语',
         'tiv' => '蒂夫语',
@@ -459,12 +490,14 @@ return [
         'tn' => '茨瓦纳语',
         'to' => '汤加语',
         'tog' => '尼亚萨汤加语',
+        'tok' => '道本语',
         'tpi' => '托克皮辛语',
         'tr' => '土耳其语',
         'trv' => '赛德克语',
         'ts' => '聪加语',
         'tsi' => '钦西安语',
         'tt' => '鞑靼语',
+        'ttm' => '北塔穹语',
         'tum' => '通布卡语',
         'tvl' => '图瓦卢语',
         'tw' => '契维语',
@@ -481,6 +514,7 @@ return [
         'uz' => '乌兹别克语',
         'vai' => '瓦伊语',
         've' => '文达语',
+        'vec' => '威尼斯语',
         'vep' => '维普森语',
         'vi' => '越南语',
         'vo' => '沃拉普克语',
@@ -503,6 +537,7 @@ return [
         'ybb' => '耶姆巴语',
         'yi' => '意第绪语',
         'yo' => '约鲁巴语',
+        'yrl' => '恩加图语',
         'yue' => '粤语',
         'za' => '壮语',
         'zap' => '萨波蒂克语',
