@@ -23,6 +23,7 @@ return [
         'am' => '阿姆哈拉文',
         'an' => '阿拉貢文',
         'ang' => '古英文',
+        'ann' => '奧博洛語',
         'anp' => '昂加文',
         'ar' => '阿拉伯文',
         'arc' => '阿拉米文',
@@ -38,6 +39,7 @@ return [
         'asa' => '阿蘇文',
         'ase' => '美國手語',
         'ast' => '阿斯圖里亞文',
+        'atj' => '阿提卡梅克語',
         'av' => '阿瓦爾文',
         'avk' => '科塔瓦文',
         'awa' => '阿瓦文',
@@ -103,14 +105,22 @@ return [
         'chr' => '柴羅基文',
         'chy' => '沙伊安文',
         'ckb' => '中庫德文',
+        'clc' => '齊爾柯廷語',
         'co' => '科西嘉文',
         'cop' => '科普特文',
         'cps' => '卡皮茲文',
         'cr' => '克里文',
+        'crg' => '米奇夫語',
         'crh' => '土耳其文（克里米亞半島）',
+        'crj' => '東南克里語',
+        'crk' => '平原克里語',
+        'crl' => '北部東克里語',
+        'crm' => '穆斯克里文',
+        'crr' => '卡羅萊納阿爾岡昆語',
         'crs' => '塞席爾克里奧爾法文',
         'cs' => '捷克文',
         'csb' => '卡舒布文',
+        'csw' => '沼澤克里語',
         'cu' => '宗教斯拉夫文',
         'cv' => '楚瓦什文',
         'cy' => '威爾斯文',
@@ -202,6 +212,7 @@ return [
         'hai' => '海達文',
         'hak' => '客家話',
         'haw' => '夏威夷文',
+        'hax' => '南海達語',
         'he' => '希伯來文',
         'hi' => '印地文',
         'hif' => '斐濟印地文',
@@ -215,6 +226,7 @@ return [
         'ht' => '海地文',
         'hu' => '匈牙利文',
         'hup' => '胡帕文',
+        'hur' => '哈爾魁梅林語',
         'hy' => '亞美尼亞文',
         'hz' => '赫雷羅文',
         'ia' => '國際文',
@@ -225,6 +237,7 @@ return [
         'ig' => '伊布文',
         'ii' => '四川彝文',
         'ik' => '依奴皮維克文',
+        'ikt' => '西加拿大因紐特語',
         'ilo' => '伊洛闊文',
         'inh' => '印古什文',
         'io' => '伊多文',
@@ -291,6 +304,7 @@ return [
         'kut' => '庫特奈文',
         'kv' => '科米文',
         'kw' => '康瓦耳文',
+        'kwk' => '誇誇嘉誇語',
         'ky' => '吉爾吉斯文',
         'la' => '拉丁文',
         'lad' => '拉迪諾文',
@@ -303,6 +317,7 @@ return [
         'lg' => '干達文',
         'li' => '林堡文',
         'lij' => '利古里亞文',
+        'lil' => '利洛威特文',
         'liv' => '利伏尼亞文',
         'lkt' => '拉科塔文',
         'lmo' => '倫巴底文',
@@ -312,6 +327,7 @@ return [
         'lou' => '路易斯安那克里奧爾文',
         'loz' => '洛齊文',
         'lrc' => '北盧爾文',
+        'lsm' => '薩米亞文',
         'lt' => '立陶宛文',
         'ltg' => '拉特加萊文',
         'lu' => '魯巴加丹加文',
@@ -350,6 +366,7 @@ return [
         'mn' => '蒙古文',
         'mnc' => '滿族文',
         'mni' => '曼尼普爾文',
+        'moe' => '因紐艾蒙語',
         'moh' => '莫霍克文',
         'mos' => '莫西文',
         'mr' => '馬拉地文',
@@ -390,7 +407,7 @@ return [
         'nr' => '南地畢列文',
         'nso' => '北索托文',
         'nus' => '努埃爾文',
-        'nv' => '納瓦霍文',
+        'nv' => '納瓦荷文',
         'nwc' => '古尼瓦爾文',
         'ny' => '尼揚賈文',
         'nym' => '尼揚韋齊文',
@@ -399,6 +416,11 @@ return [
         'nzi' => '尼茲馬文',
         'oc' => '奧克西坦文',
         'oj' => '奧杰布瓦文',
+        'ojb' => '西北奧吉布瓦語',
+        'ojc' => '中央奧吉布瓦語',
+        'ojs' => '奧吉克里語',
+        'ojw' => '西奧吉布瓦語',
+        'oka' => '奧卡諾根語',
         'om' => '奧羅莫文',
         'or' => '歐迪亞文',
         'os' => '奧塞提文',
@@ -418,10 +440,12 @@ return [
         'pfl' => '普法爾茨德文',
         'phn' => '腓尼基文',
         'pi' => '巴利文',
+        'pis' => '皮金語',
         'pl' => '波蘭文',
         'pms' => '皮埃蒙特文',
         'pnt' => '旁狄希臘文',
         'pon' => '波那貝文',
+        'pqm' => '馬里希特帕薩瑪奎迪文',
         'prg' => '普魯士文',
         'pro' => '古普羅旺斯文',
         'ps' => '普什圖文',
@@ -480,6 +504,7 @@ return [
         'sid' => '希達摩文',
         'sk' => '斯洛伐克文',
         'sl' => '斯洛維尼亞文',
+        'slh' => '南盧紹錫德語',
         'sli' => '下西利西亞文',
         'sly' => '塞拉亞文',
         'sm' => '薩摩亞文',
@@ -499,6 +524,7 @@ return [
         'ssy' => '薩霍文',
         'st' => '塞索托文',
         'stq' => '沙特菲士蘭文',
+        'str' => '海峽薩利希語',
         'su' => '巽他文',
         'suk' => '蘇庫馬文',
         'sus' => '蘇蘇文',
@@ -510,6 +536,7 @@ return [
         'syr' => '敘利亞文',
         'szl' => '西利西亞文',
         'ta' => '坦米爾文',
+        'tce' => '南塔穹語',
         'tcy' => '圖盧文',
         'te' => '泰盧固文',
         'tem' => '提姆文',
@@ -517,7 +544,9 @@ return [
         'ter' => '泰雷諾文',
         'tet' => '泰頓文',
         'tg' => '塔吉克文',
+        'tgx' => '塔吉什語',
         'th' => '泰文',
+        'tht' => '塔爾坦語',
         'ti' => '提格利尼亞文',
         'tig' => '蒂格雷文',
         'tiv' => '提夫文',
@@ -532,6 +561,7 @@ return [
         'tn' => '塞茲瓦納文',
         'to' => '東加文',
         'tog' => '東加文（尼亞薩）',
+        'tok' => '道本語',
         'tpi' => '托比辛文',
         'tr' => '土耳其文',
         'tru' => '圖羅尤文',
@@ -540,6 +570,7 @@ return [
         'tsd' => '特薩克尼恩文',
         'tsi' => '欽西安文',
         'tt' => '韃靼文',
+        'ttm' => '北塔穹語',
         'ttt' => '穆斯林塔特文',
         'tum' => '圖姆布卡文',
         'tvl' => '吐瓦魯文',
@@ -600,6 +631,7 @@ return [
     'LocalizedNames' => [
         'ar_001' => '現代標準阿拉伯文',
         'de_CH' => '高地德文（瑞士）',
+        'hi_Latn' => '印地語（拉丁文）',
         'nds_NL' => '低地薩克遜文',
         'nl_BE' => '佛蘭芒文',
         'ro_MD' => '摩爾多瓦文',
