@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Tsjetsjeens (Rusland)',
         'cs' => 'Tsjeggies',
         'cs_CZ' => 'Tsjeggies (Tsjeggië)',
+        'cv' => 'Chuvash',
+        'cv_RU' => 'Chuvash (Rusland)',
         'cy' => 'Wallies',
         'cy_GB' => 'Wallies (Verenigde Koninkryk)',
         'da' => 'Deens',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'Engels (Montserrat)',
         'en_MT' => 'Engels (Malta)',
         'en_MU' => 'Engels (Mauritius)',
+        'en_MV' => 'Engels (Maledive)',
         'en_MW' => 'Engels (Malawi)',
         'en_MY' => 'Engels (Maleisië)',
         'en_NA' => 'Engels (Namibië)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'Persies (Afganistan)',
         'fa_IR' => 'Persies (Iran)',
         'ff' => 'Fulah',
+        'ff_Adlm' => 'Fulah (Adlam)',
+        'ff_Adlm_BF' => 'Fulah (Adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'Fulah (Adlam, Kameroen)',
+        'ff_Adlm_GH' => 'Fulah (Adlam, Ghana)',
+        'ff_Adlm_GM' => 'Fulah (Adlam, Gambië)',
+        'ff_Adlm_GN' => 'Fulah (Adlam, Guinee)',
+        'ff_Adlm_GW' => 'Fulah (Adlam, Guinee-Bissau)',
+        'ff_Adlm_LR' => 'Fulah (Adlam, Liberië)',
+        'ff_Adlm_MR' => 'Fulah (Adlam, Mauritanië)',
+        'ff_Adlm_NE' => 'Fulah (Adlam, Niger)',
+        'ff_Adlm_NG' => 'Fulah (Adlam, Nigerië)',
+        'ff_Adlm_SL' => 'Fulah (Adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'Fulah (Adlam, Senegal)',
         'ff_CM' => 'Fulah (Kameroen)',
         'ff_GN' => 'Fulah (Guinee)',
         'ff_Latn' => 'Fulah (Latyn)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'Hebreeus (Israel)',
         'hi' => 'Hindi',
         'hi_IN' => 'Hindi (Indië)',
+        'hi_Latn' => 'Hindi (Latyn)',
+        'hi_Latn_IN' => 'Hindi (Latyn, Indië)',
         'hr' => 'Kroaties',
         'hr_BA' => 'Kroaties (Bosnië en Herzegowina)',
         'hr_HR' => 'Kroaties (Kroasië)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'Kasjmirs',
         'ks_Arab' => 'Kasjmirs (Arabies)',
         'ks_Arab_IN' => 'Kasjmirs (Arabies, Indië)',
+        'ks_Deva' => 'Kasjmirs (Devanagari)',
+        'ks_Deva_IN' => 'Kasjmirs (Devanagari, Indië)',
         'ks_IN' => 'Kasjmirs (Indië)',
         'ku' => 'Koerdies',
         'ku_TR' => 'Koerdies (Turkye)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Sindhi (Arabies, Pakistan)',
         'sd_Deva' => 'Sindhi (Devanagari)',
         'sd_Deva_IN' => 'Sindhi (Devanagari, Indië)',
+        'sd_IN' => 'Sindhi (Indië)',
         'sd_PK' => 'Sindhi (Pakistan)',
         'se' => 'Noord-Sami',
         'se_FI' => 'Noord-Sami (Finland)',
