@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'চেচেন (ৰাছিয়া)',
         'cs' => 'চেক',
         'cs_CZ' => 'চেক (চিজেচিয়া)',
+        'cv' => 'চুভাচ',
+        'cv_RU' => 'চুভাচ (ৰাছিয়া)',
         'cy' => 'ৱেলচ',
         'cy_GB' => 'ৱেলচ (সংযুক্ত ৰাজ্য)',
         'da' => 'ডেনিচ',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'ইংৰাজী (ম’ণ্টছেৰাট)',
         'en_MT' => 'ইংৰাজী (মাল্টা)',
         'en_MU' => 'ইংৰাজী (মৰিছাছ)',
+        'en_MV' => 'ইংৰাজী (মালদ্বীপ)',
         'en_MW' => 'ইংৰাজী (মালাৱি)',
         'en_MY' => 'ইংৰাজী (মালয়েচিয়া)',
         'en_NA' => 'ইংৰাজী (নামিবিয়া)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'ফাৰ্ছী (আফগানিস্তান)',
         'fa_IR' => 'ফাৰ্ছী (ইৰান)',
         'ff' => 'ফুলাহ',
+        'ff_Adlm' => 'ফুলাহ (এডলাম)',
+        'ff_Adlm_BF' => 'ফুলাহ (এডলাম, বুৰকিনা ফাচো)',
+        'ff_Adlm_CM' => 'ফুলাহ (এডলাম, কেমেৰুণ)',
+        'ff_Adlm_GH' => 'ফুলাহ (এডলাম, ঘানা)',
+        'ff_Adlm_GM' => 'ফুলাহ (এডলাম, গাম্বিয়া)',
+        'ff_Adlm_GN' => 'ফুলাহ (এডলাম, গিনি)',
+        'ff_Adlm_GW' => 'ফুলাহ (এডলাম, গিনি-বিছাও)',
+        'ff_Adlm_LR' => 'ফুলাহ (এডলাম, লিবেৰিয়া)',
+        'ff_Adlm_MR' => 'ফুলাহ (এডলাম, মাউৰিটানিয়া)',
+        'ff_Adlm_NE' => 'ফুলাহ (এডলাম, নাইজাৰ)',
+        'ff_Adlm_NG' => 'ফুলাহ (এডলাম, নাইজেৰিয়া)',
+        'ff_Adlm_SL' => 'ফুলাহ (এডলাম, চিয়েৰা লিঅ’ন)',
+        'ff_Adlm_SN' => 'ফুলাহ (এডলাম, চেনেগাল)',
         'ff_CM' => 'ফুলাহ (কেমেৰুণ)',
         'ff_GN' => 'ফুলাহ (গিনি)',
         'ff_Latn' => 'ফুলাহ (লেটিন)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'হিব্ৰু (ইজৰাইল)',
         'hi' => 'হিন্দী',
         'hi_IN' => 'হিন্দী (ভাৰত)',
+        'hi_Latn' => 'হিন্দী (লেটিন)',
+        'hi_Latn_IN' => 'হিন্দী (লেটিন, ভাৰত)',
         'hr' => 'ক্ৰোৱেচিয়ান',
         'hr_BA' => 'ক্ৰোৱেচিয়ান (ব’ছনিয়া আৰু হাৰ্জেগ’ভিনা)',
         'hr_HR' => 'ক্ৰোৱেচিয়ান (ক্ৰোৱেছিয়া)',
@@ -372,9 +390,11 @@ return [
         'ks' => 'কাশ্মিৰী',
         'ks_Arab' => 'কাশ্মিৰী (আৰবী)',
         'ks_Arab_IN' => 'কাশ্মিৰী (আৰবী, ভাৰত)',
+        'ks_Deva' => 'কাশ্মিৰী (দেৱনাগৰী)',
+        'ks_Deva_IN' => 'কাশ্মিৰী (দেৱনাগৰী, ভাৰত)',
         'ks_IN' => 'কাশ্মিৰী (ভাৰত)',
         'ku' => 'কুৰ্ডিচ',
-        'ku_TR' => 'কুৰ্ডিচ (তুৰ্কি)',
+        'ku_TR' => 'কুৰ্ডিচ (তুৰ্কিয়ে)',
         'kw' => 'কোৰ্নিচ',
         'kw_GB' => 'কোৰ্নিচ (সংযুক্ত ৰাজ্য)',
         'ky' => 'কিৰ্গিজ',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'সিন্ধী (আৰবী, পাকিস্তান)',
         'sd_Deva' => 'সিন্ধী (দেৱনাগৰী)',
         'sd_Deva_IN' => 'সিন্ধী (দেৱনাগৰী, ভাৰত)',
+        'sd_IN' => 'সিন্ধী (ভাৰত)',
         'sd_PK' => 'সিন্ধী (পাকিস্তান)',
         'se' => 'উদীচ্য ছামি',
         'se_FI' => 'উদীচ্য ছামি (ফিনলেণ্ড)',
@@ -567,7 +588,7 @@ return [
         'to_TO' => 'টোঙ্গান (টংগা)',
         'tr' => 'তুৰ্কী',
         'tr_CY' => 'তুৰ্কী (চাইপ্ৰাছ)',
-        'tr_TR' => 'তুৰ্কী (তুৰ্কি)',
+        'tr_TR' => 'তুৰ্কী (তুৰ্কিয়ে)',
         'tt' => 'তাতাৰ',
         'tt_RU' => 'তাতাৰ (ৰাছিয়া)',
         'ug' => 'উইঘুৰ',
