@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'çeçen (Rusiya)',
         'cs' => 'çex',
         'cs_CZ' => 'çex (Çexiya)',
+        'cv' => 'çuvaş',
+        'cv_RU' => 'çuvaş (Rusiya)',
         'cy' => 'uels',
         'cy_GB' => 'uels (Birləşmiş Krallıq)',
         'da' => 'danimarka',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'ingilis (Monserat)',
         'en_MT' => 'ingilis (Malta)',
         'en_MU' => 'ingilis (Mavriki)',
+        'en_MV' => 'ingilis (Maldiv adaları)',
         'en_MW' => 'ingilis (Malavi)',
         'en_MY' => 'ingilis (Malayziya)',
         'en_NA' => 'ingilis (Namibiya)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'fars (Əfqanıstan)',
         'fa_IR' => 'fars (İran)',
         'ff' => 'fula',
+        'ff_Adlm' => 'fula (adlam)',
+        'ff_Adlm_BF' => 'fula (adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fula (adlam, Kamerun)',
+        'ff_Adlm_GH' => 'fula (adlam, Qana)',
+        'ff_Adlm_GM' => 'fula (adlam, Qambiya)',
+        'ff_Adlm_GN' => 'fula (adlam, Qvineya)',
+        'ff_Adlm_GW' => 'fula (adlam, Qvineya-Bisau)',
+        'ff_Adlm_LR' => 'fula (adlam, Liberiya)',
+        'ff_Adlm_MR' => 'fula (adlam, Mavritaniya)',
+        'ff_Adlm_NE' => 'fula (adlam, Niger)',
+        'ff_Adlm_NG' => 'fula (adlam, Nigeriya)',
+        'ff_Adlm_SL' => 'fula (adlam, Syerra-Leone)',
+        'ff_Adlm_SN' => 'fula (adlam, Seneqal)',
         'ff_CM' => 'fula (Kamerun)',
         'ff_GN' => 'fula (Qvineya)',
         'ff_Latn' => 'fula (latın)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'ivrit (İsrail)',
         'hi' => 'hind',
         'hi_IN' => 'hind (Hindistan)',
+        'hi_Latn' => 'hind (latın)',
+        'hi_Latn_IN' => 'hind (latın, Hindistan)',
         'hr' => 'xorvat',
         'hr_BA' => 'xorvat (Bosniya və Herseqovina)',
         'hr_HR' => 'xorvat (Xorvatiya)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kəşmir',
         'ks_Arab' => 'kəşmir (ərəb)',
         'ks_Arab_IN' => 'kəşmir (ərəb, Hindistan)',
+        'ks_Deva' => 'kəşmir (devanaqari)',
+        'ks_Deva_IN' => 'kəşmir (devanaqari, Hindistan)',
         'ks_IN' => 'kəşmir (Hindistan)',
         'ku' => 'kürd',
         'ku_TR' => 'kürd (Türkiyə)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (ərəb, Pakistan)',
         'sd_Deva' => 'sindhi (devanaqari)',
         'sd_Deva_IN' => 'sindhi (devanaqari, Hindistan)',
+        'sd_IN' => 'sindhi (Hindistan)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'şimali sami',
         'se_FI' => 'şimali sami (Finlandiya)',
