@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'чечен (Русија)',
         'cs' => 'чех',
         'cs_CZ' => 'чех (Чехија)',
+        'cv' => 'чуваш',
+        'cv_RU' => 'чуваш (Русија)',
         'cy' => 'уелс',
         'cy_GB' => 'уелс (Бирләшмиш Краллыг)',
         'da' => 'данимарка',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'инҝилис (Монсерат)',
         'en_MT' => 'инҝилис (Малта)',
         'en_MU' => 'инҝилис (Маврики)',
+        'en_MV' => 'инҝилис (Малдив адалары)',
         'en_MW' => 'инҝилис (Малави)',
         'en_MY' => 'инҝилис (Малајзија)',
         'en_NA' => 'инҝилис (Намибија)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'фарс (Әфганыстан)',
         'fa_IR' => 'фарс (Иран)',
         'ff' => 'фула',
+        'ff_Adlm' => 'фула (adlam)',
+        'ff_Adlm_BF' => 'фула (adlam, Буркина Фасо)',
+        'ff_Adlm_CM' => 'фула (adlam, Камерун)',
+        'ff_Adlm_GH' => 'фула (adlam, Гана)',
+        'ff_Adlm_GM' => 'фула (adlam, Гамбија)',
+        'ff_Adlm_GN' => 'фула (adlam, Гвинеја)',
+        'ff_Adlm_GW' => 'фула (adlam, Гвинеја-Бисау)',
+        'ff_Adlm_LR' => 'фула (adlam, Либерија)',
+        'ff_Adlm_MR' => 'фула (adlam, Мавританија)',
+        'ff_Adlm_NE' => 'фула (adlam, Ниҝер)',
+        'ff_Adlm_NG' => 'фула (adlam, Ниҝерија)',
+        'ff_Adlm_SL' => 'фула (adlam, Сјерра-Леоне)',
+        'ff_Adlm_SN' => 'фула (adlam, Сенегал)',
         'ff_CM' => 'фула (Камерун)',
         'ff_GN' => 'фула (Гвинеја)',
         'ff_Latn' => 'фула (latın)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'иврит (Исраил)',
         'hi' => 'һинд',
         'hi_IN' => 'һинд (Һиндистан)',
+        'hi_Latn' => 'һинд (latın)',
+        'hi_Latn_IN' => 'һинд (latın, Һиндистан)',
         'hr' => 'хорват',
         'hr_BA' => 'хорват (Боснија вә Һерсеговина)',
         'hr_HR' => 'хорват (Хорватија)',
@@ -371,6 +389,8 @@ return [
         'ks' => 'кәшмир',
         'ks_Arab' => 'кәшмир (ərəb)',
         'ks_Arab_IN' => 'кәшмир (ərəb, Һиндистан)',
+        'ks_Deva' => 'кәшмир (devanaqari)',
+        'ks_Deva_IN' => 'кәшмир (devanaqari, Һиндистан)',
         'ks_IN' => 'кәшмир (Һиндистан)',
         'ku' => 'күрд',
         'ku_TR' => 'күрд (Түркијә)',
@@ -497,6 +517,7 @@ return [
         'sd_Arab_PK' => 'синдһи (ərəb, Пакистан)',
         'sd_Deva' => 'синдһи (devanaqari)',
         'sd_Deva_IN' => 'синдһи (devanaqari, Һиндистан)',
+        'sd_IN' => 'синдһи (Һиндистан)',
         'sd_PK' => 'синдһи (Пакистан)',
         'se' => 'шимали сами',
         'se_FI' => 'шимали сами (Финландија)',
