@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'чачэнская (Расія)',
         'cs' => 'чэшская',
         'cs_CZ' => 'чэшская (Чэхія)',
+        'cv' => 'чувашская',
+        'cv_RU' => 'чувашская (Расія)',
         'cy' => 'валійская',
         'cy_GB' => 'валійская (Вялікабрытанія)',
         'da' => 'дацкая',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'фарсі (Афганістан)',
         'fa_IR' => 'фарсі (Іран)',
         'ff' => 'фула',
+        'ff_Adlm' => 'фула (адлам)',
+        'ff_Adlm_BF' => 'фула (адлам, Буркіна-Фасо)',
+        'ff_Adlm_CM' => 'фула (адлам, Камерун)',
+        'ff_Adlm_GH' => 'фула (адлам, Гана)',
+        'ff_Adlm_GM' => 'фула (адлам, Гамбія)',
+        'ff_Adlm_GN' => 'фула (адлам, Гвінея)',
+        'ff_Adlm_GW' => 'фула (адлам, Гвінея-Бісау)',
+        'ff_Adlm_LR' => 'фула (адлам, Ліберыя)',
+        'ff_Adlm_MR' => 'фула (адлам, Маўрытанія)',
+        'ff_Adlm_NE' => 'фула (адлам, Нігер)',
+        'ff_Adlm_NG' => 'фула (адлам, Нігерыя)',
+        'ff_Adlm_SL' => 'фула (адлам, Сьера-Леонэ)',
+        'ff_Adlm_SN' => 'фула (адлам, Сенегал)',
         'ff_CM' => 'фула (Камерун)',
         'ff_GN' => 'фула (Гвінея)',
         'ff_Latn' => 'фула (лацініца)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'сіндхі (арабскае, Пакістан)',
         'sd_Deva' => 'сіндхі (дэванагары)',
         'sd_Deva_IN' => 'сіндхі (дэванагары, Індыя)',
+        'sd_IN' => 'сіндхі (Індыя)',
         'sd_PK' => 'сіндхі (Пакістан)',
         'se' => 'паўночнасаамская',
         'se_FI' => 'паўночнасаамская (Фінляндыя)',
