@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'čečenski (Rusija)',
         'cs' => 'češki',
         'cs_CZ' => 'češki (Češka)',
+        'cv' => 'čuvaški',
+        'cv_RU' => 'čuvaški (Rusija)',
         'cy' => 'velški',
         'cy_GB' => 'velški (Ujedinjeno Kraljevstvo)',
         'da' => 'danski',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'engleski (Monserat)',
         'en_MT' => 'engleski (Malta)',
         'en_MU' => 'engleski (Mauricijus)',
+        'en_MV' => 'engleski (Maldivi)',
         'en_MW' => 'engleski (Malavi)',
         'en_MY' => 'engleski (Malezija)',
         'en_NA' => 'engleski (Namibija)',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'hebrejski (Izrael)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (Indija)',
+        'hi_Latn' => 'hindi (latinica)',
+        'hi_Latn_IN' => 'hindi (latinica, Indija)',
         'hr' => 'hrvatski',
         'hr_BA' => 'hrvatski (Bosna i Hercegovina)',
         'hr_HR' => 'hrvatski (Hrvatska)',
@@ -385,6 +390,8 @@ return [
         'ks' => 'kašmirski',
         'ks_Arab' => 'kašmirski (arapsko pismo)',
         'ks_Arab_IN' => 'kašmirski (arapsko pismo, Indija)',
+        'ks_Deva' => 'kašmirski (pismo devanagari)',
+        'ks_Deva_IN' => 'kašmirski (pismo devanagari, Indija)',
         'ks_IN' => 'kašmirski (Indija)',
         'ku' => 'kurdski',
         'ku_TR' => 'kurdski (Turska)',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindi (arapsko pismo, Pakistan)',
         'sd_Deva' => 'sindi (pismo devanagari)',
         'sd_Deva_IN' => 'sindi (pismo devanagari, Indija)',
+        'sd_IN' => 'sindi (Indija)',
         'sd_PK' => 'sindi (Pakistan)',
         'se' => 'sjeverni sami',
         'se_FI' => 'sjeverni sami (Finska)',
