@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'чеченски (Русија)',
         'cs' => 'чешки',
         'cs_CZ' => 'чешки (Чешка)',
+        'cv' => 'чувашки',
+        'cv_RU' => 'чувашки (Русија)',
         'cy' => 'велшки',
         'cy_GB' => 'велшки (Уједињено Краљевство)',
         'da' => 'дански',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'енглески (Монсерат)',
         'en_MT' => 'енглески (Малта)',
         'en_MU' => 'енглески (Маурицијус)',
+        'en_MV' => 'енглески (Малдиви)',
         'en_MW' => 'енглески (Малави)',
         'en_MY' => 'енглески (Малезија)',
         'en_NA' => 'енглески (Намибија)',
@@ -238,19 +241,19 @@ return [
         'fa_AF' => 'персијски (Афганистан)',
         'fa_IR' => 'персијски (Иран)',
         'ff' => 'фулах',
-        'ff_Adlm' => 'фулах (adlam pismo)',
-        'ff_Adlm_BF' => 'фулах (adlam pismo, Буркина Фасо)',
-        'ff_Adlm_CM' => 'фулах (adlam pismo, Камерун)',
-        'ff_Adlm_GH' => 'фулах (adlam pismo, Гана)',
-        'ff_Adlm_GM' => 'фулах (adlam pismo, Гамбија)',
-        'ff_Adlm_GN' => 'фулах (adlam pismo, Гвинеја)',
-        'ff_Adlm_GW' => 'фулах (adlam pismo, Гвинеја-Бисау)',
-        'ff_Adlm_LR' => 'фулах (adlam pismo, Либерија)',
-        'ff_Adlm_MR' => 'фулах (adlam pismo, Мауританија)',
-        'ff_Adlm_NE' => 'фулах (adlam pismo, Нигер)',
-        'ff_Adlm_NG' => 'фулах (adlam pismo, Нигерија)',
-        'ff_Adlm_SL' => 'фулах (adlam pismo, Сијера Леоне)',
-        'ff_Adlm_SN' => 'фулах (adlam pismo, Сенегал)',
+        'ff_Adlm' => 'фулах (адламанско писмо)',
+        'ff_Adlm_BF' => 'фулах (адламанско писмо, Буркина Фасо)',
+        'ff_Adlm_CM' => 'фулах (адламанско писмо, Камерун)',
+        'ff_Adlm_GH' => 'фулах (адламанско писмо, Гана)',
+        'ff_Adlm_GM' => 'фулах (адламанско писмо, Гамбија)',
+        'ff_Adlm_GN' => 'фулах (адламанско писмо, Гвинеја)',
+        'ff_Adlm_GW' => 'фулах (адламанско писмо, Гвинеја-Бисау)',
+        'ff_Adlm_LR' => 'фулах (адламанско писмо, Либерија)',
+        'ff_Adlm_MR' => 'фулах (адламанско писмо, Мауританија)',
+        'ff_Adlm_NE' => 'фулах (адламанско писмо, Нигер)',
+        'ff_Adlm_NG' => 'фулах (адламанско писмо, Нигерија)',
+        'ff_Adlm_SL' => 'фулах (адламанско писмо, Сијера Леоне)',
+        'ff_Adlm_SN' => 'фулах (адламанско писмо, Сенегал)',
         'ff_CM' => 'фулах (Камерун)',
         'ff_GN' => 'фулах (Гвинеја)',
         'ff_Latn' => 'фулах (латиница)',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'хебрејски (Израел)',
         'hi' => 'хинди',
         'hi_IN' => 'хинди (Индија)',
+        'hi_Latn' => 'хинди (латиница)',
+        'hi_Latn_IN' => 'хинди (латиница, Индија)',
         'hr' => 'хрватски',
         'hr_BA' => 'хрватски (Босна и Херцеговина)',
         'hr_HR' => 'хрватски (Хрватска)',
@@ -385,6 +390,8 @@ return [
         'ks' => 'кашмирски',
         'ks_Arab' => 'кашмирски (арапско писмо)',
         'ks_Arab_IN' => 'кашмирски (арапско писмо, Индија)',
+        'ks_Deva' => 'кашмирски (деванагари)',
+        'ks_Deva_IN' => 'кашмирски (деванагари, Индија)',
         'ks_IN' => 'кашмирски (Индија)',
         'ku' => 'курдски',
         'ku_TR' => 'курдски (Турска)',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'синди (арапско писмо, Пакистан)',
         'sd_Deva' => 'синди (деванагари)',
         'sd_Deva_IN' => 'синди (деванагари, Индија)',
+        'sd_IN' => 'синди (Индија)',
         'sd_PK' => 'синди (Пакистан)',
         'se' => 'сјеверни сами',
         'se_FI' => 'сјеверни сами (Финска)',
