@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'txetxè (Rússia)',
         'cs' => 'txec',
         'cs_CZ' => 'txec (Txèquia)',
+        'cv' => 'txuvaix',
+        'cv_RU' => 'txuvaix (Rússia)',
         'cy' => 'gal·lès',
         'cy_GB' => 'gal·lès (Regne Unit)',
         'da' => 'danès',
@@ -153,10 +155,11 @@ return [
         'en_MG' => 'anglès (Madagascar)',
         'en_MH' => 'anglès (Illes Marshall)',
         'en_MO' => 'anglès (Macau [RAE Xina])',
-        'en_MP' => 'anglès (Illes Mariannes del Nord)',
+        'en_MP' => 'anglès (Illes Mariannes Septentrionals)',
         'en_MS' => 'anglès (Montserrat)',
         'en_MT' => 'anglès (Malta)',
         'en_MU' => 'anglès (Maurici)',
+        'en_MV' => 'anglès (Maldives)',
         'en_MW' => 'anglès (Malawi)',
         'en_MY' => 'anglès (Malàisia)',
         'en_NA' => 'anglès (Namíbia)',
@@ -183,7 +186,7 @@ return [
         'en_SL' => 'anglès (Sierra Leone)',
         'en_SS' => 'anglès (Sudan del Sud)',
         'en_SX' => 'anglès (Sint Maarten)',
-        'en_SZ' => 'anglès (eSwatini)',
+        'en_SZ' => 'anglès (Eswatini)',
         'en_TC' => 'anglès (Illes Turks i Caicos)',
         'en_TK' => 'anglès (Tokelau)',
         'en_TO' => 'anglès (Tonga)',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'hebreu (Israel)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (Índia)',
+        'hi_Latn' => 'hindi (llatí)',
+        'hi_Latn_IN' => 'hindi (llatí, Índia)',
         'hr' => 'croat',
         'hr_BA' => 'croat (Bòsnia i Hercegovina)',
         'hr_HR' => 'croat (Croàcia)',
@@ -385,13 +390,15 @@ return [
         'ks' => 'caixmiri',
         'ks_Arab' => 'caixmiri (àrab)',
         'ks_Arab_IN' => 'caixmiri (àrab, Índia)',
+        'ks_Deva' => 'caixmiri (devanagari)',
+        'ks_Deva_IN' => 'caixmiri (devanagari, Índia)',
         'ks_IN' => 'caixmiri (Índia)',
         'ku' => 'kurd',
         'ku_TR' => 'kurd (Turquia)',
         'kw' => 'còrnic',
         'kw_GB' => 'còrnic (Regne Unit)',
         'ky' => 'kirguís',
-        'ky_KG' => 'kirguís (Kirguizistan)',
+        'ky_KG' => 'kirguís (Kirguizstan)',
         'lb' => 'luxemburguès',
         'lb_LU' => 'luxemburguès (Luxemburg)',
         'lg' => 'ganda',
@@ -441,7 +448,7 @@ return [
         'nl' => 'neerlandès',
         'nl_AW' => 'neerlandès (Aruba)',
         'nl_BE' => 'neerlandès (Bèlgica)',
-        'nl_BQ' => 'neerlandès (Antilles Neerlandeses)',
+        'nl_BQ' => 'neerlandès (Carib Neerlandès)',
         'nl_CW' => 'neerlandès (Curaçao)',
         'nl_NL' => 'neerlandès (Països Baixos)',
         'nl_SR' => 'neerlandès (Surinam)',
@@ -482,7 +489,7 @@ return [
         'pt_MZ' => 'portuguès (Moçambic)',
         'pt_PT' => 'portuguès (Portugal)',
         'pt_ST' => 'portuguès (São Tomé i Príncipe)',
-        'pt_TL' => 'portuguès (Timor Oriental)',
+        'pt_TL' => 'portuguès (Timor-Leste)',
         'qu' => 'quítxua',
         'qu_BO' => 'quítxua (Bolívia)',
         'qu_EC' => 'quítxua (Equador)',
@@ -496,7 +503,7 @@ return [
         'ro_RO' => 'romanès (Romania)',
         'ru' => 'rus',
         'ru_BY' => 'rus (Belarús)',
-        'ru_KG' => 'rus (Kirguizistan)',
+        'ru_KG' => 'rus (Kirguizstan)',
         'ru_KZ' => 'rus (Kazakhstan)',
         'ru_MD' => 'rus (Moldàvia)',
         'ru_RU' => 'rus (Rússia)',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindi (àrab, Pakistan)',
         'sd_Deva' => 'sindi (devanagari)',
         'sd_Deva_IN' => 'sindi (devanagari, Índia)',
+        'sd_IN' => 'sindi (Índia)',
         'sd_PK' => 'sindi (Pakistan)',
         'se' => 'sami septentrional',
         'se_FI' => 'sami septentrional (Finlàndia)',
@@ -554,7 +562,7 @@ return [
         'su_Latn' => 'sondanès (llatí)',
         'su_Latn_ID' => 'sondanès (llatí, Indonèsia)',
         'sv' => 'suec',
-        'sv_AX' => 'suec (Illes Aland)',
+        'sv_AX' => 'suec (Illes Åland)',
         'sv_FI' => 'suec (Finlàndia)',
         'sv_SE' => 'suec (Suècia)',
         'sw' => 'suahili',
