@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'нохчийн (Росси)',
         'cs' => 'чехийн',
         'cs_CZ' => 'чехийн (Чехи)',
+        'cv' => 'чувашийн',
+        'cv_RU' => 'чувашийн (Росси)',
         'cy' => 'валлийн',
         'cy_GB' => 'валлийн (Йоккха Британи)',
         'da' => 'датхойн',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'ингалсан (Монтсеррат)',
         'en_MT' => 'ингалсан (Мальта)',
         'en_MU' => 'ингалсан (Маврики)',
+        'en_MV' => 'ингалсан (Мальдиваш)',
         'en_MW' => 'ингалсан (Малави)',
         'en_MY' => 'ингалсан (Малайзи)',
         'en_NA' => 'ингалсан (Намиби)',
@@ -328,6 +331,8 @@ return [
         'he_IL' => 'жугтийн (Израиль)',
         'hi' => 'хӀинди',
         'hi_IN' => 'хӀинди (ХӀинди)',
+        'hi_Latn' => 'хӀинди (латинан)',
+        'hi_Latn_IN' => 'хӀинди (латинан, ХӀинди)',
         'hr' => 'хорватийн',
         'hr_BA' => 'хорватийн (Босни а, Герцеговина а)',
         'hr_HR' => 'хорватийн (Хорвати)',
@@ -372,6 +377,8 @@ return [
         'ks' => 'кашмири',
         'ks_Arab' => 'кашмири (Ӏаьрбийн)',
         'ks_Arab_IN' => 'кашмири (Ӏаьрбийн, ХӀинди)',
+        'ks_Deva' => 'кашмири (деванагари)',
+        'ks_Deva_IN' => 'кашмири (деванагари, ХӀинди)',
         'ks_IN' => 'кашмири (ХӀинди)',
         'ku' => 'курдийн',
         'ku_TR' => 'курдийн (Туркойчоь)',
@@ -496,6 +503,7 @@ return [
         'sd_Arab_PK' => 'синдхи (Ӏаьрбийн, Пакистан)',
         'sd_Deva' => 'синдхи (деванагари)',
         'sd_Deva_IN' => 'синдхи (деванагари, ХӀинди)',
+        'sd_IN' => 'синдхи (ХӀинди)',
         'sd_PK' => 'синдхи (Пакистан)',
         'se' => 'къилбаседа саамийн',
         'se_FI' => 'къилбаседа саамийн (Финлянди)',
