@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'čečenština (Rusko)',
         'cs' => 'čeština',
         'cs_CZ' => 'čeština (Česko)',
+        'cv' => 'čuvaština',
+        'cv_RU' => 'čuvaština (Rusko)',
         'cy' => 'velština',
         'cy_GB' => 'velština (Spojené království)',
         'da' => 'dánština',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'angličtina (Montserrat)',
         'en_MT' => 'angličtina (Malta)',
         'en_MU' => 'angličtina (Mauricius)',
+        'en_MV' => 'angličtina (Maledivy)',
         'en_MW' => 'angličtina (Malawi)',
         'en_MY' => 'angličtina (Malajsie)',
         'en_NA' => 'angličtina (Namibie)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'perština (Afghánistán)',
         'fa_IR' => 'perština (Írán)',
         'ff' => 'fulbština',
+        'ff_Adlm' => 'fulbština (adlam)',
+        'ff_Adlm_BF' => 'fulbština (adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fulbština (adlam, Kamerun)',
+        'ff_Adlm_GH' => 'fulbština (adlam, Ghana)',
+        'ff_Adlm_GM' => 'fulbština (adlam, Gambie)',
+        'ff_Adlm_GN' => 'fulbština (adlam, Guinea)',
+        'ff_Adlm_GW' => 'fulbština (adlam, Guinea-Bissau)',
+        'ff_Adlm_LR' => 'fulbština (adlam, Libérie)',
+        'ff_Adlm_MR' => 'fulbština (adlam, Mauritánie)',
+        'ff_Adlm_NE' => 'fulbština (adlam, Niger)',
+        'ff_Adlm_NG' => 'fulbština (adlam, Nigérie)',
+        'ff_Adlm_SL' => 'fulbština (adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'fulbština (adlam, Senegal)',
         'ff_CM' => 'fulbština (Kamerun)',
         'ff_GN' => 'fulbština (Guinea)',
         'ff_Latn' => 'fulbština (latinka)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'hebrejština (Izrael)',
         'hi' => 'hindština',
         'hi_IN' => 'hindština (Indie)',
+        'hi_Latn' => 'hindština (latinka)',
+        'hi_Latn_IN' => 'hindština (latinka, Indie)',
         'hr' => 'chorvatština',
         'hr_BA' => 'chorvatština (Bosna a Hercegovina)',
         'hr_HR' => 'chorvatština (Chorvatsko)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kašmírština',
         'ks_Arab' => 'kašmírština (arabské)',
         'ks_Arab_IN' => 'kašmírština (arabské, Indie)',
+        'ks_Deva' => 'kašmírština (dévanágarí)',
+        'ks_Deva_IN' => 'kašmírština (dévanágarí, Indie)',
         'ks_IN' => 'kašmírština (Indie)',
         'ku' => 'kurdština',
         'ku_TR' => 'kurdština (Turecko)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhština (arabské, Pákistán)',
         'sd_Deva' => 'sindhština (dévanágarí)',
         'sd_Deva_IN' => 'sindhština (dévanágarí, Indie)',
+        'sd_IN' => 'sindhština (Indie)',
         'sd_PK' => 'sindhština (Pákistán)',
         'se' => 'sámština [severní]',
         'se_FI' => 'sámština [severní] (Finsko)',
