@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Tsietsieneg (Rwsia)',
         'cs' => 'Tsieceg',
         'cs_CZ' => 'Tsieceg (Tsiecia)',
+        'cv' => 'Tshwfasheg',
+        'cv_RU' => 'Tshwfasheg (Rwsia)',
         'cy' => 'Cymraeg',
         'cy_GB' => 'Cymraeg (Y Deyrnas Unedig)',
         'da' => 'Daneg',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'Perseg (Afghanistan)',
         'fa_IR' => 'Perseg (Iran)',
         'ff' => 'Ffwla',
+        'ff_Adlm' => 'Ffwla (Adlam)',
+        'ff_Adlm_BF' => 'Ffwla (Adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'Ffwla (Adlam, Camerŵn)',
+        'ff_Adlm_GH' => 'Ffwla (Adlam, Ghana)',
+        'ff_Adlm_GM' => 'Ffwla (Adlam, Gambia)',
+        'ff_Adlm_GN' => 'Ffwla (Adlam, Gini)',
+        'ff_Adlm_GW' => 'Ffwla (Adlam, Guiné-Bissau)',
+        'ff_Adlm_LR' => 'Ffwla (Adlam, Liberia)',
+        'ff_Adlm_MR' => 'Ffwla (Adlam, Mauritania)',
+        'ff_Adlm_NE' => 'Ffwla (Adlam, Niger)',
+        'ff_Adlm_NG' => 'Ffwla (Adlam, Nigeria)',
+        'ff_Adlm_SL' => 'Ffwla (Adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'Ffwla (Adlam, Senegal)',
         'ff_CM' => 'Ffwla (Camerŵn)',
         'ff_GN' => 'Ffwla (Gini)',
         'ff_Latn' => 'Ffwla (Lladin)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Sindhi (Arabaidd, Pakistan)',
         'sd_Deva' => 'Sindhi (Devanagari)',
         'sd_Deva_IN' => 'Sindhi (Devanagari, India)',
+        'sd_IN' => 'Sindhi (India)',
         'sd_PK' => 'Sindhi (Pakistan)',
         'se' => 'Sami Gogleddol',
         'se_FI' => 'Sami Gogleddol (Y Ffindir)',
