@@ -46,8 +46,8 @@ return [
         'az_Cyrl_AZ' => 'aserbajdsjansk (kyrillisk, Aserbajdsjan)',
         'az_Latn' => 'aserbajdsjansk (latinsk)',
         'az_Latn_AZ' => 'aserbajdsjansk (latinsk, Aserbajdsjan)',
-        'be' => 'hviderussisk',
-        'be_BY' => 'hviderussisk (Hviderusland)',
+        'be' => 'belarusisk',
+        'be_BY' => 'belarusisk (Belarus)',
         'bg' => 'bulgarsk',
         'bg_BG' => 'bulgarsk (Bulgarien)',
         'bm' => 'bambara',
@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'tjetjensk (Rusland)',
         'cs' => 'tjekkisk',
         'cs_CZ' => 'tjekkisk (Tjekkiet)',
+        'cv' => 'chuvash',
+        'cv_RU' => 'chuvash (Rusland)',
         'cy' => 'walisisk',
         'cy_GB' => 'walisisk (Storbritannien)',
         'da' => 'dansk',
@@ -163,7 +165,7 @@ return [
         'en_NA' => 'engelsk (Namibia)',
         'en_NF' => 'engelsk (Norfolk Island)',
         'en_NG' => 'engelsk (Nigeria)',
-        'en_NL' => 'engelsk (Holland)',
+        'en_NL' => 'engelsk (Nederlandene)',
         'en_NR' => 'engelsk (Nauru)',
         'en_NU' => 'engelsk (Niue)',
         'en_NZ' => 'engelsk (New Zealand)',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'persisk (Afghanistan)',
         'fa_IR' => 'persisk (Iran)',
         'ff' => 'fulah',
+        'ff_Adlm' => 'fulah (adlam)',
+        'ff_Adlm_BF' => 'fulah (adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fulah (adlam, Cameroun)',
+        'ff_Adlm_GH' => 'fulah (adlam, Ghana)',
+        'ff_Adlm_GM' => 'fulah (adlam, Gambia)',
+        'ff_Adlm_GN' => 'fulah (adlam, Guinea)',
+        'ff_Adlm_GW' => 'fulah (adlam, Guinea-Bissau)',
+        'ff_Adlm_LR' => 'fulah (adlam, Liberia)',
+        'ff_Adlm_MR' => 'fulah (adlam, Mauretanien)',
+        'ff_Adlm_NE' => 'fulah (adlam, Niger)',
+        'ff_Adlm_NG' => 'fulah (adlam, Nigeria)',
+        'ff_Adlm_SL' => 'fulah (adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'fulah (adlam, Senegal)',
         'ff_CM' => 'fulah (Cameroun)',
         'ff_GN' => 'fulah (Guinea)',
         'ff_Latn' => 'fulah (latinsk)',
@@ -309,7 +324,7 @@ return [
         'fr_WF' => 'fransk (Wallis og Futuna)',
         'fr_YT' => 'fransk (Mayotte)',
         'fy' => 'vestfrisisk',
-        'fy_NL' => 'vestfrisisk (Holland)',
+        'fy_NL' => 'vestfrisisk (Nederlandene)',
         'ga' => 'irsk',
         'ga_GB' => 'irsk (Storbritannien)',
         'ga_IE' => 'irsk (Irland)',
@@ -430,14 +445,14 @@ return [
         'ne' => 'nepalesisk',
         'ne_IN' => 'nepalesisk (Indien)',
         'ne_NP' => 'nepalesisk (Nepal)',
-        'nl' => 'hollandsk',
-        'nl_AW' => 'hollandsk (Aruba)',
-        'nl_BE' => 'hollandsk (Belgien)',
-        'nl_BQ' => 'hollandsk (De tidligere Nederlandske Antiller)',
-        'nl_CW' => 'hollandsk (Curaçao)',
-        'nl_NL' => 'hollandsk (Holland)',
-        'nl_SR' => 'hollandsk (Surinam)',
-        'nl_SX' => 'hollandsk (Sint Maarten)',
+        'nl' => 'nederlandsk',
+        'nl_AW' => 'nederlandsk (Aruba)',
+        'nl_BE' => 'nederlandsk (Belgien)',
+        'nl_BQ' => 'nederlandsk (De tidligere Nederlandske Antiller)',
+        'nl_CW' => 'nederlandsk (Curaçao)',
+        'nl_NL' => 'nederlandsk (Nederlandene)',
+        'nl_SR' => 'nederlandsk (Surinam)',
+        'nl_SX' => 'nederlandsk (Sint Maarten)',
         'nn' => 'nynorsk',
         'nn_NO' => 'nynorsk (Norge)',
         'no' => 'norsk',
@@ -487,7 +502,7 @@ return [
         'ro_MD' => 'rumænsk (Moldova)',
         'ro_RO' => 'rumænsk (Rumænien)',
         'ru' => 'russisk',
-        'ru_BY' => 'russisk (Hviderusland)',
+        'ru_BY' => 'russisk (Belarus)',
         'ru_KG' => 'russisk (Kirgisistan)',
         'ru_KZ' => 'russisk (Kasakhstan)',
         'ru_MD' => 'russisk (Moldova)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arabisk, Pakistan)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, Indien)',
+        'sd_IN' => 'sindhi (Indien)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'nordsamisk',
         'se_FI' => 'nordsamisk (Finland)',
