@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Tschetschenisch (Russland)',
         'cs' => 'Tschechisch',
         'cs_CZ' => 'Tschechisch (Tschechien)',
+        'cv' => 'Tschuwaschisch',
+        'cv_RU' => 'Tschuwaschisch (Russland)',
         'cy' => 'Walisisch',
         'cy_GB' => 'Walisisch (Vereinigtes Königreich)',
         'da' => 'Dänisch',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'Persisch (Afghanistan)',
         'fa_IR' => 'Persisch (Iran)',
         'ff' => 'Ful',
+        'ff_Adlm' => 'Ful (Adlam)',
+        'ff_Adlm_BF' => 'Ful (Adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'Ful (Adlam, Kamerun)',
+        'ff_Adlm_GH' => 'Ful (Adlam, Ghana)',
+        'ff_Adlm_GM' => 'Ful (Adlam, Gambia)',
+        'ff_Adlm_GN' => 'Ful (Adlam, Guinea)',
+        'ff_Adlm_GW' => 'Ful (Adlam, Guinea-Bissau)',
+        'ff_Adlm_LR' => 'Ful (Adlam, Liberia)',
+        'ff_Adlm_MR' => 'Ful (Adlam, Mauretanien)',
+        'ff_Adlm_NE' => 'Ful (Adlam, Niger)',
+        'ff_Adlm_NG' => 'Ful (Adlam, Nigeria)',
+        'ff_Adlm_SL' => 'Ful (Adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'Ful (Adlam, Senegal)',
         'ff_CM' => 'Ful (Kamerun)',
         'ff_GN' => 'Ful (Guinea)',
         'ff_Latn' => 'Ful (Lateinisch)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Sindhi (Arabisch, Pakistan)',
         'sd_Deva' => 'Sindhi (Devanagari)',
         'sd_Deva_IN' => 'Sindhi (Devanagari, Indien)',
+        'sd_IN' => 'Sindhi (Indien)',
         'sd_PK' => 'Sindhi (Pakistan)',
         'se' => 'Nordsamisch',
         'se_FI' => 'Nordsamisch (Finnland)',
