@@ -146,6 +146,7 @@ return [
         'en_MS' => 'ཨིང་ལིཤ་ཁ། (མོན་ས་རཊ།)',
         'en_MT' => 'ཨིང་ལིཤ་ཁ། (མཱལ་ཊ།)',
         'en_MU' => 'ཨིང་ལིཤ་ཁ། (མོ་རི་ཤཱས།)',
+        'en_MV' => 'ཨིང་ལིཤ་ཁ། (མཱལ་དིབས།)',
         'en_MW' => 'ཨིང་ལིཤ་ཁ། (མ་ལ་ཝི།)',
         'en_MY' => 'ཨིང་ལིཤ་ཁ། (མ་ལེ་ཤི་ཡ།)',
         'en_NA' => 'ཨིང་ལིཤ་ཁ། (ན་མི་བི་ཡ།)',
@@ -295,6 +296,8 @@ return [
         'he_IL' => 'ཧེ་བྲུ་ཁ། (ཨིས་ར་ཡེལ།)',
         'hi' => 'ཧིན་དི་ཁ',
         'hi_IN' => 'ཧིན་དི་ཁ། (རྒྱ་གར།)',
+        'hi_Latn' => 'ཧིན་དི་ཁ། (ལེ་ཊིན་ཡིག་གུ།)',
+        'hi_Latn_IN' => 'ཧིན་དི་ཁ། (ལེ་ཊིན་ཡིག་གུ་, རྒྱ་གར།)',
         'hr' => 'ཀྲོ་ཨེ་ཤི་ཡཱན་ཁ',
         'hr_BA' => 'ཀྲོ་ཨེ་ཤི་ཡཱན་ཁ། (བྷོས་ནི་ཡ་ ཨེནཌ་ ཧར་ཛི་གྷོ་བི་ན།)',
         'hr_HR' => 'ཀྲོ་ཨེ་ཤི་ཡཱན་ཁ། (ཀྲོ་ཨེ་ཤ།)',
@@ -331,6 +334,8 @@ return [
         'ks' => 'ཀཱཤ་མི་རི་ཁ',
         'ks_Arab' => 'ཀཱཤ་མི་རི་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ།)',
         'ks_Arab_IN' => 'ཀཱཤ་མི་རི་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ་, རྒྱ་གར།)',
+        'ks_Deva' => 'ཀཱཤ་མི་རི་ཁ། (དེ་ཝ་ན་ག་རི་ཡིག་གུ།)',
+        'ks_Deva_IN' => 'ཀཱཤ་མི་རི་ཁ། (དེ་ཝ་ན་ག་རི་ཡིག་གུ་, རྒྱ་གར།)',
         'ks_IN' => 'ཀཱཤ་མི་རི་ཁ། (རྒྱ་གར།)',
         'ku' => 'ཀར་ཌིཤ་ཁ',
         'ku_TR' => 'ཀར་ཌིཤ་ཁ། (ཊཱར་ཀི།)',
@@ -430,6 +435,7 @@ return [
         'sd_Arab_PK' => 'སིན་དཱི་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ་, པ་ཀི་སཏཱན།)',
         'sd_Deva' => 'སིན་དཱི་ཁ། (དེ་ཝ་ན་ག་རི་ཡིག་གུ།)',
         'sd_Deva_IN' => 'སིན་དཱི་ཁ། (དེ་ཝ་ན་ག་རི་ཡིག་གུ་, རྒྱ་གར།)',
+        'sd_IN' => 'སིན་དཱི་ཁ། (རྒྱ་གར།)',
         'sd_PK' => 'སིན་དཱི་ཁ། (པ་ཀི་སཏཱན།)',
         'si' => 'སིང་ཧ་ལ་ཁ',
         'si_LK' => 'སིང་ཧ་ལ་ཁ། (ཤྲཱི་ལང་ཀ།)',
