@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Τσετσενικά (Ρωσία)',
         'cs' => 'Τσεχικά',
         'cs_CZ' => 'Τσεχικά (Τσεχία)',
+        'cv' => 'Τσουβασικά',
+        'cv_RU' => 'Τσουβασικά (Ρωσία)',
         'cy' => 'Ουαλικά',
         'cy_GB' => 'Ουαλικά (Ηνωμένο Βασίλειο)',
         'da' => 'Δανικά',
@@ -157,12 +159,13 @@ return [
         'en_MS' => 'Αγγλικά (Μονσεράτ)',
         'en_MT' => 'Αγγλικά (Μάλτα)',
         'en_MU' => 'Αγγλικά (Μαυρίκιος)',
+        'en_MV' => 'Αγγλικά (Μαλδίβες)',
         'en_MW' => 'Αγγλικά (Μαλάουι)',
         'en_MY' => 'Αγγλικά (Μαλαισία)',
         'en_NA' => 'Αγγλικά (Ναμίμπια)',
         'en_NF' => 'Αγγλικά (Νήσος Νόρφολκ)',
         'en_NG' => 'Αγγλικά (Νιγηρία)',
-        'en_NL' => 'Αγγλικά (Ολλανδία)',
+        'en_NL' => 'Αγγλικά (Κάτω Χώρες)',
         'en_NR' => 'Αγγλικά (Ναουρού)',
         'en_NU' => 'Αγγλικά (Νιούε)',
         'en_NZ' => 'Αγγλικά (Νέα Ζηλανδία)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'Περσικά (Αφγανιστάν)',
         'fa_IR' => 'Περσικά (Ιράν)',
         'ff' => 'Φουλά',
+        'ff_Adlm' => 'Φουλά (Άντλαμ)',
+        'ff_Adlm_BF' => 'Φουλά (Άντλαμ, Μπουρκίνα Φάσο)',
+        'ff_Adlm_CM' => 'Φουλά (Άντλαμ, Καμερούν)',
+        'ff_Adlm_GH' => 'Φουλά (Άντλαμ, Γκάνα)',
+        'ff_Adlm_GM' => 'Φουλά (Άντλαμ, Γκάμπια)',
+        'ff_Adlm_GN' => 'Φουλά (Άντλαμ, Γουινέα)',
+        'ff_Adlm_GW' => 'Φουλά (Άντλαμ, Γουινέα Μπισάου)',
+        'ff_Adlm_LR' => 'Φουλά (Άντλαμ, Λιβερία)',
+        'ff_Adlm_MR' => 'Φουλά (Άντλαμ, Μαυριτανία)',
+        'ff_Adlm_NE' => 'Φουλά (Άντλαμ, Νίγηρας)',
+        'ff_Adlm_NG' => 'Φουλά (Άντλαμ, Νιγηρία)',
+        'ff_Adlm_SL' => 'Φουλά (Άντλαμ, Σιέρα Λεόνε)',
+        'ff_Adlm_SN' => 'Φουλά (Άντλαμ, Σενεγάλη)',
         'ff_CM' => 'Φουλά (Καμερούν)',
         'ff_GN' => 'Φουλά (Γουινέα)',
         'ff_Latn' => 'Φουλά (Λατινικό)',
@@ -308,7 +324,7 @@ return [
         'fr_WF' => 'Γαλλικά (Γουάλις και Φουτούνα)',
         'fr_YT' => 'Γαλλικά (Μαγιότ)',
         'fy' => 'Δυτικά Φριζικά',
-        'fy_NL' => 'Δυτικά Φριζικά (Ολλανδία)',
+        'fy_NL' => 'Δυτικά Φριζικά (Κάτω Χώρες)',
         'ga' => 'Ιρλανδικά',
         'ga_GB' => 'Ιρλανδικά (Ηνωμένο Βασίλειο)',
         'ga_IE' => 'Ιρλανδικά (Ιρλανδία)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'Εβραϊκά (Ισραήλ)',
         'hi' => 'Χίντι',
         'hi_IN' => 'Χίντι (Ινδία)',
+        'hi_Latn' => 'Χίντι (Λατινικό)',
+        'hi_Latn_IN' => 'Χίντι (Λατινικό, Ινδία)',
         'hr' => 'Κροατικά',
         'hr_BA' => 'Κροατικά (Βοσνία - Ερζεγοβίνη)',
         'hr_HR' => 'Κροατικά (Κροατία)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'Κασμιρικά',
         'ks_Arab' => 'Κασμιρικά (Αραβικό)',
         'ks_Arab_IN' => 'Κασμιρικά (Αραβικό, Ινδία)',
+        'ks_Deva' => 'Κασμιρικά (Ντεβαναγκάρι)',
+        'ks_Deva_IN' => 'Κασμιρικά (Ντεβαναγκάρι, Ινδία)',
         'ks_IN' => 'Κασμιρικά (Ινδία)',
         'ku' => 'Κουρδικά',
         'ku_TR' => 'Κουρδικά (Τουρκία)',
@@ -430,7 +450,7 @@ return [
         'nl_BE' => 'Ολλανδικά (Βέλγιο)',
         'nl_BQ' => 'Ολλανδικά (Ολλανδία Καραϊβικής)',
         'nl_CW' => 'Ολλανδικά (Κουρασάο)',
-        'nl_NL' => 'Ολλανδικά (Ολλανδία)',
+        'nl_NL' => 'Ολλανδικά (Κάτω Χώρες)',
         'nl_SR' => 'Ολλανδικά (Σουρινάμ)',
         'nl_SX' => 'Ολλανδικά (Άγιος Μαρτίνος [Ολλανδικό τμήμα])',
         'nn' => 'Νορβηγικά Νινόρσκ',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Σίντι (Αραβικό, Πακιστάν)',
         'sd_Deva' => 'Σίντι (Ντεβαναγκάρι)',
         'sd_Deva_IN' => 'Σίντι (Ντεβαναγκάρι, Ινδία)',
+        'sd_IN' => 'Σίντι (Ινδία)',
         'sd_PK' => 'Σίντι (Πακιστάν)',
         'se' => 'Βόρεια Σάμι',
         'se_FI' => 'Βόρεια Σάμι (Φινλανδία)',
