@@ -394,7 +394,7 @@ return [
         'ks_Deva_IN' => 'Kashmiri (Devanagari, India)',
         'ks_IN' => 'Kashmiri (India)',
         'ku' => 'Kurdish',
-        'ku_TR' => 'Kurdish (Turkey)',
+        'ku_TR' => 'Kurdish (Türkiye)',
         'kw' => 'Cornish',
         'kw_GB' => 'Cornish (United Kingdom)',
         'ky' => 'Kyrgyz',
@@ -592,7 +592,7 @@ return [
         'to_TO' => 'Tongan (Tonga)',
         'tr' => 'Turkish',
         'tr_CY' => 'Turkish (Cyprus)',
-        'tr_TR' => 'Turkish (Turkey)',
+        'tr_TR' => 'Turkish (Türkiye)',
         'tt' => 'Tatar',
         'tt_RU' => 'Tatar (Russia)',
         'ug' => 'Uyghur',
