@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'checheno (Rusia)',
         'cs' => 'checo',
         'cs_CZ' => 'checo (Chequia)',
+        'cv' => 'chuvasio',
+        'cv_RU' => 'chuvasio (Rusia)',
         'cy' => 'galés',
         'cy_GB' => 'galés (Reino Unido)',
         'da' => 'danés',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'inglés (Montserrat)',
         'en_MT' => 'inglés (Malta)',
         'en_MU' => 'inglés (Mauricio)',
+        'en_MV' => 'inglés (Maldivas)',
         'en_MW' => 'inglés (Malaui)',
         'en_MY' => 'inglés (Malasia)',
         'en_NA' => 'inglés (Namibia)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'persa (Afganistán)',
         'fa_IR' => 'persa (Irán)',
         'ff' => 'fula',
+        'ff_Adlm' => 'fula (ádlam)',
+        'ff_Adlm_BF' => 'fula (ádlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fula (ádlam, Camerún)',
+        'ff_Adlm_GH' => 'fula (ádlam, Ghana)',
+        'ff_Adlm_GM' => 'fula (ádlam, Gambia)',
+        'ff_Adlm_GN' => 'fula (ádlam, Guinea)',
+        'ff_Adlm_GW' => 'fula (ádlam, Guinea-Bisáu)',
+        'ff_Adlm_LR' => 'fula (ádlam, Liberia)',
+        'ff_Adlm_MR' => 'fula (ádlam, Mauritania)',
+        'ff_Adlm_NE' => 'fula (ádlam, Níger)',
+        'ff_Adlm_NG' => 'fula (ádlam, Nigeria)',
+        'ff_Adlm_SL' => 'fula (ádlam, Sierra Leona)',
+        'ff_Adlm_SN' => 'fula (ádlam, Senegal)',
         'ff_CM' => 'fula (Camerún)',
         'ff_GN' => 'fula (Guinea)',
         'ff_Latn' => 'fula (latino)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'hebreo (Israel)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (India)',
+        'hi_Latn' => 'hindi (latino)',
+        'hi_Latn_IN' => 'hindi (latino, India)',
         'hr' => 'croata',
         'hr_BA' => 'croata (Bosnia y Herzegovina)',
         'hr_HR' => 'croata (Croacia)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'cachemir',
         'ks_Arab' => 'cachemir (árabe)',
         'ks_Arab_IN' => 'cachemir (árabe, India)',
+        'ks_Deva' => 'cachemir (devanagari)',
+        'ks_Deva_IN' => 'cachemir (devanagari, India)',
         'ks_IN' => 'cachemir (India)',
         'ku' => 'kurdo',
         'ku_TR' => 'kurdo (Turquía)',
@@ -494,12 +514,13 @@ return [
         'sa_IN' => 'sánscrito (India)',
         'sc' => 'sardo',
         'sc_IT' => 'sardo (Italia)',
-        'sd' => 'sindhi',
-        'sd_Arab' => 'sindhi (árabe)',
-        'sd_Arab_PK' => 'sindhi (árabe, Pakistán)',
-        'sd_Deva' => 'sindhi (devanagari)',
-        'sd_Deva_IN' => 'sindhi (devanagari, India)',
-        'sd_PK' => 'sindhi (Pakistán)',
+        'sd' => 'sindi',
+        'sd_Arab' => 'sindi (árabe)',
+        'sd_Arab_PK' => 'sindi (árabe, Pakistán)',
+        'sd_Deva' => 'sindi (devanagari)',
+        'sd_Deva_IN' => 'sindi (devanagari, India)',
+        'sd_IN' => 'sindi (India)',
+        'sd_PK' => 'sindi (Pakistán)',
         'se' => 'sami septentrional',
         'se_FI' => 'sami septentrional (Finlandia)',
         'se_NO' => 'sami septentrional (Noruega)',
