@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'tšetšeeni (Venemaa)',
         'cs' => 'tšehhi',
         'cs_CZ' => 'tšehhi (Tšehhi)',
+        'cv' => 'tšuvaši',
+        'cv_RU' => 'tšuvaši (Venemaa)',
         'cy' => 'kõmri',
         'cy_GB' => 'kõmri (Ühendkuningriik)',
         'da' => 'taani',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'pärsia (Afganistan)',
         'fa_IR' => 'pärsia (Iraan)',
         'ff' => 'fula',
+        'ff_Adlm' => 'fula (adlami)',
+        'ff_Adlm_BF' => 'fula (adlami, Burkina Faso)',
+        'ff_Adlm_CM' => 'fula (adlami, Kamerun)',
+        'ff_Adlm_GH' => 'fula (adlami, Ghana)',
+        'ff_Adlm_GM' => 'fula (adlami, Gambia)',
+        'ff_Adlm_GN' => 'fula (adlami, Guinea)',
+        'ff_Adlm_GW' => 'fula (adlami, Guinea-Bissau)',
+        'ff_Adlm_LR' => 'fula (adlami, Libeeria)',
+        'ff_Adlm_MR' => 'fula (adlami, Mauritaania)',
+        'ff_Adlm_NE' => 'fula (adlami, Niger)',
+        'ff_Adlm_NG' => 'fula (adlami, Nigeeria)',
+        'ff_Adlm_SL' => 'fula (adlami, Sierra Leone)',
+        'ff_Adlm_SN' => 'fula (adlami, Senegal)',
         'ff_CM' => 'fula (Kamerun)',
         'ff_GN' => 'fula (Guinea)',
         'ff_Latn' => 'fula (ladina)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (araabia, Pakistan)',
         'sd_Deva' => 'sindhi (devanaagari)',
         'sd_Deva_IN' => 'sindhi (devanaagari, India)',
+        'sd_IN' => 'sindhi (India)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'põhjasaami',
         'se_FI' => 'põhjasaami (Soome)',
