@@ -2,9 +2,9 @@
 
 return [
     'Names' => [
-        'af' => 'afrikaans',
-        'af_NA' => 'afrikaans (Namibia)',
-        'af_ZA' => 'afrikaans (Hegoafrika)',
+        'af' => 'afrikaansa',
+        'af_NA' => 'afrikaansa (Namibia)',
+        'af_ZA' => 'afrikaansa (Hegoafrika)',
         'ak' => 'akanera',
         'ak_GH' => 'akanera (Ghana)',
         'am' => 'amharera',
@@ -66,28 +66,30 @@ return [
         'bs_Cyrl_BA' => 'bosniera (zirilikoa, Bosnia-Herzegovina)',
         'bs_Latn' => 'bosniera (latinoa)',
         'bs_Latn_BA' => 'bosniera (latinoa, Bosnia-Herzegovina)',
-        'ca' => 'katalan',
-        'ca_AD' => 'katalan (Andorra)',
-        'ca_ES' => 'katalan (Espainia)',
-        'ca_FR' => 'katalan (Frantzia)',
-        'ca_IT' => 'katalan (Italia)',
+        'ca' => 'katalana',
+        'ca_AD' => 'katalana (Andorra)',
+        'ca_ES' => 'katalana (Espainia)',
+        'ca_FR' => 'katalana (Frantzia)',
+        'ca_IT' => 'katalana (Italia)',
         'ce' => 'txetxenera',
         'ce_RU' => 'txetxenera (Errusia)',
         'cs' => 'txekiera',
         'cs_CZ' => 'txekiera (Txekia)',
-        'cy' => 'gales',
-        'cy_GB' => 'gales (Erresuma Batua)',
+        'cv' => 'txuvaxera',
+        'cv_RU' => 'txuvaxera (Errusia)',
+        'cy' => 'galesa',
+        'cy_GB' => 'galesa (Erresuma Batua)',
         'da' => 'daniera',
         'da_DK' => 'daniera (Danimarka)',
         'da_GL' => 'daniera (Groenlandia)',
-        'de' => 'aleman',
-        'de_AT' => 'aleman (Austria)',
-        'de_BE' => 'aleman (Belgika)',
-        'de_CH' => 'aleman (Suitza)',
-        'de_DE' => 'aleman (Alemania)',
-        'de_IT' => 'aleman (Italia)',
-        'de_LI' => 'aleman (Liechtenstein)',
-        'de_LU' => 'aleman (Luxenburgo)',
+        'de' => 'alemana',
+        'de_AT' => 'alemana (Austria)',
+        'de_BE' => 'alemana (Belgika)',
+        'de_CH' => 'alemana (Suitza)',
+        'de_DE' => 'alemana (Alemania)',
+        'de_IT' => 'alemana (Italia)',
+        'de_LI' => 'alemana (Liechtenstein)',
+        'de_LU' => 'alemana (Luxenburgo)',
         'dz' => 'dzongkha',
         'dz_BT' => 'dzongkha (Bhutan)',
         'ee' => 'eweera',
@@ -96,113 +98,114 @@ return [
         'el' => 'greziera',
         'el_CY' => 'greziera (Zipre)',
         'el_GR' => 'greziera (Grezia)',
-        'en' => 'ingeles',
-        'en_001' => 'ingeles (Mundua)',
-        'en_150' => 'ingeles (Europa)',
-        'en_AE' => 'ingeles (Arabiar Emirerri Batuak)',
-        'en_AG' => 'ingeles (Antigua eta Barbuda)',
-        'en_AI' => 'ingeles (Aingira)',
-        'en_AS' => 'ingeles (Samoa Estatubatuarra)',
-        'en_AT' => 'ingeles (Austria)',
-        'en_AU' => 'ingeles (Australia)',
-        'en_BB' => 'ingeles (Barbados)',
-        'en_BE' => 'ingeles (Belgika)',
-        'en_BI' => 'ingeles (Burundi)',
-        'en_BM' => 'ingeles (Bermuda)',
-        'en_BS' => 'ingeles (Bahamak)',
-        'en_BW' => 'ingeles (Botswana)',
-        'en_BZ' => 'ingeles (Belize)',
-        'en_CA' => 'ingeles (Kanada)',
-        'en_CC' => 'ingeles (Cocos [Keeling] uharteak)',
-        'en_CH' => 'ingeles (Suitza)',
-        'en_CK' => 'ingeles (Cook uharteak)',
-        'en_CM' => 'ingeles (Kamerun)',
-        'en_CX' => 'ingeles (Christmas uhartea)',
-        'en_CY' => 'ingeles (Zipre)',
-        'en_DE' => 'ingeles (Alemania)',
-        'en_DK' => 'ingeles (Danimarka)',
-        'en_DM' => 'ingeles (Dominika)',
-        'en_ER' => 'ingeles (Eritrea)',
-        'en_FI' => 'ingeles (Finlandia)',
-        'en_FJ' => 'ingeles (Fiji)',
-        'en_FK' => 'ingeles (Falklandak)',
-        'en_FM' => 'ingeles (Mikronesia)',
-        'en_GB' => 'ingeles (Erresuma Batua)',
-        'en_GD' => 'ingeles (Grenada)',
-        'en_GG' => 'ingeles (Guernesey)',
-        'en_GH' => 'ingeles (Ghana)',
-        'en_GI' => 'ingeles (Gibraltar)',
-        'en_GM' => 'ingeles (Gambia)',
-        'en_GU' => 'ingeles (Guam)',
-        'en_GY' => 'ingeles (Guyana)',
-        'en_HK' => 'ingeles (Hong Kong Txinako AEB)',
-        'en_IE' => 'ingeles (Irlanda)',
-        'en_IL' => 'ingeles (Israel)',
-        'en_IM' => 'ingeles (Man uhartea)',
-        'en_IN' => 'ingeles (India)',
-        'en_IO' => 'ingeles (Indiako Ozeanoko lurralde britainiarra)',
-        'en_JE' => 'ingeles (Jersey)',
-        'en_JM' => 'ingeles (Jamaika)',
-        'en_KE' => 'ingeles (Kenya)',
-        'en_KI' => 'ingeles (Kiribati)',
-        'en_KN' => 'ingeles (Saint Kitts eta Nevis)',
-        'en_KY' => 'ingeles (Kaiman uharteak)',
-        'en_LC' => 'ingeles (Santa Luzia)',
-        'en_LR' => 'ingeles (Liberia)',
-        'en_LS' => 'ingeles (Lesotho)',
-        'en_MG' => 'ingeles (Madagaskar)',
-        'en_MH' => 'ingeles (Marshall Uharteak)',
-        'en_MO' => 'ingeles (Macau Txinako AEB)',
-        'en_MP' => 'ingeles (Ipar Mariana uharteak)',
-        'en_MS' => 'ingeles (Montserrat)',
-        'en_MT' => 'ingeles (Malta)',
-        'en_MU' => 'ingeles (Maurizio)',
-        'en_MW' => 'ingeles (Malawi)',
-        'en_MY' => 'ingeles (Malaysia)',
-        'en_NA' => 'ingeles (Namibia)',
-        'en_NF' => 'ingeles (Norfolk uhartea)',
-        'en_NG' => 'ingeles (Nigeria)',
-        'en_NL' => 'ingeles (Herbehereak)',
-        'en_NR' => 'ingeles (Nauru)',
-        'en_NU' => 'ingeles (Niue)',
-        'en_NZ' => 'ingeles (Zeelanda Berria)',
-        'en_PG' => 'ingeles (Papua Ginea Berria)',
-        'en_PH' => 'ingeles (Filipinak)',
-        'en_PK' => 'ingeles (Pakistan)',
-        'en_PN' => 'ingeles (Pitcairn uharteak)',
-        'en_PR' => 'ingeles (Puerto Rico)',
-        'en_PW' => 'ingeles (Palau)',
-        'en_RW' => 'ingeles (Ruanda)',
-        'en_SB' => 'ingeles (Salomon Uharteak)',
-        'en_SC' => 'ingeles (Seychelleak)',
-        'en_SD' => 'ingeles (Sudan)',
-        'en_SE' => 'ingeles (Suedia)',
-        'en_SG' => 'ingeles (Singapur)',
-        'en_SH' => 'ingeles (Santa Helena)',
-        'en_SI' => 'ingeles (Eslovenia)',
-        'en_SL' => 'ingeles (Sierra Leona)',
-        'en_SS' => 'ingeles (Hego Sudan)',
-        'en_SX' => 'ingeles (Sint Maarten)',
-        'en_SZ' => 'ingeles (Swazilandia)',
-        'en_TC' => 'ingeles (Turk eta Caico uharteak)',
-        'en_TK' => 'ingeles (Tokelau)',
-        'en_TO' => 'ingeles (Tonga)',
-        'en_TT' => 'ingeles (Trinidad eta Tobago)',
-        'en_TV' => 'ingeles (Tuvalu)',
-        'en_TZ' => 'ingeles (Tanzania)',
-        'en_UG' => 'ingeles (Uganda)',
-        'en_UM' => 'ingeles (Ameriketako Estatu Batuetako Kanpoaldeko Uharte Txikiak)',
-        'en_US' => 'ingeles (Ameriketako Estatu Batuak)',
-        'en_VC' => 'ingeles (Saint Vincent eta Grenadinak)',
-        'en_VG' => 'ingeles (Birjina uharte britainiarrak)',
-        'en_VI' => 'ingeles (Birjina uharte amerikarrak)',
-        'en_VU' => 'ingeles (Vanuatu)',
-        'en_WS' => 'ingeles (Samoa)',
-        'en_ZA' => 'ingeles (Hegoafrika)',
-        'en_ZM' => 'ingeles (Zambia)',
-        'en_ZW' => 'ingeles (Zimbabwe)',
-        'eo' => 'esperanto',
-        'eo_001' => 'esperanto (Mundua)',
+        'en' => 'ingelesa',
+        'en_001' => 'ingelesa (Mundua)',
+        'en_150' => 'ingelesa (Europa)',
+        'en_AE' => 'ingelesa (Arabiar Emirerri Batuak)',
+        'en_AG' => 'ingelesa (Antigua eta Barbuda)',
+        'en_AI' => 'ingelesa (Aingira)',
+        'en_AS' => 'ingelesa (Samoa Estatubatuarra)',
+        'en_AT' => 'ingelesa (Austria)',
+        'en_AU' => 'ingelesa (Australia)',
+        'en_BB' => 'ingelesa (Barbados)',
+        'en_BE' => 'ingelesa (Belgika)',
+        'en_BI' => 'ingelesa (Burundi)',
+        'en_BM' => 'ingelesa (Bermuda)',
+        'en_BS' => 'ingelesa (Bahamak)',
+        'en_BW' => 'ingelesa (Botswana)',
+        'en_BZ' => 'ingelesa (Belize)',
+        'en_CA' => 'ingelesa (Kanada)',
+        'en_CC' => 'ingelesa (Cocos [Keeling] uharteak)',
+        'en_CH' => 'ingelesa (Suitza)',
+        'en_CK' => 'ingelesa (Cook uharteak)',
+        'en_CM' => 'ingelesa (Kamerun)',
+        'en_CX' => 'ingelesa (Christmas uhartea)',
+        'en_CY' => 'ingelesa (Zipre)',
+        'en_DE' => 'ingelesa (Alemania)',
+        'en_DK' => 'ingelesa (Danimarka)',
+        'en_DM' => 'ingelesa (Dominika)',
+        'en_ER' => 'ingelesa (Eritrea)',
+        'en_FI' => 'ingelesa (Finlandia)',
+        'en_FJ' => 'ingelesa (Fiji)',
+        'en_FK' => 'ingelesa (Falklandak)',
+        'en_FM' => 'ingelesa (Mikronesia)',
+        'en_GB' => 'ingelesa (Erresuma Batua)',
+        'en_GD' => 'ingelesa (Grenada)',
+        'en_GG' => 'ingelesa (Guernesey)',
+        'en_GH' => 'ingelesa (Ghana)',
+        'en_GI' => 'ingelesa (Gibraltar)',
+        'en_GM' => 'ingelesa (Gambia)',
+        'en_GU' => 'ingelesa (Guam)',
+        'en_GY' => 'ingelesa (Guyana)',
+        'en_HK' => 'ingelesa (Hong Kong Txinako AEB)',
+        'en_IE' => 'ingelesa (Irlanda)',
+        'en_IL' => 'ingelesa (Israel)',
+        'en_IM' => 'ingelesa (Man uhartea)',
+        'en_IN' => 'ingelesa (India)',
+        'en_IO' => 'ingelesa (Indiako Ozeanoko lurralde britainiarra)',
+        'en_JE' => 'ingelesa (Jersey)',
+        'en_JM' => 'ingelesa (Jamaika)',
+        'en_KE' => 'ingelesa (Kenya)',
+        'en_KI' => 'ingelesa (Kiribati)',
+        'en_KN' => 'ingelesa (Saint Kitts eta Nevis)',
+        'en_KY' => 'ingelesa (Kaiman uharteak)',
+        'en_LC' => 'ingelesa (Santa Luzia)',
+        'en_LR' => 'ingelesa (Liberia)',
+        'en_LS' => 'ingelesa (Lesotho)',
+        'en_MG' => 'ingelesa (Madagaskar)',
+        'en_MH' => 'ingelesa (Marshall Uharteak)',
+        'en_MO' => 'ingelesa (Macau Txinako AEB)',
+        'en_MP' => 'ingelesa (Ipar Mariana uharteak)',
+        'en_MS' => 'ingelesa (Montserrat)',
+        'en_MT' => 'ingelesa (Malta)',
+        'en_MU' => 'ingelesa (Maurizio)',
+        'en_MV' => 'ingelesa (Maldivak)',
+        'en_MW' => 'ingelesa (Malawi)',
+        'en_MY' => 'ingelesa (Malaysia)',
+        'en_NA' => 'ingelesa (Namibia)',
+        'en_NF' => 'ingelesa (Norfolk uhartea)',
+        'en_NG' => 'ingelesa (Nigeria)',
+        'en_NL' => 'ingelesa (Herbehereak)',
+        'en_NR' => 'ingelesa (Nauru)',
+        'en_NU' => 'ingelesa (Niue)',
+        'en_NZ' => 'ingelesa (Zeelanda Berria)',
+        'en_PG' => 'ingelesa (Papua Ginea Berria)',
+        'en_PH' => 'ingelesa (Filipinak)',
+        'en_PK' => 'ingelesa (Pakistan)',
+        'en_PN' => 'ingelesa (Pitcairn uharteak)',
+        'en_PR' => 'ingelesa (Puerto Rico)',
+        'en_PW' => 'ingelesa (Palau)',
+        'en_RW' => 'ingelesa (Ruanda)',
+        'en_SB' => 'ingelesa (Salomon Uharteak)',
+        'en_SC' => 'ingelesa (Seychelleak)',
+        'en_SD' => 'ingelesa (Sudan)',
+        'en_SE' => 'ingelesa (Suedia)',
+        'en_SG' => 'ingelesa (Singapur)',
+        'en_SH' => 'ingelesa (Santa Helena)',
+        'en_SI' => 'ingelesa (Eslovenia)',
+        'en_SL' => 'ingelesa (Sierra Leona)',
+        'en_SS' => 'ingelesa (Hego Sudan)',
+        'en_SX' => 'ingelesa (Sint Maarten)',
+        'en_SZ' => 'ingelesa (Swazilandia)',
+        'en_TC' => 'ingelesa (Turk eta Caico uharteak)',
+        'en_TK' => 'ingelesa (Tokelau)',
+        'en_TO' => 'ingelesa (Tonga)',
+        'en_TT' => 'ingelesa (Trinidad eta Tobago)',
+        'en_TV' => 'ingelesa (Tuvalu)',
+        'en_TZ' => 'ingelesa (Tanzania)',
+        'en_UG' => 'ingelesa (Uganda)',
+        'en_UM' => 'ingelesa (Ameriketako Estatu Batuetako Kanpoaldeko Uharte Txikiak)',
+        'en_US' => 'ingelesa (Ameriketako Estatu Batuak)',
+        'en_VC' => 'ingelesa (Saint Vincent eta Grenadinak)',
+        'en_VG' => 'ingelesa (Birjina uharte britainiarrak)',
+        'en_VI' => 'ingelesa (Birjina uharte amerikarrak)',
+        'en_VU' => 'ingelesa (Vanuatu)',
+        'en_WS' => 'ingelesa (Samoa)',
+        'en_ZA' => 'ingelesa (Hegoafrika)',
+        'en_ZM' => 'ingelesa (Zambia)',
+        'en_ZW' => 'ingelesa (Zimbabwe)',
+        'eo' => 'esperantoa',
+        'eo_001' => 'esperantoa (Mundua)',
         'es' => 'espainiera',
         'es_419' => 'espainiera (Latinoamerika)',
         'es_AR' => 'espainiera (Argentina)',
@@ -273,60 +276,60 @@ return [
         'fo' => 'faroera',
         'fo_DK' => 'faroera (Danimarka)',
         'fo_FO' => 'faroera (Faroe uharteak)',
-        'fr' => 'frantses',
-        'fr_BE' => 'frantses (Belgika)',
-        'fr_BF' => 'frantses (Burkina Faso)',
-        'fr_BI' => 'frantses (Burundi)',
-        'fr_BJ' => 'frantses (Benin)',
-        'fr_BL' => 'frantses (Saint Barthélemy)',
-        'fr_CA' => 'frantses (Kanada)',
-        'fr_CD' => 'frantses (Kongoko Errepublika Demokratikoa)',
-        'fr_CF' => 'frantses (Afrika Erdiko Errepublika)',
-        'fr_CG' => 'frantses (Kongo)',
-        'fr_CH' => 'frantses (Suitza)',
-        'fr_CI' => 'frantses (Boli Kosta)',
-        'fr_CM' => 'frantses (Kamerun)',
-        'fr_DJ' => 'frantses (Djibuti)',
-        'fr_DZ' => 'frantses (Aljeria)',
-        'fr_FR' => 'frantses (Frantzia)',
-        'fr_GA' => 'frantses (Gabon)',
-        'fr_GF' => 'frantses (Guyana Frantsesa)',
-        'fr_GN' => 'frantses (Ginea)',
-        'fr_GP' => 'frantses (Guadalupe)',
-        'fr_GQ' => 'frantses (Ekuatore Ginea)',
-        'fr_HT' => 'frantses (Haiti)',
-        'fr_KM' => 'frantses (Komoreak)',
-        'fr_LU' => 'frantses (Luxenburgo)',
-        'fr_MA' => 'frantses (Maroko)',
-        'fr_MC' => 'frantses (Monako)',
-        'fr_MF' => 'frantses (San Martin)',
-        'fr_MG' => 'frantses (Madagaskar)',
-        'fr_ML' => 'frantses (Mali)',
-        'fr_MQ' => 'frantses (Martinika)',
-        'fr_MR' => 'frantses (Mauritania)',
-        'fr_MU' => 'frantses (Maurizio)',
-        'fr_NC' => 'frantses (Kaledonia Berria)',
-        'fr_NE' => 'frantses (Niger)',
-        'fr_PF' => 'frantses (Polinesia Frantsesa)',
-        'fr_PM' => 'frantses (Saint-Pierre eta Mikelune)',
-        'fr_RE' => 'frantses (Reunion)',
-        'fr_RW' => 'frantses (Ruanda)',
-        'fr_SC' => 'frantses (Seychelleak)',
-        'fr_SN' => 'frantses (Senegal)',
-        'fr_SY' => 'frantses (Siria)',
-        'fr_TD' => 'frantses (Txad)',
-        'fr_TG' => 'frantses (Togo)',
-        'fr_TN' => 'frantses (Tunisia)',
-        'fr_VU' => 'frantses (Vanuatu)',
-        'fr_WF' => 'frantses (Wallis eta Futuna)',
-        'fr_YT' => 'frantses (Mayotte)',
+        'fr' => 'frantsesa',
+        'fr_BE' => 'frantsesa (Belgika)',
+        'fr_BF' => 'frantsesa (Burkina Faso)',
+        'fr_BI' => 'frantsesa (Burundi)',
+        'fr_BJ' => 'frantsesa (Benin)',
+        'fr_BL' => 'frantsesa (Saint Barthélemy)',
+        'fr_CA' => 'frantsesa (Kanada)',
+        'fr_CD' => 'frantsesa (Kongoko Errepublika Demokratikoa)',
+        'fr_CF' => 'frantsesa (Afrika Erdiko Errepublika)',
+        'fr_CG' => 'frantsesa (Kongo)',
+        'fr_CH' => 'frantsesa (Suitza)',
+        'fr_CI' => 'frantsesa (Boli Kosta)',
+        'fr_CM' => 'frantsesa (Kamerun)',
+        'fr_DJ' => 'frantsesa (Djibuti)',
+        'fr_DZ' => 'frantsesa (Aljeria)',
+        'fr_FR' => 'frantsesa (Frantzia)',
+        'fr_GA' => 'frantsesa (Gabon)',
+        'fr_GF' => 'frantsesa (Guyana Frantsesa)',
+        'fr_GN' => 'frantsesa (Ginea)',
+        'fr_GP' => 'frantsesa (Guadalupe)',
+        'fr_GQ' => 'frantsesa (Ekuatore Ginea)',
+        'fr_HT' => 'frantsesa (Haiti)',
+        'fr_KM' => 'frantsesa (Komoreak)',
+        'fr_LU' => 'frantsesa (Luxenburgo)',
+        'fr_MA' => 'frantsesa (Maroko)',
+        'fr_MC' => 'frantsesa (Monako)',
+        'fr_MF' => 'frantsesa (San Martin)',
+        'fr_MG' => 'frantsesa (Madagaskar)',
+        'fr_ML' => 'frantsesa (Mali)',
+        'fr_MQ' => 'frantsesa (Martinika)',
+        'fr_MR' => 'frantsesa (Mauritania)',
+        'fr_MU' => 'frantsesa (Maurizio)',
+        'fr_NC' => 'frantsesa (Kaledonia Berria)',
+        'fr_NE' => 'frantsesa (Niger)',
+        'fr_PF' => 'frantsesa (Polinesia Frantsesa)',
+        'fr_PM' => 'frantsesa (Saint-Pierre eta Mikelune)',
+        'fr_RE' => 'frantsesa (Reunion)',
+        'fr_RW' => 'frantsesa (Ruanda)',
+        'fr_SC' => 'frantsesa (Seychelleak)',
+        'fr_SN' => 'frantsesa (Senegal)',
+        'fr_SY' => 'frantsesa (Siria)',
+        'fr_TD' => 'frantsesa (Txad)',
+        'fr_TG' => 'frantsesa (Togo)',
+        'fr_TN' => 'frantsesa (Tunisia)',
+        'fr_VU' => 'frantsesa (Vanuatu)',
+        'fr_WF' => 'frantsesa (Wallis eta Futuna)',
+        'fr_YT' => 'frantsesa (Mayotte)',
         'fy' => 'frisiera',
         'fy_NL' => 'frisiera (Herbehereak)',
         'ga' => 'irlandera',
         'ga_GB' => 'irlandera (Erresuma Batua)',
         'ga_IE' => 'irlandera (Irlanda)',
-        'gd' => 'Eskoziako gaeliko',
-        'gd_GB' => 'Eskoziako gaeliko (Erresuma Batua)',
+        'gd' => 'Eskoziako gaelikoa',
+        'gd_GB' => 'Eskoziako gaelikoa (Erresuma Batua)',
         'gl' => 'galiziera',
         'gl_ES' => 'galiziera (Espainia)',
         'gu' => 'gujaratera',
@@ -339,8 +342,10 @@ return [
         'ha_NG' => 'hausa (Nigeria)',
         'he' => 'hebreera',
         'he_IL' => 'hebreera (Israel)',
-        'hi' => 'hindi',
-        'hi_IN' => 'hindi (India)',
+        'hi' => 'hindia',
+        'hi_IN' => 'hindia (India)',
+        'hi_Latn' => 'hindia (latinoa)',
+        'hi_Latn_IN' => 'hindia (latinoa, India)',
         'hr' => 'kroaziera',
         'hr_BA' => 'kroaziera (Bosnia-Herzegovina)',
         'hr_HR' => 'kroaziera (Kroazia)',
@@ -385,6 +390,8 @@ return [
         'ks' => 'kaxmirera',
         'ks_Arab' => 'kaxmirera (arabiarra)',
         'ks_Arab_IN' => 'kaxmirera (arabiarra, India)',
+        'ks_Deva' => 'kaxmirera (devanagaria)',
+        'ks_Deva_IN' => 'kaxmirera (devanagaria, India)',
         'ks_IN' => 'kaxmirera (India)',
         'ku' => 'kurduera',
         'ku_TR' => 'kurduera (Turkia)',
@@ -409,8 +416,8 @@ return [
         'lu_CD' => 'Katangako lubera (Kongoko Errepublika Demokratikoa)',
         'lv' => 'letoniera',
         'lv_LV' => 'letoniera (Letonia)',
-        'mg' => 'malgaxe',
-        'mg_MG' => 'malgaxe (Madagaskar)',
+        'mg' => 'malgaxea',
+        'mg_MG' => 'malgaxea (Madagaskar)',
         'mi' => 'maoriera',
         'mi_NZ' => 'maoriera (Zeelanda Berria)',
         'mk' => 'mazedoniera',
@@ -467,22 +474,22 @@ return [
         'pa_PK' => 'punjabera (Pakistan)',
         'pl' => 'poloniera',
         'pl_PL' => 'poloniera (Polonia)',
-        'ps' => 'paxtuera',
-        'ps_AF' => 'paxtuera (Afganistan)',
-        'ps_PK' => 'paxtuera (Pakistan)',
-        'pt' => 'portuges',
-        'pt_AO' => 'portuges (Angola)',
-        'pt_BR' => 'portuges (Brasil)',
-        'pt_CH' => 'portuges (Suitza)',
-        'pt_CV' => 'portuges (Cabo Verde)',
-        'pt_GQ' => 'portuges (Ekuatore Ginea)',
-        'pt_GW' => 'portuges (Ginea Bissau)',
-        'pt_LU' => 'portuges (Luxenburgo)',
-        'pt_MO' => 'portuges (Macau Txinako AEB)',
-        'pt_MZ' => 'portuges (Mozambike)',
-        'pt_PT' => 'portuges (Portugal)',
-        'pt_ST' => 'portuges (Sao Tome eta Principe)',
-        'pt_TL' => 'portuges (Ekialdeko Timor)',
+        'ps' => 'paxtunera',
+        'ps_AF' => 'paxtunera (Afganistan)',
+        'ps_PK' => 'paxtunera (Pakistan)',
+        'pt' => 'portugesa',
+        'pt_AO' => 'portugesa (Angola)',
+        'pt_BR' => 'portugesa (Brasil)',
+        'pt_CH' => 'portugesa (Suitza)',
+        'pt_CV' => 'portugesa (Cabo Verde)',
+        'pt_GQ' => 'portugesa (Ekuatore Ginea)',
+        'pt_GW' => 'portugesa (Ginea Bissau)',
+        'pt_LU' => 'portugesa (Luxenburgo)',
+        'pt_MO' => 'portugesa (Macau Txinako AEB)',
+        'pt_MZ' => 'portugesa (Mozambike)',
+        'pt_PT' => 'portugesa (Portugal)',
+        'pt_ST' => 'portugesa (Sao Tome eta Principe)',
+        'pt_TL' => 'portugesa (Ekialdeko Timor)',
         'qu' => 'kitxua',
         'qu_BO' => 'kitxua (Bolivia)',
         'qu_EC' => 'kitxua (Ekuador)',
@@ -503,22 +510,23 @@ return [
         'ru_UA' => 'errusiera (Ukraina)',
         'rw' => 'kinyaruanda',
         'rw_RW' => 'kinyaruanda (Ruanda)',
-        'sa' => 'sanskrito',
-        'sa_IN' => 'sanskrito (India)',
+        'sa' => 'sanskritoa',
+        'sa_IN' => 'sanskritoa (India)',
         'sc' => 'sardiniera',
         'sc_IT' => 'sardiniera (Italia)',
-        'sd' => 'sindhi',
-        'sd_Arab' => 'sindhi (arabiarra)',
-        'sd_Arab_PK' => 'sindhi (arabiarra, Pakistan)',
-        'sd_Deva' => 'sindhi (devanagaria)',
-        'sd_Deva_IN' => 'sindhi (devanagaria, India)',
-        'sd_PK' => 'sindhi (Pakistan)',
+        'sd' => 'sindhia',
+        'sd_Arab' => 'sindhia (arabiarra)',
+        'sd_Arab_PK' => 'sindhia (arabiarra, Pakistan)',
+        'sd_Deva' => 'sindhia (devanagaria)',
+        'sd_Deva_IN' => 'sindhia (devanagaria, India)',
+        'sd_IN' => 'sindhia (India)',
+        'sd_PK' => 'sindhia (Pakistan)',
         'se' => 'iparraldeko samiera',
         'se_FI' => 'iparraldeko samiera (Finlandia)',
         'se_NO' => 'iparraldeko samiera (Norvegia)',
         'se_SE' => 'iparraldeko samiera (Suedia)',
-        'sg' => 'sango',
-        'sg_CF' => 'sango (Afrika Erdiko Errepublika)',
+        'sg' => 'sangoa',
+        'sg_CF' => 'sangoa (Afrika Erdiko Errepublika)',
         'sh' => 'serbokroaziera',
         'sh_BA' => 'serbokroaziera (Bosnia-Herzegovina)',
         'si' => 'sinhala',
@@ -567,8 +575,8 @@ return [
         'ta_LK' => 'tamilera (Sri Lanka)',
         'ta_MY' => 'tamilera (Malaysia)',
         'ta_SG' => 'tamilera (Singapur)',
-        'te' => 'telugu',
-        'te_IN' => 'telugu (India)',
+        'te' => 'telugua',
+        'te_IN' => 'telugua (India)',
         'tg' => 'tajikera',
         'tg_TJ' => 'tajikera (Tajikistan)',
         'th' => 'thailandiera',
@@ -591,9 +599,9 @@ return [
         'ug_CN' => 'uigurrera (Txina)',
         'uk' => 'ukrainera',
         'uk_UA' => 'ukrainera (Ukraina)',
-        'ur' => 'urdu',
-        'ur_IN' => 'urdu (India)',
-        'ur_PK' => 'urdu (Pakistan)',
+        'ur' => 'urdua',
+        'ur_IN' => 'urdua (India)',
+        'ur_PK' => 'urdua (Pakistan)',
         'uz' => 'uzbekera',
         'uz_AF' => 'uzbekera (Afganistan)',
         'uz_Arab' => 'uzbekera (arabiarra)',
@@ -609,8 +617,8 @@ return [
         'wo_SN' => 'wolofera (Senegal)',
         'xh' => 'xhosera',
         'xh_ZA' => 'xhosera (Hegoafrika)',
-        'yi' => 'yiddish',
-        'yi_001' => 'yiddish (Mundua)',
+        'yi' => 'yiddisha',
+        'yi_001' => 'yiddisha (Mundua)',
         'yo' => 'jorubera',
         'yo_BJ' => 'jorubera (Benin)',
         'yo_NG' => 'jorubera (Nigeria)',
