@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'چچنی (روسیه)',
         'cs' => 'چکی',
         'cs_CZ' => 'چکی (چک)',
+        'cv' => 'چوواشی',
+        'cv_RU' => 'چوواشی (روسیه)',
         'cy' => 'ولزی',
         'cy_GB' => 'ولزی (بریتانیا)',
         'da' => 'دانمارکی',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'انگلیسی (مونت‌سرات)',
         'en_MT' => 'انگلیسی (مالت)',
         'en_MU' => 'انگلیسی (موریس)',
+        'en_MV' => 'انگلیسی (مالدیو)',
         'en_MW' => 'انگلیسی (مالاوی)',
         'en_MY' => 'انگلیسی (مالزی)',
         'en_NA' => 'انگلیسی (نامیبیا)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'فارسی (افغانستان)',
         'fa_IR' => 'فارسی (ایران)',
         'ff' => 'فولانی',
+        'ff_Adlm' => 'فولانی (آدلام)',
+        'ff_Adlm_BF' => 'فولانی (آدلام، بورکینافاسو)',
+        'ff_Adlm_CM' => 'فولانی (آدلام، کامرون)',
+        'ff_Adlm_GH' => 'فولانی (آدلام، غنا)',
+        'ff_Adlm_GM' => 'فولانی (آدلام، گامبیا)',
+        'ff_Adlm_GN' => 'فولانی (آدلام، گینه)',
+        'ff_Adlm_GW' => 'فولانی (آدلام، گینهٔ بیسائو)',
+        'ff_Adlm_LR' => 'فولانی (آدلام، لیبریا)',
+        'ff_Adlm_MR' => 'فولانی (آدلام، موریتانی)',
+        'ff_Adlm_NE' => 'فولانی (آدلام، نیجر)',
+        'ff_Adlm_NG' => 'فولانی (آدلام، نیجریه)',
+        'ff_Adlm_SL' => 'فولانی (آدلام، سیرالئون)',
+        'ff_Adlm_SN' => 'فولانی (آدلام، سنگال)',
         'ff_CM' => 'فولانی (کامرون)',
         'ff_GN' => 'فولانی (گینه)',
         'ff_Latn' => 'فولانی (لاتین)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'عبری (اسرائیل)',
         'hi' => 'هندی',
         'hi_IN' => 'هندی (هند)',
+        'hi_Latn' => 'هندی (لاتین)',
+        'hi_Latn_IN' => 'هندی (لاتین، هند)',
         'hr' => 'کروات',
         'hr_BA' => 'کروات (بوسنی و هرزگوین)',
         'hr_HR' => 'کروات (کرواسی)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'کشمیری',
         'ks_Arab' => 'کشمیری (عربی)',
         'ks_Arab_IN' => 'کشمیری (عربی، هند)',
+        'ks_Deva' => 'کشمیری (دوناگری)',
+        'ks_Deva_IN' => 'کشمیری (دوناگری، هند)',
         'ks_IN' => 'کشمیری (هند)',
         'ku' => 'کردی',
         'ku_TR' => 'کردی (ترکیه)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'سندی (عربی، پاکستان)',
         'sd_Deva' => 'سندی (دوناگری)',
         'sd_Deva_IN' => 'سندی (دوناگری، هند)',
+        'sd_IN' => 'سندی (هند)',
         'sd_PK' => 'سندی (پاکستان)',
         'se' => 'سامی شمالی',
         'se_FI' => 'سامی شمالی (فنلاند)',
