@@ -55,6 +55,9 @@ return [
         'bn' => '𞤄𞤫𞤲𞤺𞤢𞤤𞤭𞥅𞤪𞤫',
         'bn_BD' => '𞤄𞤫𞤲𞤺𞤢𞤤𞤭𞥅𞤪𞤫 (𞤄𞤢𞤲𞤺𞤭𞤤𞤢𞤣𞤫𞥅𞤧)',
         'bn_IN' => '𞤄𞤫𞤲𞤺𞤢𞤤𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'bo' => '𞤚𞤭𞤦𞤫𞤼𞤫𞤲𞤪𞤫',
+        'bo_CN' => '𞤚𞤭𞤦𞤫𞤼𞤫𞤲𞤪𞤫 (𞤕𞤢𞤴𞤲𞤢)',
+        'bo_IN' => '𞤚𞤭𞤦𞤫𞤼𞤫𞤲𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
         'br' => '𞤄𞤫𞤪𞤫𞤼𞤮𞤲𞤪𞤫',
         'br_FR' => '𞤄𞤫𞤪𞤫𞤼𞤮𞤲𞤪𞤫 (𞤊𞤢𞤪𞤢𞤲𞤧𞤭)',
         'bs' => '𞤄𞤮𞤧𞤲𞤭𞤴𞤢𞥄𞤪𞤫',
@@ -72,6 +75,8 @@ return [
         'ce_RU' => '𞤕𞤫𞤷𞤫𞤲𞤪𞤫 (𞤈𞤮𞥅𞤧𞤭𞤴𞤢)',
         'cs' => '𞤕𞤫𞤳𞤧𞤭𞤲𞤢𞥄𞤪𞤫',
         'cs_CZ' => '𞤕𞤫𞤳𞤧𞤭𞤲𞤢𞥄𞤪𞤫 (𞤕𞤫𞥅𞤳𞤭𞤴𞤢𞥄)',
+        'cv' => '𞤕𞤵𞥅𞤾𞤢𞤧𞤪𞤫',
+        'cv_RU' => '𞤕𞤵𞥅𞤾𞤢𞤧𞤪𞤫 (𞤈𞤮𞥅𞤧𞤭𞤴𞤢)',
         'cy' => '𞤘𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
         'cy_GB' => '𞤘𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤐𞤺𞤫𞤯𞤵𞥅𞤪𞤭)',
         'da' => '𞤁𞤢𞥄𞤲𞤭𞤧𞤳𞤮𞥅𞤪𞤫',
@@ -87,8 +92,12 @@ return [
         'de_LU' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤂𞤵𞤳𞤧𞤢𞤲𞤦𞤵𞥅𞤺)',
         'dz' => '𞤄𞤵𞥅𞤼𞤢𞤲𞤪𞤫',
         'dz_BT' => '𞤄𞤵𞥅𞤼𞤢𞤲𞤪𞤫 (𞤄𞤵𞥅𞤼𞤢𞥄𞤲)',
-        'el_CY' => 'Gerke (𞤑𞤵𞤦𞤪𞤵𞥅𞤧)',
-        'el_GR' => 'Gerke (𞤀𞤤𞤴𞤵𞤲𞤢𞥄𞤲)',
+        'ee' => '𞤉𞤱𞤫𞥅𞤪𞤫',
+        'ee_GH' => '𞤉𞤱𞤫𞥅𞤪𞤫 (𞤘𞤢𞤲𞤢)',
+        'ee_TG' => '𞤉𞤱𞤫𞥅𞤪𞤫 (𞤚𞤮𞤺𞤮)',
+        'el' => '𞤘𞤭𞥅𞤪𞤧𞤢𞥄𞤪𞤫',
+        'el_CY' => '𞤘𞤭𞥅𞤪𞤧𞤢𞥄𞤪𞤫 (𞤑𞤵𞤦𞤪𞤵𞥅𞤧)',
+        'el_GR' => '𞤘𞤭𞥅𞤪𞤧𞤢𞥄𞤪𞤫 (𞤀𞤤𞤴𞤵𞤲𞤢𞥄𞤲)',
         'en' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫',
         'en_001' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤀𞤣𞤵𞤲𞤢)',
         'en_150' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤓𞤪𞤨𞤢)',
@@ -128,7 +137,7 @@ return [
         'en_GM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤘𞤢𞤥𞤦𞤭𞤴𞤢)',
         'en_GU' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤘𞤵𞤱𞤢𞥄𞤥)',
         'en_GY' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤘𞤢𞤴𞤢𞤲𞤢𞥄)',
-        'en_HK' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤅𞤭𞥅𞤲 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
+        'en_HK' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
         'en_IE' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤋𞤪𞤤𞤢𞤲𞤣)',
         'en_IL' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤋𞤧𞤪𞤢𞥄𞤴𞤭𞥅𞤤)',
         'en_IM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤪𞤭𞥅𞤪𞤫 𞤃𞤫𞥅𞤲)',
@@ -145,11 +154,12 @@ return [
         'en_LS' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤂𞤫𞤧𞤮𞤼𞤮𞥅)',
         'en_MG' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤣𞤢𞤺𞤢𞤧𞤳𞤢𞥄𞤪)',
         'en_MH' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤪𞤭𞥅𞤪𞤫 𞤃𞤢𞤪𞥃𞤢𞤤)',
-        'en_MO' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤅𞤭𞥅𞤲 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
+        'en_MO' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
         'en_MP' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤃𞤢𞤪𞤭𞤴𞤢𞥄𞤲𞤢 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤭)',
         'en_MS' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤮𞤲𞤧𞤭𞤪𞤢𞥄𞤼)',
         'en_MT' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤤𞤼𞤢)',
         'en_MU' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤮𞤪𞤭𞥅𞤧𞤭)',
+        'en_MV' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤤𞤣𞤭𞥅𞤬)',
         'en_MW' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤤𞤢𞤱𞤭𞥅)',
         'en_MY' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤤𞤫𞥅𞤧𞤭𞤴𞤢)',
         'en_NA' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤐𞤢𞤥𞤭𞥅𞤦𞤭𞤴𞤢𞥄)',
@@ -194,11 +204,13 @@ return [
         'en_ZA' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤀𞤬𞤪𞤭𞤳𞤢 𞤂𞤫𞤧𞤤𞤫𞤴𞤪𞤭)',
         'en_ZM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤟𞤢𞤥𞤦𞤭𞤴𞤢)',
         'en_ZW' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤟𞤭𞤥𞤦𞤢𞥄𞤥𞤵𞤴𞤢)',
+        'eo' => '𞤉𞤧𞤨𞤫𞤪𞤢𞤲𞤼𞤮𞥅𞤪𞤫',
+        'eo_001' => '𞤉𞤧𞤨𞤫𞤪𞤢𞤲𞤼𞤮𞥅𞤪𞤫 (𞤀𞤣𞤵𞤲𞤢)',
         'es' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
         'es_419' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤀𞤥𞤫𞤪𞤭𞤳𞤢𞥄 𞤂𞤢𞤼𞤭𞤲𞤳𞤮)',
         'es_AR' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤀𞤪𞤶𞤢𞤲𞤼𞤭𞤲𞤢𞥄)',
         'es_BO' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤄𞤮𞤤𞤭𞥅𞤾𞤭𞤴𞤢𞥄)',
-        'es_BR' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤄𞤪𞤢𞥄𞥁𞤭𞤤)',
+        'es_BR' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤄𞤪𞤢𞤧𞤭𞤤)',
         'es_BZ' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤄𞤫𞤤𞤭𞥅𞥁)',
         'es_CL' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤕𞤭𞤤𞤫𞥊𞥅)',
         'es_CO' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤑𞤮𞤤𞤮𞤥𞤦𞤭𞤴𞤢𞥄)',
@@ -219,12 +231,15 @@ return [
         'es_PY' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤆𞤢𞥄𞤪𞤢𞤺𞤵𞤱𞤢𞥄𞤴)',
         'es_SV' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤉𞤤 𞤅𞤢𞤤𞤾𞤢𞤣𞤮𞥅𞤪)',
         'es_US' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤂𞤢𞤪𞤫)',
-        'es_UY' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤓𞤪𞤵𞤺𞤵𞤱𞤢𞥄𞤴)',
+        'es_UY' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤒𞤵𞤪𞤺𞤮𞤴)',
         'es_VE' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤜𞤫𞥊𞤲𞤭𞥅𞥁𞤵𞤱𞤫𞤤𞤢𞥄)',
+        'et' => '𞤉𞤧𞤼𞤮𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
+        'et_EE' => '𞤉𞤧𞤼𞤮𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤉𞤧𞤼𞤮𞤲𞤭𞤴𞤢𞥄)',
         'eu' => '𞤄𞤢𞤧𞤳𞤢𞤪𞤢𞥄𞤪𞤫',
         'eu_ES' => '𞤄𞤢𞤧𞤳𞤢𞤪𞤢𞥄𞤪𞤫 (𞤉𞤧𞤨𞤢𞤻𞤢𞥄)',
-        'fa_AF' => 'Perseere (𞤀𞤬𞤺𞤢𞤲𞤭𞤧𞤼𞤢𞥄𞤲)',
-        'fa_IR' => 'Perseere (𞤋𞤪𞤢𞥄𞤲)',
+        'fa' => '𞤊𞤢𞥄𞤪𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
+        'fa_AF' => '𞤊𞤢𞥄𞤪𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤀𞤬𞤺𞤢𞤲𞤭𞤧𞤼𞤢𞥄𞤲)',
+        'fa_IR' => '𞤊𞤢𞥄𞤪𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤋𞤪𞤢𞥄𞤲)',
         'ff' => '𞤆𞤵𞤤𞤢𞤪',
         'ff_Adlm' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃)',
         'ff_Adlm_BF' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤄𞤵𞤪𞤳𞤭𞤲𞤢 𞤊𞤢𞤧𞤮𞥅)',
@@ -256,6 +271,11 @@ return [
         'ff_Latn_SN' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤅𞤫𞤲𞤫𞤺𞤢𞥄𞤤)',
         'ff_MR' => '𞤆𞤵𞤤𞤢𞤪 (𞤃𞤮𞤪𞤼𞤢𞤲𞤭𞥅)',
         'ff_SN' => '𞤆𞤵𞤤𞤢𞤪 (𞤅𞤫𞤲𞤫𞤺𞤢𞥄𞤤)',
+        'fi' => '𞤊𞤫𞤲𞤭𞤧𞤪𞤫',
+        'fi_FI' => '𞤊𞤫𞤲𞤭𞤧𞤪𞤫 (𞤊𞤭𞤲𞤤𞤢𞤲𞤣)',
+        'fo' => '𞤊𞤫𞤪𞤮𞤱𞤫𞤧𞤪𞤫',
+        'fo_DK' => '𞤊𞤫𞤪𞤮𞤱𞤫𞤧𞤪𞤫 (𞤁𞤢𞤲𞤵𞤥𞤢𞤪𞤳)',
+        'fo_FO' => '𞤊𞤫𞤪𞤮𞤱𞤫𞤧𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤊𞤢𞤪𞤵𞥅𞤧)',
         'fr' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫',
         'fr_BE' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤄𞤫𞤤𞤶𞤭𞤳𞤢𞥄)',
         'fr_BF' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤄𞤵𞤪𞤳𞤭𞤲𞤢 𞤊𞤢𞤧𞤮𞥅)',
@@ -308,22 +328,41 @@ return [
         'ga' => '𞤋𞤪𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
         'ga_GB' => '𞤋𞤪𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤐𞤺𞤫𞤯𞤵𞥅𞤪𞤭)',
         'ga_IE' => '𞤋𞤪𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫 (𞤋𞤪𞤤𞤢𞤲𞤣)',
-        'ha_GH' => 'Hawsaŋkoore (𞤘𞤢𞤲𞤢)',
-        'ha_NE' => 'Hawsaŋkoore (𞤐𞤭𞥅𞤶𞤫𞤪)',
-        'ha_NG' => 'Hawsaŋkoore (𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
+        'gd' => '𞤅𞤭𞤳𞤮𞤼𞤭𞤧𞤪𞤫 𞤘𞤢𞤫𞤭𞤳',
+        'gd_GB' => '𞤅𞤭𞤳𞤮𞤼𞤭𞤧𞤪𞤫 𞤘𞤢𞤫𞤭𞤳 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤐𞤺𞤫𞤯𞤵𞥅𞤪𞤭)',
+        'gl' => '𞤘𞤢𞤤𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫',
+        'gl_ES' => '𞤘𞤢𞤤𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤉𞤧𞤨𞤢𞤻𞤢𞥄)',
+        'gu' => '𞤘𞤵𞤶𞤢𞤪𞤢𞤼𞤭𞥅𞤪𞤫',
+        'gu_IN' => '𞤘𞤵𞤶𞤢𞤪𞤢𞤼𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'gv' => '𞤃𞤢𞤲𞤳𞤭𞤧𞤪𞤫',
+        'gv_IM' => '𞤃𞤢𞤲𞤳𞤭𞤧𞤪𞤫 (𞤅𞤵𞤪𞤭𞥅𞤪𞤫 𞤃𞤫𞥅𞤲)',
+        'ha' => '𞤖𞤢𞤱𞤧𞤢𞥄𞤪𞤫',
+        'ha_GH' => '𞤖𞤢𞤱𞤧𞤢𞥄𞤪𞤫 (𞤘𞤢𞤲𞤢)',
+        'ha_NE' => '𞤖𞤢𞤱𞤧𞤢𞥄𞤪𞤫 (𞤐𞤭𞥅𞤶𞤫𞤪)',
+        'ha_NG' => '𞤖𞤢𞤱𞤧𞤢𞥄𞤪𞤫 (𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
+        'he' => '𞤖𞤭𞤦𞤵𞤪𞤵𞥅𞤪𞤫',
+        'he_IL' => '𞤖𞤭𞤦𞤵𞤪𞤵𞥅𞤪𞤫 (𞤋𞤧𞤪𞤢𞥄𞤴𞤭𞥅𞤤)',
         'hi' => '𞤖𞤭𞤲𞤣𞤭𞥅𞤪𞤫',
         'hi_IN' => '𞤖𞤭𞤲𞤣𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'hi_Latn' => '𞤖𞤭𞤲𞤣𞤭𞥅𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲)',
+        'hi_Latn_IN' => '𞤖𞤭𞤲𞤣𞤭𞥅𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤋𞤲𞤣𞤭𞤴𞤢)',
         'hr' => '𞤑𞤮𞤪𞤮𞤱𞤢𞤧𞤭𞥅𞤪𞤫',
         'hr_BA' => '𞤑𞤮𞤪𞤮𞤱𞤢𞤧𞤭𞥅𞤪𞤫 (𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
         'hr_HR' => '𞤑𞤮𞤪𞤮𞤱𞤢𞤧𞤭𞥅𞤪𞤫 (𞤑𞤵𞤪𞤱𞤢𞥄𞤧𞤭𞤴𞤢)',
-        'hu_HU' => 'Hongariire (𞤖𞤢𞤲𞤺𞤢𞤪𞤭𞤴𞤢𞥄)',
+        'hu' => '𞤖𞤵𞤲𞤺𞤢𞤪𞤭𞤴𞤢𞤲𞤪𞤫',
+        'hu_HU' => '𞤖𞤵𞤲𞤺𞤢𞤪𞤭𞤴𞤢𞤲𞤪𞤫 (𞤖𞤢𞤲𞤺𞤢𞤪𞤭𞤴𞤢𞥄)',
         'hy' => '𞤀𞤪𞤥𞤫𞤲𞤭𞥅𞤪𞤫',
         'hy_AM' => '𞤀𞤪𞤥𞤫𞤲𞤭𞥅𞤪𞤫 (𞤀𞤪𞤥𞤫𞤲𞤭𞤴𞤢𞥄)',
         'ia' => '𞤉𞤲𞤼𞤫𞤪𞤤𞤭𞤺𞤢𞥄𞤪𞤫',
         'ia_001' => '𞤉𞤲𞤼𞤫𞤪𞤤𞤭𞤺𞤢𞥄𞤪𞤫 (𞤀𞤣𞤵𞤲𞤢)',
         'id' => '𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
         'id_ID' => '𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤴𞤢)',
-        'ig_NG' => 'Igiboore (𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
+        'ig' => '𞤋𞤦𞤮𞥅𞤪𞤫',
+        'ig_NG' => '𞤋𞤦𞤮𞥅𞤪𞤫 (𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
+        'ii' => '𞤅𞤭𞤧𞤵𞤢𞤲𞤪𞤫 𞤒𞤭𞥅',
+        'ii_CN' => '𞤅𞤭𞤧𞤵𞤢𞤲𞤪𞤫 𞤒𞤭𞥅 (𞤕𞤢𞤴𞤲𞤢)',
+        'is' => '𞤀𞤴𞤧𞤭𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
+        'is_IS' => '𞤀𞤴𞤧𞤭𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫 (𞤀𞤴𞤧𞤵𞤤𞤢𞤲𞤣)',
         'it' => '𞤋𞤼𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
         'it_CH' => '𞤋𞤼𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤅𞤵𞤱𞤭𞤪𞤧𞤢𞥄)',
         'it_IT' => '𞤋𞤼𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤋𞤼𞤢𞤤𞤭𞥅)',
@@ -333,20 +372,62 @@ return [
         'ja_JP' => '𞤐𞤭𞤨𞤮𞤲𞤪𞤫 (𞤐𞤭𞤨𞥆𞤮𞤲)',
         'jv' => '𞤔𞤢𞥄𞤱𞤢𞤫𞥅𞤪𞤫',
         'jv_ID' => '𞤔𞤢𞥄𞤱𞤢𞤫𞥅𞤪𞤫 (𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤴𞤢)',
-        'km_KH' => 'Kemeere (𞤑𞤢𞤥𞤦𞤮𞥅𞤣𞤭𞤴𞤢)',
+        'ka' => '𞤔𞤮𞥅𞤪𞥁𞤭𞤴𞤢𞤲𞤪𞤫',
+        'ka_GE' => '𞤔𞤮𞥅𞤪𞥁𞤭𞤴𞤢𞤲𞤪𞤫 (𞤔𞤮𞤪𞤶𞤭𞤴𞤢𞥄)',
+        'ki' => '𞤑𞤭𞤳𞤵𞤴𞤵𞥅𞤪𞤫',
+        'ki_KE' => '𞤑𞤭𞤳𞤵𞤴𞤵𞥅𞤪𞤫 (𞤑𞤫𞤲𞤭𞤴𞤢𞥄)',
+        'kk' => '𞤑𞤢𞥁𞤢𞤳𞤪𞤫',
+        'kk_KZ' => '𞤑𞤢𞥁𞤢𞤳𞤪𞤫 (𞤑𞤢𞥁𞤢𞤧𞤼𞤢𞥄𞤲)',
+        'kl' => '𞤑𞤢𞤤𞤢𞥄𞤤𞤧𞤵𞤼𞤪𞤫',
+        'kl_GL' => '𞤑𞤢𞤤𞤢𞥄𞤤𞤧𞤵𞤼𞤪𞤫 (𞤘𞤭𞤪𞤤𞤢𞤲𞤣𞤭)',
+        'km' => '𞤑𞤵𞤥𞤢𞤴𞤪𞤫',
+        'km_KH' => '𞤑𞤵𞤥𞤢𞤴𞤪𞤫 (𞤑𞤢𞤥𞤦𞤮𞥅𞤣𞤭𞤴𞤢)',
+        'kn' => '𞤑𞤢𞤲𞥆𞤢𞤣𞤢𞥄𞤪𞤫',
+        'kn_IN' => '𞤑𞤢𞤲𞥆𞤢𞤣𞤢𞥄𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
         'ko' => '𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞤲𞤪𞤫',
         'ko_KP' => '𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞤲𞤪𞤫 (𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞥄 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫)',
         'ko_KR' => '𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞤲𞤪𞤫 (𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞥄 𞤙𞤢𞤥𞤲𞤢𞥄𞤲𞤺𞤫)',
+        'ks' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫',
+        'ks_Arab' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵)',
+        'ks_Arab_IN' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵⹁ 𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'ks_Deva' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫 (𞤁𞤫𞤾𞤢𞤲𞤢𞤺𞤢𞤪𞤭)',
+        'ks_Deva_IN' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫 (𞤁𞤫𞤾𞤢𞤲𞤢𞤺𞤢𞤪𞤭⹁ 𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'ks_IN' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'ku' => '𞤑𞤵𞤪𞤣𞤭𞤧𞤭𞥅𞤪𞤫',
+        'ku_TR' => '𞤑𞤵𞤪𞤣𞤭𞤧𞤭𞥅𞤪𞤫 (𞤚𞤵𞤪𞤳𞤭𞤴𞤢𞥄)',
         'kw' => '𞤑𞤮𞤪𞤲𞤭𞥅𞤪𞤫',
         'kw_GB' => '𞤑𞤮𞤪𞤲𞤭𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤐𞤺𞤫𞤯𞤵𞥅𞤪𞤭)',
+        'ky' => '𞤑𞤭𞤪𞤺𞤵𞥅𞤪𞤫',
+        'ky_KG' => '𞤑𞤭𞤪𞤺𞤵𞥅𞤪𞤫 (𞤑𞤭𞤪𞤶𞤭𞤧𞤼𞤢𞥄𞤲)',
+        'lb' => '𞤂𞤵𞥁𞤫𞤲𞤦𞤵𞥅𞤪𞤺𞤭𞤧𞤪𞤫',
+        'lb_LU' => '𞤂𞤵𞥁𞤫𞤲𞤦𞤵𞥅𞤪𞤺𞤭𞤧𞤪𞤫 (𞤂𞤵𞤳𞤧𞤢𞤲𞤦𞤵𞥅𞤺)',
+        'lg' => '𞤘𞤢𞤲𞤣𞤢𞥄𞤪𞤫',
+        'lg_UG' => '𞤘𞤢𞤲𞤣𞤢𞥄𞤪𞤫 (𞤓𞤺𞤢𞤲𞤣𞤢𞥄)',
+        'ln' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫',
+        'ln_AO' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫 (𞤀𞤲𞤺𞤮𞤤𞤢𞥄)',
+        'ln_CD' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫 (𞤑𞤮𞤲𞤺𞤮 - 𞤑𞤭𞤲𞤧𞤢𞤧𞤢)',
+        'ln_CF' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫 (𞤐𞤣𞤫𞤲𞤣𞤭 𞤚𞤵𞤥𞤦𞤮𞥅𞤪𞤭 𞤀𞤬𞤪𞤭𞤳𞤢𞥄)',
+        'ln_CG' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫 (𞤑𞤮𞤲𞤺𞤮 - 𞤄𞤪𞤢𞥁𞤢𞤾𞤭𞤤)',
+        'lo' => '𞤂𞤢𞤮𞥅𞤪𞤫',
+        'lo_LA' => '𞤂𞤢𞤮𞥅𞤪𞤫 (𞤂𞤢𞤱𞤮𞥅𞤧)',
+        'lt' => '𞤂𞤭𞤼𞤮𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
+        'lt_LT' => '𞤂𞤭𞤼𞤮𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤭𞤼𞤵𞤾𞤢)',
+        'lu' => '𞤂𞤵𞤦𞤢-𞤑𞤢𞤼𞤢𞤲𞤺𞤢𞥄𞤪𞤫',
+        'lu_CD' => '𞤂𞤵𞤦𞤢-𞤑𞤢𞤼𞤢𞤲𞤺𞤢𞥄𞤪𞤫 (𞤑𞤮𞤲𞤺𞤮 - 𞤑𞤭𞤲𞤧𞤢𞤧𞤢)',
+        'lv' => '𞤂𞤢𞤼𞤾𞤭𞤴𞤢𞤲𞤪𞤫',
+        'lv_LV' => '𞤂𞤢𞤼𞤾𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤢𞤼𞤾𞤭𞤴𞤢)',
         'mg' => '𞤃𞤢𞤤𞤢𞤺𞤢𞤧𞤭𞥅𞤪𞤫',
         'mg_MG' => '𞤃𞤢𞤤𞤢𞤺𞤢𞤧𞤭𞥅𞤪𞤫 (𞤃𞤢𞤣𞤢𞤺𞤢𞤧𞤳𞤢𞥄𞤪)',
+        'mi' => '𞤃𞤢𞥄𞤮𞤪𞤭𞥅𞤪𞤫',
+        'mi_NZ' => '𞤃𞤢𞥄𞤮𞤪𞤭𞥅𞤪𞤫 (𞤐𞤫𞤱 𞤟𞤫𞤤𞤢𞤲𞤣)',
         'mk' => '𞤃𞤢𞤧𞤫𞤣𞤮𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
         'mk_MK' => '𞤃𞤢𞤧𞤫𞤣𞤮𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤃𞤢𞤳𞤫𞤣𞤮𞤲𞤭𞤴𞤢𞥄 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫)',
         'ml' => '𞤃𞤢𞤤𞤢𞤴𞤢𞤤𞤢𞤥𞤪𞤫',
         'ml_IN' => '𞤃𞤢𞤤𞤢𞤴𞤢𞤤𞤢𞤥𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
         'mn' => '𞤃𞤮𞤲𞤺𞤮𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
         'mn_MN' => '𞤃𞤮𞤲𞤺𞤮𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤃𞤮𞤲𞤺𞤮𞤤𞤭𞤴𞤢)',
+        'mr' => '𞤃𞤢𞤪𞤢𞤼𞤭𞥅𞤪𞤫',
+        'mr_IN' => '𞤃𞤢𞤪𞤢𞤼𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
         'ms' => '𞤃𞤢𞤤𞤫𞥅𞤪𞤫',
         'ms_BN' => '𞤃𞤢𞤤𞤫𞥅𞤪𞤫 (𞤄𞤵𞤪𞤲𞤢𞥄𞤴)',
         'ms_ID' => '𞤃𞤢𞤤𞤫𞥅𞤪𞤫 (𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤴𞤢)',
@@ -356,6 +437,11 @@ return [
         'mt_MT' => '𞤃𞤢𞤤𞤼𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤃𞤢𞤤𞤼𞤢)',
         'my' => '𞤄𞤵𞤪𞤥𞤢𞥄𞤪𞤫',
         'my_MM' => '𞤄𞤵𞤪𞤥𞤢𞥄𞤪𞤫 (𞤃𞤭𞤴𞤢𞤥𞤢𞥄𞤪 [𞤄𞤵𞥅𞤪𞤥𞤢])',
+        'nb' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤄𞤮𞤳𞤥𞤢𞤤',
+        'nb_NO' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤄𞤮𞤳𞤥𞤢𞤤 (𞤐𞤮𞤪𞤺𞤫𞤴𞤢𞥄)',
+        'nb_SJ' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤄𞤮𞤳𞤥𞤢𞤤 (𞤅𞤢𞤾𞤢𞤤𞤦𞤢𞤪𞤣 & 𞤔𞤢𞤲 𞤃𞤢𞤴𞤫𞤲)',
+        'nd' => '𞤐𞤣𞤫𞤦𞤫𞤤𞤫𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤺𞤫',
+        'nd_ZW' => '𞤐𞤣𞤫𞤦𞤫𞤤𞤫𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤺𞤫 (𞤟𞤭𞤥𞤦𞤢𞥄𞤥𞤵𞤴𞤢)',
         'ne' => '𞤐𞤫𞤨𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
         'ne_IN' => '𞤐𞤫𞤨𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
         'ne_NP' => '𞤐𞤫𞤨𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤐𞤭𞤨𞤢𞥄𞤤)',
@@ -367,27 +453,54 @@ return [
         'nl_NL' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫 (𞤖𞤮𞤤𞤢𞤲𞤣𞤭𞤴𞤢𞥄)',
         'nl_SR' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫 (𞤅𞤵𞤪𞤭𞤲𞤢𞥄𞤥)',
         'nl_SX' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫 (𞤅𞤫𞤲𞤼𞤵 𞤃𞤢𞥄𞤪𞤼𞤫𞤲)',
-        'pa_Arab' => 'Punjabeere (𞤀𞥄𞤪𞤢𞤦𞤵)',
-        'pa_Arab_PK' => 'Punjabeere (𞤀𞥄𞤪𞤢𞤦𞤵⹁ 𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
-        'pa_IN' => 'Punjabeere (𞤋𞤲𞤣𞤭𞤴𞤢)',
-        'pa_PK' => 'Punjabeere (𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
+        'nn' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤙𞤮𞤪𞤧𞤳',
+        'nn_NO' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤙𞤮𞤪𞤧𞤳 (𞤐𞤮𞤪𞤺𞤫𞤴𞤢𞥄)',
+        'no' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫',
+        'no_NO' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 (𞤐𞤮𞤪𞤺𞤫𞤴𞤢𞥄)',
+        'om' => '𞤌𞤪𞤮𞤥𞤮𞥅𞤪𞤫',
+        'om_ET' => '𞤌𞤪𞤮𞤥𞤮𞥅𞤪𞤫 (𞤀𞤦𞤢𞤧𞤭𞤲𞤭𞥅)',
+        'om_KE' => '𞤌𞤪𞤮𞤥𞤮𞥅𞤪𞤫 (𞤑𞤫𞤲𞤭𞤴𞤢𞥄)',
+        'or' => '𞤌𞤣𞤭𞤢𞥄𞤪𞤫',
+        'or_IN' => '𞤌𞤣𞤭𞤢𞥄𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'os' => '𞤌𞤧𞥆𞤫𞤼𞤭𞤳𞤪𞤫',
+        'os_GE' => '𞤌𞤧𞥆𞤫𞤼𞤭𞤳𞤪𞤫 (𞤔𞤮𞤪𞤶𞤭𞤴𞤢𞥄)',
+        'os_RU' => '𞤌𞤧𞥆𞤫𞤼𞤭𞤳𞤪𞤫 (𞤈𞤮𞥅𞤧𞤭𞤴𞤢)',
+        'pa' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫',
+        'pa_Arab' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵)',
+        'pa_Arab_PK' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵⹁ 𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
+        'pa_Guru' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤘𞤵𞤪𞤥𞤵𞤿𞤭)',
+        'pa_Guru_IN' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤘𞤵𞤪𞤥𞤵𞤿𞤭⹁ 𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'pa_IN' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'pa_PK' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
         'pl' => '𞤆𞤮𞤤𞤢𞤲𞤣𞤭𞥅𞤪𞤫',
         'pl_PL' => '𞤆𞤮𞤤𞤢𞤲𞤣𞤭𞥅𞤪𞤫 (𞤆𞤮𞤤𞤢𞤲𞤣)',
+        'ps' => '𞤆𞤢𞤧𞤼𞤵𞤲𞤪𞤫',
+        'ps_AF' => '𞤆𞤢𞤧𞤼𞤵𞤲𞤪𞤫 (𞤀𞤬𞤺𞤢𞤲𞤭𞤧𞤼𞤢𞥄𞤲)',
+        'ps_PK' => '𞤆𞤢𞤧𞤼𞤵𞤲𞤪𞤫 (𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
         'pt' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫',
         'pt_AO' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤀𞤲𞤺𞤮𞤤𞤢𞥄)',
-        'pt_BR' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤄𞤪𞤢𞥄𞥁𞤭𞤤)',
+        'pt_BR' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤄𞤪𞤢𞤧𞤭𞤤)',
         'pt_CH' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤅𞤵𞤱𞤭𞤪𞤧𞤢𞥄)',
         'pt_CV' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤑𞤢𞥄𞤦𞤮 𞤜𞤫𞤪𞤣𞤫)',
         'pt_GQ' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤘𞤭𞤲𞤫 𞤕𞤢𞤳𞤢𞤲𞤼𞤫𞥅𞤪𞤭)',
         'pt_GW' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤘𞤭𞤲𞤫-𞤄𞤭𞤧𞤢𞤱𞤮𞥅)',
         'pt_LU' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤂𞤵𞤳𞤧𞤢𞤲𞤦𞤵𞥅𞤺)',
-        'pt_MO' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤅𞤭𞥅𞤲 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
+        'pt_MO' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
         'pt_MZ' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤃𞤮𞤧𞤢𞤥𞤦𞤭𞥅𞤳)',
         'pt_PT' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤆𞤮𞥅𞤪𞤼𞤵𞤺𞤢𞥄𞤤)',
         'pt_ST' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤅𞤢𞤱𞤵 𞤚𞤵𞤥𞤫𞥅 & 𞤆𞤫𞤪𞤫𞤲𞤧𞤭𞤨𞤫)',
         'pt_TL' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤚𞤭𞤥𞤮𞥅𞤪 𞤂𞤫𞤧𞤼𞤫)',
-        'ro_MD' => 'Romaneere (𞤃𞤮𞤤𞤣𞤮𞤾𞤢𞥄)',
-        'ro_RO' => 'Romaneere (𞤈𞤵𞤥𞤢𞥄𞤲𞤭𞤴𞤢)',
+        'qu' => '𞤗𞤵𞤷𞤵𞤢𞤲𞤪𞤫',
+        'qu_BO' => '𞤗𞤵𞤷𞤵𞤢𞤲𞤪𞤫 (𞤄𞤮𞤤𞤭𞥅𞤾𞤭𞤴𞤢𞥄)',
+        'qu_EC' => '𞤗𞤵𞤷𞤵𞤢𞤲𞤪𞤫 (𞤉𞤳𞤵𞤱𞤢𞤣𞤮𞥅𞤪)',
+        'qu_PE' => '𞤗𞤵𞤷𞤵𞤢𞤲𞤪𞤫 (𞤆𞤫𞤪𞤵𞥅)',
+        'rm' => '𞤈𞤮𞤥𞤢𞤲𞤧𞤪𞤫',
+        'rm_CH' => '𞤈𞤮𞤥𞤢𞤲𞤧𞤪𞤫 (𞤅𞤵𞤱𞤭𞤪𞤧𞤢𞥄)',
+        'rn' => '𞤈𞤵𞤲𞤣𞤭𞥅𞤪𞤫',
+        'rn_BI' => '𞤈𞤵𞤲𞤣𞤭𞥅𞤪𞤫 (𞤄𞤵𞤪𞤵𞤲𞤣𞤭)',
+        'ro' => '𞤈𞤮𞤥𞤢𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
+        'ro_MD' => '𞤈𞤮𞤥𞤢𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤃𞤮𞤤𞤣𞤮𞤾𞤢𞥄)',
+        'ro_RO' => '𞤈𞤮𞤥𞤢𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤈𞤵𞤥𞤢𞥄𞤲𞤭𞤴𞤢)',
         'ru' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫',
         'ru_BY' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤄𞤫𞤤𞤢𞤪𞤵𞥅𞤧)',
         'ru_KG' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤑𞤭𞤪𞤶𞤭𞤧𞤼𞤢𞥄𞤲)',
@@ -395,29 +508,93 @@ return [
         'ru_MD' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤃𞤮𞤤𞤣𞤮𞤾𞤢𞥄)',
         'ru_RU' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤈𞤮𞥅𞤧𞤭𞤴𞤢)',
         'ru_UA' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤓𞤳𞤪𞤫𞥅𞤲𞤭𞤴𞤢)',
-        'rw_RW' => 'Ruwaanndeere (𞤈𞤵𞤱𞤢𞤲𞤣𞤢𞥄)',
-        'so_DJ' => 'Somalii (𞤔𞤭𞤦𞤵𞥅𞤼𞤭)',
-        'so_ET' => 'Somalii (𞤀𞤦𞤢𞤧𞤭𞤲𞤭𞥅)',
-        'so_KE' => 'Somalii (𞤑𞤫𞤲𞤭𞤴𞤢𞥄)',
-        'so_SO' => 'Somalii (𞤅𞤵𞥅𞤥𞤢𞥄𞤤𞤭)',
+        'rw' => '𞤑𞤭𞤻𞤭𞤪𞤵𞤱𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
+        'rw_RW' => '𞤑𞤭𞤻𞤭𞤪𞤵𞤱𞤢𞤲𞤣𞤫𞥅𞤪𞤫 (𞤈𞤵𞤱𞤢𞤲𞤣𞤢𞥄)',
+        'sa' => '𞤅𞤢𞤲𞤧𞤳𞤪𞤭𞤼𞤪𞤫',
+        'sa_IN' => '𞤅𞤢𞤲𞤧𞤳𞤪𞤭𞤼𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'sc' => '𞤅𞤢𞤪𞤣𞤭𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
+        'sc_IT' => '𞤅𞤢𞤪𞤣𞤭𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤋𞤼𞤢𞤤𞤭𞥅)',
+        'sd' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫',
+        'sd_Arab' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵)',
+        'sd_Arab_PK' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵⹁ 𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
+        'sd_Deva' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤁𞤫𞤾𞤢𞤲𞤢𞤺𞤢𞤪𞤭)',
+        'sd_Deva_IN' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤁𞤫𞤾𞤢𞤲𞤢𞤺𞤢𞤪𞤭⹁ 𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'sd_IN' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'sd_PK' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
+        'se' => '𞤅𞤢𞤥𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫',
+        'se_FI' => '𞤅𞤢𞤥𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫 (𞤊𞤭𞤲𞤤𞤢𞤲𞤣)',
+        'se_NO' => '𞤅𞤢𞤥𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫 (𞤐𞤮𞤪𞤺𞤫𞤴𞤢𞥄)',
+        'se_SE' => '𞤅𞤢𞤥𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫 (𞤅𞤵𞤱𞤫𞤣𞤭𞤴𞤢𞥄)',
+        'sg' => '𞤅𞤢𞤲𞤺𞤮𞥅𞤪𞤫',
+        'sg_CF' => '𞤅𞤢𞤲𞤺𞤮𞥅𞤪𞤫 (𞤐𞤣𞤫𞤲𞤣𞤭 𞤚𞤵𞤥𞤦𞤮𞥅𞤪𞤭 𞤀𞤬𞤪𞤭𞤳𞤢𞥄)',
+        'si' => '𞤅𞤭𞤲𞤸𞤢𞤤𞤢𞥄𞤪𞤫',
+        'si_LK' => '𞤅𞤭𞤲𞤸𞤢𞤤𞤢𞥄𞤪𞤫 (𞤅𞤭𞤪 𞤂𞤢𞤲𞤳𞤢𞥄)',
+        'sk' => '𞤅𞤤𞤮𞤾𞤢𞥄𞤳𞤪𞤫',
+        'sk_SK' => '𞤅𞤤𞤮𞤾𞤢𞥄𞤳𞤪𞤫 (𞤅𞤵𞤤𞤮𞤾𞤢𞥄𞤳𞤭𞤴𞤢)',
+        'sl' => '𞤅𞤤𞤮𞤾𞤫𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
+        'sl_SI' => '𞤅𞤤𞤮𞤾𞤫𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤵𞤤𞤮𞤾𞤫𞤲𞤭𞤴𞤢𞥄)',
+        'sn' => '𞤅𞤮𞤲𞤢𞥄𞤪𞤫',
+        'sn_ZW' => '𞤅𞤮𞤲𞤢𞥄𞤪𞤫 (𞤟𞤭𞤥𞤦𞤢𞥄𞤥𞤵𞤴𞤢)',
+        'so' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫',
+        'so_DJ' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫 (𞤔𞤭𞤦𞤵𞥅𞤼𞤭)',
+        'so_ET' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫 (𞤀𞤦𞤢𞤧𞤭𞤲𞤭𞥅)',
+        'so_KE' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫 (𞤑𞤫𞤲𞤭𞤴𞤢𞥄)',
+        'so_SO' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫 (𞤅𞤵𞥅𞤥𞤢𞥄𞤤𞤭)',
         'sq' => '𞤀𞤤𞤦𞤢𞤲𞤭𞥅𞤪𞤫',
         'sq_AL' => '𞤀𞤤𞤦𞤢𞤲𞤭𞥅𞤪𞤫 (𞤀𞤤𞤦𞤢𞤲𞤭𞤴𞤢𞥄)',
         'sq_MK' => '𞤀𞤤𞤦𞤢𞤲𞤭𞥅𞤪𞤫 (𞤃𞤢𞤳𞤫𞤣𞤮𞤲𞤭𞤴𞤢𞥄 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫)',
-        'sv_AX' => 'Sweedeere (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤀𞤤𞤢𞤲𞤣)',
-        'sv_FI' => 'Sweedeere (𞤊𞤭𞤲𞤤𞤢𞤲𞤣)',
-        'sv_SE' => 'Sweedeere (𞤅𞤵𞤱𞤫𞤣𞤭𞤴𞤢𞥄)',
-        'ta_IN' => 'Tamil (𞤋𞤲𞤣𞤭𞤴𞤢)',
-        'ta_LK' => 'Tamil (𞤅𞤭𞤪 𞤂𞤢𞤲𞤳𞤢𞥄)',
-        'ta_MY' => 'Tamil (𞤃𞤢𞤤𞤫𞥅𞤧𞤭𞤴𞤢)',
-        'ta_SG' => 'Tamil (𞤅𞤭𞤲𞤺𞤢𞤨𞤵𞥅𞤪)',
+        'sr' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫',
+        'sr_BA' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
+        'sr_Cyrl' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳)',
+        'sr_Cyrl_BA' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳⹁ 𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
+        'sr_Cyrl_ME' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳⹁ 𞤃𞤮𞤲𞤼𞤫𞤲𞤫𞥅𞤺𞤮𞤪𞤮)',
+        'sr_Cyrl_RS' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳⹁ 𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞥄)',
+        'sr_Latn' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲)',
+        'sr_Latn_BA' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
+        'sr_Latn_ME' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤃𞤮𞤲𞤼𞤫𞤲𞤫𞥅𞤺𞤮𞤪𞤮)',
+        'sr_Latn_RS' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞥄)',
+        'sr_ME' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤃𞤮𞤲𞤼𞤫𞤲𞤫𞥅𞤺𞤮𞤪𞤮)',
+        'sr_RS' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞥄)',
+        'su' => '𞤅𞤵𞤲𞤣𞤢𞤲𞤭𞥅𞤪𞤫',
+        'su_ID' => '𞤅𞤵𞤲𞤣𞤢𞤲𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤴𞤢)',
+        'su_Latn' => '𞤅𞤵𞤲𞤣𞤢𞤲𞤭𞥅𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲)',
+        'su_Latn_ID' => '𞤅𞤵𞤲𞤣𞤢𞤲𞤭𞥅𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤴𞤢)',
+        'sv' => '𞤅𞤱𞤫𞤣𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
+        'sv_AX' => '𞤅𞤱𞤫𞤣𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤀𞤤𞤢𞤲𞤣)',
+        'sv_FI' => '𞤅𞤱𞤫𞤣𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤊𞤭𞤲𞤤𞤢𞤲𞤣)',
+        'sv_SE' => '𞤅𞤱𞤫𞤣𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤅𞤵𞤱𞤫𞤣𞤭𞤴𞤢𞥄)',
+        'sw' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫',
+        'sw_CD' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫 (𞤑𞤮𞤲𞤺𞤮 - 𞤑𞤭𞤲𞤧𞤢𞤧𞤢)',
+        'sw_KE' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫 (𞤑𞤫𞤲𞤭𞤴𞤢𞥄)',
+        'sw_TZ' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫 (𞤚𞤢𞤲𞤧𞤢𞤲𞤭𞥅)',
+        'sw_UG' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫 (𞤓𞤺𞤢𞤲𞤣𞤢𞥄)',
+        'ta' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫',
+        'ta_IN' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'ta_LK' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫 (𞤅𞤭𞤪 𞤂𞤢𞤲𞤳𞤢𞥄)',
+        'ta_MY' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫 (𞤃𞤢𞤤𞤫𞥅𞤧𞤭𞤴𞤢)',
+        'ta_SG' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫 (𞤅𞤭𞤲𞤺𞤢𞤨𞤵𞥅𞤪)',
+        'te' => '𞤚𞤫𞤤𞤫𞤺𞤵𞥅𞤪𞤫',
+        'te_IN' => '𞤚𞤫𞤤𞤫𞤺𞤵𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
+        'tg' => '𞤚𞤢𞤶𞤭𞤳𞤪𞤫',
+        'tg_TJ' => '𞤚𞤢𞤶𞤭𞤳𞤪𞤫 (𞤚𞤢𞤶𞤭𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
         'th' => '𞤚𞤢𞤴𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
         'th_TH' => '𞤚𞤢𞤴𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫 (𞤚𞤢𞥄𞤴𞤤𞤢𞤲𞤣)',
+        'ti' => '𞤚𞤭𞤺𞤭𞤪𞤻𞤢𞥄𞤪𞤫',
+        'ti_ER' => '𞤚𞤭𞤺𞤭𞤪𞤻𞤢𞥄𞤪𞤫 (𞤉𞤪𞤭𞥅𞤼𞤫𞤪𞤫)',
+        'ti_ET' => '𞤚𞤭𞤺𞤭𞤪𞤻𞤢𞥄𞤪𞤫 (𞤀𞤦𞤢𞤧𞤭𞤲𞤭𞥅)',
+        'tk' => '𞤼𞤵𞤪𞤳𞤥𞤢𞤲𞤪𞤫',
+        'tk_TM' => '𞤼𞤵𞤪𞤳𞤥𞤢𞤲𞤪𞤫 (𞤚𞤵𞤪𞤳𞤵𞤥𞤫𞤲𞤭𞤧𞤼𞤢𞥄𞤲)',
+        'to' => '𞤚𞤮𞤲𞤺𞤢𞤲𞤪𞤫',
+        'to_TO' => '𞤚𞤮𞤲𞤺𞤢𞤲𞤪𞤫 (𞤚𞤮𞤲𞤺𞤢)',
         'tr' => '𞤚𞤵𞥅𞤪𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
         'tr_CY' => '𞤚𞤵𞥅𞤪𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤑𞤵𞤦𞤪𞤵𞥅𞤧)',
         'tr_TR' => '𞤚𞤵𞥅𞤪𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤵𞤪𞤳𞤭𞤴𞤢𞥄)',
+        'tt' => '𞤚𞤢𞤼𞤢𞤪𞥇𞤪𞤫',
+        'tt_RU' => '𞤚𞤢𞤼𞤢𞤪𞥇𞤪𞤫 (𞤈𞤮𞥅𞤧𞤭𞤴𞤢)',
         'ug' => '𞤓𞥅𞤴𞤺𞤵𞥅𞤪𞤫',
-        'ug_CN' => '𞤓𞥅𞤴𞤺𞤵𞥅𞤪𞤫 (𞤅𞤭𞥅𞤲)',
-        'uk_UA' => 'Ukereneere (𞤓𞤳𞤪𞤫𞥅𞤲𞤭𞤴𞤢)',
+        'ug_CN' => '𞤓𞥅𞤴𞤺𞤵𞥅𞤪𞤫 (𞤕𞤢𞤴𞤲𞤢)',
+        'uk' => '𞤒𞤵𞤳𞤪𞤫𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
+        'uk_UA' => '𞤒𞤵𞤳𞤪𞤫𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤓𞤳𞤪𞤫𞥅𞤲𞤭𞤴𞤢)',
         'ur' => '𞤓𞤪𞤣𞤵𞥅𞤪𞤫',
         'ur_IN' => '𞤓𞤪𞤣𞤵𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
         'ur_PK' => '𞤓𞤪𞤣𞤵𞥅𞤪𞤫 (𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
@@ -442,18 +619,18 @@ return [
         'yo_BJ' => '𞤒𞤮𞥅𞤪𞤵𞤦𞤢𞥄𞤪𞤫 (𞤄𞤫𞤲𞤫𞤲)',
         'yo_NG' => '𞤒𞤮𞥅𞤪𞤵𞤦𞤢𞥄𞤪𞤫 (𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
         'zh' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
-        'zh_CN' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤅𞤭𞥅𞤲)',
-        'zh_HK' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤅𞤭𞥅𞤲 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
+        'zh_CN' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤕𞤢𞤴𞤲𞤢)',
+        'zh_HK' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
         'zh_Hans' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫)',
-        'zh_Hans_CN' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤅𞤭𞥅𞤲)',
-        'zh_Hans_HK' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤅𞤭𞥅𞤲 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
-        'zh_Hans_MO' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤅𞤭𞥅𞤲 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
+        'zh_Hans_CN' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤕𞤢𞤴𞤲𞤢)',
+        'zh_Hans_HK' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
+        'zh_Hans_MO' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
         'zh_Hans_SG' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤅𞤭𞤲𞤺𞤢𞤨𞤵𞥅𞤪)',
         'zh_Hant' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤱𞤢𞥄𞤲𞤣𞤫)',
-        'zh_Hant_HK' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤱𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤅𞤭𞥅𞤲 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
-        'zh_Hant_MO' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤱𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤅𞤭𞥅𞤲 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
+        'zh_Hant_HK' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤱𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
+        'zh_Hant_MO' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤱𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
         'zh_Hant_TW' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤱𞤢𞥄𞤲𞤣𞤫⹁ 𞤚𞤢𞤴𞤱𞤢𞥄𞤲)',
-        'zh_MO' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤅𞤭𞥅𞤲 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
+        'zh_MO' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
         'zh_SG' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤅𞤭𞤲𞤺𞤢𞤨𞤵𞥅𞤪)',
         'zh_TW' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤴𞤱𞤢𞥄𞤲)',
         'zu' => '𞥁𞤵𞤤𞤵𞥅𞤪𞤫',
