@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'tšetšeeni (Venäjä)',
         'cs' => 'tšekki',
         'cs_CZ' => 'tšekki (Tšekki)',
+        'cv' => 'tšuvassi',
+        'cv_RU' => 'tšuvassi (Venäjä)',
         'cy' => 'kymri',
         'cy_GB' => 'kymri (Iso-Britannia)',
         'da' => 'tanska',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'englanti (Montserrat)',
         'en_MT' => 'englanti (Malta)',
         'en_MU' => 'englanti (Mauritius)',
+        'en_MV' => 'englanti (Malediivit)',
         'en_MW' => 'englanti (Malawi)',
         'en_MY' => 'englanti (Malesia)',
         'en_NA' => 'englanti (Namibia)',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'heprea (Israel)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (Intia)',
+        'hi_Latn' => 'hindi (latinalainen)',
+        'hi_Latn_IN' => 'hindi (latinalainen, Intia)',
         'hr' => 'kroatia',
         'hr_BA' => 'kroatia (Bosnia ja Hertsegovina)',
         'hr_HR' => 'kroatia (Kroatia)',
@@ -385,6 +390,8 @@ return [
         'ks' => 'kašmiri',
         'ks_Arab' => 'kašmiri (arabialainen)',
         'ks_Arab_IN' => 'kašmiri (arabialainen, Intia)',
+        'ks_Deva' => 'kašmiri (devanagari)',
+        'ks_Deva_IN' => 'kašmiri (devanagari, Intia)',
         'ks_IN' => 'kašmiri (Intia)',
         'ku' => 'kurdi',
         'ku_TR' => 'kurdi (Turkki)',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arabialainen, Pakistan)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, Intia)',
+        'sd_IN' => 'sindhi (Intia)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'pohjoissaame',
         'se_FI' => 'pohjoissaame (Suomi)',
