@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'tjetjenskt (Russland)',
         'cs' => 'kekkiskt',
         'cs_CZ' => 'kekkiskt (Kekkia)',
+        'cv' => 'chuvash',
+        'cv_RU' => 'chuvash (Russland)',
         'cy' => 'walisiskt',
         'cy_GB' => 'walisiskt (Stórabretland)',
         'da' => 'danskt',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'enskt (Montserrat)',
         'en_MT' => 'enskt (Malta)',
         'en_MU' => 'enskt (Móritius)',
+        'en_MV' => 'enskt (Maldivoyggjar)',
         'en_MW' => 'enskt (Malavi)',
         'en_MY' => 'enskt (Malaisia)',
         'en_NA' => 'enskt (Namibia)',
@@ -328,6 +331,8 @@ return [
         'he_IL' => 'hebraiskt (Ísrael)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (India)',
+        'hi_Latn' => 'hindi (latínskt)',
+        'hi_Latn_IN' => 'hindi (latínskt, India)',
         'hr' => 'kroatiskt',
         'hr_BA' => 'kroatiskt (Bosnia-Hersegovina)',
         'hr_HR' => 'kroatiskt (Kroatia)',
@@ -372,6 +377,8 @@ return [
         'ks' => 'kashmiri',
         'ks_Arab' => 'kashmiri (arabisk)',
         'ks_Arab_IN' => 'kashmiri (arabisk, India)',
+        'ks_Deva' => 'kashmiri (devanagari)',
+        'ks_Deva_IN' => 'kashmiri (devanagari, India)',
         'ks_IN' => 'kashmiri (India)',
         'ku' => 'kurdiskt',
         'ku_TR' => 'kurdiskt (Turkaland)',
@@ -499,6 +506,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arabisk, Pakistan)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, India)',
+        'sd_IN' => 'sindhi (India)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'norður sámiskt',
         'se_FI' => 'norður sámiskt (Finnland)',
