@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'tchétchène (Russie)',
         'cs' => 'tchèque',
         'cs_CZ' => 'tchèque (Tchéquie)',
+        'cv' => 'tchouvache',
+        'cv_RU' => 'tchouvache (Russie)',
         'cy' => 'gallois',
         'cy_GB' => 'gallois (Royaume-Uni)',
         'da' => 'danois',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'anglais (Montserrat)',
         'en_MT' => 'anglais (Malte)',
         'en_MU' => 'anglais (Maurice)',
+        'en_MV' => 'anglais (Maldives)',
         'en_MW' => 'anglais (Malawi)',
         'en_MY' => 'anglais (Malaisie)',
         'en_NA' => 'anglais (Namibie)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'persan (Afghanistan)',
         'fa_IR' => 'persan (Iran)',
         'ff' => 'peul',
+        'ff_Adlm' => 'peul (adlam)',
+        'ff_Adlm_BF' => 'peul (adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'peul (adlam, Cameroun)',
+        'ff_Adlm_GH' => 'peul (adlam, Ghana)',
+        'ff_Adlm_GM' => 'peul (adlam, Gambie)',
+        'ff_Adlm_GN' => 'peul (adlam, Guinée)',
+        'ff_Adlm_GW' => 'peul (adlam, Guinée-Bissau)',
+        'ff_Adlm_LR' => 'peul (adlam, Liberia)',
+        'ff_Adlm_MR' => 'peul (adlam, Mauritanie)',
+        'ff_Adlm_NE' => 'peul (adlam, Niger)',
+        'ff_Adlm_NG' => 'peul (adlam, Nigeria)',
+        'ff_Adlm_SL' => 'peul (adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'peul (adlam, Sénégal)',
         'ff_CM' => 'peul (Cameroun)',
         'ff_GN' => 'peul (Guinée)',
         'ff_Latn' => 'peul (latin)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'hébreu (Israël)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (Inde)',
+        'hi_Latn' => 'hindi (latin)',
+        'hi_Latn_IN' => 'hindi (latin, Inde)',
         'hr' => 'croate',
         'hr_BA' => 'croate (Bosnie-Herzégovine)',
         'hr_HR' => 'croate (Croatie)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'cachemiri',
         'ks_Arab' => 'cachemiri (arabe)',
         'ks_Arab_IN' => 'cachemiri (arabe, Inde)',
+        'ks_Deva' => 'cachemiri (dévanagari)',
+        'ks_Deva_IN' => 'cachemiri (dévanagari, Inde)',
         'ks_IN' => 'cachemiri (Inde)',
         'ku' => 'kurde',
         'ku_TR' => 'kurde (Turquie)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arabe, Pakistan)',
         'sd_Deva' => 'sindhi (dévanagari)',
         'sd_Deva_IN' => 'sindhi (dévanagari, Inde)',
+        'sd_IN' => 'sindhi (Inde)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'same du Nord',
         'se_FI' => 'same du Nord (Finlande)',
