@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Tsjetsjeensk (Ruslân)',
         'cs' => 'Tsjechysk',
         'cs_CZ' => 'Tsjechysk (Tsjechje)',
+        'cv' => 'Tsjoevasjysk',
+        'cv_RU' => 'Tsjoevasjysk (Ruslân)',
         'cy' => 'Welsk',
         'cy_GB' => 'Welsk (Verenigd Koninkrijk)',
         'da' => 'Deensk',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'Ingelsk (Montserrat)',
         'en_MT' => 'Ingelsk (Malta)',
         'en_MU' => 'Ingelsk (Mauritius)',
+        'en_MV' => 'Ingelsk (Maldiven)',
         'en_MW' => 'Ingelsk (Malawi)',
         'en_MY' => 'Ingelsk (Maleisië)',
         'en_NA' => 'Ingelsk (Namibië)',
@@ -328,6 +331,8 @@ return [
         'he_IL' => 'Hebreeuwsk (Israël)',
         'hi' => 'Hindi',
         'hi_IN' => 'Hindi (India)',
+        'hi_Latn' => 'Hindi (Latyn)',
+        'hi_Latn_IN' => 'Hindi (Latyn, India)',
         'hr' => 'Kroatysk',
         'hr_BA' => 'Kroatysk (Bosnië en Herzegovina)',
         'hr_HR' => 'Kroatysk (Kroatië)',
@@ -372,6 +377,8 @@ return [
         'ks' => 'Kasjmiri',
         'ks_Arab' => 'Kasjmiri (Arabysk)',
         'ks_Arab_IN' => 'Kasjmiri (Arabysk, India)',
+        'ks_Deva' => 'Kasjmiri (Devanagari)',
+        'ks_Deva_IN' => 'Kasjmiri (Devanagari, India)',
         'ks_IN' => 'Kasjmiri (India)',
         'ku' => 'Koerdysk',
         'ku_TR' => 'Koerdysk (Turkije)',
@@ -498,6 +505,7 @@ return [
         'sd_Arab_PK' => 'Sindhi (Arabysk, Pakistan)',
         'sd_Deva' => 'Sindhi (Devanagari)',
         'sd_Deva_IN' => 'Sindhi (Devanagari, India)',
+        'sd_IN' => 'Sindhi (India)',
         'sd_PK' => 'Sindhi (Pakistan)',
         'se' => 'Noard-Samysk',
         'se_FI' => 'Noard-Samysk (Finlân)',
