@@ -394,7 +394,7 @@ return [
         'ks_Deva_IN' => 'કાશ્મીરી (દેવનાગરી, ભારત)',
         'ks_IN' => 'કાશ્મીરી (ભારત)',
         'ku' => 'કુર્દિશ',
-        'ku_TR' => 'કુર્દિશ (તુર્કી)',
+        'ku_TR' => 'કુર્દિશ (તુર્કિયે)',
         'kw' => 'કોર્નિશ',
         'kw_GB' => 'કોર્નિશ (યુનાઇટેડ કિંગડમ)',
         'ky' => 'કિર્ગીઝ',
@@ -592,7 +592,7 @@ return [
         'to_TO' => 'ટોંગાન (ટોંગા)',
         'tr' => 'ટર્કિશ',
         'tr_CY' => 'ટર્કિશ (સાયપ્રસ)',
-        'tr_TR' => 'ટર્કિશ (તુર્કી)',
+        'tr_TR' => 'ટર્કિશ (તુર્કિયે)',
         'tt' => 'તતાર',
         'tt_RU' => 'તતાર (રશિયા)',
         'ug' => 'ઉઇગુર',
