@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'צ׳צ׳נית (רוסיה)',
         'cs' => 'צ׳כית',
         'cs_CZ' => 'צ׳כית (צ׳כיה)',
+        'cv' => 'צ׳ובאש',
+        'cv_RU' => 'צ׳ובאש (רוסיה)',
         'cy' => 'וולשית',
         'cy_GB' => 'וולשית (בריטניה)',
         'da' => 'דנית',
@@ -110,7 +112,7 @@ return [
         'en_BI' => 'אנגלית (בורונדי)',
         'en_BM' => 'אנגלית (ברמודה)',
         'en_BS' => 'אנגלית (איי בהאמה)',
-        'en_BW' => 'אנגלית (בוצוואנה)',
+        'en_BW' => 'אנגלית (בוטסואנה)',
         'en_BZ' => 'אנגלית (בליז)',
         'en_CA' => 'אנגלית (קנדה)',
         'en_CC' => 'אנגלית (איי קוקוס [קילינג])',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'אנגלית (מונסראט)',
         'en_MT' => 'אנגלית (מלטה)',
         'en_MU' => 'אנגלית (מאוריציוס)',
+        'en_MV' => 'אנגלית (האיים המלדיביים)',
         'en_MW' => 'אנגלית (מלאווי)',
         'en_MY' => 'אנגלית (מלזיה)',
         'en_NA' => 'אנגלית (נמיביה)',
@@ -180,7 +183,7 @@ return [
         'en_SG' => 'אנגלית (סינגפור)',
         'en_SH' => 'אנגלית (סנט הלנה)',
         'en_SI' => 'אנגלית (סלובניה)',
-        'en_SL' => 'אנגלית (סיירה לאונה)',
+        'en_SL' => 'אנגלית (סיירה לאון)',
         'en_SS' => 'אנגלית (דרום סודן)',
         'en_SX' => 'אנגלית (סנט מארטן)',
         'en_SZ' => 'אנגלית (אסוואטיני)',
@@ -249,7 +252,7 @@ return [
         'ff_Adlm_MR' => 'פולה (אדלם, מאוריטניה)',
         'ff_Adlm_NE' => 'פולה (אדלם, ניז׳ר)',
         'ff_Adlm_NG' => 'פולה (אדלם, ניגריה)',
-        'ff_Adlm_SL' => 'פולה (אדלם, סיירה לאונה)',
+        'ff_Adlm_SL' => 'פולה (אדלם, סיירה לאון)',
         'ff_Adlm_SN' => 'פולה (אדלם, סנגל)',
         'ff_CM' => 'פולה (קמרון)',
         'ff_GN' => 'פולה (גינאה)',
@@ -264,7 +267,7 @@ return [
         'ff_Latn_MR' => 'פולה (לטיני, מאוריטניה)',
         'ff_Latn_NE' => 'פולה (לטיני, ניז׳ר)',
         'ff_Latn_NG' => 'פולה (לטיני, ניגריה)',
-        'ff_Latn_SL' => 'פולה (לטיני, סיירה לאונה)',
+        'ff_Latn_SL' => 'פולה (לטיני, סיירה לאון)',
         'ff_Latn_SN' => 'פולה (לטיני, סנגל)',
         'ff_MR' => 'פולה (מאוריטניה)',
         'ff_SN' => 'פולה (סנגל)',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'עברית (ישראל)',
         'hi' => 'הינדי',
         'hi_IN' => 'הינדי (הודו)',
+        'hi_Latn' => 'הינדי (לטיני)',
+        'hi_Latn_IN' => 'הינדי (לטיני, הודו)',
         'hr' => 'קרואטית',
         'hr_BA' => 'קרואטית (בוסניה והרצגובינה)',
         'hr_HR' => 'קרואטית (קרואטיה)',
@@ -385,6 +390,8 @@ return [
         'ks' => 'קשמירית',
         'ks_Arab' => 'קשמירית (ערבי)',
         'ks_Arab_IN' => 'קשמירית (ערבי, הודו)',
+        'ks_Deva' => 'קשמירית (דוואנגרי)',
+        'ks_Deva_IN' => 'קשמירית (דוואנגרי, הודו)',
         'ks_IN' => 'קשמירית (הודו)',
         'ku' => 'כורדית',
         'ku_TR' => 'כורדית (טורקיה)',
@@ -419,8 +426,8 @@ return [
         'ml_IN' => 'מליאלאם (הודו)',
         'mn' => 'מונגולית',
         'mn_MN' => 'מונגולית (מונגוליה)',
-        'mr' => 'מראטהי',
-        'mr_IN' => 'מראטהי (הודו)',
+        'mr' => 'מראטהית',
+        'mr_IN' => 'מראטהית (הודו)',
         'ms' => 'מלאית',
         'ms_BN' => 'מלאית (ברוניי)',
         'ms_ID' => 'מלאית (אינדונזיה)',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'סינדהית (ערבי, פקיסטן)',
         'sd_Deva' => 'סינדהית (דוואנגרי)',
         'sd_Deva_IN' => 'סינדהית (דוואנגרי, הודו)',
+        'sd_IN' => 'סינדהית (הודו)',
         'sd_PK' => 'סינדהית (פקיסטן)',
         'se' => 'סמי צפונית',
         'se_FI' => 'סמי צפונית (פינלנד)',
