@@ -394,7 +394,7 @@ return [
         'ks_Deva_IN' => 'कश्मीरी (देवनागरी, भारत)',
         'ks_IN' => 'कश्मीरी (भारत)',
         'ku' => 'कुर्दिश',
-        'ku_TR' => 'कुर्दिश (तुर्की)',
+        'ku_TR' => 'कुर्दिश (तुर्किये)',
         'kw' => 'कोर्निश',
         'kw_GB' => 'कोर्निश (यूनाइटेड किंगडम)',
         'ky' => 'किर्गीज़',
@@ -592,7 +592,7 @@ return [
         'to_TO' => 'टोंगन (टोंगा)',
         'tr' => 'तुर्की',
         'tr_CY' => 'तुर्की (साइप्रस)',
-        'tr_TR' => 'तुर्की (तुर्की)',
+        'tr_TR' => 'तुर्की (तुर्किये)',
         'tt' => 'तातार',
         'tt_RU' => 'तातार (रूस)',
         'ug' => 'उइगर',
