@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'čečenski (Rusija)',
         'cs' => 'češki',
         'cs_CZ' => 'češki (Češka)',
+        'cv' => 'čuvaški',
+        'cv_RU' => 'čuvaški (Rusija)',
         'cy' => 'velški',
         'cy_GB' => 'velški (Ujedinjeno Kraljevstvo)',
         'da' => 'danski',
@@ -115,7 +117,7 @@ return [
         'en_CA' => 'engleski (Kanada)',
         'en_CC' => 'engleski (Kokosovi [Keelingovi] otoci)',
         'en_CH' => 'engleski (Švicarska)',
-        'en_CK' => 'engleski (Cookovi Otoci)',
+        'en_CK' => 'engleski (Cookovi otoci)',
         'en_CM' => 'engleski (Kamerun)',
         'en_CX' => 'engleski (Božićni otok)',
         'en_CY' => 'engleski (Cipar)',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'perzijski (Afganistan)',
         'fa_IR' => 'perzijski (Iran)',
         'ff' => 'fula',
+        'ff_Adlm' => 'fula (adlam pismo)',
+        'ff_Adlm_BF' => 'fula (adlam pismo, Burkina Faso)',
+        'ff_Adlm_CM' => 'fula (adlam pismo, Kamerun)',
+        'ff_Adlm_GH' => 'fula (adlam pismo, Gana)',
+        'ff_Adlm_GM' => 'fula (adlam pismo, Gambija)',
+        'ff_Adlm_GN' => 'fula (adlam pismo, Gvineja)',
+        'ff_Adlm_GW' => 'fula (adlam pismo, Gvineja Bisau)',
+        'ff_Adlm_LR' => 'fula (adlam pismo, Liberija)',
+        'ff_Adlm_MR' => 'fula (adlam pismo, Mauretanija)',
+        'ff_Adlm_NE' => 'fula (adlam pismo, Niger)',
+        'ff_Adlm_NG' => 'fula (adlam pismo, Nigerija)',
+        'ff_Adlm_SL' => 'fula (adlam pismo, Sijera Leone)',
+        'ff_Adlm_SN' => 'fula (adlam pismo, Senegal)',
         'ff_CM' => 'fula (Kamerun)',
         'ff_GN' => 'fula (Gvineja)',
         'ff_Latn' => 'fula (latinica)',
@@ -290,7 +305,7 @@ return [
         'fr_MF' => 'francuski (Saint Martin)',
         'fr_MG' => 'francuski (Madagaskar)',
         'fr_ML' => 'francuski (Mali)',
-        'fr_MQ' => 'francuski (Martinique)',
+        'fr_MQ' => 'francuski (Martinik)',
         'fr_MR' => 'francuski (Mauretanija)',
         'fr_MU' => 'francuski (Mauricijus)',
         'fr_NC' => 'francuski (Nova Kaledonija)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindski (arapsko pismo, Pakistan)',
         'sd_Deva' => 'sindski (devangari pismo)',
         'sd_Deva_IN' => 'sindski (devangari pismo, Indija)',
+        'sd_IN' => 'sindski (Indija)',
         'sd_PK' => 'sindski (Pakistan)',
         'se' => 'sjeverni sami',
         'se_FI' => 'sjeverni sami (Finska)',
