@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'csecsen (Oroszország)',
         'cs' => 'cseh',
         'cs_CZ' => 'cseh (Csehország)',
+        'cv' => 'csuvas',
+        'cv_RU' => 'csuvas (Oroszország)',
         'cy' => 'walesi',
         'cy_GB' => 'walesi (Egyesült Királyság)',
         'da' => 'dán',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'angol (Montserrat)',
         'en_MT' => 'angol (Málta)',
         'en_MU' => 'angol (Mauritius)',
+        'en_MV' => 'angol (Maldív-szigetek)',
         'en_MW' => 'angol (Malawi)',
         'en_MY' => 'angol (Malajzia)',
         'en_NA' => 'angol (Namíbia)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'perzsa (Afganisztán)',
         'fa_IR' => 'perzsa (Irán)',
         'ff' => 'fulani',
+        'ff_Adlm' => 'fulani (Adlam)',
+        'ff_Adlm_BF' => 'fulani (Adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fulani (Adlam, Kamerun)',
+        'ff_Adlm_GH' => 'fulani (Adlam, Ghána)',
+        'ff_Adlm_GM' => 'fulani (Adlam, Gambia)',
+        'ff_Adlm_GN' => 'fulani (Adlam, Guinea)',
+        'ff_Adlm_GW' => 'fulani (Adlam, Bissau-Guinea)',
+        'ff_Adlm_LR' => 'fulani (Adlam, Libéria)',
+        'ff_Adlm_MR' => 'fulani (Adlam, Mauritánia)',
+        'ff_Adlm_NE' => 'fulani (Adlam, Niger)',
+        'ff_Adlm_NG' => 'fulani (Adlam, Nigéria)',
+        'ff_Adlm_SL' => 'fulani (Adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'fulani (Adlam, Szenegál)',
         'ff_CM' => 'fulani (Kamerun)',
         'ff_GN' => 'fulani (Guinea)',
         'ff_Latn' => 'fulani (Latin)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'héber (Izrael)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (India)',
+        'hi_Latn' => 'hindi (Latin)',
+        'hi_Latn_IN' => 'hindi (Latin, India)',
         'hr' => 'horvát',
         'hr_BA' => 'horvát (Bosznia-Hercegovina)',
         'hr_HR' => 'horvát (Horvátország)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kasmíri',
         'ks_Arab' => 'kasmíri (Arab)',
         'ks_Arab_IN' => 'kasmíri (Arab, India)',
+        'ks_Deva' => 'kasmíri (Devanagári)',
+        'ks_Deva_IN' => 'kasmíri (Devanagári, India)',
         'ks_IN' => 'kasmíri (India)',
         'ku' => 'kurd',
         'ku_TR' => 'kurd (Törökország)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'szindhi (Arab, Pakisztán)',
         'sd_Deva' => 'szindhi (Devanagári)',
         'sd_Deva_IN' => 'szindhi (Devanagári, India)',
+        'sd_IN' => 'szindhi (India)',
         'sd_PK' => 'szindhi (Pakisztán)',
         'se' => 'északi számi',
         'se_FI' => 'északi számi (Finnország)',
