@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'checheno (Russia)',
         'cs' => 'checo',
         'cs_CZ' => 'checo (Chechia)',
+        'cv' => 'chuvash',
+        'cv_RU' => 'chuvash (Russia)',
         'cy' => 'gallese',
         'cy_GB' => 'gallese (Regno Unite)',
         'da' => 'danese',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'anglese (Montserrat)',
         'en_MT' => 'anglese (Malta)',
         'en_MU' => 'anglese (Mauritio)',
+        'en_MV' => 'anglese (Maldivas)',
         'en_MW' => 'anglese (Malawi)',
         'en_MY' => 'anglese (Malaysia)',
         'en_NA' => 'anglese (Namibia)',
@@ -328,6 +331,8 @@ return [
         'he_IL' => 'hebreo (Israel)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (India)',
+        'hi_Latn' => 'hindi (latin)',
+        'hi_Latn_IN' => 'hindi (latin, India)',
         'hr' => 'croato',
         'hr_BA' => 'croato (Bosnia e Herzegovina)',
         'hr_HR' => 'croato (Croatia)',
@@ -372,6 +377,8 @@ return [
         'ks' => 'kashmiri',
         'ks_Arab' => 'kashmiri (arabe)',
         'ks_Arab_IN' => 'kashmiri (arabe, India)',
+        'ks_Deva' => 'kashmiri (devanagari)',
+        'ks_Deva_IN' => 'kashmiri (devanagari, India)',
         'ks_IN' => 'kashmiri (India)',
         'ku' => 'kurdo',
         'ku_TR' => 'kurdo (Turchia)',
@@ -499,6 +506,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arabe, Pakistan)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, India)',
+        'sd_IN' => 'sindhi (India)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'sami del nord',
         'se_FI' => 'sami del nord (Finlandia)',
