@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Chechen (Rusia)',
         'cs' => 'Cheska',
         'cs_CZ' => 'Cheska (Ceko)',
+        'cv' => 'Chuvash',
+        'cv_RU' => 'Chuvash (Rusia)',
         'cy' => 'Welsh',
         'cy_GB' => 'Welsh (Inggris Raya)',
         'da' => 'Dansk',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'Inggris (Montserrat)',
         'en_MT' => 'Inggris (Malta)',
         'en_MU' => 'Inggris (Mauritius)',
+        'en_MV' => 'Inggris (Maladewa)',
         'en_MW' => 'Inggris (Malawi)',
         'en_MY' => 'Inggris (Malaysia)',
         'en_NA' => 'Inggris (Namibia)',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'Ibrani (Israel)',
         'hi' => 'Hindi',
         'hi_IN' => 'Hindi (India)',
+        'hi_Latn' => 'Hindi (Latin)',
+        'hi_Latn_IN' => 'Hindi (Latin, India)',
         'hr' => 'Kroasia',
         'hr_BA' => 'Kroasia (Bosnia dan Herzegovina)',
         'hr_HR' => 'Kroasia (Kroasia)',
@@ -385,6 +390,8 @@ return [
         'ks' => 'Kashmir',
         'ks_Arab' => 'Kashmir (Arab)',
         'ks_Arab_IN' => 'Kashmir (Arab, India)',
+        'ks_Deva' => 'Kashmir (Dewanagari)',
+        'ks_Deva_IN' => 'Kashmir (Dewanagari, India)',
         'ks_IN' => 'Kashmir (India)',
         'ku' => 'Kurdi',
         'ku_TR' => 'Kurdi (Turki)',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Sindhi (Arab, Pakistan)',
         'sd_Deva' => 'Sindhi (Dewanagari)',
         'sd_Deva_IN' => 'Sindhi (Dewanagari, India)',
+        'sd_IN' => 'Sindhi (India)',
         'sd_PK' => 'Sindhi (Pakistan)',
         'se' => 'Sami Utara',
         'se_FI' => 'Sami Utara (Finlandia)',
