@@ -38,6 +38,8 @@ return [
         'ar_TD' => 'Arabiikị (Chad)',
         'ar_TN' => 'Arabiikị (Tunisia)',
         'ar_YE' => 'Arabiikị (Yemen)',
+        'as' => 'Asamisị',
+        'as_IN' => 'Asamisị (India)',
         'az' => 'Azerbajanị',
         'az_AZ' => 'Azerbajanị (Azerbaijan)',
         'az_Cyrl' => 'Azerbajanị (Mkpụrụ Okwu Cyrillic)',
@@ -73,6 +75,8 @@ return [
         'ce_RU' => 'Chechen (Rụssịa)',
         'cs' => 'Cheekị',
         'cs_CZ' => 'Cheekị (Czechia)',
+        'cv' => 'Chuvash',
+        'cv_RU' => 'Chuvash (Rụssịa)',
         'cy' => 'Wesh',
         'cy_GB' => 'Wesh (United Kingdom)',
         'da' => 'Danịsh',
@@ -237,6 +241,19 @@ return [
         'fa_AF' => 'Peshianụ (Afghanistan)',
         'fa_IR' => 'Peshianụ (Iran)',
         'ff' => 'Fula',
+        'ff_Adlm' => 'Fula (Adlam)',
+        'ff_Adlm_BF' => 'Fula (Adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'Fula (Adlam, Cameroon)',
+        'ff_Adlm_GH' => 'Fula (Adlam, Ghana)',
+        'ff_Adlm_GM' => 'Fula (Adlam, Gambia)',
+        'ff_Adlm_GN' => 'Fula (Adlam, Guinea)',
+        'ff_Adlm_GW' => 'Fula (Adlam, Guinea-Bissau)',
+        'ff_Adlm_LR' => 'Fula (Adlam, Liberia)',
+        'ff_Adlm_MR' => 'Fula (Adlam, Mauritania)',
+        'ff_Adlm_NE' => 'Fula (Adlam, Niger)',
+        'ff_Adlm_NG' => 'Fula (Adlam, Naịjịrịa)',
+        'ff_Adlm_SL' => 'Fula (Adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'Fula (Adlam, Senegal)',
         'ff_CM' => 'Fula (Cameroon)',
         'ff_GN' => 'Fula (Guinea)',
         'ff_Latn' => 'Fula (Latin)',
@@ -334,6 +351,8 @@ return [
         'hr_HR' => 'Kọrọtịan (Croatia)',
         'hu' => 'Hụngarian',
         'hu_HU' => 'Hụngarian (Hungary)',
+        'hy' => 'Armenianị',
+        'hy_AM' => 'Armenianị (Armenia)',
         'ia' => 'Intalịgụa',
         'ia_001' => 'Intalịgụa (Uwa)',
         'id' => 'Indonisia',
@@ -436,6 +455,8 @@ return [
         'nl_SX' => 'Dọchị (Sint Maarten)',
         'nn' => 'Nọrweyịan Nynersk',
         'nn_NO' => 'Nọrweyịan Nynersk (Norway)',
+        'no' => 'Nọrweyịan',
+        'no_NO' => 'Nọrweyịan (Norway)',
         'om' => 'Ọromo',
         'om_ET' => 'Ọromo (Ethiopia)',
         'om_KE' => 'Ọromo (Kenya)',
@@ -491,11 +512,14 @@ return [
         'rw_RW' => 'Kinyarwanda (Rwanda)',
         'sa' => 'Sansịkịt',
         'sa_IN' => 'Sansịkịt (India)',
+        'sc' => 'Sardinian',
+        'sc_IT' => 'Sardinian (Italy)',
         'sd' => 'Sịndh',
         'sd_Arab' => 'Sịndh (Mkpụrụ Okwu Arabic)',
         'sd_Arab_PK' => 'Sịndh (Mkpụrụ Okwu Arabic, Pakistan)',
         'sd_Deva' => 'Sịndh (Mkpụrụ ọkwụ Devangarị)',
         'sd_Deva_IN' => 'Sịndh (Mkpụrụ ọkwụ Devangarị, India)',
+        'sd_IN' => 'Sịndh (India)',
         'sd_PK' => 'Sịndh (Pakistan)',
         'se' => 'Nọrtan Samị',
         'se_FI' => 'Nọrtan Samị (Finland)',
@@ -516,6 +540,9 @@ return [
         'so_ET' => 'Somali (Ethiopia)',
         'so_KE' => 'Somali (Kenya)',
         'so_SO' => 'Somali (Somalia)',
+        'sq' => 'Albanianị',
+        'sq_AL' => 'Albanianị (Albania)',
+        'sq_MK' => 'Albanianị (North Macedonia)',
         'sr' => 'Sebịan',
         'sr_BA' => 'Sebịan (Bosnia & Herzegovina)',
         'sr_Cyrl' => 'Sebịan (Mkpụrụ Okwu Cyrillic)',
@@ -528,10 +555,19 @@ return [
         'sr_Latn_RS' => 'Sebịan (Latin, Serbia)',
         'sr_ME' => 'Sebịan (Montenegro)',
         'sr_RS' => 'Sebịan (Serbia)',
+        'su' => 'Sudanese',
+        'su_ID' => 'Sudanese (Indonesia)',
+        'su_Latn' => 'Sudanese (Latin)',
+        'su_Latn_ID' => 'Sudanese (Latin, Indonesia)',
         'sv' => 'Sụwidiishi',
         'sv_AX' => 'Sụwidiishi (Agwaetiti Aland)',
         'sv_FI' => 'Sụwidiishi (Finland)',
         'sv_SE' => 'Sụwidiishi (Sweden)',
+        'sw' => 'Swahili',
+        'sw_CD' => 'Swahili (Congo - Kinshasa)',
+        'sw_KE' => 'Swahili (Kenya)',
+        'sw_TZ' => 'Swahili (Tanzania)',
+        'sw_UG' => 'Swahili (Uganda)',
         'ta' => 'Tamil',
         'ta_IN' => 'Tamil (India)',
         'ta_LK' => 'Tamil (Sri Lanka)',
