@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'tsjetsjenska (Rússland)',
         'cs' => 'tékkneska',
         'cs_CZ' => 'tékkneska (Tékkland)',
+        'cv' => 'sjúvas',
+        'cv_RU' => 'sjúvas (Rússland)',
         'cy' => 'velska',
         'cy_GB' => 'velska (Bretland)',
         'da' => 'danska',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'persneska (Afganistan)',
         'fa_IR' => 'persneska (Íran)',
         'ff' => 'fúla',
+        'ff_Adlm' => 'fúla (adlam)',
+        'ff_Adlm_BF' => 'fúla (adlam, Búrkína Fasó)',
+        'ff_Adlm_CM' => 'fúla (adlam, Kamerún)',
+        'ff_Adlm_GH' => 'fúla (adlam, Gana)',
+        'ff_Adlm_GM' => 'fúla (adlam, Gambía)',
+        'ff_Adlm_GN' => 'fúla (adlam, Gínea)',
+        'ff_Adlm_GW' => 'fúla (adlam, Gínea-Bissá)',
+        'ff_Adlm_LR' => 'fúla (adlam, Líbería)',
+        'ff_Adlm_MR' => 'fúla (adlam, Máritanía)',
+        'ff_Adlm_NE' => 'fúla (adlam, Níger)',
+        'ff_Adlm_NG' => 'fúla (adlam, Nígería)',
+        'ff_Adlm_SL' => 'fúla (adlam, Síerra Leóne)',
+        'ff_Adlm_SN' => 'fúla (adlam, Senegal)',
         'ff_CM' => 'fúla (Kamerún)',
         'ff_GN' => 'fúla (Gínea)',
         'ff_Latn' => 'fúla (latneskt)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindí (arabískt, Pakistan)',
         'sd_Deva' => 'sindí (devanagari)',
         'sd_Deva_IN' => 'sindí (devanagari, Indland)',
+        'sd_IN' => 'sindí (Indland)',
         'sd_PK' => 'sindí (Pakistan)',
         'se' => 'norðursamíska',
         'se_FI' => 'norðursamíska (Finnland)',
