@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'ceceno (Russia)',
         'cs' => 'ceco',
         'cs_CZ' => 'ceco (Cechia)',
+        'cv' => 'ciuvascio',
+        'cv_RU' => 'ciuvascio (Russia)',
         'cy' => 'gallese',
         'cy_GB' => 'gallese (Regno Unito)',
         'da' => 'danese',
@@ -184,7 +186,7 @@ return [
         'en_SL' => 'inglese (Sierra Leone)',
         'en_SS' => 'inglese (Sud Sudan)',
         'en_SX' => 'inglese (Sint Maarten)',
-        'en_SZ' => 'inglese (Swaziland)',
+        'en_SZ' => 'inglese (eSwatini)',
         'en_TC' => 'inglese (Isole Turks e Caicos)',
         'en_TK' => 'inglese (Tokelau)',
         'en_TO' => 'inglese (Tonga)',
@@ -192,7 +194,7 @@ return [
         'en_TV' => 'inglese (Tuvalu)',
         'en_TZ' => 'inglese (Tanzania)',
         'en_UG' => 'inglese (Uganda)',
-        'en_UM' => 'inglese (Altre isole americane del Pacifico)',
+        'en_UM' => 'inglese (Isole Minori Esterne degli Stati Uniti)',
         'en_US' => 'inglese (Stati Uniti)',
         'en_VC' => 'inglese (Saint Vincent e Grenadine)',
         'en_VG' => 'inglese (Isole Vergini Britanniche)',
@@ -222,7 +224,7 @@ return [
         'es_HN' => 'spagnolo (Honduras)',
         'es_MX' => 'spagnolo (Messico)',
         'es_NI' => 'spagnolo (Nicaragua)',
-        'es_PA' => 'spagnolo (Panamá)',
+        'es_PA' => 'spagnolo (Panama)',
         'es_PE' => 'spagnolo (Perù)',
         'es_PH' => 'spagnolo (Filippine)',
         'es_PR' => 'spagnolo (Portorico)',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'persiano (Afghanistan)',
         'fa_IR' => 'persiano (Iran)',
         'ff' => 'fulah',
+        'ff_Adlm' => 'fulah (adlam)',
+        'ff_Adlm_BF' => 'fulah (adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fulah (adlam, Camerun)',
+        'ff_Adlm_GH' => 'fulah (adlam, Ghana)',
+        'ff_Adlm_GM' => 'fulah (adlam, Gambia)',
+        'ff_Adlm_GN' => 'fulah (adlam, Guinea)',
+        'ff_Adlm_GW' => 'fulah (adlam, Guinea-Bissau)',
+        'ff_Adlm_LR' => 'fulah (adlam, Liberia)',
+        'ff_Adlm_MR' => 'fulah (adlam, Mauritania)',
+        'ff_Adlm_NE' => 'fulah (adlam, Niger)',
+        'ff_Adlm_NG' => 'fulah (adlam, Nigeria)',
+        'ff_Adlm_SL' => 'fulah (adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'fulah (adlam, Senegal)',
         'ff_CM' => 'fulah (Camerun)',
         'ff_GN' => 'fulah (Guinea)',
         'ff_Latn' => 'fulah (latino)',
@@ -278,7 +293,7 @@ return [
         'fr_DZ' => 'francese (Algeria)',
         'fr_FR' => 'francese (Francia)',
         'fr_GA' => 'francese (Gabon)',
-        'fr_GF' => 'francese (Guyana francese)',
+        'fr_GF' => 'francese (Guyana Francese)',
         'fr_GN' => 'francese (Guinea)',
         'fr_GP' => 'francese (Guadalupa)',
         'fr_GQ' => 'francese (Guinea Equatoriale)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arabo, Pakistan)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, India)',
+        'sd_IN' => 'sindhi (India)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'sami del nord',
         'se_FI' => 'sami del nord (Finlandia)',
@@ -563,8 +579,8 @@ return [
         'te_IN' => 'telugu (India)',
         'tg' => 'tagico',
         'tg_TJ' => 'tagico (Tagikistan)',
-        'th' => 'thai',
-        'th_TH' => 'thai (Thailandia)',
+        'th' => 'thailandese',
+        'th_TH' => 'thailandese (Thailandia)',
         'ti' => 'tigrino',
         'ti_ER' => 'tigrino (Eritrea)',
         'ti_ET' => 'tigrino (Etiopia)',
