@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'チェチェン語 (ロシア)',
         'cs' => 'チェコ語',
         'cs_CZ' => 'チェコ語 (チェコ)',
+        'cv' => 'チュヴァシ語',
+        'cv_RU' => 'チュヴァシ語 (ロシア)',
         'cy' => 'ウェールズ語',
         'cy_GB' => 'ウェールズ語 (イギリス)',
         'da' => 'デンマーク語',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'ペルシア語 (アフガニスタン)',
         'fa_IR' => 'ペルシア語 (イラン)',
         'ff' => 'フラ語',
+        'ff_Adlm' => 'フラ語 (アドラム文字)',
+        'ff_Adlm_BF' => 'フラ語 (アドラム文字、ブルキナファソ)',
+        'ff_Adlm_CM' => 'フラ語 (アドラム文字、カメルーン)',
+        'ff_Adlm_GH' => 'フラ語 (アドラム文字、ガーナ)',
+        'ff_Adlm_GM' => 'フラ語 (アドラム文字、ガンビア)',
+        'ff_Adlm_GN' => 'フラ語 (アドラム文字、ギニア)',
+        'ff_Adlm_GW' => 'フラ語 (アドラム文字、ギニアビサウ)',
+        'ff_Adlm_LR' => 'フラ語 (アドラム文字、リベリア)',
+        'ff_Adlm_MR' => 'フラ語 (アドラム文字、モーリタニア)',
+        'ff_Adlm_NE' => 'フラ語 (アドラム文字、ニジェール)',
+        'ff_Adlm_NG' => 'フラ語 (アドラム文字、ナイジェリア)',
+        'ff_Adlm_SL' => 'フラ語 (アドラム文字、シエラレオネ)',
+        'ff_Adlm_SN' => 'フラ語 (アドラム文字、セネガル)',
         'ff_CM' => 'フラ語 (カメルーン)',
         'ff_GN' => 'フラ語 (ギニア)',
         'ff_Latn' => 'フラ語 (ラテン文字)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'シンド語 (アラビア文字、パキスタン)',
         'sd_Deva' => 'シンド語 (デーバナーガリー文字)',
         'sd_Deva_IN' => 'シンド語 (デーバナーガリー文字、インド)',
+        'sd_IN' => 'シンド語 (インド)',
         'sd_PK' => 'シンド語 (パキスタン)',
         'se' => '北サーミ語',
         'se_FI' => '北サーミ語 (フィンランド)',
