@@ -4,13 +4,13 @@ return [
     'Names' => [
         'af' => 'африкаанс тілі',
         'af_NA' => 'африкаанс тілі (Намибия)',
-        'af_ZA' => 'африкаанс тілі (Оңтүстік Африка Республикасы)',
+        'af_ZA' => 'африкаанс тілі (Оңтүстік Африка)',
         'ak' => 'акан тілі',
         'ak_GH' => 'акан тілі (Гана)',
         'am' => 'амхар тілі',
         'am_ET' => 'амхар тілі (Эфиопия)',
         'ar' => 'араб тілі',
-        'ar_001' => 'араб тілі (Әлем)',
+        'ar_001' => 'араб тілі (әлем)',
         'ar_AE' => 'араб тілі (Біріккен Араб Әмірліктері)',
         'ar_BH' => 'араб тілі (Бахрейн)',
         'ar_DJ' => 'араб тілі (Джибути)',
@@ -75,13 +75,15 @@ return [
         'ce_RU' => 'шешен тілі (Ресей)',
         'cs' => 'чех тілі',
         'cs_CZ' => 'чех тілі (Чехия)',
+        'cv' => 'чуваш тілі',
+        'cv_RU' => 'чуваш тілі (Ресей)',
         'cy' => 'валлий тілі',
         'cy_GB' => 'валлий тілі (Ұлыбритания)',
         'da' => 'дат тілі',
         'da_DK' => 'дат тілі (Дания)',
         'da_GL' => 'дат тілі (Гренландия)',
         'de' => 'неміс тілі',
-        'de_AT' => 'неміс тілі (Австрия)',
+        'de_AT' => 'неміс тілі (Аустрия)',
         'de_BE' => 'неміс тілі (Бельгия)',
         'de_CH' => 'неміс тілі (Швейцария)',
         'de_DE' => 'неміс тілі (Германия)',
@@ -97,14 +99,14 @@ return [
         'el_CY' => 'грек тілі (Кипр)',
         'el_GR' => 'грек тілі (Грекия)',
         'en' => 'ағылшын тілі',
-        'en_001' => 'ағылшын тілі (Әлем)',
+        'en_001' => 'ағылшын тілі (әлем)',
         'en_150' => 'ағылшын тілі (Еуропа)',
         'en_AE' => 'ағылшын тілі (Біріккен Араб Әмірліктері)',
         'en_AG' => 'ағылшын тілі (Антигуа және Барбуда)',
         'en_AI' => 'ағылшын тілі (Ангилья)',
         'en_AS' => 'ағылшын тілі (Америкалық Самоа)',
-        'en_AT' => 'ағылшын тілі (Австрия)',
-        'en_AU' => 'ағылшын тілі (Австралия)',
+        'en_AT' => 'ағылшын тілі (Аустрия)',
+        'en_AU' => 'ағылшын тілі (Аустралия)',
         'en_BB' => 'ағылшын тілі (Барбадос)',
         'en_BE' => 'ағылшын тілі (Бельгия)',
         'en_BI' => 'ағылшын тілі (Бурунди)',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'ағылшын тілі (Монтсеррат)',
         'en_MT' => 'ағылшын тілі (Мальта)',
         'en_MU' => 'ағылшын тілі (Маврикий)',
+        'en_MV' => 'ағылшын тілі (Мальдив аралдары)',
         'en_MW' => 'ағылшын тілі (Малави)',
         'en_MY' => 'ағылшын тілі (Малайзия)',
         'en_NA' => 'ағылшын тілі (Намибия)',
@@ -183,7 +186,7 @@ return [
         'en_SL' => 'ағылшын тілі (Сьерра-Леоне)',
         'en_SS' => 'ағылшын тілі (Оңтүстік Судан)',
         'en_SX' => 'ағылшын тілі (Синт-Мартен)',
-        'en_SZ' => 'ағылшын тілі (Свазиленд)',
+        'en_SZ' => 'ағылшын тілі (Эсватини)',
         'en_TC' => 'ағылшын тілі (Теркс және Кайкос аралдары)',
         'en_TK' => 'ағылшын тілі (Токелау)',
         'en_TO' => 'ағылшын тілі (Тонга)',
@@ -198,11 +201,11 @@ return [
         'en_VI' => 'ағылшын тілі (АҚШ-тың Виргин аралдары)',
         'en_VU' => 'ағылшын тілі (Вануату)',
         'en_WS' => 'ағылшын тілі (Самоа)',
-        'en_ZA' => 'ағылшын тілі (Оңтүстік Африка Республикасы)',
+        'en_ZA' => 'ағылшын тілі (Оңтүстік Африка)',
         'en_ZM' => 'ағылшын тілі (Замбия)',
         'en_ZW' => 'ағылшын тілі (Зимбабве)',
         'eo' => 'эсперанто тілі',
-        'eo_001' => 'эсперанто тілі (Әлем)',
+        'eo_001' => 'эсперанто тілі (әлем)',
         'es' => 'испан тілі',
         'es_419' => 'испан тілі (Латын Америкасы)',
         'es_AR' => 'испан тілі (Аргентина)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'парсы тілі (Ауғанстан)',
         'fa_IR' => 'парсы тілі (Иран)',
         'ff' => 'фула тілі',
+        'ff_Adlm' => 'фула тілі (адлам жазуы)',
+        'ff_Adlm_BF' => 'фула тілі (адлам жазуы, Буркина-Фасо)',
+        'ff_Adlm_CM' => 'фула тілі (адлам жазуы, Камерун)',
+        'ff_Adlm_GH' => 'фула тілі (адлам жазуы, Гана)',
+        'ff_Adlm_GM' => 'фула тілі (адлам жазуы, Гамбия)',
+        'ff_Adlm_GN' => 'фула тілі (адлам жазуы, Гвинея)',
+        'ff_Adlm_GW' => 'фула тілі (адлам жазуы, Гвинея-Бисау)',
+        'ff_Adlm_LR' => 'фула тілі (адлам жазуы, Либерия)',
+        'ff_Adlm_MR' => 'фула тілі (адлам жазуы, Мавритания)',
+        'ff_Adlm_NE' => 'фула тілі (адлам жазуы, Нигер)',
+        'ff_Adlm_NG' => 'фула тілі (адлам жазуы, Нигерия)',
+        'ff_Adlm_SL' => 'фула тілі (адлам жазуы, Сьерра-Леоне)',
+        'ff_Adlm_SN' => 'фула тілі (адлам жазуы, Сенегал)',
         'ff_CM' => 'фула тілі (Камерун)',
         'ff_GN' => 'фула тілі (Гвинея)',
         'ff_Latn' => 'фула тілі (латын жазуы)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'иврит тілі (Израиль)',
         'hi' => 'хинди тілі',
         'hi_IN' => 'хинди тілі (Үндістан)',
+        'hi_Latn' => 'хинди тілі (латын жазуы)',
+        'hi_Latn_IN' => 'хинди тілі (латын жазуы, Үндістан)',
         'hr' => 'хорват тілі',
         'hr_BA' => 'хорват тілі (Босния және Герцеговина)',
         'hr_HR' => 'хорват тілі (Хорватия)',
@@ -336,7 +354,7 @@ return [
         'hy' => 'армян тілі',
         'hy_AM' => 'армян тілі (Армения)',
         'ia' => 'интерлингва тілі',
-        'ia_001' => 'интерлингва тілі (Әлем)',
+        'ia_001' => 'интерлингва тілі (әлем)',
         'id' => 'индонезия тілі',
         'id_ID' => 'индонезия тілі (Индонезия)',
         'ig' => 'игбо тілі',
@@ -372,6 +390,8 @@ return [
         'ks' => 'кашмир тілі',
         'ks_Arab' => 'кашмир тілі (араб жазуы)',
         'ks_Arab_IN' => 'кашмир тілі (араб жазуы, Үндістан)',
+        'ks_Deva' => 'кашмир тілі (деванагари жазуы)',
+        'ks_Deva_IN' => 'кашмир тілі (деванагари жазуы, Үндістан)',
         'ks_IN' => 'кашмир тілі (Үндістан)',
         'ku' => 'күрд тілі',
         'ku_TR' => 'күрд тілі (Түркия)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'синдхи тілі (араб жазуы, Пәкістан)',
         'sd_Deva' => 'синдхи тілі (деванагари жазуы)',
         'sd_Deva_IN' => 'синдхи тілі (деванагари жазуы, Үндістан)',
+        'sd_IN' => 'синдхи тілі (Үндістан)',
         'sd_PK' => 'синдхи тілі (Пәкістан)',
         'se' => 'солтүстік саам тілі',
         'se_FI' => 'солтүстік саам тілі (Финляндия)',
@@ -593,28 +614,28 @@ return [
         'wo' => 'волоф тілі',
         'wo_SN' => 'волоф тілі (Сенегал)',
         'xh' => 'кхоса тілі',
-        'xh_ZA' => 'кхоса тілі (Оңтүстік Африка Республикасы)',
+        'xh_ZA' => 'кхоса тілі (Оңтүстік Африка)',
         'yi' => 'идиш тілі',
-        'yi_001' => 'идиш тілі (Әлем)',
+        'yi_001' => 'идиш тілі (әлем)',
         'yo' => 'йоруба тілі',
         'yo_BJ' => 'йоруба тілі (Бенин)',
         'yo_NG' => 'йоруба тілі (Нигерия)',
         'zh' => 'қытай тілі',
         'zh_CN' => 'қытай тілі (Қытай)',
         'zh_HK' => 'қытай тілі (Сянган АӘА)',
-        'zh_Hans' => 'қытай тілі (жеңілдетілген қытай иероглифы)',
-        'zh_Hans_CN' => 'қытай тілі (жеңілдетілген қытай иероглифы, Қытай)',
-        'zh_Hans_HK' => 'қытай тілі (жеңілдетілген қытай иероглифы, Сянган АӘА)',
-        'zh_Hans_MO' => 'қытай тілі (жеңілдетілген қытай иероглифы, Макао АӘА)',
-        'zh_Hans_SG' => 'қытай тілі (жеңілдетілген қытай иероглифы, Сингапур)',
-        'zh_Hant' => 'қытай тілі (дәстүрлі қытай иероглифы)',
-        'zh_Hant_HK' => 'қытай тілі (дәстүрлі қытай иероглифы, Сянган АӘА)',
-        'zh_Hant_MO' => 'қытай тілі (дәстүрлі қытай иероглифы, Макао АӘА)',
-        'zh_Hant_TW' => 'қытай тілі (дәстүрлі қытай иероглифы, Тайвань)',
+        'zh_Hans' => 'қытай тілі (жеңілдетілген жазу)',
+        'zh_Hans_CN' => 'қытай тілі (жеңілдетілген жазу, Қытай)',
+        'zh_Hans_HK' => 'қытай тілі (жеңілдетілген жазу, Сянган АӘА)',
+        'zh_Hans_MO' => 'қытай тілі (жеңілдетілген жазу, Макао АӘА)',
+        'zh_Hans_SG' => 'қытай тілі (жеңілдетілген жазу, Сингапур)',
+        'zh_Hant' => 'қытай тілі (дәстүрлі жазу)',
+        'zh_Hant_HK' => 'қытай тілі (дәстүрлі жазу, Сянган АӘА)',
+        'zh_Hant_MO' => 'қытай тілі (дәстүрлі жазу, Макао АӘА)',
+        'zh_Hant_TW' => 'қытай тілі (дәстүрлі жазу, Тайвань)',
         'zh_MO' => 'қытай тілі (Макао АӘА)',
         'zh_SG' => 'қытай тілі (Сингапур)',
         'zh_TW' => 'қытай тілі (Тайвань)',
         'zu' => 'зулу тілі',
-        'zu_ZA' => 'зулу тілі (Оңтүстік Африка Республикасы)',
+        'zu_ZA' => 'зулу тілі (Оңтүстік Африка)',
     ],
 ];
