@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'ಚಚೆನ್ (ರಷ್ಯಾ)',
         'cs' => 'ಜೆಕ್',
         'cs_CZ' => 'ಜೆಕ್ (ಝೆಕಿಯಾ)',
+        'cv' => 'ಚುವಾಶ್',
+        'cv_RU' => 'ಚುವಾಶ್ (ರಷ್ಯಾ)',
         'cy' => 'ವೆಲ್ಶ್',
         'cy_GB' => 'ವೆಲ್ಶ್ (ಯುನೈಟೆಡ್ ಕಿಂಗ್‌ಡಮ್)',
         'da' => 'ಡ್ಯಾನಿಶ್',
@@ -184,7 +186,7 @@ return [
         'en_SL' => 'ಇಂಗ್ಲಿಷ್ (ಸಿಯೆರ್ರಾ ಲಿಯೋನ್)',
         'en_SS' => 'ಇಂಗ್ಲಿಷ್ (ದಕ್ಷಿಣ ಸುಡಾನ್)',
         'en_SX' => 'ಇಂಗ್ಲಿಷ್ (ಸಿಂಟ್ ಮಾರ್ಟೆನ್)',
-        'en_SZ' => 'ಇಂಗ್ಲಿಷ್ (ಸ್ವಾತಿನಿ)',
+        'en_SZ' => 'ಇಂಗ್ಲಿಷ್ (ಎಸ್ವಾಟಿನಿ)',
         'en_TC' => 'ಇಂಗ್ಲಿಷ್ (ಟರ್ಕ್ಸ್ ಮತ್ತು ಕೈಕೋಸ್ ದ್ವೀಪಗಳು)',
         'en_TK' => 'ಇಂಗ್ಲಿಷ್ (ಟೊಕೆಲಾವ್)',
         'en_TO' => 'ಇಂಗ್ಲಿಷ್ (ಟೊಂಗಾ)',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'ಪರ್ಶಿಯನ್ (ಅಫಘಾನಿಸ್ಥಾನ)',
         'fa_IR' => 'ಪರ್ಶಿಯನ್ (ಇರಾನ್)',
         'ff' => 'ಫುಲಾ',
+        'ff_Adlm' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್)',
+        'ff_Adlm_BF' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಬುರ್ಕಿನಾ ಫಾಸೊ)',
+        'ff_Adlm_CM' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಕ್ಯಾಮರೂನ್)',
+        'ff_Adlm_GH' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಘಾನಾ)',
+        'ff_Adlm_GM' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಗ್ಯಾಂಬಿಯಾ)',
+        'ff_Adlm_GN' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಗಿನಿ)',
+        'ff_Adlm_GW' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಗಿನಿ-ಬಿಸ್ಸಾವ್)',
+        'ff_Adlm_LR' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಲಿಬೇರಿಯಾ)',
+        'ff_Adlm_MR' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಮಾರಿಟೇನಿಯಾ)',
+        'ff_Adlm_NE' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ನೈಜರ್)',
+        'ff_Adlm_NG' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ನೈಜೀರಿಯಾ)',
+        'ff_Adlm_SL' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಸಿಯೆರ್ರಾ ಲಿಯೋನ್)',
+        'ff_Adlm_SN' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಸೆನೆಗಲ್)',
         'ff_CM' => 'ಫುಲಾ (ಕ್ಯಾಮರೂನ್)',
         'ff_GN' => 'ಫುಲಾ (ಗಿನಿ)',
         'ff_Latn' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್)',
@@ -474,7 +489,7 @@ return [
         'pt_MZ' => 'ಪೋರ್ಚುಗೀಸ್ (ಮೊಜಾಂಬಿಕ್)',
         'pt_PT' => 'ಪೋರ್ಚುಗೀಸ್ (ಪೋರ್ಚುಗಲ್)',
         'pt_ST' => 'ಪೋರ್ಚುಗೀಸ್ (ಸಾವೋ ಟೋಮ್ ಮತ್ತು ಪ್ರಿನ್ಸಿಪಿ)',
-        'pt_TL' => 'ಪೋರ್ಚುಗೀಸ್ (ಪೂರ್ವ ತಿಮೋರ್)',
+        'pt_TL' => 'ಪೋರ್ಚುಗೀಸ್ (ಟಿಮೋರ್ ಲೆಸ್ಟೆ)',
         'qu' => 'ಕ್ವೆಚುವಾ',
         'qu_BO' => 'ಕ್ವೆಚುವಾ (ಬೊಲಿವಿಯಾ)',
         'qu_EC' => 'ಕ್ವೆಚುವಾ (ಈಕ್ವೆಡಾರ್)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'ಸಿಂಧಿ (ಅರೇಬಿಕ್, ಪಾಕಿಸ್ತಾನ)',
         'sd_Deva' => 'ಸಿಂಧಿ (ದೇವನಾಗರಿ)',
         'sd_Deva_IN' => 'ಸಿಂಧಿ (ದೇವನಾಗರಿ, ಭಾರತ)',
+        'sd_IN' => 'ಸಿಂಧಿ (ಭಾರತ)',
         'sd_PK' => 'ಸಿಂಧಿ (ಪಾಕಿಸ್ತಾನ)',
         'se' => 'ಉತ್ತರ ಸಾಮಿ',
         'se_FI' => 'ಉತ್ತರ ಸಾಮಿ (ಫಿನ್‌ಲ್ಯಾಂಡ್)',
