@@ -75,6 +75,8 @@ return [
         'ce_RU' => '체첸어(러시아)',
         'cs' => '체코어',
         'cs_CZ' => '체코어(체코)',
+        'cv' => '추바시어',
+        'cv_RU' => '추바시어(러시아)',
         'cy' => '웨일스어',
         'cy_GB' => '웨일스어(영국)',
         'da' => '덴마크어',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => '페르시아어(아프가니스탄)',
         'fa_IR' => '페르시아어(이란)',
         'ff' => '풀라어',
+        'ff_Adlm' => '풀라어(아들람 문자)',
+        'ff_Adlm_BF' => '풀라어(아들람 문자, 부르키나파소)',
+        'ff_Adlm_CM' => '풀라어(아들람 문자, 카메룬)',
+        'ff_Adlm_GH' => '풀라어(아들람 문자, 가나)',
+        'ff_Adlm_GM' => '풀라어(아들람 문자, 감비아)',
+        'ff_Adlm_GN' => '풀라어(아들람 문자, 기니)',
+        'ff_Adlm_GW' => '풀라어(아들람 문자, 기니비사우)',
+        'ff_Adlm_LR' => '풀라어(아들람 문자, 라이베리아)',
+        'ff_Adlm_MR' => '풀라어(아들람 문자, 모리타니)',
+        'ff_Adlm_NE' => '풀라어(아들람 문자, 니제르)',
+        'ff_Adlm_NG' => '풀라어(아들람 문자, 나이지리아)',
+        'ff_Adlm_SL' => '풀라어(아들람 문자, 시에라리온)',
+        'ff_Adlm_SN' => '풀라어(아들람 문자, 세네갈)',
         'ff_CM' => '풀라어(카메룬)',
         'ff_GN' => '풀라어(기니)',
         'ff_Latn' => '풀라어(로마자)',
@@ -379,7 +394,7 @@ return [
         'ks_Deva_IN' => '카슈미르어(데바나가리 문자, 인도)',
         'ks_IN' => '카슈미르어(인도)',
         'ku' => '쿠르드어',
-        'ku_TR' => '쿠르드어(터키)',
+        'ku_TR' => '쿠르드어(튀르키예)',
         'kw' => '콘월어',
         'kw_GB' => '콘월어(영국)',
         'ky' => '키르기스어',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => '신디어(아랍 문자, 파키스탄)',
         'sd_Deva' => '신디어(데바나가리 문자)',
         'sd_Deva_IN' => '신디어(데바나가리 문자, 인도)',
+        'sd_IN' => '신디어(인도)',
         'sd_PK' => '신디어(파키스탄)',
         'se' => '북부 사미어',
         'se_FI' => '북부 사미어(핀란드)',
@@ -576,7 +592,7 @@ return [
         'to_TO' => '통가어(통가)',
         'tr' => '터키어',
         'tr_CY' => '터키어(키프로스)',
-        'tr_TR' => '터키어(터키)',
+        'tr_TR' => '터키어(튀르키예)',
         'tt' => '타타르어',
         'tt_RU' => '타타르어(러시아)',
         'ug' => '위구르어',
