@@ -4,7 +4,7 @@ return [
     'Names' => [
         'af' => 'اَفریٖکانز',
         'af_NA' => 'اَفریٖکانز (نامِبِیا)',
-        'af_ZA' => 'اَفریٖکانز (جَنوٗبی اَفریٖکا)',
+        'af_ZA' => 'اَفریٖکانز (جنوبی افریقہ)',
         'ak' => 'اَکان',
         'ak_GH' => 'اَکان (گانا)',
         'am' => 'اَمہاری',
@@ -15,11 +15,12 @@ return [
         'ar_BH' => 'عربی (بحریٖن)',
         'ar_DJ' => 'عربی (جِبوٗتی)',
         'ar_DZ' => 'عربی (اؠلجیرِیا)',
-        'ar_EG' => 'عربی (مِسٔر)',
+        'ar_EG' => 'عربی (مصر)',
         'ar_EH' => 'عربی (مشرِقی سَہارا)',
         'ar_ER' => 'عربی (اِرٕٹِیا)',
-        'ar_IL' => 'عربی (اِسرایٖل)',
+        'ar_IL' => 'عربی (اسرا ییل)',
         'ar_IQ' => 'عربی (ایٖراق)',
+        'ar_JO' => 'عربی (جورڈن)',
         'ar_KM' => 'عربی (کَمورَس)',
         'ar_KW' => 'عربی (کُویت)',
         'ar_LB' => 'عربی (لؠبنان)',
@@ -27,11 +28,12 @@ return [
         'ar_MA' => 'عربی (موروکو)',
         'ar_MR' => 'عربی (مارٕٹانِیا)',
         'ar_OM' => 'عربی (اومان)',
-        'ar_PS' => 'عربی (فَلَستیٖن)',
+        'ar_PS' => 'عربی (فلسطینی علاقٕہ)',
         'ar_QA' => 'عربی (قَطِر)',
-        'ar_SA' => 'عربی (سوٗدی عربِیہ)',
+        'ar_SA' => 'عربی (سعودی عرب)',
         'ar_SD' => 'عربی (سوٗڈان)',
         'ar_SO' => 'عربی (سومالِیا)',
+        'ar_SS' => 'عربی (جنوبی سوڈان)',
         'ar_SY' => 'عربی (شام)',
         'ar_TD' => 'عربی (چاڑ)',
         'ar_TN' => 'عربی (ٹونیشِیا)',
@@ -39,11 +41,11 @@ return [
         'as' => 'اسٲمۍ',
         'as_IN' => 'اسٲمۍ (ہِندوستان)',
         'az' => 'اَزَربیجانی',
-        'az_AZ' => 'اَزَربیجانی (آزَرباجان)',
+        'az_AZ' => 'اَزَربیجانی (آذربائیجان)',
         'az_Cyrl' => 'اَزَربیجانی (سَیرِلِک)',
-        'az_Cyrl_AZ' => 'اَزَربیجانی (سَیرِلِک, آزَرباجان)',
+        'az_Cyrl_AZ' => 'اَزَربیجانی (سَیرِلِک, آذربائیجان)',
         'az_Latn' => 'اَزَربیجانی (لاطیٖنی)',
-        'az_Latn_AZ' => 'اَزَربیجانی (لاطیٖنی, آزَرباجان)',
+        'az_Latn_AZ' => 'اَزَربیجانی (لاطیٖنی, آذربائیجان)',
         'be' => 'بیلَروٗشیَن',
         'be_BY' => 'بیلَروٗشیَن (بیلاروٗس)',
         'bg' => 'بینا',
@@ -65,21 +67,23 @@ return [
         'bs_Latn' => 'بوسنِیَن (لاطیٖنی)',
         'bs_Latn_BA' => 'بوسنِیَن (لاطیٖنی, بوسنِیا تہٕ ہَرزِگووِنا)',
         'ca' => 'کَتلان',
-        'ca_AD' => 'کَتلان (اؠنڑورا)',
+        'ca_AD' => 'کَتلان (اینڈورا)',
         'ca_ES' => 'کَتلان (سٕپین)',
         'ca_FR' => 'کَتلان (فرانس)',
         'ca_IT' => 'کَتلان (اِٹلی)',
         'ce' => 'چیچَن',
         'ce_RU' => 'چیچَن (روٗس)',
         'cs' => 'چیک',
-        'cs_CZ' => 'چیک (چیک جَموٗرِیَت)',
+        'cs_CZ' => 'چیک (چیکیا)',
+        'cv' => 'چُواش',
+        'cv_RU' => 'چُواش (روٗس)',
         'cy' => 'ویلش',
-        'cy_GB' => 'ویلش (یُنایٹِڑ کِنگڈَم)',
+        'cy_GB' => 'ویلش (متحدہ مملِکت)',
         'da' => 'ڈینِش',
         'da_DK' => 'ڈینِش (ڈینمارٕک)',
-        'da_GL' => 'ڈینِش (گریٖنلینڑ)',
+        'da_GL' => 'ڈینِش (گرین لینڈ)',
         'de' => 'جٔرمَن',
-        'de_AT' => 'جٔرمَن (آسٹِیا)',
+        'de_AT' => 'جٔرمَن (آسٹریا)',
         'de_BE' => 'جٔرمَن (بیلجِیَم)',
         'de_CH' => 'جٔرمَن (سُوِزَرلینڑ)',
         'de_DE' => 'جٔرمَن (جرمٔنی)',
@@ -92,7 +96,7 @@ return [
         'ee_GH' => 'ایٖو (گانا)',
         'ee_TG' => 'ایٖو (ٹوگو)',
         'el' => 'یوٗنٲنی',
-        'el_CY' => 'یوٗنٲنی (سایفرس)',
+        'el_CY' => 'یوٗنٲنی (سائپرس)',
         'el_GR' => 'یوٗنٲنی (گریٖس)',
         'en' => 'اَنگیٖزۍ',
         'en_001' => 'اَنگیٖزۍ (دُنیا)',
@@ -101,32 +105,33 @@ return [
         'en_AG' => 'اَنگیٖزۍ (اؠنٹِگُوا تہٕ باربوڑا)',
         'en_AI' => 'اَنگیٖزۍ (انگوئیلا)',
         'en_AS' => 'اَنگیٖزۍ (اَمریٖکَن سَموا)',
-        'en_AT' => 'اَنگیٖزۍ (آسٹِیا)',
+        'en_AT' => 'اَنگیٖزۍ (آسٹریا)',
         'en_AU' => 'اَنگیٖزۍ (آسٹریلِیا)',
-        'en_BB' => 'اَنگیٖزۍ (باربیڈاس)',
+        'en_BB' => 'اَنگیٖزۍ (باربیڈوس)',
         'en_BE' => 'اَنگیٖزۍ (بیلجِیَم)',
         'en_BI' => 'اَنگیٖزۍ (بورَنڈِ)',
-        'en_BM' => 'اَنگیٖزۍ (بٔرمیوڈا)',
+        'en_BM' => 'اَنگیٖزۍ (برمودا)',
         'en_BS' => 'اَنگیٖزۍ (بَہامَس)',
         'en_BW' => 'اَنگیٖزۍ (بوتَسوانا)',
-        'en_BZ' => 'اَنگیٖزۍ (بیلِج)',
-        'en_CA' => 'اَنگیٖزۍ (کینَڑا)',
-        'en_CC' => 'اَنگیٖزۍ (کوکَس کیٖلِنگ جٔزیٖرٕ)',
+        'en_BZ' => 'اَنگیٖزۍ (بیلز)',
+        'en_CA' => 'اَنگیٖزۍ (کینیڈا)',
+        'en_CC' => 'اَنگیٖزۍ (کوکَس [کیٖلِنگ] جٔزیٖرٕ)',
         'en_CH' => 'اَنگیٖزۍ (سُوِزَرلینڑ)',
         'en_CK' => 'اَنگیٖزۍ (کُک جٔزیٖرٕ)',
         'en_CM' => 'اَنگیٖزۍ (کیمِروٗن)',
         'en_CX' => 'اَنگیٖزۍ (کرِسمَس جٔزیٖرٕ)',
-        'en_CY' => 'اَنگیٖزۍ (سایفرس)',
+        'en_CY' => 'اَنگیٖزۍ (سائپرس)',
         'en_DE' => 'اَنگیٖزۍ (جرمٔنی)',
         'en_DK' => 'اَنگیٖزۍ (ڈینمارٕک)',
         'en_DM' => 'اَنگیٖزۍ (ڈومِنِکا)',
         'en_ER' => 'اَنگیٖزۍ (اِرٕٹِیا)',
-        'en_FI' => 'اَنگیٖزۍ (فِنلینڑ)',
+        'en_FI' => 'اَنگیٖزۍ (فِن لینڈ)',
         'en_FJ' => 'اَنگیٖزۍ (فِجی)',
         'en_FK' => 'اَنگیٖزۍ (فٕلاکلینڑ جٔزیٖرٕ)',
-        'en_GB' => 'اَنگیٖزۍ (یُنایٹِڑ کِنگڈَم)',
-        'en_GD' => 'اَنگیٖزۍ (گرنیڑا)',
-        'en_GG' => 'اَنگیٖزۍ (گیوَنَرسے)',
+        'en_FM' => 'اَنگیٖزۍ (مائیکرونیشیا)',
+        'en_GB' => 'اَنگیٖزۍ (متحدہ مملِکت)',
+        'en_GD' => 'اَنگیٖزۍ (گرینیڈا)',
+        'en_GG' => 'اَنگیٖزۍ (گورنسے)',
         'en_GH' => 'اَنگیٖزۍ (گانا)',
         'en_GI' => 'اَنگیٖزۍ (جِبرالٹَر)',
         'en_GM' => 'اَنگیٖزۍ (گَمبِیا)',
@@ -134,7 +139,7 @@ return [
         'en_GY' => 'اَنگیٖزۍ (گُیانا)',
         'en_HK' => 'اَنگیٖزۍ (ہانگ کانگ ایس اے آر چیٖن)',
         'en_IE' => 'اَنگیٖزۍ (اَیَرلینڑ)',
-        'en_IL' => 'اَنگیٖزۍ (اِسرایٖل)',
+        'en_IL' => 'اَنگیٖزۍ (اسرا ییل)',
         'en_IM' => 'اَنگیٖزۍ (آیِل آف مین)',
         'en_IN' => 'اَنگیٖزۍ (ہِندوستان)',
         'en_IO' => 'اَنگیٖزۍ (برطانوی بحرِ ہِندۍ علاقہٕ)',
@@ -147,7 +152,7 @@ return [
         'en_LC' => 'اَنگیٖزۍ (سینٹ لوٗسِیا)',
         'en_LR' => 'اَنگیٖزۍ (لایبیرِیا)',
         'en_LS' => 'اَنگیٖزۍ (لیسوتھو)',
-        'en_MG' => 'اَنگیٖزۍ (میڑاگاسکار)',
+        'en_MG' => 'اَنگیٖزۍ (میڈاگاسکار)',
         'en_MH' => 'اَنگیٖزۍ (مارشَل جٔزیٖرٕ)',
         'en_MO' => 'اَنگیٖزۍ (مَکاوو ایس اے آر چیٖن)',
         'en_MP' => 'اَنگیٖزۍ (شُمٲلی مارِیانا جٔزیٖرٕ)',
@@ -163,9 +168,9 @@ return [
         'en_NL' => 'اَنگیٖزۍ (نیٖدَرلینڑ)',
         'en_NR' => 'اَنگیٖزۍ (نارووٗ)',
         'en_NU' => 'اَنگیٖزۍ (نیوٗ)',
-        'en_NZ' => 'اَنگیٖزۍ (نیوٗزِلینڑ)',
+        'en_NZ' => 'اَنگیٖزۍ (نیوزی لینڈ)',
         'en_PG' => 'اَنگیٖزۍ (پاپُوا نیوٗ گیٖنی)',
-        'en_PH' => 'اَنگیٖزۍ (فِلِپِینس)',
+        'en_PH' => 'اَنگیٖزۍ (فلپائن)',
         'en_PK' => 'اَنگیٖزۍ (پاکِستان)',
         'en_PN' => 'اَنگیٖزۍ (پِٹکیرٕنۍ جٔزیٖرٕ)',
         'en_PR' => 'اَنگیٖزۍ (پٔرٹو رِکو)',
@@ -174,14 +179,16 @@ return [
         'en_SB' => 'اَنگیٖزۍ (سولامان جٔزیٖرٕ)',
         'en_SC' => 'اَنگیٖزۍ (سیشَلِس)',
         'en_SD' => 'اَنگیٖزۍ (سوٗڈان)',
-        'en_SE' => 'اَنگیٖزۍ (سُوِڈَن)',
+        'en_SE' => 'اَنگیٖزۍ (سویڈن)',
         'en_SG' => 'اَنگیٖزۍ (سِنگاپوٗر)',
         'en_SH' => 'اَنگیٖزۍ (سینٹ ہؠلِنا)',
         'en_SI' => 'اَنگیٖزۍ (سَلووینِیا)',
-        'en_SL' => 'اَنگیٖزۍ (سیٖرالیوون)',
-        'en_SZ' => 'اَنگیٖزۍ (سُوزِلینڑ)',
-        'en_TC' => 'اَنگیٖزۍ (تُرُک تہٕ کیکوس جٔزیٖرٕ)',
-        'en_TK' => 'اَنگیٖزۍ (توکیلاو)',
+        'en_SL' => 'اَنگیٖزۍ (سیرا لیون)',
+        'en_SS' => 'اَنگیٖزۍ (جنوبی سوڈان)',
+        'en_SX' => 'اَنگیٖزۍ (سِنٹ مارٹِن)',
+        'en_SZ' => 'اَنگیٖزۍ (ایسواتنی)',
+        'en_TC' => 'اَنگیٖزۍ (تُرکس تٕہ کیکو جزیرٕ)',
+        'en_TK' => 'اَنگیٖزۍ (ٹوکلو)',
         'en_TO' => 'اَنگیٖزۍ (ٹونگا)',
         'en_TT' => 'اَنگیٖزۍ (ٹرنِنداد تہٕ ٹوبیگو)',
         'en_TV' => 'اَنگیٖزۍ (توٗوالوٗ)',
@@ -193,36 +200,36 @@ return [
         'en_VG' => 'اَنگیٖزۍ (بَرطانوی ؤرجِن جٔزیٖرٕ)',
         'en_VI' => 'اَنگیٖزۍ (یوٗ ایس ؤرجِن جٔزیٖرٕ)',
         'en_VU' => 'اَنگیٖزۍ (وانوٗتوٗ)',
-        'en_WS' => 'اَنگیٖزۍ (سیمووا)',
-        'en_ZA' => 'اَنگیٖزۍ (جَنوٗبی اَفریٖکا)',
-        'en_ZM' => 'اَنگیٖزۍ (جامبِیا)',
+        'en_WS' => 'اَنگیٖزۍ (سامو)',
+        'en_ZA' => 'اَنگیٖزۍ (جنوبی افریقہ)',
+        'en_ZM' => 'اَنگیٖزۍ (زیمبیا)',
         'en_ZW' => 'اَنگیٖزۍ (زِمبابے)',
         'eo' => 'ایسپَرینٹو',
         'eo_001' => 'ایسپَرینٹو (دُنیا)',
         'es' => 'ہسپانوی',
-        'es_419' => 'ہسپانوی (لاطیٖنی اَمریٖکا تہٕ کیرَبیٖن)',
+        'es_419' => 'ہسپانوی (لاطیٖنی اَمریٖکا)',
         'es_AR' => 'ہسپانوی (أرجَنٹینا)',
         'es_BO' => 'ہسپانوی (بولِوِیا)',
         'es_BR' => 'ہسپانوی (برازِل)',
-        'es_BZ' => 'ہسپانوی (بیلِج)',
+        'es_BZ' => 'ہسپانوی (بیلز)',
         'es_CL' => 'ہسپانوی (چِلی)',
         'es_CO' => 'ہسپانوی (کولَمبِیا)',
-        'es_CR' => 'ہسپانوی (کوسٹا رِکا)',
+        'es_CR' => 'ہسپانوی (کوسٹا ریکا)',
         'es_CU' => 'ہسپانوی (کیوٗبا)',
         'es_DO' => 'ہسپانوی (ڈومِنِکَن جموٗرِیَت)',
         'es_EC' => 'ہسپانوی (اِکواڑور)',
         'es_ES' => 'ہسپانوی (سٕپین)',
         'es_GQ' => 'ہسپانوی (اِکوِٹورِیَل گِنی)',
-        'es_GT' => 'ہسپانوی (گوتیدالا)',
-        'es_HN' => 'ہسپانوی (ہانڈوٗرِس)',
+        'es_GT' => 'ہسپانوی (گواٹمالا)',
+        'es_HN' => 'ہسپانوی (ہونڈورس)',
         'es_MX' => 'ہسپانوی (مؠکسِکو)',
         'es_NI' => 'ہسپانوی (ناکاراگُوا)',
         'es_PA' => 'ہسپانوی (پَناما)',
         'es_PE' => 'ہسپانوی (پیٖروٗ)',
-        'es_PH' => 'ہسپانوی (فِلِپِینس)',
+        'es_PH' => 'ہسپانوی (فلپائن)',
         'es_PR' => 'ہسپانوی (پٔرٹو رِکو)',
         'es_PY' => 'ہسپانوی (پَراگُے)',
-        'es_SV' => 'ہسپانوی (اؠل سَلواڑور)',
+        'es_SV' => 'ہسپانوی (ایل سلویڈر)',
         'es_US' => 'ہسپانوی (یوٗنایٹِڑ سِٹیٹِس)',
         'es_UY' => 'ہسپانوی (یوٗروگے)',
         'es_VE' => 'ہسپانوی (وینازوٗلا)',
@@ -247,26 +254,27 @@ return [
         'ff_Latn_MR' => 'فُلاہ (لاطیٖنی, مارٕٹانِیا)',
         'ff_Latn_NE' => 'فُلاہ (لاطیٖنی, نایجَر)',
         'ff_Latn_NG' => 'فُلاہ (لاطیٖنی, نایجیرِیا)',
-        'ff_Latn_SL' => 'فُلاہ (لاطیٖنی, سیٖرالیوون)',
+        'ff_Latn_SL' => 'فُلاہ (لاطیٖنی, سیرا لیون)',
         'ff_Latn_SN' => 'فُلاہ (لاطیٖنی, سینیگَل)',
         'ff_MR' => 'فُلاہ (مارٕٹانِیا)',
         'ff_SN' => 'فُلاہ (سینیگَل)',
         'fi' => 'فِنِش',
-        'fi_FI' => 'فِنِش (فِنلینڑ)',
+        'fi_FI' => 'فِنِش (فِن لینڈ)',
         'fo' => 'فَروس',
         'fo_DK' => 'فَروس (ڈینمارٕک)',
+        'fo_FO' => 'فَروس (فارو جزیرہ)',
         'fr' => 'فرانسیسی',
         'fr_BE' => 'فرانسیسی (بیلجِیَم)',
         'fr_BF' => 'فرانسیسی (بُرکِنا فیسو)',
         'fr_BI' => 'فرانسیسی (بورَنڈِ)',
         'fr_BJ' => 'فرانسیسی (بِنِن)',
         'fr_BL' => 'فرانسیسی (سینٹ بارتَھیلمی)',
-        'fr_CA' => 'فرانسیسی (کینَڑا)',
+        'fr_CA' => 'فرانسیسی (کینیڈا)',
         'fr_CD' => 'فرانسیسی (کونگو کِنشاسا)',
         'fr_CF' => 'فرانسیسی (مرکٔزی اَفریٖکی جموٗریَت)',
         'fr_CG' => 'فرانسیسی (کونگو بٔرزاوِلی)',
         'fr_CH' => 'فرانسیسی (سُوِزَرلینڑ)',
-        'fr_CI' => 'فرانسیسی (اَیوٕری کوسٹ)',
+        'fr_CI' => 'فرانسیسی (کوٹ ڈلوائر)',
         'fr_CM' => 'فرانسیسی (کیمِروٗن)',
         'fr_DJ' => 'فرانسیسی (جِبوٗتی)',
         'fr_DZ' => 'فرانسیسی (اؠلجیرِیا)',
@@ -274,15 +282,15 @@ return [
         'fr_GA' => 'فرانسیسی (گیبان)',
         'fr_GF' => 'فرانسیسی (فرانسِسی گِانا)',
         'fr_GN' => 'فرانسیسی (گِنی)',
-        'fr_GP' => 'فرانسیسی (گَواڑیلوپ)',
+        'fr_GP' => 'فرانسیسی (گواڈلوپ)',
         'fr_GQ' => 'فرانسیسی (اِکوِٹورِیَل گِنی)',
-        'fr_HT' => 'فرانسیسی (ہایتی)',
+        'fr_HT' => 'فرانسیسی (ہیتی)',
         'fr_KM' => 'فرانسیسی (کَمورَس)',
         'fr_LU' => 'فرانسیسی (لَکسَمبٔرٕگ)',
         'fr_MA' => 'فرانسیسی (موروکو)',
         'fr_MC' => 'فرانسیسی (مونیکو)',
         'fr_MF' => 'فرانسیسی (سینٹ مارٹِن)',
-        'fr_MG' => 'فرانسیسی (میڑاگاسکار)',
+        'fr_MG' => 'فرانسیسی (میڈاگاسکار)',
         'fr_ML' => 'فرانسیسی (مالی)',
         'fr_MQ' => 'فرانسیسی (مارٹِنِک)',
         'fr_MR' => 'فرانسیسی (مارٕٹانِیا)',
@@ -305,10 +313,10 @@ return [
         'fy' => 'مغربی فرِشیَن',
         'fy_NL' => 'مغربی فرِشیَن (نیٖدَرلینڑ)',
         'ga' => 'اَیرِش',
-        'ga_GB' => 'اَیرِش (یُنایٹِڑ کِنگڈَم)',
+        'ga_GB' => 'اَیرِش (متحدہ مملِکت)',
         'ga_IE' => 'اَیرِش (اَیَرلینڑ)',
         'gd' => 'سکوٹِش گیےلِک',
-        'gd_GB' => 'سکوٹِش گیےلِک (یُنایٹِڑ کِنگڈَم)',
+        'gd_GB' => 'سکوٹِش گیےلِک (متحدہ مملِکت)',
         'gl' => 'گیلِشِیَن',
         'gl_ES' => 'گیلِشِیَن (سٕپین)',
         'gu' => 'گُجرٲتی',
@@ -320,7 +328,7 @@ return [
         'ha_NE' => 'ہاوسا (نایجَر)',
         'ha_NG' => 'ہاوسا (نایجیرِیا)',
         'he' => 'عبرٲنۍ',
-        'he_IL' => 'عبرٲنۍ (اِسرایٖل)',
+        'he_IL' => 'عبرٲنۍ (اسرا ییل)',
         'hi' => 'ہِندی',
         'hi_IN' => 'ہِندی (ہِندوستان)',
         'hi_Latn' => 'ہِندی (لاطیٖنی)',
@@ -335,7 +343,7 @@ return [
         'ia' => 'اِنٹَرلِنگوا',
         'ia_001' => 'اِنٹَرلِنگوا (دُنیا)',
         'id' => 'اِنڈونیشیا',
-        'id_ID' => 'اِنڈونیشیا (اِنڑونیشِیا)',
+        'id_ID' => 'اِنڈونیشیا (انڈونیشیا)',
         'ig' => 'اِگبو',
         'ig_NG' => 'اِگبو (نایجیرِیا)',
         'ii' => 'سِچوان یٖی',
@@ -350,15 +358,15 @@ return [
         'ja' => 'جاپٲنۍ',
         'ja_JP' => 'جاپٲنۍ (جاپان)',
         'jv' => 'جَوَنیٖز',
-        'jv_ID' => 'جَوَنیٖز (اِنڑونیشِیا)',
+        'jv_ID' => 'جَوَنیٖز (انڈونیشیا)',
         'ka' => 'جارجِیَن',
         'ka_GE' => 'جارجِیَن (جارجِیا)',
         'ki' => 'کِکُیوٗ',
         'ki_KE' => 'کِکُیوٗ (کِنیا)',
         'kk' => 'کازَخ',
-        'kk_KZ' => 'کازَخ (کَزاکِستان)',
+        'kk_KZ' => 'کازَخ (قازقستان)',
         'kl' => 'کَلالِسُت',
-        'kl_GL' => 'کَلالِسُت (گریٖنلینڑ)',
+        'kl_GL' => 'کَلالِسُت (گرین لینڈ)',
         'km' => 'خَمیر',
         'km_KH' => 'خَمیر (کَمبوڑِیا)',
         'kn' => 'کَنَڑ',
@@ -367,17 +375,17 @@ return [
         'ko_KP' => 'کوریَن (شُمٲلی کورِیا)',
         'ko_KR' => 'کوریَن (جنوٗبی کورِیا)',
         'ks' => 'کٲشُر',
-        'ks_Arab' => 'کٲشُر (اَربی)',
-        'ks_Arab_IN' => 'کٲشُر (اَربی, ہِندوستان)',
+        'ks_Arab' => 'کٲشُر (عربی)',
+        'ks_Arab_IN' => 'کٲشُر (عربی, ہِندوستان)',
         'ks_Deva' => 'کٲشُر (دیوناگری)',
         'ks_Deva_IN' => 'کٲشُر (دیوناگری, ہِندوستان)',
         'ks_IN' => 'کٲشُر (ہِندوستان)',
         'ku' => 'کُردِش',
         'ku_TR' => 'کُردِش (تُرکی)',
         'kw' => 'کورنِش',
-        'kw_GB' => 'کورنِش (یُنایٹِڑ کِنگڈَم)',
+        'kw_GB' => 'کورنِش (متحدہ مملِکت)',
         'ky' => 'کِرگِز',
-        'ky_KG' => 'کِرگِز (کِرگِستان)',
+        'ky_KG' => 'کِرگِز (کرغزستان)',
         'lb' => 'لُکھزیمبورگِش',
         'lb_LU' => 'لُکھزیمبورگِش (لَکسَمبٔرٕگ)',
         'lg' => 'گاندا',
@@ -396,10 +404,11 @@ return [
         'lv' => 'لَتوِیَن',
         'lv_LV' => 'لَتوِیَن (لیٹوِیا)',
         'mg' => 'مَلاگَسی',
-        'mg_MG' => 'مَلاگَسی (میڑاگاسکار)',
+        'mg_MG' => 'مَلاگَسی (میڈاگاسکار)',
         'mi' => 'ماوری',
-        'mi_NZ' => 'ماوری (نیوٗزِلینڑ)',
+        'mi_NZ' => 'ماوری (نیوزی لینڈ)',
         'mk' => 'میکَڈونیَن',
+        'mk_MK' => 'میکَڈونیَن (شُمالی میسڈونیا)',
         'ml' => 'مٔلیالَم',
         'ml_IN' => 'مٔلیالَم (ہِندوستان)',
         'mn' => 'مَنگولی',
@@ -407,14 +416,14 @@ return [
         'mr' => 'مَرٲٹھۍ',
         'mr_IN' => 'مَرٲٹھۍ (ہِندوستان)',
         'ms' => 'مَلَے',
-        'ms_BN' => 'مَلَے (بُرنٔے)',
-        'ms_ID' => 'مَلَے (اِنڑونیشِیا)',
+        'ms_BN' => 'مَلَے (برونے)',
+        'ms_ID' => 'مَلَے (انڈونیشیا)',
         'ms_MY' => 'مَلَے (مَلیشِیا)',
         'ms_SG' => 'مَلَے (سِنگاپوٗر)',
         'mt' => 'مَلتیٖس',
         'mt_MT' => 'مَلتیٖس (مالٹا)',
         'my' => 'بٔمیٖز',
-        'my_MM' => 'بٔمیٖز (مَیَنما بٔرما)',
+        'my_MM' => 'بٔمیٖز (میانمار [برما])',
         'nb' => 'ناروییَن بوکمال',
         'nb_NO' => 'ناروییَن بوکمال (ناروے)',
         'nb_SJ' => 'ناروییَن بوکمال (سَوالبریڑ تہٕ جان ماییڑ)',
@@ -426,9 +435,11 @@ return [
         'nl' => 'ڈَچ',
         'nl_AW' => 'ڈَچ (اَروٗبا)',
         'nl_BE' => 'ڈَچ (بیلجِیَم)',
-        'nl_BQ' => 'ڈَچ (برطانوی قُطبہِ جَنوٗبی علاقہٕ)',
+        'nl_BQ' => 'ڈَچ (کیریبین نیدرلینڈس)',
+        'nl_CW' => 'ڈَچ (کیوراکو)',
         'nl_NL' => 'ڈَچ (نیٖدَرلینڑ)',
         'nl_SR' => 'ڈَچ (سُرِنام)',
+        'nl_SX' => 'ڈَچ (سِنٹ مارٹِن)',
         'nn' => 'ناروییَن نَے نورسک',
         'nn_NO' => 'ناروییَن نَے نورسک (ناروے)',
         'no' => 'ناروییَن',
@@ -442,14 +453,14 @@ return [
         'os_GE' => 'اۆسیٹِک (جارجِیا)',
         'os_RU' => 'اۆسیٹِک (روٗس)',
         'pa' => 'پَنجٲبۍ',
-        'pa_Arab' => 'پَنجٲبۍ (اَربی)',
-        'pa_Arab_PK' => 'پَنجٲبۍ (اَربی, پاکِستان)',
+        'pa_Arab' => 'پَنجٲبۍ (عربی)',
+        'pa_Arab_PK' => 'پَنجٲبۍ (عربی, پاکِستان)',
         'pa_Guru' => 'پَنجٲبۍ (گُجرٲتۍ)',
         'pa_Guru_IN' => 'پَنجٲبۍ (گُجرٲتۍ, ہِندوستان)',
         'pa_IN' => 'پَنجٲبۍ (ہِندوستان)',
         'pa_PK' => 'پَنجٲبۍ (پاکِستان)',
         'pl' => 'پالِش',
-        'pl_PL' => 'پالِش (پولینڑ)',
+        'pl_PL' => 'پالِش (پولینڈ)',
         'ps' => 'پَشتوٗ',
         'ps_AF' => 'پَشتوٗ (اَفغانَستان)',
         'ps_PK' => 'پَشتوٗ (پاکِستان)',
@@ -465,7 +476,7 @@ return [
         'pt_MZ' => 'پُرتَگیٖز (موزَمبِک)',
         'pt_PT' => 'پُرتَگیٖز (پُرتِگال)',
         'pt_ST' => 'پُرتَگیٖز (ساو توم تہٕ پرنسِپی)',
-        'pt_TL' => 'پُرتَگیٖز (مَشرِقی تایمور)',
+        'pt_TL' => 'پُرتَگیٖز (تیمور-لیسٹ)',
         'qu' => 'کُویشُوا',
         'qu_BO' => 'کُویشُوا (بولِوِیا)',
         'qu_EC' => 'کُویشُوا (اِکواڑور)',
@@ -475,13 +486,13 @@ return [
         'rn' => 'رُندی',
         'rn_BI' => 'رُندی (بورَنڈِ)',
         'ro' => 'رومٲنی',
-        'ro_MD' => 'رومٲنی (مولڑاوِیا)',
+        'ro_MD' => 'رومٲنی (مولڈووا)',
         'ro_RO' => 'رومٲنی (رومانِیا)',
         'ru' => 'روٗسی',
         'ru_BY' => 'روٗسی (بیلاروٗس)',
-        'ru_KG' => 'روٗسی (کِرگِستان)',
-        'ru_KZ' => 'روٗسی (کَزاکِستان)',
-        'ru_MD' => 'روٗسی (مولڑاوِیا)',
+        'ru_KG' => 'روٗسی (کرغزستان)',
+        'ru_KZ' => 'روٗسی (قازقستان)',
+        'ru_MD' => 'روٗسی (مولڈووا)',
         'ru_RU' => 'روٗسی (روٗس)',
         'ru_UA' => 'روٗسی (یوٗرِکین)',
         'rw' => 'کِنیاوِندا',
@@ -491,21 +502,22 @@ return [
         'sc' => 'سراڈیٖنی',
         'sc_IT' => 'سراڈیٖنی (اِٹلی)',
         'sd' => 'سِندی',
-        'sd_Arab' => 'سِندی (اَربی)',
-        'sd_Arab_PK' => 'سِندی (اَربی, پاکِستان)',
+        'sd_Arab' => 'سِندی (عربی)',
+        'sd_Arab_PK' => 'سِندی (عربی, پاکِستان)',
         'sd_Deva' => 'سِندی (دیوناگری)',
         'sd_Deva_IN' => 'سِندی (دیوناگری, ہِندوستان)',
+        'sd_IN' => 'سِندی (ہِندوستان)',
         'sd_PK' => 'سِندی (پاکِستان)',
         'se' => 'شُمٲلی سَمی',
-        'se_FI' => 'شُمٲلی سَمی (فِنلینڑ)',
+        'se_FI' => 'شُمٲلی سَمی (فِن لینڈ)',
         'se_NO' => 'شُمٲلی سَمی (ناروے)',
-        'se_SE' => 'شُمٲلی سَمی (سُوِڈَن)',
+        'se_SE' => 'شُمٲلی سَمی (سویڈن)',
         'sg' => 'سَنگو',
         'sg_CF' => 'سَنگو (مرکٔزی اَفریٖکی جموٗریَت)',
         'sh' => 'سیربو کروشِیَن',
         'sh_BA' => 'سیربو کروشِیَن (بوسنِیا تہٕ ہَرزِگووِنا)',
         'si' => 'سِنہالا',
-        'si_LK' => 'سِنہالا (سِریٖلَنکا)',
+        'si_LK' => 'سِنہالا (سری لنکا)',
         'sk' => 'سلووَک',
         'sk_SK' => 'سلووَک (سَلوواکِیا)',
         'sl' => 'سلووینیَن',
@@ -518,7 +530,8 @@ return [
         'so_KE' => 'سومٲلی (کِنیا)',
         'so_SO' => 'سومٲلی (سومالِیا)',
         'sq' => 'البانِیَن',
-        'sq_AL' => 'البانِیَن (اؠلبانِیا)',
+        'sq_AL' => 'البانِیَن (البانیا)',
+        'sq_MK' => 'البانِیَن (شُمالی میسڈونیا)',
         'sr' => 'سٔربِیَن',
         'sr_BA' => 'سٔربِیَن (بوسنِیا تہٕ ہَرزِگووِنا)',
         'sr_Cyrl' => 'سٔربِیَن (سَیرِلِک)',
@@ -532,13 +545,13 @@ return [
         'sr_ME' => 'سٔربِیَن (موٹونیگِریو)',
         'sr_RS' => 'سٔربِیَن (سَربِیا)',
         'su' => 'سَنڈَنیٖز',
-        'su_ID' => 'سَنڈَنیٖز (اِنڑونیشِیا)',
+        'su_ID' => 'سَنڈَنیٖز (انڈونیشیا)',
         'su_Latn' => 'سَنڈَنیٖز (لاطیٖنی)',
-        'su_Latn_ID' => 'سَنڈَنیٖز (لاطیٖنی, اِنڑونیشِیا)',
+        'su_Latn_ID' => 'سَنڈَنیٖز (لاطیٖنی, انڈونیشیا)',
         'sv' => 'سویٖڈِش',
         'sv_AX' => 'سویٖڈِش (ایلینڑ جٔزیٖرٕ)',
-        'sv_FI' => 'سویٖڈِش (فِنلینڑ)',
-        'sv_SE' => 'سویٖڈِش (سُوِڈَن)',
+        'sv_FI' => 'سویٖڈِش (فِن لینڈ)',
+        'sv_SE' => 'سویٖڈِش (سویڈن)',
         'sw' => 'سواہِلی',
         'sw_CD' => 'سواہِلی (کونگو کِنشاسا)',
         'sw_KE' => 'سواہِلی (کِنیا)',
@@ -546,7 +559,7 @@ return [
         'sw_UG' => 'سواہِلی (یوٗگانڑا)',
         'ta' => 'تَمِل',
         'ta_IN' => 'تَمِل (ہِندوستان)',
-        'ta_LK' => 'تَمِل (سِریٖلَنکا)',
+        'ta_LK' => 'تَمِل (سری لنکا)',
         'ta_MY' => 'تَمِل (مَلیشِیا)',
         'ta_SG' => 'تَمِل (سِنگاپوٗر)',
         'te' => 'تیلگوٗ',
@@ -554,18 +567,18 @@ return [
         'tg' => 'تاجِک',
         'tg_TJ' => 'تاجِک (تاجکِستان)',
         'th' => 'تھاے',
-        'th_TH' => 'تھاے (تھایلینڑ)',
+        'th_TH' => 'تھاے (تھائی لینڈ)',
         'ti' => 'ٹِگرِنیا',
         'ti_ER' => 'ٹِگرِنیا (اِرٕٹِیا)',
         'ti_ET' => 'ٹِگرِنیا (اِتھوپِیا)',
         'tk' => 'تُرکمین',
-        'tk_TM' => 'تُرکمین (تُرمِنِستان)',
+        'tk_TM' => 'تُرکمین (تُرکمنستان)',
         'tl' => 'تَماشیک',
-        'tl_PH' => 'تَماشیک (فِلِپِینس)',
+        'tl_PH' => 'تَماشیک (فلپائن)',
         'to' => 'ٹونگا',
         'to_TO' => 'ٹونگا (ٹونگا)',
         'tr' => 'تُرکِش',
-        'tr_CY' => 'تُرکِش (سایفرس)',
+        'tr_CY' => 'تُرکِش (سائپرس)',
         'tr_TR' => 'تُرکِش (تُرکی)',
         'tt' => 'تَتار',
         'tt_RU' => 'تَتار (روٗس)',
@@ -576,19 +589,19 @@ return [
         'ur_PK' => 'اُردوٗ (پاکِستان)',
         'uz' => 'اُزبیک',
         'uz_AF' => 'اُزبیک (اَفغانَستان)',
-        'uz_Arab' => 'اُزبیک (اَربی)',
-        'uz_Arab_AF' => 'اُزبیک (اَربی, اَفغانَستان)',
+        'uz_Arab' => 'اُزبیک (عربی)',
+        'uz_Arab_AF' => 'اُزبیک (عربی, اَفغانَستان)',
         'uz_Cyrl' => 'اُزبیک (سَیرِلِک)',
         'uz_Cyrl_UZ' => 'اُزبیک (سَیرِلِک, اُزبِکِستان)',
         'uz_Latn' => 'اُزبیک (لاطیٖنی)',
         'uz_Latn_UZ' => 'اُزبیک (لاطیٖنی, اُزبِکِستان)',
         'uz_UZ' => 'اُزبیک (اُزبِکِستان)',
         'vi' => 'وِیَتنَمیٖز',
-        'vi_VN' => 'وِیَتنَمیٖز (ویٹِنام)',
+        'vi_VN' => 'وِیَتنَمیٖز (ویتنام)',
         'wo' => 'وولوف',
         'wo_SN' => 'وولوف (سینیگَل)',
         'xh' => 'کھوسا',
-        'xh_ZA' => 'کھوسا (جَنوٗبی اَفریٖکا)',
+        'xh_ZA' => 'کھوسا (جنوبی افریقہ)',
         'yi' => 'یِدِش',
         'yi_001' => 'یِدِش (دُنیا)',
         'yo' => 'یورُبا',
@@ -610,6 +623,6 @@ return [
         'zh_SG' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (سِنگاپوٗر)',
         'zh_TW' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (تایوان)',
         'zu' => 'زُلوٗ',
-        'zu_ZA' => 'زُلوٗ (جَنوٗبی اَفریٖکا)',
+        'zu_ZA' => 'زُلوٗ (جنوبی افریقہ)',
     ],
 ];
