@@ -73,6 +73,8 @@ return [
         'ce_RU' => 'çeçenî (Rûsya)',
         'cs' => 'çekî',
         'cs_CZ' => 'çekî (Çekya)',
+        'cv' => 'çuvaşî',
+        'cv_RU' => 'çuvaşî (Rûsya)',
         'cy' => 'weylsî',
         'cy_GB' => 'weylsî (Keyaniya Yekbûyî)',
         'da' => 'danmarkî',
@@ -470,6 +472,7 @@ return [
         'sd_Arab_PK' => 'sindhî (erebî, Pakistan)',
         'sd_Deva' => 'sindhî (devanagarî)',
         'sd_Deva_IN' => 'sindhî (devanagarî, Hindistan)',
+        'sd_IN' => 'sindhî (Hindistan)',
         'sd_PK' => 'sindhî (Pakistan)',
         'se' => 'samiya bakur',
         'se_FI' => 'samiya bakur (Fînlenda)',
