@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'чеченче (Россия)',
         'cs' => 'чехче',
         'cs_CZ' => 'чехче (Чехия)',
+        'cv' => 'чувашча',
+        'cv_RU' => 'чувашча (Россия)',
         'cy' => 'уелшче',
         'cy_GB' => 'уелшче (Улуу Британия)',
         'da' => 'датча',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'англисче (Монтсеррат)',
         'en_MT' => 'англисче (Мальта)',
         'en_MU' => 'англисче (Маврикий)',
+        'en_MV' => 'англисче (Мальдив)',
         'en_MW' => 'англисче (Малави)',
         'en_MY' => 'англисче (Малайзия)',
         'en_NA' => 'англисче (Намибия)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'фарсча (Афганистан)',
         'fa_IR' => 'фарсча (Иран)',
         'ff' => 'фулача',
+        'ff_Adlm' => 'фулача (Адлам [жазуу])',
+        'ff_Adlm_BF' => 'фулача (Адлам [жазуу], Буркина-Фасо)',
+        'ff_Adlm_CM' => 'фулача (Адлам [жазуу], Камерун)',
+        'ff_Adlm_GH' => 'фулача (Адлам [жазуу], Гана)',
+        'ff_Adlm_GM' => 'фулача (Адлам [жазуу], Гамбия)',
+        'ff_Adlm_GN' => 'фулача (Адлам [жазуу], Гвинея)',
+        'ff_Adlm_GW' => 'фулача (Адлам [жазуу], Гвинея-Бисау)',
+        'ff_Adlm_LR' => 'фулача (Адлам [жазуу], Либерия)',
+        'ff_Adlm_MR' => 'фулача (Адлам [жазуу], Мавритания)',
+        'ff_Adlm_NE' => 'фулача (Адлам [жазуу], Нигер)',
+        'ff_Adlm_NG' => 'фулача (Адлам [жазуу], Нигерия)',
+        'ff_Adlm_SL' => 'фулача (Адлам [жазуу], Сьерра-Леоне)',
+        'ff_Adlm_SN' => 'фулача (Адлам [жазуу], Сенегал)',
         'ff_CM' => 'фулача (Камерун)',
         'ff_GN' => 'фулача (Гвинея)',
         'ff_Latn' => 'фулача (Латын)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'ивритче (Израиль)',
         'hi' => 'хиндиче',
         'hi_IN' => 'хиндиче (Индия)',
+        'hi_Latn' => 'хиндиче (Латын)',
+        'hi_Latn_IN' => 'хиндиче (Латын, Индия)',
         'hr' => 'хорватча',
         'hr_BA' => 'хорватча (Босния жана Герцеговина)',
         'hr_HR' => 'хорватча (Хорватия)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'кашмирче',
         'ks_Arab' => 'кашмирче (Араб)',
         'ks_Arab_IN' => 'кашмирче (Араб, Индия)',
+        'ks_Deva' => 'кашмирче (Деванагари)',
+        'ks_Deva_IN' => 'кашмирче (Деванагари, Индия)',
         'ks_IN' => 'кашмирче (Индия)',
         'ku' => 'курдча',
         'ku_TR' => 'курдча (Түркия)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'синдхиче (Араб, Пакистан)',
         'sd_Deva' => 'синдхиче (Деванагари)',
         'sd_Deva_IN' => 'синдхиче (Деванагари, Индия)',
+        'sd_IN' => 'синдхиче (Индия)',
         'sd_PK' => 'синдхиче (Пакистан)',
         'se' => 'түндүк саамиче',
         'se_FI' => 'түндүк саамиче (Финляндия)',
