@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Tschetschenesch (Russland)',
         'cs' => 'Tschechesch',
         'cs_CZ' => 'Tschechesch (Tschechien)',
+        'cv' => 'Tschuwaschesch',
+        'cv_RU' => 'Tschuwaschesch (Russland)',
         'cy' => 'Walisesch',
         'cy_GB' => 'Walisesch (Groussbritannien)',
         'da' => 'Dänesch',
@@ -504,6 +506,7 @@ return [
         'sd_Arab_PK' => 'Sindhi (Arabesch, Pakistan)',
         'sd_Deva' => 'Sindhi (Devanagari)',
         'sd_Deva_IN' => 'Sindhi (Devanagari, Indien)',
+        'sd_IN' => 'Sindhi (Indien)',
         'sd_PK' => 'Sindhi (Pakistan)',
         'se' => 'Nordsamesch',
         'se_FI' => 'Nordsamesch (Finnland)',
