@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'ຊີເຄນ (ຣັດເຊຍ)',
         'cs' => 'ເຊກ',
         'cs_CZ' => 'ເຊກ (ເຊັກເຊຍ)',
+        'cv' => 'ຊູວາຊ',
+        'cv_RU' => 'ຊູວາຊ (ຣັດເຊຍ)',
         'cy' => 'ເວວ',
         'cy_GB' => 'ເວວ (ສະຫະລາດຊະອະນາຈັກ)',
         'da' => 'ແດນິຊ',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'ອັງກິດ (ມອນເຊີຣາດ)',
         'en_MT' => 'ອັງກິດ (ມອນທາ)',
         'en_MU' => 'ອັງກິດ (ມົວຣິຊຽສ)',
+        'en_MV' => 'ອັງກິດ (ມັນດິຟ)',
         'en_MW' => 'ອັງກິດ (ມາລາວີ)',
         'en_MY' => 'ອັງກິດ (ມາເລເຊຍ)',
         'en_NA' => 'ອັງກິດ (ນາມີເບຍ)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'ເປີຊຽນ (ອາຟການິດສະຖານ)',
         'fa_IR' => 'ເປີຊຽນ (ອີຣານ)',
         'ff' => 'ຟູລາ',
+        'ff_Adlm' => 'ຟູລາ (ແອດລາມ)',
+        'ff_Adlm_BF' => 'ຟູລາ (ແອດລາມ, ເບີກິນາ ຟາໂຊ)',
+        'ff_Adlm_CM' => 'ຟູລາ (ແອດລາມ, ຄາເມຣູນ)',
+        'ff_Adlm_GH' => 'ຟູລາ (ແອດລາມ, ການາ)',
+        'ff_Adlm_GM' => 'ຟູລາ (ແອດລາມ, ສາທາລະນະລັດແກມເບຍ)',
+        'ff_Adlm_GN' => 'ຟູລາ (ແອດລາມ, ກິນີ)',
+        'ff_Adlm_GW' => 'ຟູລາ (ແອດລາມ, ກິນີ-ບິສເຊົາ)',
+        'ff_Adlm_LR' => 'ຟູລາ (ແອດລາມ, ລິເບີເຣຍ)',
+        'ff_Adlm_MR' => 'ຟູລາ (ແອດລາມ, ມົວຣິເທເນຍ)',
+        'ff_Adlm_NE' => 'ຟູລາ (ແອດລາມ, ນິເຈີ)',
+        'ff_Adlm_NG' => 'ຟູລາ (ແອດລາມ, ໄນຈີເຣຍ)',
+        'ff_Adlm_SL' => 'ຟູລາ (ແອດລາມ, ເຊຍຣາ ລີໂອນ)',
+        'ff_Adlm_SN' => 'ຟູລາ (ແອດລາມ, ເຊນີໂກລ)',
         'ff_CM' => 'ຟູລາ (ຄາເມຣູນ)',
         'ff_GN' => 'ຟູລາ (ກິນີ)',
         'ff_Latn' => 'ຟູລາ (ລາຕິນ)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'ຮີບຣິວ (ອິສຣາເອວ)',
         'hi' => 'ຮິນດິ',
         'hi_IN' => 'ຮິນດິ (ອິນເດຍ)',
+        'hi_Latn' => 'ຮິນດິ (ລາຕິນ)',
+        'hi_Latn_IN' => 'ຮິນດິ (ລາຕິນ, ອິນເດຍ)',
         'hr' => 'ໂຄຣເອທຽນ',
         'hr_BA' => 'ໂຄຣເອທຽນ (ບອດສະເນຍ ແລະ ແຮສໂກວີນາ)',
         'hr_HR' => 'ໂຄຣເອທຽນ (ໂຄຣເອເທຍ)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'ຄາສເມຍຣິ',
         'ks_Arab' => 'ຄາສເມຍຣິ (ອາຣາບິກ)',
         'ks_Arab_IN' => 'ຄາສເມຍຣິ (ອາຣາບິກ, ອິນເດຍ)',
+        'ks_Deva' => 'ຄາສເມຍຣິ (ດີວານາກາຣີ)',
+        'ks_Deva_IN' => 'ຄາສເມຍຣິ (ດີວານາກາຣີ, ອິນເດຍ)',
         'ks_IN' => 'ຄາສເມຍຣິ (ອິນເດຍ)',
         'ku' => 'ເຄີດິສ',
         'ku_TR' => 'ເຄີດິສ (ເທີຄີ)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'ສິນທິ (ອາຣາບິກ, ປາກິດສະຖານ)',
         'sd_Deva' => 'ສິນທິ (ດີວານາກາຣີ)',
         'sd_Deva_IN' => 'ສິນທິ (ດີວານາກາຣີ, ອິນເດຍ)',
+        'sd_IN' => 'ສິນທິ (ອິນເດຍ)',
         'sd_PK' => 'ສິນທິ (ປາກິດສະຖານ)',
         'se' => 'ຊາມິເໜືອ',
         'se_FI' => 'ຊາມິເໜືອ (ຟິນແລນ)',
