@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'čečenu (Krievija)',
         'cs' => 'čehu',
         'cs_CZ' => 'čehu (Čehija)',
+        'cv' => 'čuvašu',
+        'cv_RU' => 'čuvašu (Krievija)',
         'cy' => 'velsiešu',
         'cy_GB' => 'velsiešu (Apvienotā Karaliste)',
         'da' => 'dāņu',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'angļu (Montserrata)',
         'en_MT' => 'angļu (Malta)',
         'en_MU' => 'angļu (Maurīcija)',
+        'en_MV' => 'angļu (Maldīvija)',
         'en_MW' => 'angļu (Malāvija)',
         'en_MY' => 'angļu (Malaizija)',
         'en_NA' => 'angļu (Namībija)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'persiešu (Afganistāna)',
         'fa_IR' => 'persiešu (Irāna)',
         'ff' => 'fulu',
+        'ff_Adlm' => 'fulu (adlama)',
+        'ff_Adlm_BF' => 'fulu (adlama, Burkinafaso)',
+        'ff_Adlm_CM' => 'fulu (adlama, Kamerūna)',
+        'ff_Adlm_GH' => 'fulu (adlama, Gana)',
+        'ff_Adlm_GM' => 'fulu (adlama, Gambija)',
+        'ff_Adlm_GN' => 'fulu (adlama, Gvineja)',
+        'ff_Adlm_GW' => 'fulu (adlama, Gvineja-Bisava)',
+        'ff_Adlm_LR' => 'fulu (adlama, Libērija)',
+        'ff_Adlm_MR' => 'fulu (adlama, Mauritānija)',
+        'ff_Adlm_NE' => 'fulu (adlama, Nigēra)',
+        'ff_Adlm_NG' => 'fulu (adlama, Nigērija)',
+        'ff_Adlm_SL' => 'fulu (adlama, Sjerraleone)',
+        'ff_Adlm_SN' => 'fulu (adlama, Senegāla)',
         'ff_CM' => 'fulu (Kamerūna)',
         'ff_GN' => 'fulu (Gvineja)',
         'ff_Latn' => 'fulu (latīņu)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'ivrits (Izraēla)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (Indija)',
+        'hi_Latn' => 'hindi (latīņu)',
+        'hi_Latn_IN' => 'hindi (latīņu, Indija)',
         'hr' => 'horvātu',
         'hr_BA' => 'horvātu (Bosnija un Hercegovina)',
         'hr_HR' => 'horvātu (Horvātija)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kašmiriešu',
         'ks_Arab' => 'kašmiriešu (arābu)',
         'ks_Arab_IN' => 'kašmiriešu (arābu, Indija)',
+        'ks_Deva' => 'kašmiriešu (dēvanāgari)',
+        'ks_Deva_IN' => 'kašmiriešu (dēvanāgari, Indija)',
         'ks_IN' => 'kašmiriešu (Indija)',
         'ku' => 'kurdu',
         'ku_TR' => 'kurdu (Turcija)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhu (arābu, Pakistāna)',
         'sd_Deva' => 'sindhu (dēvanāgari)',
         'sd_Deva_IN' => 'sindhu (dēvanāgari, Indija)',
+        'sd_IN' => 'sindhu (Indija)',
         'sd_PK' => 'sindhu (Pakistāna)',
         'se' => 'ziemeļsāmu',
         'se_FI' => 'ziemeļsāmu (Somija)',
