@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'чеченски (Русија)',
         'cs' => 'чешки',
         'cs_CZ' => 'чешки (Чешка)',
+        'cv' => 'чувашки',
+        'cv_RU' => 'чувашки (Русија)',
         'cy' => 'велшки',
         'cy_GB' => 'велшки (Обединето Кралство)',
         'da' => 'дански',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'персиски (Авганистан)',
         'fa_IR' => 'персиски (Иран)',
         'ff' => 'фула',
+        'ff_Adlm' => 'фула (адламско)',
+        'ff_Adlm_BF' => 'фула (адламско, Буркина Фасо)',
+        'ff_Adlm_CM' => 'фула (адламско, Камерун)',
+        'ff_Adlm_GH' => 'фула (адламско, Гана)',
+        'ff_Adlm_GM' => 'фула (адламско, Гамбија)',
+        'ff_Adlm_GN' => 'фула (адламско, Гвинеја)',
+        'ff_Adlm_GW' => 'фула (адламско, Гвинеја Бисао)',
+        'ff_Adlm_LR' => 'фула (адламско, Либерија)',
+        'ff_Adlm_MR' => 'фула (адламско, Мавританија)',
+        'ff_Adlm_NE' => 'фула (адламско, Нигер)',
+        'ff_Adlm_NG' => 'фула (адламско, Нигерија)',
+        'ff_Adlm_SL' => 'фула (адламско, Сиера Леоне)',
+        'ff_Adlm_SN' => 'фула (адламско, Сенегал)',
         'ff_CM' => 'фула (Камерун)',
         'ff_GN' => 'фула (Гвинеја)',
         'ff_Latn' => 'фула (латинично писмо)',
@@ -297,7 +312,7 @@ return [
         'fr_NE' => 'француски (Нигер)',
         'fr_PF' => 'француски (Француска Полинезија)',
         'fr_PM' => 'француски (Сент Пјер и Микелан)',
-        'fr_RE' => 'француски (Реунион)',
+        'fr_RE' => 'француски (Рејунион)',
         'fr_RW' => 'француски (Руанда)',
         'fr_SC' => 'француски (Сејшели)',
         'fr_SN' => 'француски (Сенегал)',
@@ -466,7 +481,7 @@ return [
         'pt_AO' => 'португалски (Ангола)',
         'pt_BR' => 'португалски (Бразил)',
         'pt_CH' => 'португалски (Швајцарија)',
-        'pt_CV' => 'португалски (Зелен ’Рт)',
+        'pt_CV' => 'португалски (Кабо Верде)',
         'pt_GQ' => 'португалски (Екваторска Гвинеја)',
         'pt_GW' => 'португалски (Гвинеја Бисао)',
         'pt_LU' => 'португалски (Луксембург)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'синди (арапско писмо, Пакистан)',
         'sd_Deva' => 'синди (деванагари)',
         'sd_Deva_IN' => 'синди (деванагари, Индија)',
+        'sd_IN' => 'синди (Индија)',
         'sd_PK' => 'синди (Пакистан)',
         'se' => 'северен сами',
         'se_FI' => 'северен сами (Финска)',
