@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Chechen (Rusia)',
         'cs' => 'Czech',
         'cs_CZ' => 'Czech (Czechia)',
+        'cv' => 'Chuvash',
+        'cv_RU' => 'Chuvash (Rusia)',
         'cy' => 'Wales',
         'cy_GB' => 'Wales (United Kingdom)',
         'da' => 'Denmark',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'Inggeris (Montserrat)',
         'en_MT' => 'Inggeris (Malta)',
         'en_MU' => 'Inggeris (Mauritius)',
+        'en_MV' => 'Inggeris (Maldives)',
         'en_MW' => 'Inggeris (Malawi)',
         'en_MY' => 'Inggeris (Malaysia)',
         'en_NA' => 'Inggeris (Namibia)',
@@ -183,7 +186,7 @@ return [
         'en_SL' => 'Inggeris (Sierra Leone)',
         'en_SS' => 'Inggeris (Sudan Selatan)',
         'en_SX' => 'Inggeris (Sint Maarten)',
-        'en_SZ' => 'Inggeris (Swaziland)',
+        'en_SZ' => 'Inggeris (Eswatini)',
         'en_TC' => 'Inggeris (Kepulauan Turks dan Caicos)',
         'en_TK' => 'Inggeris (Tokelau)',
         'en_TO' => 'Inggeris (Tonga)',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'Ibrani (Israel)',
         'hi' => 'Hindi',
         'hi_IN' => 'Hindi (India)',
+        'hi_Latn' => 'Hindi (Latin)',
+        'hi_Latn_IN' => 'Hindi (Latin, India)',
         'hr' => 'Croatia',
         'hr_BA' => 'Croatia (Bosnia dan Herzegovina)',
         'hr_HR' => 'Croatia (Croatia)',
@@ -385,9 +390,11 @@ return [
         'ks' => 'Kashmir',
         'ks_Arab' => 'Kashmir (Arab)',
         'ks_Arab_IN' => 'Kashmir (Arab, India)',
+        'ks_Deva' => 'Kashmir (Devanagari)',
+        'ks_Deva_IN' => 'Kashmir (Devanagari, India)',
         'ks_IN' => 'Kashmir (India)',
         'ku' => 'Kurdish',
-        'ku_TR' => 'Kurdish (Turki)',
+        'ku_TR' => 'Kurdish (Turkiye)',
         'kw' => 'Cornish',
         'kw_GB' => 'Cornish (United Kingdom)',
         'ky' => 'Kirghiz',
@@ -430,9 +437,9 @@ return [
         'mt_MT' => 'Malta (Malta)',
         'my' => 'Burma',
         'my_MM' => 'Burma (Myanmar [Burma])',
-        'nb' => 'Bokmål Norway',
-        'nb_NO' => 'Bokmål Norway (Norway)',
-        'nb_SJ' => 'Bokmål Norway (Svalbard dan Jan Mayen)',
+        'nb' => 'Bokmal Norway',
+        'nb_NO' => 'Bokmal Norway (Norway)',
+        'nb_SJ' => 'Bokmal Norway (Svalbard dan Jan Mayen)',
         'nd' => 'Ndebele Utara',
         'nd_ZW' => 'Ndebele Utara (Zimbabwe)',
         'ne' => 'Nepal',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Sindhi (Arab, Pakistan)',
         'sd_Deva' => 'Sindhi (Devanagari)',
         'sd_Deva_IN' => 'Sindhi (Devanagari, India)',
+        'sd_IN' => 'Sindhi (India)',
         'sd_PK' => 'Sindhi (Pakistan)',
         'se' => 'Sami Utara',
         'se_FI' => 'Sami Utara (Finland)',
@@ -582,7 +590,7 @@ return [
         'to_TO' => 'Tonga (Tonga)',
         'tr' => 'Turki',
         'tr_CY' => 'Turki (Cyprus)',
-        'tr_TR' => 'Turki (Turki)',
+        'tr_TR' => 'Turki (Turkiye)',
         'tt' => 'Tatar',
         'tt_RU' => 'Tatar (Rusia)',
         'ug' => 'Uyghur',
