@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Chechen (ir-Russja)',
         'cs' => 'Ċek',
         'cs_CZ' => 'Ċek (ir-Repubblika Ċeka)',
+        'cv' => 'Chuvash',
+        'cv_RU' => 'Chuvash (ir-Russja)',
         'cy' => 'Welsh',
         'cy_GB' => 'Welsh (ir-Renju Unit)',
         'da' => 'Daniż',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'Ingliż (Montserrat)',
         'en_MT' => 'Ingliż (Malta)',
         'en_MU' => 'Ingliż (Mauritius)',
+        'en_MV' => 'Ingliż (il-Maldivi)',
         'en_MW' => 'Ingliż (il-Malawi)',
         'en_MY' => 'Ingliż (il-Malasja)',
         'en_NA' => 'Ingliż (in-Namibja)',
@@ -328,6 +331,8 @@ return [
         'he_IL' => 'Ebrajk (Iżrael)',
         'hi' => 'Hindi',
         'hi_IN' => 'Hindi (l-Indja)',
+        'hi_Latn' => 'Hindi (Latin)',
+        'hi_Latn_IN' => 'Hindi (Latin, l-Indja)',
         'hr' => 'Kroat',
         'hr_BA' => 'Kroat (il-Bożnija-Ħerzegovina)',
         'hr_HR' => 'Kroat (il-Kroazja)',
@@ -495,6 +500,7 @@ return [
         'sd' => 'Sindhi',
         'sd_Arab' => 'Sindhi (Għarbi)',
         'sd_Arab_PK' => 'Sindhi (Għarbi, il-Pakistan)',
+        'sd_IN' => 'Sindhi (l-Indja)',
         'sd_PK' => 'Sindhi (il-Pakistan)',
         'se' => 'Sami tat-Tramuntana',
         'se_FI' => 'Sami tat-Tramuntana (il-Finlandja)',
