@@ -2,9 +2,9 @@
 
 return [
     'Names' => [
-        'af' => 'တောင်အာဖရိက',
-        'af_NA' => 'တောင်အာဖရိက (နမီးဘီးယား)',
-        'af_ZA' => 'တောင်အာဖရိက (တောင်အာဖရိက)',
+        'af' => 'အာဖရိကန်',
+        'af_NA' => 'အာဖရိကန် (နမီးဘီးယား)',
+        'af_ZA' => 'အာဖရိကန် (တောင်အာဖရိက)',
         'ak' => 'အာကန်',
         'ak_GH' => 'အာကန် (ဂါနာ)',
         'am' => 'အမ်ဟာရစ်ခ်',
@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'ချက်ချန်း (ရုရှား)',
         'cs' => 'ချက်',
         'cs_CZ' => 'ချက် (ချက်ကီယား)',
+        'cv' => 'ချူဗက်ရှ်',
+        'cv_RU' => 'ချူဗက်ရှ် (ရုရှား)',
         'cy' => 'ဝေလ',
         'cy_GB' => 'ဝေလ (ယူနိုက်တက်ကင်းဒမ်း)',
         'da' => 'ဒိန်းမတ်',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'အင်္ဂလိပ် (မောင့်စဲရက်)',
         'en_MT' => 'အင်္ဂလိပ် (မောလ်တာ)',
         'en_MU' => 'အင်္ဂလိပ် (မောရစ်ရှ)',
+        'en_MV' => 'အင်္ဂလိပ် (မော်လ်ဒိုက်)',
         'en_MW' => 'အင်္ဂလိပ် (မာလာဝီ)',
         'en_MY' => 'အင်္ဂလိပ် (မလေးရှား)',
         'en_NA' => 'အင်္ဂလိပ် (နမီးဘီးယား)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'ပါရှန် (အာဖဂန်နစ္စတန်)',
         'fa_IR' => 'ပါရှန် (အီရန်)',
         'ff' => 'ဖူလာ',
+        'ff_Adlm' => 'ဖူလာ (အက်ဒ်လမ်)',
+        'ff_Adlm_BF' => 'ဖူလာ (အက်ဒ်လမ်/ ဘာကီးနား ဖားဆို)',
+        'ff_Adlm_CM' => 'ဖူလာ (အက်ဒ်လမ်/ ကင်မရွန်း)',
+        'ff_Adlm_GH' => 'ဖူလာ (အက်ဒ်လမ်/ ဂါနာ)',
+        'ff_Adlm_GM' => 'ဖူလာ (အက်ဒ်လမ်/ ဂမ်ဘီရာ)',
+        'ff_Adlm_GN' => 'ဖူလာ (အက်ဒ်လမ်/ ဂီနီ)',
+        'ff_Adlm_GW' => 'ဖူလာ (အက်ဒ်လမ်/ ဂီနီ-ဘီစော)',
+        'ff_Adlm_LR' => 'ဖူလာ (အက်ဒ်လမ်/ လိုက်ဘေးရီးယား)',
+        'ff_Adlm_MR' => 'ဖူလာ (အက်ဒ်လမ်/ မော်ရီတေးနီးယား)',
+        'ff_Adlm_NE' => 'ဖူလာ (အက်ဒ်လမ်/ နိုင်ဂျာ)',
+        'ff_Adlm_NG' => 'ဖူလာ (အက်ဒ်လမ်/ နိုင်ဂျီးရီးယား)',
+        'ff_Adlm_SL' => 'ဖူလာ (အက်ဒ်လမ်/ ဆီယာရာ လီယွန်း)',
+        'ff_Adlm_SN' => 'ဖူလာ (အက်ဒ်လမ်/ ဆီနီဂေါ)',
         'ff_CM' => 'ဖူလာ (ကင်မရွန်း)',
         'ff_GN' => 'ဖူလာ (ဂီနီ)',
         'ff_Latn' => 'ဖူလာ (လက်တင်)',
@@ -324,10 +340,12 @@ return [
         'ha_GH' => 'ဟာဥစာ (ဂါနာ)',
         'ha_NE' => 'ဟာဥစာ (နိုင်ဂျာ)',
         'ha_NG' => 'ဟာဥစာ (နိုင်ဂျီးရီးယား)',
-        'he' => 'ဟီးဘရူး',
-        'he_IL' => 'ဟီးဘရူး (အစ္စရေး)',
+        'he' => 'ဟီဘရူး',
+        'he_IL' => 'ဟီဘရူး (အစ္စရေး)',
         'hi' => 'ဟိန်ဒူ',
         'hi_IN' => 'ဟိန်ဒူ (အိန္ဒိယ)',
+        'hi_Latn' => 'ဟိန်ဒူ (လက်တင်)',
+        'hi_Latn_IN' => 'ဟိန်ဒူ (လက်တင်/ အိန္ဒိယ)',
         'hr' => 'ခရိုအေးရှား',
         'hr_BA' => 'ခရိုအေးရှား (ဘော့စနီးယားနှင့် ဟာဇီဂိုဗီနား)',
         'hr_HR' => 'ခရိုအေးရှား (ခရိုအေးရှား)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'ကက်ရှ်မီးယား',
         'ks_Arab' => 'ကက်ရှ်မီးယား (အာရေဗျ)',
         'ks_Arab_IN' => 'ကက်ရှ်မီးယား (အာရေဗျ/ အိန္ဒိယ)',
+        'ks_Deva' => 'ကက်ရှ်မီးယား (ဒီဗနာဂရီ)',
+        'ks_Deva_IN' => 'ကက်ရှ်မီးယား (ဒီဗနာဂရီ/ အိန္ဒိယ)',
         'ks_IN' => 'ကက်ရှ်မီးယား (အိန္ဒိယ)',
         'ku' => 'ကဒ်',
         'ku_TR' => 'ကဒ် (တူရကီ)',
@@ -435,8 +455,8 @@ return [
         'nl_SX' => 'ဒတ်ခ်ျ (စင့်မာတင်)',
         'nn' => 'နော်ဝေ နီးနောစ်',
         'nn_NO' => 'နော်ဝေ နီးနောစ် (နော်ဝေ)',
-        'no' => 'နော်ဝေး',
-        'no_NO' => 'နော်ဝေး (နော်ဝေ)',
+        'no' => 'နော်ဝေ',
+        'no_NO' => 'နော်ဝေ (နော်ဝေ)',
         'om' => 'အိုရိုမို',
         'om_ET' => 'အိုရိုမို (အီသီယိုးပီးယား)',
         'om_KE' => 'အိုရိုမို (ကင်ညာ)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'စင်ဒီ (အာရေဗျ/ ပါကစ္စတန်)',
         'sd_Deva' => 'စင်ဒီ (ဒီဗနာဂရီ)',
         'sd_Deva_IN' => 'စင်ဒီ (ဒီဗနာဂရီ/ အိန္ဒိယ)',
+        'sd_IN' => 'စင်ဒီ (အိန္ဒိယ)',
         'sd_PK' => 'စင်ဒီ (ပါကစ္စတန်)',
         'se' => 'မြောက် ဆာမိ',
         'se_FI' => 'မြောက် ဆာမိ (ဖင်လန်)',
@@ -592,8 +613,8 @@ return [
         'wo_SN' => 'ဝူလိုဖ် (ဆီနီဂေါ)',
         'xh' => 'ဇိုစာ',
         'xh_ZA' => 'ဇိုစာ (တောင်အာဖရိက)',
-        'yi' => 'ဂျူး',
-        'yi_001' => 'ဂျူး (ကမ္ဘာ)',
+        'yi' => 'ရဟူဒီ',
+        'yi_001' => 'ရဟူဒီ (ကမ္ဘာ)',
         'yo' => 'ယိုရူဘာ',
         'yo_BJ' => 'ယိုရူဘာ (ဘီနင်)',
         'yo_NG' => 'ယိုရူဘာ (နိုင်ဂျီးရီးယား)',
