@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Tsjetsjeens (Rusland)',
         'cs' => 'Tsjechisch',
         'cs_CZ' => 'Tsjechisch (Tsjechië)',
+        'cv' => 'Tsjoevasjisch',
+        'cv_RU' => 'Tsjoevasjisch (Rusland)',
         'cy' => 'Welsh',
         'cy_GB' => 'Welsh (Verenigd Koninkrijk)',
         'da' => 'Deens',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'Engels (Montserrat)',
         'en_MT' => 'Engels (Malta)',
         'en_MU' => 'Engels (Mauritius)',
+        'en_MV' => 'Engels (Maldiven)',
         'en_MW' => 'Engels (Malawi)',
         'en_MY' => 'Engels (Maleisië)',
         'en_NA' => 'Engels (Namibië)',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'Hebreeuws (Israël)',
         'hi' => 'Hindi',
         'hi_IN' => 'Hindi (India)',
+        'hi_Latn' => 'Hindi (Latijns)',
+        'hi_Latn_IN' => 'Hindi (Latijns, India)',
         'hr' => 'Kroatisch',
         'hr_BA' => 'Kroatisch (Bosnië en Herzegovina)',
         'hr_HR' => 'Kroatisch (Kroatië)',
@@ -385,6 +390,8 @@ return [
         'ks' => 'Kasjmiri',
         'ks_Arab' => 'Kasjmiri (Arabisch)',
         'ks_Arab_IN' => 'Kasjmiri (Arabisch, India)',
+        'ks_Deva' => 'Kasjmiri (Devanagari)',
+        'ks_Deva_IN' => 'Kasjmiri (Devanagari, India)',
         'ks_IN' => 'Kasjmiri (India)',
         'ku' => 'Koerdisch',
         'ku_TR' => 'Koerdisch (Turkije)',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Sindhi (Arabisch, Pakistan)',
         'sd_Deva' => 'Sindhi (Devanagari)',
         'sd_Deva_IN' => 'Sindhi (Devanagari, India)',
+        'sd_IN' => 'Sindhi (India)',
         'sd_PK' => 'Sindhi (Pakistan)',
         'se' => 'Noord-Samisch',
         'se_FI' => 'Noord-Samisch (Finland)',
