@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'tsjetsjensk (Russland)',
         'cs' => 'tsjekkisk',
         'cs_CZ' => 'tsjekkisk (Tsjekkia)',
+        'cv' => 'tsjuvasjisk',
+        'cv_RU' => 'tsjuvasjisk (Russland)',
         'cy' => 'walisisk',
         'cy_GB' => 'walisisk (Storbritannia)',
         'da' => 'dansk',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'engelsk (Montserrat)',
         'en_MT' => 'engelsk (Malta)',
         'en_MU' => 'engelsk (Mauritius)',
+        'en_MV' => 'engelsk (Maldivene)',
         'en_MW' => 'engelsk (Malawi)',
         'en_MY' => 'engelsk (Malaysia)',
         'en_NA' => 'engelsk (Namibia)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'persisk (Afghanistan)',
         'fa_IR' => 'persisk (Iran)',
         'ff' => 'fulfulde',
+        'ff_Adlm' => 'fulfulde (adlam)',
+        'ff_Adlm_BF' => 'fulfulde (adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fulfulde (adlam, Kamerun)',
+        'ff_Adlm_GH' => 'fulfulde (adlam, Ghana)',
+        'ff_Adlm_GM' => 'fulfulde (adlam, Gambia)',
+        'ff_Adlm_GN' => 'fulfulde (adlam, Guinea)',
+        'ff_Adlm_GW' => 'fulfulde (adlam, Guinea-Bissau)',
+        'ff_Adlm_LR' => 'fulfulde (adlam, Liberia)',
+        'ff_Adlm_MR' => 'fulfulde (adlam, Mauritania)',
+        'ff_Adlm_NE' => 'fulfulde (adlam, Niger)',
+        'ff_Adlm_NG' => 'fulfulde (adlam, Nigeria)',
+        'ff_Adlm_SL' => 'fulfulde (adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'fulfulde (adlam, Senegal)',
         'ff_CM' => 'fulfulde (Kamerun)',
         'ff_GN' => 'fulfulde (Guinea)',
         'ff_Latn' => 'fulfulde (latinsk)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'hebraisk (Israel)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (India)',
+        'hi_Latn' => 'hindi (latinsk)',
+        'hi_Latn_IN' => 'hindi (latinsk, India)',
         'hr' => 'kroatisk',
         'hr_BA' => 'kroatisk (Bosnia-Hercegovina)',
         'hr_HR' => 'kroatisk (Kroatia)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kasjmiri',
         'ks_Arab' => 'kasjmiri (arabisk)',
         'ks_Arab_IN' => 'kasjmiri (arabisk, India)',
+        'ks_Deva' => 'kasjmiri (devanagari)',
+        'ks_Deva_IN' => 'kasjmiri (devanagari, India)',
         'ks_IN' => 'kasjmiri (India)',
         'ku' => 'kurdisk',
         'ku_TR' => 'kurdisk (Tyrkia)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arabisk, Pakistan)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, India)',
+        'sd_IN' => 'sindhi (India)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'nordsamisk',
         'se_FI' => 'nordsamisk (Finland)',
