@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'ଚେଚନ୍ (ରୁଷିଆ)',
         'cs' => 'ଚେକ୍',
         'cs_CZ' => 'ଚେକ୍ (ଚେଚିଆ)',
+        'cv' => 'ଚୁଭାଶ୍',
+        'cv_RU' => 'ଚୁଭାଶ୍ (ରୁଷିଆ)',
         'cy' => 'ୱେଲ୍ସ',
         'cy_GB' => 'ୱେଲ୍ସ (ଯୁକ୍ତରାଜ୍ୟ)',
         'da' => 'ଡାନ୍ନିସ୍',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'ପର୍ସିଆନ୍ (ଆଫଗାନିସ୍ତାନ୍)',
         'fa_IR' => 'ପର୍ସିଆନ୍ (ଇରାନ)',
         'ff' => 'ଫୁଲାହ',
+        'ff_Adlm' => 'ଫୁଲାହ (ଆଡଲମ୍)',
+        'ff_Adlm_BF' => 'ଫୁଲାହ (ଆଡଲମ୍, ବୁର୍କିନା ଫାସୋ)',
+        'ff_Adlm_CM' => 'ଫୁଲାହ (ଆଡଲମ୍, କାମେରୁନ୍)',
+        'ff_Adlm_GH' => 'ଫୁଲାହ (ଆଡଲମ୍, ଘାନା)',
+        'ff_Adlm_GM' => 'ଫୁଲାହ (ଆଡଲମ୍, ଗାମ୍ବିଆ)',
+        'ff_Adlm_GN' => 'ଫୁଲାହ (ଆଡଲମ୍, ଗୁଇନିଆ)',
+        'ff_Adlm_GW' => 'ଫୁଲାହ (ଆଡଲମ୍, ଗୁଇନିଆ-ବିସାଉ)',
+        'ff_Adlm_LR' => 'ଫୁଲାହ (ଆଡଲମ୍, ଲାଇବେରିଆ)',
+        'ff_Adlm_MR' => 'ଫୁଲାହ (ଆଡଲମ୍, ମୌରିଟାନିଆ)',
+        'ff_Adlm_NE' => 'ଫୁଲାହ (ଆଡଲମ୍, ନାଇଜର)',
+        'ff_Adlm_NG' => 'ଫୁଲାହ (ଆଡଲମ୍, ନାଇଜେରିଆ)',
+        'ff_Adlm_SL' => 'ଫୁଲାହ (ଆଡଲମ୍, ସିଏରା ଲିଓନ)',
+        'ff_Adlm_SN' => 'ଫୁଲାହ (ଆଡଲମ୍, ସେନେଗାଲ୍)',
         'ff_CM' => 'ଫୁଲାହ (କାମେରୁନ୍)',
         'ff_GN' => 'ଫୁଲାହ (ଗୁଇନିଆ)',
         'ff_Latn' => 'ଫୁଲାହ (ଲାଟିନ୍)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'ସିନ୍ଧୀ (ଆରବିକ୍, ପାକିସ୍ତାନ)',
         'sd_Deva' => 'ସିନ୍ଧୀ (ଦେବନଗରୀ)',
         'sd_Deva_IN' => 'ସିନ୍ଧୀ (ଦେବନଗରୀ, ଭାରତ)',
+        'sd_IN' => 'ସିନ୍ଧୀ (ଭାରତ)',
         'sd_PK' => 'ସିନ୍ଧୀ (ପାକିସ୍ତାନ)',
         'se' => 'ଉତ୍ତର ସାମି',
         'se_FI' => 'ଉତ୍ତର ସାମି (ଫିନଲ୍ୟାଣ୍ଡ)',
