@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'ਚੇਚਨ (ਰੂਸ)',
         'cs' => 'ਚੈੱਕ',
         'cs_CZ' => 'ਚੈੱਕ (ਚੈਕੀਆ)',
+        'cv' => 'ਚੁਵਾਸ਼',
+        'cv_RU' => 'ਚੁਵਾਸ਼ (ਰੂਸ)',
         'cy' => 'ਵੈਲਸ਼',
         'cy_GB' => 'ਵੈਲਸ਼ (ਯੂਨਾਈਟਡ ਕਿੰਗਡਮ)',
         'da' => 'ਡੈਨਿਸ਼',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'ਅੰਗਰੇਜ਼ੀ (ਮੋਂਟਸੇਰਾਤ)',
         'en_MT' => 'ਅੰਗਰੇਜ਼ੀ (ਮਾਲਟਾ)',
         'en_MU' => 'ਅੰਗਰੇਜ਼ੀ (ਮੌਰੀਸ਼ਸ)',
+        'en_MV' => 'ਅੰਗਰੇਜ਼ੀ (ਮਾਲਦੀਵ)',
         'en_MW' => 'ਅੰਗਰੇਜ਼ੀ (ਮਲਾਵੀ)',
         'en_MY' => 'ਅੰਗਰੇਜ਼ੀ (ਮਲੇਸ਼ੀਆ)',
         'en_NA' => 'ਅੰਗਰੇਜ਼ੀ (ਨਾਮੀਬੀਆ)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'ਫ਼ਾਰਸੀ (ਅਫ਼ਗਾਨਿਸਤਾਨ)',
         'fa_IR' => 'ਫ਼ਾਰਸੀ (ਈਰਾਨ)',
         'ff' => 'ਫੁਲਾਹ',
+        'ff_Adlm' => 'ਫੁਲਾਹ (ਅਦਲਾਮ)',
+        'ff_Adlm_BF' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਬੁਰਕੀਨਾ ਫ਼ਾਸੋ)',
+        'ff_Adlm_CM' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਕੈਮਰੂਨ)',
+        'ff_Adlm_GH' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਘਾਨਾ)',
+        'ff_Adlm_GM' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਗੈਂਬੀਆ)',
+        'ff_Adlm_GN' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਗਿਨੀ)',
+        'ff_Adlm_GW' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਗਿਨੀ-ਬਿਸਾਉ)',
+        'ff_Adlm_LR' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਲਾਈਬੀਰੀਆ)',
+        'ff_Adlm_MR' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਮੋਰਿਟਾਨੀਆ)',
+        'ff_Adlm_NE' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਨਾਈਜਰ)',
+        'ff_Adlm_NG' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਨਾਈਜੀਰੀਆ)',
+        'ff_Adlm_SL' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਸਿਏਰਾ ਲਿਓਨ)',
+        'ff_Adlm_SN' => 'ਫੁਲਾਹ (ਅਦਲਾਮ, ਸੇਨੇਗਲ)',
         'ff_CM' => 'ਫੁਲਾਹ (ਕੈਮਰੂਨ)',
         'ff_GN' => 'ਫੁਲਾਹ (ਗਿਨੀ)',
         'ff_Latn' => 'ਫੁਲਾਹ (ਲਾਤੀਨੀ)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'ਹਿਬਰੂ (ਇਜ਼ਰਾਈਲ)',
         'hi' => 'ਹਿੰਦੀ',
         'hi_IN' => 'ਹਿੰਦੀ (ਭਾਰਤ)',
+        'hi_Latn' => 'ਹਿੰਦੀ (ਲਾਤੀਨੀ)',
+        'hi_Latn_IN' => 'ਹਿੰਦੀ (ਲਾਤੀਨੀ, ਭਾਰਤ)',
         'hr' => 'ਕ੍ਰੋਏਸ਼ਿਆਈ',
         'hr_BA' => 'ਕ੍ਰੋਏਸ਼ਿਆਈ (ਬੋਸਨੀਆ ਅਤੇ ਹਰਜ਼ੇਗੋਵੀਨਾ)',
         'hr_HR' => 'ਕ੍ਰੋਏਸ਼ਿਆਈ (ਕਰੋਏਸ਼ੀਆ)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'ਕਸ਼ਮੀਰੀ',
         'ks_Arab' => 'ਕਸ਼ਮੀਰੀ (ਅਰਬੀ)',
         'ks_Arab_IN' => 'ਕਸ਼ਮੀਰੀ (ਅਰਬੀ, ਭਾਰਤ)',
+        'ks_Deva' => 'ਕਸ਼ਮੀਰੀ (ਦੇਵਨਾਗਰੀ)',
+        'ks_Deva_IN' => 'ਕਸ਼ਮੀਰੀ (ਦੇਵਨਾਗਰੀ, ਭਾਰਤ)',
         'ks_IN' => 'ਕਸ਼ਮੀਰੀ (ਭਾਰਤ)',
         'ku' => 'ਕੁਰਦਿਸ਼',
         'ku_TR' => 'ਕੁਰਦਿਸ਼ (ਤੁਰਕੀ)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'ਸਿੰਧੀ (ਅਰਬੀ, ਪਾਕਿਸਤਾਨ)',
         'sd_Deva' => 'ਸਿੰਧੀ (ਦੇਵਨਾਗਰੀ)',
         'sd_Deva_IN' => 'ਸਿੰਧੀ (ਦੇਵਨਾਗਰੀ, ਭਾਰਤ)',
+        'sd_IN' => 'ਸਿੰਧੀ (ਭਾਰਤ)',
         'sd_PK' => 'ਸਿੰਧੀ (ਪਾਕਿਸਤਾਨ)',
         'se' => 'ਉੱਤਰੀ ਸਾਮੀ',
         'se_FI' => 'ਉੱਤਰੀ ਸਾਮੀ (ਫਿਨਲੈਂਡ)',
