@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'czeczeński (Rosja)',
         'cs' => 'czeski',
         'cs_CZ' => 'czeski (Czechy)',
+        'cv' => 'czuwaski',
+        'cv_RU' => 'czuwaski (Rosja)',
         'cy' => 'walijski',
         'cy_GB' => 'walijski (Wielka Brytania)',
         'da' => 'duński',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'perski (Afganistan)',
         'fa_IR' => 'perski (Iran)',
         'ff' => 'fulani',
+        'ff_Adlm' => 'fulani (adlam)',
+        'ff_Adlm_BF' => 'fulani (adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fulani (adlam, Kamerun)',
+        'ff_Adlm_GH' => 'fulani (adlam, Ghana)',
+        'ff_Adlm_GM' => 'fulani (adlam, Gambia)',
+        'ff_Adlm_GN' => 'fulani (adlam, Gwinea)',
+        'ff_Adlm_GW' => 'fulani (adlam, Gwinea Bissau)',
+        'ff_Adlm_LR' => 'fulani (adlam, Liberia)',
+        'ff_Adlm_MR' => 'fulani (adlam, Mauretania)',
+        'ff_Adlm_NE' => 'fulani (adlam, Niger)',
+        'ff_Adlm_NG' => 'fulani (adlam, Nigeria)',
+        'ff_Adlm_SL' => 'fulani (adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'fulani (adlam, Senegal)',
         'ff_CM' => 'fulani (Kamerun)',
         'ff_GN' => 'fulani (Gwinea)',
         'ff_Latn' => 'fulani (łacińskie)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arabskie, Pakistan)',
         'sd_Deva' => 'sindhi (dewanagari)',
         'sd_Deva_IN' => 'sindhi (dewanagari, Indie)',
+        'sd_IN' => 'sindhi (Indie)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'północnolapoński',
         'se_FI' => 'północnolapoński (Finlandia)',
