@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'چيچني (روسیه)',
         'cs' => 'چېکي',
         'cs_CZ' => 'چېکي (چکیا)',
+        'cv' => 'چوواشي',
+        'cv_RU' => 'چوواشي (روسیه)',
         'cy' => 'ويلشي',
         'cy_GB' => 'ويلشي (برتانیه)',
         'da' => 'ډنمارکي',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'انګليسي (مانټیسیرت)',
         'en_MT' => 'انګليسي (مالټا)',
         'en_MU' => 'انګليسي (موریشیس)',
+        'en_MV' => 'انګليسي (مالديپ)',
         'en_MW' => 'انګليسي (مالاوي)',
         'en_MY' => 'انګليسي (مالیزیا)',
         'en_NA' => 'انګليسي (نیمبیا)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'فارسي (افغانستان)',
         'fa_IR' => 'فارسي (ايران)',
         'ff' => 'فولاح',
+        'ff_Adlm' => 'فولاح (اډلام)',
+        'ff_Adlm_BF' => 'فولاح (اډلام, بورکینا فاسو)',
+        'ff_Adlm_CM' => 'فولاح (اډلام, کامرون)',
+        'ff_Adlm_GH' => 'فولاح (اډلام, ګانا)',
+        'ff_Adlm_GM' => 'فولاح (اډلام, ګامبیا)',
+        'ff_Adlm_GN' => 'فولاح (اډلام, ګینه)',
+        'ff_Adlm_GW' => 'فولاح (اډلام, ګینه بیسو)',
+        'ff_Adlm_LR' => 'فولاح (اډلام, لايبيريا)',
+        'ff_Adlm_MR' => 'فولاح (اډلام, موریتانیا)',
+        'ff_Adlm_NE' => 'فولاح (اډلام, نايجير)',
+        'ff_Adlm_NG' => 'فولاح (اډلام, نایجیریا)',
+        'ff_Adlm_SL' => 'فولاح (اډلام, سییرا لیون)',
+        'ff_Adlm_SN' => 'فولاح (اډلام, سينيګال)',
         'ff_CM' => 'فولاح (کامرون)',
         'ff_GN' => 'فولاح (ګینه)',
         'ff_Latn' => 'فولاح (لاتين/لاتيني)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'عبراني (اسراييل)',
         'hi' => 'هندي',
         'hi_IN' => 'هندي (هند)',
+        'hi_Latn' => 'هندي (لاتين/لاتيني)',
+        'hi_Latn_IN' => 'هندي (لاتين/لاتيني, هند)',
         'hr' => 'کروايشيايي',
         'hr_BA' => 'کروايشيايي (بوسنيا او هېرزګوينا)',
         'hr_HR' => 'کروايشيايي (کرواشيا)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'کشمیري',
         'ks_Arab' => 'کشمیري (عربي)',
         'ks_Arab_IN' => 'کشمیري (عربي, هند)',
+        'ks_Deva' => 'کشمیري (دیواناګري)',
+        'ks_Deva_IN' => 'کشمیري (دیواناګري, هند)',
         'ks_IN' => 'کشمیري (هند)',
         'ku' => 'کردي',
         'ku_TR' => 'کردي (ترکي)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'سندهي (عربي, پاکستان)',
         'sd_Deva' => 'سندهي (دیواناګري)',
         'sd_Deva_IN' => 'سندهي (دیواناګري, هند)',
+        'sd_IN' => 'سندهي (هند)',
         'sd_PK' => 'سندهي (پاکستان)',
         'se' => 'شمالي سامي',
         'se_FI' => 'شمالي سامي (فنلینډ)',
