@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'checheno (Rússia)',
         'cs' => 'tcheco',
         'cs_CZ' => 'tcheco (Tchéquia)',
+        'cv' => 'tchuvache',
+        'cv_RU' => 'tchuvache (Rússia)',
         'cy' => 'galês',
         'cy_GB' => 'galês (Reino Unido)',
         'da' => 'dinamarquês',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'inglês (Montserrat)',
         'en_MT' => 'inglês (Malta)',
         'en_MU' => 'inglês (Maurício)',
+        'en_MV' => 'inglês (Maldivas)',
         'en_MW' => 'inglês (Malaui)',
         'en_MY' => 'inglês (Malásia)',
         'en_NA' => 'inglês (Namíbia)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'persa (Afeganistão)',
         'fa_IR' => 'persa (Irã)',
         'ff' => 'fula',
+        'ff_Adlm' => 'fula (adlam)',
+        'ff_Adlm_BF' => 'fula (adlam, Burquina Faso)',
+        'ff_Adlm_CM' => 'fula (adlam, Camarões)',
+        'ff_Adlm_GH' => 'fula (adlam, Gana)',
+        'ff_Adlm_GM' => 'fula (adlam, Gâmbia)',
+        'ff_Adlm_GN' => 'fula (adlam, Guiné)',
+        'ff_Adlm_GW' => 'fula (adlam, Guiné-Bissau)',
+        'ff_Adlm_LR' => 'fula (adlam, Libéria)',
+        'ff_Adlm_MR' => 'fula (adlam, Mauritânia)',
+        'ff_Adlm_NE' => 'fula (adlam, Níger)',
+        'ff_Adlm_NG' => 'fula (adlam, Nigéria)',
+        'ff_Adlm_SL' => 'fula (adlam, Serra Leoa)',
+        'ff_Adlm_SN' => 'fula (adlam, Senegal)',
         'ff_CM' => 'fula (Camarões)',
         'ff_GN' => 'fula (Guiné)',
         'ff_Latn' => 'fula (latim)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'hebraico (Israel)',
         'hi' => 'híndi',
         'hi_IN' => 'híndi (Índia)',
+        'hi_Latn' => 'híndi (latim)',
+        'hi_Latn_IN' => 'híndi (latim, Índia)',
         'hr' => 'croata',
         'hr_BA' => 'croata (Bósnia e Herzegovina)',
         'hr_HR' => 'croata (Croácia)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'caxemira',
         'ks_Arab' => 'caxemira (árabe)',
         'ks_Arab_IN' => 'caxemira (árabe, Índia)',
+        'ks_Deva' => 'caxemira (devanágari)',
+        'ks_Deva_IN' => 'caxemira (devanágari, Índia)',
         'ks_IN' => 'caxemira (Índia)',
         'ku' => 'curdo',
         'ku_TR' => 'curdo (Turquia)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindi (árabe, Paquistão)',
         'sd_Deva' => 'sindi (devanágari)',
         'sd_Deva_IN' => 'sindi (devanágari, Índia)',
+        'sd_IN' => 'sindi (Índia)',
         'sd_PK' => 'sindi (Paquistão)',
         'se' => 'sami setentrional',
         'se_FI' => 'sami setentrional (Finlândia)',
