@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Checheno Simi (Rusia)',
         'cs' => 'Checo Simi',
         'cs_CZ' => 'Checo Simi (Chequia)',
+        'cv' => 'Chuvash Simi',
+        'cv_RU' => 'Chuvash Simi (Rusia)',
         'cy' => 'Gales Simi',
         'cy_GB' => 'Gales Simi (Reino Unido)',
         'da' => 'Danes Simi',
@@ -184,7 +186,7 @@ return [
         'en_SL' => 'Ingles Simi (Sierra Leona)',
         'en_SS' => 'Ingles Simi (Sudán del Sur)',
         'en_SX' => 'Ingles Simi (Sint Maarten)',
-        'en_SZ' => 'Ingles Simi (Suazilandia)',
+        'en_SZ' => 'Ingles Simi (Esuatini)',
         'en_TC' => 'Ingles Simi (Islas Turcas y Caicos)',
         'en_TK' => 'Ingles Simi (Tokelau)',
         'en_TO' => 'Ingles Simi (Tonga)',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'Persa Simi (Afganistán)',
         'fa_IR' => 'Persa Simi (Irán)',
         'ff' => 'Fulah Simi',
+        'ff_Adlm' => 'Fulah Simi (Adlam Simi)',
+        'ff_Adlm_BF' => 'Fulah Simi (Adlam Simi, Burkina Faso)',
+        'ff_Adlm_CM' => 'Fulah Simi (Adlam Simi, Camerún)',
+        'ff_Adlm_GH' => 'Fulah Simi (Adlam Simi, Ghana)',
+        'ff_Adlm_GM' => 'Fulah Simi (Adlam Simi, Gambia)',
+        'ff_Adlm_GN' => 'Fulah Simi (Adlam Simi, Guinea)',
+        'ff_Adlm_GW' => 'Fulah Simi (Adlam Simi, Guinea-Bisáu)',
+        'ff_Adlm_LR' => 'Fulah Simi (Adlam Simi, Liberia)',
+        'ff_Adlm_MR' => 'Fulah Simi (Adlam Simi, Mauritania)',
+        'ff_Adlm_NE' => 'Fulah Simi (Adlam Simi, Níger)',
+        'ff_Adlm_NG' => 'Fulah Simi (Adlam Simi, Nigeria)',
+        'ff_Adlm_SL' => 'Fulah Simi (Adlam Simi, Sierra Leona)',
+        'ff_Adlm_SN' => 'Fulah Simi (Adlam Simi, Senegal)',
         'ff_CM' => 'Fulah Simi (Camerún)',
         'ff_GN' => 'Fulah Simi (Guinea)',
         'ff_Latn' => 'Fulah Simi (Latin Simi)',
@@ -497,11 +512,14 @@ return [
         'rw_RW' => 'Kinyarwanda Simi (Ruanda)',
         'sa' => 'Sanscrito Simi',
         'sa_IN' => 'Sanscrito Simi (India)',
+        'sc' => 'Sardinian Simi',
+        'sc_IT' => 'Sardinian Simi (Italia)',
         'sd' => 'Sindhi Simi',
         'sd_Arab' => 'Sindhi Simi (Arabe Simi)',
         'sd_Arab_PK' => 'Sindhi Simi (Arabe Simi, Pakistán)',
         'sd_Deva' => 'Sindhi Simi (Devanagari)',
         'sd_Deva_IN' => 'Sindhi Simi (Devanagari, India)',
+        'sd_IN' => 'Sindhi Simi (India)',
         'sd_PK' => 'Sindhi Simi (Pakistán)',
         'se' => 'Chincha Sami Simi',
         'se_FI' => 'Chincha Sami Simi (Finlandia)',
