@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'tschetschen (Russia)',
         'cs' => 'tschec',
         'cs_CZ' => 'tschec (Tschechia)',
+        'cv' => 'tschuvasch',
+        'cv_RU' => 'tschuvasch (Russia)',
         'cy' => 'kimric',
         'cy_GB' => 'kimric (Reginavel Unì)',
         'da' => 'danais',
@@ -504,6 +506,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arab, Pakistan)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, India)',
+        'sd_IN' => 'sindhi (India)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'sami dal nord',
         'se_FI' => 'sami dal nord (Finlanda)',
