@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'cecenă (Rusia)',
         'cs' => 'cehă',
         'cs_CZ' => 'cehă (Cehia)',
+        'cv' => 'ciuvașă',
+        'cv_RU' => 'ciuvașă (Rusia)',
         'cy' => 'galeză',
         'cy_GB' => 'galeză (Regatul Unit)',
         'da' => 'daneză',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'engleză (Montserrat)',
         'en_MT' => 'engleză (Malta)',
         'en_MU' => 'engleză (Mauritius)',
+        'en_MV' => 'engleză (Maldive)',
         'en_MW' => 'engleză (Malawi)',
         'en_MY' => 'engleză (Malaysia)',
         'en_NA' => 'engleză (Namibia)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'persană (Afganistan)',
         'fa_IR' => 'persană (Iran)',
         'ff' => 'fulah',
+        'ff_Adlm' => 'fulah (adlam)',
+        'ff_Adlm_BF' => 'fulah (adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fulah (adlam, Camerun)',
+        'ff_Adlm_GH' => 'fulah (adlam, Ghana)',
+        'ff_Adlm_GM' => 'fulah (adlam, Gambia)',
+        'ff_Adlm_GN' => 'fulah (adlam, Guineea)',
+        'ff_Adlm_GW' => 'fulah (adlam, Guineea-Bissau)',
+        'ff_Adlm_LR' => 'fulah (adlam, Liberia)',
+        'ff_Adlm_MR' => 'fulah (adlam, Mauritania)',
+        'ff_Adlm_NE' => 'fulah (adlam, Niger)',
+        'ff_Adlm_NG' => 'fulah (adlam, Nigeria)',
+        'ff_Adlm_SL' => 'fulah (adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'fulah (adlam, Senegal)',
         'ff_CM' => 'fulah (Camerun)',
         'ff_GN' => 'fulah (Guineea)',
         'ff_Latn' => 'fulah (latină)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'ebraică (Israel)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (India)',
+        'hi_Latn' => 'hindi (latină)',
+        'hi_Latn_IN' => 'hindi (latină, India)',
         'hr' => 'croată',
         'hr_BA' => 'croată (Bosnia și Herțegovina)',
         'hr_HR' => 'croată (Croația)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'cașmiră',
         'ks_Arab' => 'cașmiră (arabă)',
         'ks_Arab_IN' => 'cașmiră (arabă, India)',
+        'ks_Deva' => 'cașmiră (devanagari)',
+        'ks_Deva_IN' => 'cașmiră (devanagari, India)',
         'ks_IN' => 'cașmiră (India)',
         'ku' => 'kurdă',
         'ku_TR' => 'kurdă (Turcia)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arabă, Pakistan)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, India)',
+        'sd_IN' => 'sindhi (India)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'sami de nord',
         'se_FI' => 'sami de nord (Finlanda)',
