@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'чеченский (Россия)',
         'cs' => 'чешский',
         'cs_CZ' => 'чешский (Чехия)',
+        'cv' => 'чувашский',
+        'cv_RU' => 'чувашский (Россия)',
         'cy' => 'валлийский',
         'cy_GB' => 'валлийский (Великобритания)',
         'da' => 'датский',
@@ -115,7 +117,7 @@ return [
         'en_CA' => 'английский (Канада)',
         'en_CC' => 'английский (Кокосовые о-ва)',
         'en_CH' => 'английский (Швейцария)',
-        'en_CK' => 'английский (Острова Кука)',
+        'en_CK' => 'английский (о-ва Кука)',
         'en_CM' => 'английский (Камерун)',
         'en_CX' => 'английский (о-в Рождества)',
         'en_CY' => 'английский (Кипр)',
@@ -146,12 +148,12 @@ return [
         'en_KE' => 'английский (Кения)',
         'en_KI' => 'английский (Кирибати)',
         'en_KN' => 'английский (Сент-Китс и Невис)',
-        'en_KY' => 'английский (Острова Кайман)',
+        'en_KY' => 'английский (о-ва Кайман)',
         'en_LC' => 'английский (Сент-Люсия)',
         'en_LR' => 'английский (Либерия)',
         'en_LS' => 'английский (Лесото)',
         'en_MG' => 'английский (Мадагаскар)',
-        'en_MH' => 'английский (Маршалловы Острова)',
+        'en_MH' => 'английский (Маршалловы о-ва)',
         'en_MO' => 'английский (Макао [САР])',
         'en_MP' => 'английский (Северные Марианские о-ва)',
         'en_MS' => 'английский (Монтсеррат)',
@@ -174,8 +176,8 @@ return [
         'en_PR' => 'английский (Пуэрто-Рико)',
         'en_PW' => 'английский (Палау)',
         'en_RW' => 'английский (Руанда)',
-        'en_SB' => 'английский (Соломоновы Острова)',
-        'en_SC' => 'английский (Сейшельские Острова)',
+        'en_SB' => 'английский (Соломоновы о-ва)',
+        'en_SC' => 'английский (Сейшельские о-ва)',
         'en_SD' => 'английский (Судан)',
         'en_SE' => 'английский (Швеция)',
         'en_SG' => 'английский (Сингапур)',
@@ -185,7 +187,7 @@ return [
         'en_SS' => 'английский (Южный Судан)',
         'en_SX' => 'английский (Синт-Мартен)',
         'en_SZ' => 'английский (Эсватини)',
-        'en_TC' => 'английский (о-ва Тёркс и Кайкос)',
+        'en_TC' => 'английский (Тёркс и Кайкос)',
         'en_TK' => 'английский (Токелау)',
         'en_TO' => 'английский (Тонга)',
         'en_TT' => 'английский (Тринидад и Тобаго)',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'персидский (Афганистан)',
         'fa_IR' => 'персидский (Иран)',
         'ff' => 'фулах',
+        'ff_Adlm' => 'фулах (адлам)',
+        'ff_Adlm_BF' => 'фулах (адлам, Буркина-Фасо)',
+        'ff_Adlm_CM' => 'фулах (адлам, Камерун)',
+        'ff_Adlm_GH' => 'фулах (адлам, Гана)',
+        'ff_Adlm_GM' => 'фулах (адлам, Гамбия)',
+        'ff_Adlm_GN' => 'фулах (адлам, Гвинея)',
+        'ff_Adlm_GW' => 'фулах (адлам, Гвинея-Бисау)',
+        'ff_Adlm_LR' => 'фулах (адлам, Либерия)',
+        'ff_Adlm_MR' => 'фулах (адлам, Мавритания)',
+        'ff_Adlm_NE' => 'фулах (адлам, Нигер)',
+        'ff_Adlm_NG' => 'фулах (адлам, Нигерия)',
+        'ff_Adlm_SL' => 'фулах (адлам, Сьерра-Леоне)',
+        'ff_Adlm_SN' => 'фулах (адлам, Сенегал)',
         'ff_CM' => 'фулах (Камерун)',
         'ff_GN' => 'фулах (Гвинея)',
         'ff_Latn' => 'фулах (латиница)',
@@ -299,7 +314,7 @@ return [
         'fr_PM' => 'французский (Сен-Пьер и Микелон)',
         'fr_RE' => 'французский (Реюньон)',
         'fr_RW' => 'французский (Руанда)',
-        'fr_SC' => 'французский (Сейшельские Острова)',
+        'fr_SC' => 'французский (Сейшельские о-ва)',
         'fr_SN' => 'французский (Сенегал)',
         'fr_SY' => 'французский (Сирия)',
         'fr_TD' => 'французский (Чад)',
@@ -414,7 +429,7 @@ return [
         'mr' => 'маратхи',
         'mr_IN' => 'маратхи (Индия)',
         'ms' => 'малайский',
-        'ms_BN' => 'малайский (Бруней-Даруссалам)',
+        'ms_BN' => 'малайский (Бруней)',
         'ms_ID' => 'малайский (Индонезия)',
         'ms_MY' => 'малайский (Малайзия)',
         'ms_SG' => 'малайский (Сингапур)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'синдхи (арабица, Пакистан)',
         'sd_Deva' => 'синдхи (деванагари)',
         'sd_Deva_IN' => 'синдхи (деванагари, Индия)',
+        'sd_IN' => 'синдхи (Индия)',
         'sd_PK' => 'синдхи (Пакистан)',
         'se' => 'северносаамский',
         'se_FI' => 'северносаамский (Финляндия)',
@@ -609,15 +625,15 @@ return [
         'zh' => 'китайский',
         'zh_CN' => 'китайский (Китай)',
         'zh_HK' => 'китайский (Гонконг [САР])',
-        'zh_Hans' => 'китайский (упрощенная китайская)',
-        'zh_Hans_CN' => 'китайский (упрощенная китайская, Китай)',
-        'zh_Hans_HK' => 'китайский (упрощенная китайская, Гонконг [САР])',
-        'zh_Hans_MO' => 'китайский (упрощенная китайская, Макао [САР])',
-        'zh_Hans_SG' => 'китайский (упрощенная китайская, Сингапур)',
-        'zh_Hant' => 'китайский (традиционная китайская)',
-        'zh_Hant_HK' => 'китайский (традиционная китайская, Гонконг [САР])',
-        'zh_Hant_MO' => 'китайский (традиционная китайская, Макао [САР])',
-        'zh_Hant_TW' => 'китайский (традиционная китайская, Тайвань)',
+        'zh_Hans' => 'китайский (упрощенная)',
+        'zh_Hans_CN' => 'китайский (упрощенная, Китай)',
+        'zh_Hans_HK' => 'китайский (упрощенная, Гонконг [САР])',
+        'zh_Hans_MO' => 'китайский (упрощенная, Макао [САР])',
+        'zh_Hans_SG' => 'китайский (упрощенная, Сингапур)',
+        'zh_Hant' => 'китайский (традиционная)',
+        'zh_Hant_HK' => 'китайский (традиционная, Гонконг [САР])',
+        'zh_Hant_MO' => 'китайский (традиционная, Макао [САР])',
+        'zh_Hant_TW' => 'китайский (традиционная, Тайвань)',
         'zh_MO' => 'китайский (Макао [САР])',
         'zh_SG' => 'китайский (Сингапур)',
         'zh_TW' => 'китайский (Тайвань)',
