@@ -58,8 +58,8 @@ return [
         'bo' => 'tibetanu',
         'bo_CN' => 'tibetanu (Tzina)',
         'bo_IN' => 'tibetanu (Ìndia)',
-        'br' => 'brètonu',
-        'br_FR' => 'brètonu (Frantza)',
+        'br' => 'brètone',
+        'br_FR' => 'brètone (Frantza)',
         'bs' => 'bosnìacu',
         'bs_BA' => 'bosnìacu (Bòsnia e Erzegòvina)',
         'bs_Cyrl' => 'bosnìacu (tzirìllicu)',
@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'cecenu (Rùssia)',
         'cs' => 'tzecu',
         'cs_CZ' => 'tzecu (Tzèchia)',
+        'cv' => 'ciuvàsciu',
+        'cv_RU' => 'ciuvàsciu (Rùssia)',
         'cy' => 'gallesu',
         'cy_GB' => 'gallesu (Regnu Unidu)',
         'da' => 'danesu',
@@ -321,8 +323,8 @@ return [
         'fr_VU' => 'frantzesu (Vanuatu)',
         'fr_WF' => 'frantzesu (Wallis e Futuna)',
         'fr_YT' => 'frantzesu (Mayotte)',
-        'fy' => 'frìsonu otzidentale',
-        'fy_NL' => 'frìsonu otzidentale (Paisos Bassos)',
+        'fy' => 'frisone otzidentale',
+        'fy_NL' => 'frisone otzidentale (Paisos Bassos)',
         'ga' => 'irlandesu',
         'ga_GB' => 'irlandesu (Regnu Unidu)',
         'ga_IE' => 'irlandesu (Irlanda)',
@@ -374,8 +376,8 @@ return [
         'ka_GE' => 'georgianu (Geòrgia)',
         'ki' => 'kikuyu',
         'ki_KE' => 'kikuyu (Kènya)',
-        'kk' => 'kazaku',
-        'kk_KZ' => 'kazaku (Kazàkistan)',
+        'kk' => 'kazacu',
+        'kk_KZ' => 'kazacu (Kazàkistan)',
         'kl' => 'groenlandesu',
         'kl_GL' => 'groenlandesu (Groenlàndia)',
         'km' => 'khmer',
@@ -395,8 +397,8 @@ return [
         'ku_TR' => 'curdu (Turchia)',
         'kw' => 'còrnicu',
         'kw_GB' => 'còrnicu (Regnu Unidu)',
-        'ky' => 'kirghisu',
-        'ky_KG' => 'kirghisu (Kirghìzistan)',
+        'ky' => 'chirghisu',
+        'ky_KG' => 'chirghisu (Kirghìzistan)',
         'lb' => 'lussemburghesu',
         'lb_LU' => 'lussemburghesu (Lussemburgu)',
         'lg' => 'ganda',
@@ -517,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (àrabu, Pàkistan)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, Ìndia)',
+        'sd_IN' => 'sindhi (Ìndia)',
         'sd_PK' => 'sindhi (Pàkistan)',
         'se' => 'sami setentrionale',
         'se_FI' => 'sami setentrionale (Finlàndia)',
