@@ -61,11 +61,11 @@ return [
         'br' => 'بريٽن',
         'br_FR' => 'بريٽن (فرانس)',
         'bs' => 'بوسنيائي',
-        'bs_BA' => 'بوسنيائي (بوسنيا ۽ ھرزيگوينا)',
+        'bs_BA' => 'بوسنيائي (بوسنيا ۽ هرزوگووينا)',
         'bs_Cyrl' => 'بوسنيائي (سيريلي)',
-        'bs_Cyrl_BA' => 'بوسنيائي (سيريلي, بوسنيا ۽ ھرزيگوينا)',
+        'bs_Cyrl_BA' => 'بوسنيائي (سيريلي, بوسنيا ۽ هرزوگووينا)',
         'bs_Latn' => 'بوسنيائي (لاطيني)',
-        'bs_Latn_BA' => 'بوسنيائي (لاطيني, بوسنيا ۽ ھرزيگوينا)',
+        'bs_Latn_BA' => 'بوسنيائي (لاطيني, بوسنيا ۽ هرزوگووينا)',
         'ca' => 'ڪيٽالان',
         'ca_AD' => 'ڪيٽالان (اندورا)',
         'ca_ES' => 'ڪيٽالان (اسپين)',
@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'چیچن (روس)',
         'cs' => 'چيڪ',
         'cs_CZ' => 'چيڪ (چيڪيا)',
+        'cv' => 'چو واش',
+        'cv_RU' => 'چو واش (روس)',
         'cy' => 'ويلش',
         'cy_GB' => 'ويلش (برطانيہ)',
         'da' => 'ڊينش',
@@ -100,7 +102,7 @@ return [
         'en_001' => 'انگريزي (دنيا)',
         'en_150' => 'انگريزي (يورپ)',
         'en_AE' => 'انگريزي (متحده عرب امارات)',
-        'en_AG' => 'انگريزي (انٽيگا ۽ باربوڊا)',
+        'en_AG' => 'انگريزي (انٽيگا ۽ باربد)',
         'en_AI' => 'انگريزي (انگويلا)',
         'en_AS' => 'انگريزي (آمريڪي ساموا)',
         'en_AT' => 'انگريزي (آسٽريا)',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'انگريزي (مونٽسراٽ)',
         'en_MT' => 'انگريزي (مالٽا)',
         'en_MU' => 'انگريزي (موريشس)',
+        'en_MV' => 'انگريزي (مالديپ)',
         'en_MW' => 'انگريزي (مالاوي)',
         'en_MY' => 'انگريزي (ملائيشيا)',
         'en_NA' => 'انگريزي (نيميبيا)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'فارسي (افغانستان)',
         'fa_IR' => 'فارسي (ايران)',
         'ff' => 'فلاهه',
+        'ff_Adlm' => 'فلاهه (ايڊلام)',
+        'ff_Adlm_BF' => 'فلاهه (ايڊلام, برڪينا فاسو)',
+        'ff_Adlm_CM' => 'فلاهه (ايڊلام, ڪيمرون)',
+        'ff_Adlm_GH' => 'فلاهه (ايڊلام, گهانا)',
+        'ff_Adlm_GM' => 'فلاهه (ايڊلام, گيمبيا)',
+        'ff_Adlm_GN' => 'فلاهه (ايڊلام, گني)',
+        'ff_Adlm_GW' => 'فلاهه (ايڊلام, گني بسائو)',
+        'ff_Adlm_LR' => 'فلاهه (ايڊلام, لائبیریا)',
+        'ff_Adlm_MR' => 'فلاهه (ايڊلام, موريتانيا)',
+        'ff_Adlm_NE' => 'فلاهه (ايڊلام, نائيجر)',
+        'ff_Adlm_NG' => 'فلاهه (ايڊلام, نائيجيريا)',
+        'ff_Adlm_SL' => 'فلاهه (ايڊلام, سيرا ليون)',
+        'ff_Adlm_SN' => 'فلاهه (ايڊلام, سينيگال)',
         'ff_CM' => 'فلاهه (ڪيمرون)',
         'ff_GN' => 'فلاهه (گني)',
         'ff_Latn' => 'فلاهه (لاطيني)',
@@ -271,7 +287,7 @@ return [
         'fr_CF' => 'فرانسيسي (وچ آفريقي جمهوريه)',
         'fr_CG' => 'فرانسيسي (ڪانگو - برازاویل)',
         'fr_CH' => 'فرانسيسي (سوئزرلينڊ)',
-        'fr_CI' => 'فرانسيسي (ڪوٽ ڊي وار)',
+        'fr_CI' => 'فرانسيسي (ڪوٽي ويرا)',
         'fr_CM' => 'فرانسيسي (ڪيمرون)',
         'fr_DJ' => 'فرانسيسي (ڊجبيوتي)',
         'fr_DZ' => 'فرانسيسي (الجيريا)',
@@ -328,8 +344,10 @@ return [
         'he_IL' => 'عبراني (اسرائيل)',
         'hi' => 'هندي',
         'hi_IN' => 'هندي (ڀارت)',
+        'hi_Latn' => 'هندي (لاطيني)',
+        'hi_Latn_IN' => 'هندي (لاطيني, ڀارت)',
         'hr' => 'ڪروشيائي',
-        'hr_BA' => 'ڪروشيائي (بوسنيا ۽ ھرزيگوينا)',
+        'hr_BA' => 'ڪروشيائي (بوسنيا ۽ هرزوگووينا)',
         'hr_HR' => 'ڪروشيائي (ڪروئيشيا)',
         'hu' => 'هنگري',
         'hu_HU' => 'هنگري (هنگري)',
@@ -372,9 +390,11 @@ return [
         'ks' => 'ڪشميري',
         'ks_Arab' => 'ڪشميري (عربي)',
         'ks_Arab_IN' => 'ڪشميري (عربي, ڀارت)',
+        'ks_Deva' => 'ڪشميري (ديوناگري)',
+        'ks_Deva_IN' => 'ڪشميري (ديوناگري, ڀارت)',
         'ks_IN' => 'ڪشميري (ڀارت)',
         'ku' => 'ڪردي',
-        'ku_TR' => 'ڪردي (ترڪي)',
+        'ku_TR' => 'ڪردي (ترڪييي)',
         'kw' => 'ڪورنش',
         'kw_GB' => 'ڪورنش (برطانيہ)',
         'ky' => 'ڪرغيز',
@@ -435,6 +455,8 @@ return [
         'nl_SX' => 'ڊچ (سنٽ مارٽن)',
         'nn' => 'نارويائي نيوناسڪ',
         'nn_NO' => 'نارويائي نيوناسڪ (ناروي)',
+        'no' => 'نارويجيائي',
+        'no_NO' => 'نارويجيائي (ناروي)',
         'om' => 'اورومو',
         'om_ET' => 'اورومو (ايٿوپيا)',
         'om_KE' => 'اورومو (ڪينيا)',
@@ -497,6 +519,7 @@ return [
         'sd_Arab_PK' => 'سنڌي (عربي, پاڪستان)',
         'sd_Deva' => 'سنڌي (ديوناگري)',
         'sd_Deva_IN' => 'سنڌي (ديوناگري, ڀارت)',
+        'sd_IN' => 'سنڌي (ڀارت)',
         'sd_PK' => 'سنڌي (پاڪستان)',
         'se' => 'اتر سامي',
         'se_FI' => 'اتر سامي (فن لينڊ)',
@@ -521,13 +544,13 @@ return [
         'sq_AL' => 'الباني (البانيا)',
         'sq_MK' => 'الباني (اتر مقدونيا)',
         'sr' => 'سربيائي',
-        'sr_BA' => 'سربيائي (بوسنيا ۽ ھرزيگوينا)',
+        'sr_BA' => 'سربيائي (بوسنيا ۽ هرزوگووينا)',
         'sr_Cyrl' => 'سربيائي (سيريلي)',
-        'sr_Cyrl_BA' => 'سربيائي (سيريلي, بوسنيا ۽ ھرزيگوينا)',
+        'sr_Cyrl_BA' => 'سربيائي (سيريلي, بوسنيا ۽ هرزوگووينا)',
         'sr_Cyrl_ME' => 'سربيائي (سيريلي, مونٽي نيگرو)',
         'sr_Cyrl_RS' => 'سربيائي (سيريلي, سربيا)',
         'sr_Latn' => 'سربيائي (لاطيني)',
-        'sr_Latn_BA' => 'سربيائي (لاطيني, بوسنيا ۽ ھرزيگوينا)',
+        'sr_Latn_BA' => 'سربيائي (لاطيني, بوسنيا ۽ هرزوگووينا)',
         'sr_Latn_ME' => 'سربيائي (لاطيني, مونٽي نيگرو)',
         'sr_Latn_RS' => 'سربيائي (لاطيني, سربيا)',
         'sr_ME' => 'سربيائي (مونٽي نيگرو)',
@@ -565,7 +588,7 @@ return [
         'to_TO' => 'تونگن (ٽونگا)',
         'tr' => 'ترڪش',
         'tr_CY' => 'ترڪش (سائپرس)',
-        'tr_TR' => 'ترڪش (ترڪي)',
+        'tr_TR' => 'ترڪش (ترڪييي)',
         'tt' => 'تاتار',
         'tt_RU' => 'تاتار (روس)',
         'ug' => 'يوغور',
