@@ -12,12 +12,13 @@ return [
         'bo_IN' => 'تبيتائي (भारत)',
         'br_FR' => 'بريٽن (फ़्रांस)',
         'bs_Cyrl' => 'بوسنيائي (सिरिलिक)',
-        'bs_Cyrl_BA' => 'بوسنيائي (सिरिलिक, بوسنيا ۽ ھرزيگوينا)',
+        'bs_Cyrl_BA' => 'بوسنيائي (सिरिलिक, بوسنيا ۽ هرزوگووينا)',
         'bs_Latn' => 'بوسنيائي (लैटिन)',
-        'bs_Latn_BA' => 'بوسنيائي (लैटिन, بوسنيا ۽ ھرزيگوينا)',
+        'bs_Latn_BA' => 'بوسنيائي (लैटिन, بوسنيا ۽ هرزوگووينا)',
         'ca_FR' => 'ڪيٽالان (फ़्रांस)',
         'ca_IT' => 'ڪيٽالان (इटली)',
         'ce_RU' => 'چیچن (रशिया)',
+        'cv_RU' => 'چو واش (रशिया)',
         'cy_GB' => 'ويلش (बरतानी)',
         'de' => 'जर्मन',
         'de_AT' => 'जर्मन (آسٽريا)',
@@ -31,7 +32,7 @@ return [
         'en_001' => 'अंगरेज़ी (دنيا)',
         'en_150' => 'अंगरेज़ी (يورپ)',
         'en_AE' => 'अंगरेज़ी (متحده عرب امارات)',
-        'en_AG' => 'अंगरेज़ी (انٽيگا ۽ باربوڊا)',
+        'en_AG' => 'अंगरेज़ी (انٽيگا ۽ باربد)',
         'en_AI' => 'अंगरेज़ी (انگويلا)',
         'en_AS' => 'अंगरेज़ी (آمريڪي ساموا)',
         'en_AT' => 'अंगरेज़ी (آسٽريا)',
@@ -100,7 +101,7 @@ return [
         'en_NZ' => 'अंगरेज़ी (نيو زيلينڊ)',
         'en_PG' => 'अंगरेज़ी (پاپوا نیو گني)',
         'en_PH' => 'अंगरेज़ी (فلپائن)',
-        'en_PK' => 'अंगरेज़ी (پاڪستان)',
+        'en_PK' => 'अंगरेज़ी (पाकिस्तान)',
         'en_PN' => 'अंगरेज़ी (پٽڪئرن ٻيٽ)',
         'en_PR' => 'अंगरेज़ी (پيوئرٽو ريڪو)',
         'en_PW' => 'अंगरेज़ी (پلائو)',
@@ -184,7 +185,7 @@ return [
         'fr_CF' => 'फ्रेंच (وچ آفريقي جمهوريه)',
         'fr_CG' => 'फ्रेंच (ڪانگو - برازاویل)',
         'fr_CH' => 'फ्रेंच (سوئزرلينڊ)',
-        'fr_CI' => 'फ्रेंच (ڪوٽ ڊي وار)',
+        'fr_CI' => 'फ्रेंच (ڪوٽي ويرا)',
         'fr_CM' => 'फ्रेंच (ڪيمرون)',
         'fr_DJ' => 'फ्रेंच (ڊجبيوتي)',
         'fr_DZ' => 'फ्रेंच (الجيريا)',
@@ -247,9 +248,11 @@ return [
         'or_IN' => 'اوڊيا (भारत)',
         'os_RU' => 'اوسيٽڪ (रशिया)',
         'pa_Arab' => 'پنجابي (अरबी)',
-        'pa_Arab_PK' => 'پنجابي (अरबी, پاڪستان)',
+        'pa_Arab_PK' => 'پنجابي (अरबी, पाकिस्तान)',
         'pa_Guru_IN' => 'پنجابي (گرمکي, भारत)',
         'pa_IN' => 'پنجابي (भारत)',
+        'pa_PK' => 'پنجابي (पाकिस्तान)',
+        'ps_PK' => 'پشتو (पाकिस्तान)',
         'pt' => 'पुर्तगाली',
         'pt_AO' => 'पुर्तगाली (انگولا)',
         'pt_BR' => 'पुर्तगाली (ब्राज़ील)',
@@ -274,16 +277,17 @@ return [
         'sc_IT' => 'سارڊيني (इटली)',
         'sd' => 'सिन्धी',
         'sd_Arab' => 'सिन्धी (अरबी)',
-        'sd_Arab_PK' => 'सिन्धी (अरबी, پاڪستان)',
+        'sd_Arab_PK' => 'सिन्धी (अरबी, पाकिस्तान)',
         'sd_Deva' => 'सिन्धी (देवनागिरी)',
         'sd_Deva_IN' => 'सिन्धी (देवनागिरी, भारत)',
-        'sd_PK' => 'सिन्धी (پاڪستان)',
+        'sd_IN' => 'सिन्धी (भारत)',
+        'sd_PK' => 'सिन्धी (पाकिस्तान)',
         'sr_Cyrl' => 'سربيائي (सिरिलिक)',
-        'sr_Cyrl_BA' => 'سربيائي (सिरिलिक, بوسنيا ۽ ھرزيگوينا)',
+        'sr_Cyrl_BA' => 'سربيائي (सिरिलिक, بوسنيا ۽ هرزوگووينا)',
         'sr_Cyrl_ME' => 'سربيائي (सिरिलिक, مونٽي نيگرو)',
         'sr_Cyrl_RS' => 'سربيائي (सिरिलिक, سربيا)',
         'sr_Latn' => 'سربيائي (लैटिन)',
-        'sr_Latn_BA' => 'سربيائي (लैटिन, بوسنيا ۽ ھرزيگوينا)',
+        'sr_Latn_BA' => 'سربيائي (लैटिन, بوسنيا ۽ هرزوگووينا)',
         'sr_Latn_ME' => 'سربيائي (लैटिन, مونٽي نيگرو)',
         'sr_Latn_RS' => 'سربيائي (लैटिन, سربيا)',
         'su_Latn' => 'سوڊاني (लैटिन)',
@@ -293,6 +297,7 @@ return [
         'tt_RU' => 'تاتار (रशिया)',
         'ug_CN' => 'يوغور (चीन)',
         'ur_IN' => 'اردو (भारत)',
+        'ur_PK' => 'اردو (पाकिस्तान)',
         'uz_Arab' => 'ازبڪ (अरबी)',
         'uz_Arab_AF' => 'ازبڪ (अरबी, افغانستان)',
         'uz_Cyrl' => 'ازبڪ (सिरिलिक)',
