@@ -137,6 +137,7 @@ return [
         'en_MS' => 'eaŋgalsgiella (Montserrat)',
         'en_MT' => 'eaŋgalsgiella (Málta)',
         'en_MU' => 'eaŋgalsgiella (Mauritius)',
+        'en_MV' => 'eaŋgalsgiella (Malediivvat)',
         'en_MW' => 'eaŋgalsgiella (Malawi)',
         'en_MY' => 'eaŋgalsgiella (Malesia)',
         'en_NA' => 'eaŋgalsgiella (Namibia)',
@@ -279,6 +280,8 @@ return [
         'ha_NG' => 'haussagiella (Nigeria)',
         'hi' => 'hindigiella',
         'hi_IN' => 'hindigiella (India)',
+        'hi_Latn' => 'hindigiella (láhtenaš)',
+        'hi_Latn_IN' => 'hindigiella (láhtenaš, India)',
         'hr' => 'kroátiagiella',
         'hr_BA' => 'kroátiagiella (Bosnia-Hercegovina)',
         'hr_HR' => 'kroátiagiella (Kroátia)',
