@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'චෙච්නියානු (රුසියාව)',
         'cs' => 'චෙක්',
         'cs_CZ' => 'චෙක් (චෙචියාව)',
+        'cv' => 'චවේෂ්',
+        'cv_RU' => 'චවේෂ් (රුසියාව)',
         'cy' => 'වෙල්ෂ්',
         'cy_GB' => 'වෙල්ෂ් (එක්සත් රාජධානිය)',
         'da' => 'ඩැනිශ්',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'පර්සියානු (ඇෆ්ගනිස්ථානය)',
         'fa_IR' => 'පර්සියානු (ඉරානය)',
         'ff' => 'ෆුලාහ්',
+        'ff_Adlm' => 'ෆුලාහ් (ඇඩ්ලම්)',
+        'ff_Adlm_BF' => 'ෆුලාහ් (ඇඩ්ලම්, බර්කිනා ෆාසෝ)',
+        'ff_Adlm_CM' => 'ෆුලාහ් (ඇඩ්ලම්, කැමරූන්)',
+        'ff_Adlm_GH' => 'ෆුලාහ් (ඇඩ්ලම්, ඝානාව)',
+        'ff_Adlm_GM' => 'ෆුලාහ් (ඇඩ්ලම්, ගැම්බියාව)',
+        'ff_Adlm_GN' => 'ෆුලාහ් (ඇඩ්ලම්, ගිණියාව)',
+        'ff_Adlm_GW' => 'ෆුලාහ් (ඇඩ්ලම්, ගිනි බිසව්)',
+        'ff_Adlm_LR' => 'ෆුලාහ් (ඇඩ්ලම්, ලයිබීරියාව)',
+        'ff_Adlm_MR' => 'ෆුලාහ් (ඇඩ්ලම්, මොරිටේනියාව)',
+        'ff_Adlm_NE' => 'ෆුලාහ් (ඇඩ්ලම්, නයිජර්)',
+        'ff_Adlm_NG' => 'ෆුලාහ් (ඇඩ්ලම්, නයිජීරියාව)',
+        'ff_Adlm_SL' => 'ෆුලාහ් (ඇඩ්ලම්, සියරාලියෝන්)',
+        'ff_Adlm_SN' => 'ෆුලාහ් (ඇඩ්ලම්, සෙනගාලය)',
         'ff_CM' => 'ෆුලාහ් (කැමරූන්)',
         'ff_GN' => 'ෆුලාහ් (ගිණියාව)',
         'ff_Latn' => 'ෆුලාහ් (ලතින්)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'සින්ධි (අරාබි, පාකිස්තානය)',
         'sd_Deva' => 'සින්ධි (දේවනාගරී)',
         'sd_Deva_IN' => 'සින්ධි (දේවනාගරී, ඉන්දියාව)',
+        'sd_IN' => 'සින්ධි (ඉන්දියාව)',
         'sd_PK' => 'සින්ධි (පාකිස්තානය)',
         'se' => 'උතුරු සාමි',
         'se_FI' => 'උතුරු සාමි (ෆින්ලන්තය)',
