@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'čečenčina (Rusko)',
         'cs' => 'čeština',
         'cs_CZ' => 'čeština (Česko)',
+        'cv' => 'čuvaština',
+        'cv_RU' => 'čuvaština (Rusko)',
         'cy' => 'waleština',
         'cy_GB' => 'waleština (Spojené kráľovstvo)',
         'da' => 'dánčina',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'angličtina (Montserrat)',
         'en_MT' => 'angličtina (Malta)',
         'en_MU' => 'angličtina (Maurícius)',
+        'en_MV' => 'angličtina (Maldivy)',
         'en_MW' => 'angličtina (Malawi)',
         'en_MY' => 'angličtina (Malajzia)',
         'en_NA' => 'angličtina (Namíbia)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'perzština (Afganistan)',
         'fa_IR' => 'perzština (Irán)',
         'ff' => 'fulbčina',
+        'ff_Adlm' => 'fulbčina (adlam)',
+        'ff_Adlm_BF' => 'fulbčina (adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fulbčina (adlam, Kamerun)',
+        'ff_Adlm_GH' => 'fulbčina (adlam, Ghana)',
+        'ff_Adlm_GM' => 'fulbčina (adlam, Gambia)',
+        'ff_Adlm_GN' => 'fulbčina (adlam, Guinea)',
+        'ff_Adlm_GW' => 'fulbčina (adlam, Guinea-Bissau)',
+        'ff_Adlm_LR' => 'fulbčina (adlam, Libéria)',
+        'ff_Adlm_MR' => 'fulbčina (adlam, Mauritánia)',
+        'ff_Adlm_NE' => 'fulbčina (adlam, Niger)',
+        'ff_Adlm_NG' => 'fulbčina (adlam, Nigéria)',
+        'ff_Adlm_SL' => 'fulbčina (adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'fulbčina (adlam, Senegal)',
         'ff_CM' => 'fulbčina (Kamerun)',
         'ff_GN' => 'fulbčina (Guinea)',
         'ff_Latn' => 'fulbčina (latinka)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'hebrejčina (Izrael)',
         'hi' => 'hindčina',
         'hi_IN' => 'hindčina (India)',
+        'hi_Latn' => 'hindčina (latinka)',
+        'hi_Latn_IN' => 'hindčina (latinka, India)',
         'hr' => 'chorvátčina',
         'hr_BA' => 'chorvátčina (Bosna a Hercegovina)',
         'hr_HR' => 'chorvátčina (Chorvátsko)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kašmírčina',
         'ks_Arab' => 'kašmírčina (arabské)',
         'ks_Arab_IN' => 'kašmírčina (arabské, India)',
+        'ks_Deva' => 'kašmírčina (dévanágarí)',
+        'ks_Deva_IN' => 'kašmírčina (dévanágarí, India)',
         'ks_IN' => 'kašmírčina (India)',
         'ku' => 'kurdčina',
         'ku_TR' => 'kurdčina (Turecko)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhčina (arabské, Pakistan)',
         'sd_Deva' => 'sindhčina (dévanágarí)',
         'sd_Deva_IN' => 'sindhčina (dévanágarí, India)',
+        'sd_IN' => 'sindhčina (India)',
         'sd_PK' => 'sindhčina (Pakistan)',
         'se' => 'saamčina [severná]',
         'se_FI' => 'saamčina [severná] (Fínsko)',
