@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'čečenščina (Rusija)',
         'cs' => 'češčina',
         'cs_CZ' => 'češčina (Češka)',
+        'cv' => 'čuvaščina',
+        'cv_RU' => 'čuvaščina (Rusija)',
         'cy' => 'valižanščina',
         'cy_GB' => 'valižanščina (Združeno kraljestvo)',
         'da' => 'danščina',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'angleščina (Montserrat)',
         'en_MT' => 'angleščina (Malta)',
         'en_MU' => 'angleščina (Mauritius)',
+        'en_MV' => 'angleščina (Maldivi)',
         'en_MW' => 'angleščina (Malavi)',
         'en_MY' => 'angleščina (Malezija)',
         'en_NA' => 'angleščina (Namibija)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'perzijščina (Afganistan)',
         'fa_IR' => 'perzijščina (Iran)',
         'ff' => 'fulščina',
+        'ff_Adlm' => 'fulščina (adlamski)',
+        'ff_Adlm_BF' => 'fulščina (adlamski, Burkina Faso)',
+        'ff_Adlm_CM' => 'fulščina (adlamski, Kamerun)',
+        'ff_Adlm_GH' => 'fulščina (adlamski, Gana)',
+        'ff_Adlm_GM' => 'fulščina (adlamski, Gambija)',
+        'ff_Adlm_GN' => 'fulščina (adlamski, Gvineja)',
+        'ff_Adlm_GW' => 'fulščina (adlamski, Gvineja Bissau)',
+        'ff_Adlm_LR' => 'fulščina (adlamski, Liberija)',
+        'ff_Adlm_MR' => 'fulščina (adlamski, Mavretanija)',
+        'ff_Adlm_NE' => 'fulščina (adlamski, Niger)',
+        'ff_Adlm_NG' => 'fulščina (adlamski, Nigerija)',
+        'ff_Adlm_SL' => 'fulščina (adlamski, Sierra Leone)',
+        'ff_Adlm_SN' => 'fulščina (adlamski, Senegal)',
         'ff_CM' => 'fulščina (Kamerun)',
         'ff_GN' => 'fulščina (Gvineja)',
         'ff_Latn' => 'fulščina (latinica)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'hebrejščina (Izrael)',
         'hi' => 'hindijščina',
         'hi_IN' => 'hindijščina (Indija)',
+        'hi_Latn' => 'hindijščina (latinica)',
+        'hi_Latn_IN' => 'hindijščina (latinica, Indija)',
         'hr' => 'hrvaščina',
         'hr_BA' => 'hrvaščina (Bosna in Hercegovina)',
         'hr_HR' => 'hrvaščina (Hrvaška)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kašmirščina',
         'ks_Arab' => 'kašmirščina (arabski)',
         'ks_Arab_IN' => 'kašmirščina (arabski, Indija)',
+        'ks_Deva' => 'kašmirščina (devanagarščica)',
+        'ks_Deva_IN' => 'kašmirščina (devanagarščica, Indija)',
         'ks_IN' => 'kašmirščina (Indija)',
         'ku' => 'kurdščina',
         'ku_TR' => 'kurdščina (Turčija)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindščina (arabski, Pakistan)',
         'sd_Deva' => 'sindščina (devanagarščica)',
         'sd_Deva_IN' => 'sindščina (devanagarščica, Indija)',
+        'sd_IN' => 'sindščina (Indija)',
         'sd_PK' => 'sindščina (Pakistan)',
         'se' => 'severna samijščina',
         'se_FI' => 'severna samijščina (Finska)',
