@@ -7,8 +7,8 @@ return [
         'af_ZA' => 'Afrikaanka (Koonfur Afrika)',
         'ak' => 'Akan',
         'ak_GH' => 'Akan (Gaana)',
-        'am' => 'Axmaari',
-        'am_ET' => 'Axmaari (Itoobiya)',
+        'am' => 'Axmaar',
+        'am_ET' => 'Axmaar (Itoobiya)',
         'ar' => 'Carabi',
         'ar_001' => 'Carabi (Dunida)',
         'ar_AE' => 'Carabi (Midawga Imaaraatka Carabta)',
@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Jejen (Ruush)',
         'cs' => 'Jeeg',
         'cs_CZ' => 'Jeeg (Jekiya)',
+        'cv' => 'Chuvash',
+        'cv_RU' => 'Chuvash (Ruush)',
         'cy' => 'Welsh',
         'cy_GB' => 'Welsh (Boqortooyada Midowday)',
         'da' => 'Dhaanish',
@@ -510,11 +512,14 @@ return [
         'rw_RW' => 'Ruwaandha (Ruwanda)',
         'sa' => 'Sanskrit',
         'sa_IN' => 'Sanskrit (Hindiya)',
+        'sc' => 'Sardinian',
+        'sc_IT' => 'Sardinian (Talyaani)',
         'sd' => 'Siindhi',
         'sd_Arab' => 'Siindhi (Carabi)',
         'sd_Arab_PK' => 'Siindhi (Carabi, Bakistaan)',
         'sd_Deva' => 'Siindhi (Dhefangaari)',
         'sd_Deva_IN' => 'Siindhi (Dhefangaari, Hindiya)',
+        'sd_IN' => 'Siindhi (Hindiya)',
         'sd_PK' => 'Siindhi (Bakistaan)',
         'se' => 'Sami Waqooyi',
         'se_FI' => 'Sami Waqooyi (Finland)',
