@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'çeçenisht (Rusi)',
         'cs' => 'çekisht',
         'cs_CZ' => 'çekisht (Çeki)',
+        'cv' => 'çuvashisht',
+        'cv_RU' => 'çuvashisht (Rusi)',
         'cy' => 'uellsisht',
         'cy_GB' => 'uellsisht (Mbretëria e Bashkuar)',
         'da' => 'danisht',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'anglisht (Montserat)',
         'en_MT' => 'anglisht (Maltë)',
         'en_MU' => 'anglisht (Mauritius)',
+        'en_MV' => 'anglisht (Maldive)',
         'en_MW' => 'anglisht (Malavi)',
         'en_MY' => 'anglisht (Malajzi)',
         'en_NA' => 'anglisht (Namibi)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'persisht (Afganistan)',
         'fa_IR' => 'persisht (Iran)',
         'ff' => 'fulaisht',
+        'ff_Adlm' => 'fulaisht (adlam)',
+        'ff_Adlm_BF' => 'fulaisht (adlam, Burkina-Faso)',
+        'ff_Adlm_CM' => 'fulaisht (adlam, Kamerun)',
+        'ff_Adlm_GH' => 'fulaisht (adlam, Ganë)',
+        'ff_Adlm_GM' => 'fulaisht (adlam, Gambi)',
+        'ff_Adlm_GN' => 'fulaisht (adlam, Guine)',
+        'ff_Adlm_GW' => 'fulaisht (adlam, Guine-Bisau)',
+        'ff_Adlm_LR' => 'fulaisht (adlam, Liberi)',
+        'ff_Adlm_MR' => 'fulaisht (adlam, Mauritani)',
+        'ff_Adlm_NE' => 'fulaisht (adlam, Niger)',
+        'ff_Adlm_NG' => 'fulaisht (adlam, Nigeri)',
+        'ff_Adlm_SL' => 'fulaisht (adlam, Sierra-Leone)',
+        'ff_Adlm_SN' => 'fulaisht (adlam, Senegal)',
         'ff_CM' => 'fulaisht (Kamerun)',
         'ff_GN' => 'fulaisht (Guine)',
         'ff_Latn' => 'fulaisht (latin)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'hebraisht (Izrael)',
         'hi' => 'indisht',
         'hi_IN' => 'indisht (Indi)',
+        'hi_Latn' => 'indisht (latin)',
+        'hi_Latn_IN' => 'indisht (latin, Indi)',
         'hr' => 'kroatisht',
         'hr_BA' => 'kroatisht (Bosnjë-Hercegovinë)',
         'hr_HR' => 'kroatisht (Kroaci)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kashmirisht',
         'ks_Arab' => 'kashmirisht (arabik)',
         'ks_Arab_IN' => 'kashmirisht (arabik, Indi)',
+        'ks_Deva' => 'kashmirisht (devanagar)',
+        'ks_Deva_IN' => 'kashmirisht (devanagar, Indi)',
         'ks_IN' => 'kashmirisht (Indi)',
         'ku' => 'kurdisht',
         'ku_TR' => 'kurdisht (Turqi)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindisht (arabik, Pakistan)',
         'sd_Deva' => 'sindisht (devanagar)',
         'sd_Deva_IN' => 'sindisht (devanagar, Indi)',
+        'sd_IN' => 'sindisht (Indi)',
         'sd_PK' => 'sindisht (Pakistan)',
         'se' => 'samishte veriore',
         'se_FI' => 'samishte veriore (Finlandë)',
