@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'чеченски (Русија)',
         'cs' => 'чешки',
         'cs_CZ' => 'чешки (Чешка)',
+        'cv' => 'чувашки',
+        'cv_RU' => 'чувашки (Русија)',
         'cy' => 'велшки',
         'cy_GB' => 'велшки (Уједињено Краљевство)',
         'da' => 'дански',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'енглески (Монсерат)',
         'en_MT' => 'енглески (Малта)',
         'en_MU' => 'енглески (Маурицијус)',
+        'en_MV' => 'енглески (Малдиви)',
         'en_MW' => 'енглески (Малави)',
         'en_MY' => 'енглески (Малезија)',
         'en_NA' => 'енглески (Намибија)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'персијски (Авганистан)',
         'fa_IR' => 'персијски (Иран)',
         'ff' => 'фула',
+        'ff_Adlm' => 'фула (адлам)',
+        'ff_Adlm_BF' => 'фула (адлам, Буркина Фасо)',
+        'ff_Adlm_CM' => 'фула (адлам, Камерун)',
+        'ff_Adlm_GH' => 'фула (адлам, Гана)',
+        'ff_Adlm_GM' => 'фула (адлам, Гамбија)',
+        'ff_Adlm_GN' => 'фула (адлам, Гвинеја)',
+        'ff_Adlm_GW' => 'фула (адлам, Гвинеја-Бисао)',
+        'ff_Adlm_LR' => 'фула (адлам, Либерија)',
+        'ff_Adlm_MR' => 'фула (адлам, Мауританија)',
+        'ff_Adlm_NE' => 'фула (адлам, Нигер)',
+        'ff_Adlm_NG' => 'фула (адлам, Нигерија)',
+        'ff_Adlm_SL' => 'фула (адлам, Сијера Леоне)',
+        'ff_Adlm_SN' => 'фула (адлам, Сенегал)',
         'ff_CM' => 'фула (Камерун)',
         'ff_GN' => 'фула (Гвинеја)',
         'ff_Latn' => 'фула (латиница)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'хебрејски (Израел)',
         'hi' => 'хинди',
         'hi_IN' => 'хинди (Индија)',
+        'hi_Latn' => 'хинди (латиница)',
+        'hi_Latn_IN' => 'хинди (латиница, Индија)',
         'hr' => 'хрватски',
         'hr_BA' => 'хрватски (Босна и Херцеговина)',
         'hr_HR' => 'хрватски (Хрватска)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'кашмирски',
         'ks_Arab' => 'кашмирски (арапско писмо)',
         'ks_Arab_IN' => 'кашмирски (арапско писмо, Индија)',
+        'ks_Deva' => 'кашмирски (деванагари)',
+        'ks_Deva_IN' => 'кашмирски (деванагари, Индија)',
         'ks_IN' => 'кашмирски (Индија)',
         'ku' => 'курдски',
         'ku_TR' => 'курдски (Турска)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'синди (арапско писмо, Пакистан)',
         'sd_Deva' => 'синди (деванагари)',
         'sd_Deva_IN' => 'синди (деванагари, Индија)',
+        'sd_IN' => 'синди (Индија)',
         'sd_PK' => 'синди (Пакистан)',
         'se' => 'северни сами',
         'se_FI' => 'северни сами (Финска)',
