@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'čečenski (Rusija)',
         'cs' => 'češki',
         'cs_CZ' => 'češki (Češka)',
+        'cv' => 'čuvaški',
+        'cv_RU' => 'čuvaški (Rusija)',
         'cy' => 'velški',
         'cy_GB' => 'velški (Ujedinjeno Kraljevstvo)',
         'da' => 'danski',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'engleski (Monserat)',
         'en_MT' => 'engleski (Malta)',
         'en_MU' => 'engleski (Mauricijus)',
+        'en_MV' => 'engleski (Maldivi)',
         'en_MW' => 'engleski (Malavi)',
         'en_MY' => 'engleski (Malezija)',
         'en_NA' => 'engleski (Namibija)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'persijski (Avganistan)',
         'fa_IR' => 'persijski (Iran)',
         'ff' => 'fula',
+        'ff_Adlm' => 'fula (adlam)',
+        'ff_Adlm_BF' => 'fula (adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'fula (adlam, Kamerun)',
+        'ff_Adlm_GH' => 'fula (adlam, Gana)',
+        'ff_Adlm_GM' => 'fula (adlam, Gambija)',
+        'ff_Adlm_GN' => 'fula (adlam, Gvineja)',
+        'ff_Adlm_GW' => 'fula (adlam, Gvineja-Bisao)',
+        'ff_Adlm_LR' => 'fula (adlam, Liberija)',
+        'ff_Adlm_MR' => 'fula (adlam, Mauritanija)',
+        'ff_Adlm_NE' => 'fula (adlam, Niger)',
+        'ff_Adlm_NG' => 'fula (adlam, Nigerija)',
+        'ff_Adlm_SL' => 'fula (adlam, Sijera Leone)',
+        'ff_Adlm_SN' => 'fula (adlam, Senegal)',
         'ff_CM' => 'fula (Kamerun)',
         'ff_GN' => 'fula (Gvineja)',
         'ff_Latn' => 'fula (latinica)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'hebrejski (Izrael)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (Indija)',
+        'hi_Latn' => 'hindi (latinica)',
+        'hi_Latn_IN' => 'hindi (latinica, Indija)',
         'hr' => 'hrvatski',
         'hr_BA' => 'hrvatski (Bosna i Hercegovina)',
         'hr_HR' => 'hrvatski (Hrvatska)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kašmirski',
         'ks_Arab' => 'kašmirski (arapsko pismo)',
         'ks_Arab_IN' => 'kašmirski (arapsko pismo, Indija)',
+        'ks_Deva' => 'kašmirski (devanagari)',
+        'ks_Deva_IN' => 'kašmirski (devanagari, Indija)',
         'ks_IN' => 'kašmirski (Indija)',
         'ku' => 'kurdski',
         'ku_TR' => 'kurdski (Turska)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindi (arapsko pismo, Pakistan)',
         'sd_Deva' => 'sindi (devanagari)',
         'sd_Deva_IN' => 'sindi (devanagari, Indija)',
+        'sd_IN' => 'sindi (Indija)',
         'sd_PK' => 'sindi (Pakistan)',
         'se' => 'severni sami',
         'se_FI' => 'severni sami (Finska)',
