@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'tjetjenska (Ryssland)',
         'cs' => 'tjeckiska',
         'cs_CZ' => 'tjeckiska (Tjeckien)',
+        'cv' => 'tjuvasjiska',
+        'cv_RU' => 'tjuvasjiska (Ryssland)',
         'cy' => 'walesiska',
         'cy_GB' => 'walesiska (Storbritannien)',
         'da' => 'danska',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'engelska (Montserrat)',
         'en_MT' => 'engelska (Malta)',
         'en_MU' => 'engelska (Mauritius)',
+        'en_MV' => 'engelska (Maldiverna)',
         'en_MW' => 'engelska (Malawi)',
         'en_MY' => 'engelska (Malaysia)',
         'en_NA' => 'engelska (Namibia)',
@@ -183,7 +186,7 @@ return [
         'en_SL' => 'engelska (Sierra Leone)',
         'en_SS' => 'engelska (Sydsudan)',
         'en_SX' => 'engelska (Sint Maarten)',
-        'en_SZ' => 'engelska (Swaziland)',
+        'en_SZ' => 'engelska (Eswatini)',
         'en_TC' => 'engelska (Turks- och Caicosöarna)',
         'en_TK' => 'engelska (Tokelauöarna)',
         'en_TO' => 'engelska (Tonga)',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'hebreiska (Israel)',
         'hi' => 'hindi',
         'hi_IN' => 'hindi (Indien)',
+        'hi_Latn' => 'hindi (latinska)',
+        'hi_Latn_IN' => 'hindi (latinska, Indien)',
         'hr' => 'kroatiska',
         'hr_BA' => 'kroatiska (Bosnien och Hercegovina)',
         'hr_HR' => 'kroatiska (Kroatien)',
@@ -385,6 +390,8 @@ return [
         'ks' => 'kashmiriska',
         'ks_Arab' => 'kashmiriska (arabiska)',
         'ks_Arab_IN' => 'kashmiriska (arabiska, Indien)',
+        'ks_Deva' => 'kashmiriska (devanagari)',
+        'ks_Deva_IN' => 'kashmiriska (devanagari, Indien)',
         'ks_IN' => 'kashmiriska (Indien)',
         'ku' => 'kurdiska',
         'ku_TR' => 'kurdiska (Turkiet)',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arabiska, Pakistan)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, Indien)',
+        'sd_IN' => 'sindhi (Indien)',
         'sd_PK' => 'sindhi (Pakistan)',
         'se' => 'nordsamiska',
         'se_FI' => 'nordsamiska (Finland)',
