@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Kichechenia (Urusi)',
         'cs' => 'Kicheki',
         'cs_CZ' => 'Kicheki (Chechia)',
+        'cv' => 'Kichuvash',
+        'cv_RU' => 'Kichuvash (Urusi)',
         'cy' => 'Kiwelisi',
         'cy_GB' => 'Kiwelisi (Ufalme wa Muungano)',
         'da' => 'Kidenmaki',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'Kiajemi (Afghanistan)',
         'fa_IR' => 'Kiajemi (Iran)',
         'ff' => 'Kifulani',
+        'ff_Adlm' => 'Kifulani (Kiadlamu)',
+        'ff_Adlm_BF' => 'Kifulani (Kiadlamu, Bukinafaso)',
+        'ff_Adlm_CM' => 'Kifulani (Kiadlamu, Kameruni)',
+        'ff_Adlm_GH' => 'Kifulani (Kiadlamu, Ghana)',
+        'ff_Adlm_GM' => 'Kifulani (Kiadlamu, Gambia)',
+        'ff_Adlm_GN' => 'Kifulani (Kiadlamu, Gine)',
+        'ff_Adlm_GW' => 'Kifulani (Kiadlamu, Ginebisau)',
+        'ff_Adlm_LR' => 'Kifulani (Kiadlamu, Liberia)',
+        'ff_Adlm_MR' => 'Kifulani (Kiadlamu, Moritania)',
+        'ff_Adlm_NE' => 'Kifulani (Kiadlamu, Niger)',
+        'ff_Adlm_NG' => 'Kifulani (Kiadlamu, Nigeria)',
+        'ff_Adlm_SL' => 'Kifulani (Kiadlamu, Siera Leoni)',
+        'ff_Adlm_SN' => 'Kifulani (Kiadlamu, Senegali)',
         'ff_CM' => 'Kifulani (Kameruni)',
         'ff_GN' => 'Kifulani (Gine)',
         'ff_Latn' => 'Kifulani (Kilatini)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Kisindhi (Kiarabu, Pakistani)',
         'sd_Deva' => 'Kisindhi (Kidevanagari)',
         'sd_Deva_IN' => 'Kisindhi (Kidevanagari, India)',
+        'sd_IN' => 'Kisindhi (India)',
         'sd_PK' => 'Kisindhi (Pakistani)',
         'se' => 'Kisami cha Kaskazini',
         'se_FI' => 'Kisami cha Kaskazini (Ufini)',
