@@ -394,7 +394,7 @@ return [
         'ks_Deva_IN' => 'కాశ్మీరి (దేవనాగరి, భారతదేశం)',
         'ks_IN' => 'కాశ్మీరి (భారతదేశం)',
         'ku' => 'కుర్దిష్',
-        'ku_TR' => 'కుర్దిష్ (టర్కీ)',
+        'ku_TR' => 'కుర్దిష్ (తుర్కియె)',
         'kw' => 'కోర్నిష్',
         'kw_GB' => 'కోర్నిష్ (యునైటెడ్ కింగ్‌డమ్)',
         'ky' => 'కిర్గిజ్',
@@ -592,7 +592,7 @@ return [
         'to_TO' => 'టాంగాన్ (టోంగా)',
         'tr' => 'టర్కిష్',
         'tr_CY' => 'టర్కిష్ (సైప్రస్)',
-        'tr_TR' => 'టర్కిష్ (టర్కీ)',
+        'tr_TR' => 'టర్కిష్ (తుర్కియె)',
         'tt' => 'టాటర్',
         'tt_RU' => 'టాటర్ (రష్యా)',
         'ug' => 'ఉయ్‌ఘర్',
