@@ -84,110 +84,110 @@ return [
         'el' => 'юнонӣ',
         'el_CY' => 'юнонӣ (Кипр)',
         'el_GR' => 'юнонӣ (Юнон)',
-        'en' => 'англисӣ',
-        'en_AE' => 'англисӣ (Аморатҳои Муттаҳидаи Араб)',
-        'en_AG' => 'англисӣ (Антигуа ва Барбуда)',
-        'en_AI' => 'англисӣ (Ангилия)',
-        'en_AS' => 'англисӣ (Самоаи Америка)',
-        'en_AT' => 'англисӣ (Австрия)',
-        'en_AU' => 'англисӣ (Австралия)',
-        'en_BB' => 'англисӣ (Барбадос)',
-        'en_BE' => 'англисӣ (Белгия)',
-        'en_BI' => 'англисӣ (Бурунди)',
-        'en_BM' => 'англисӣ (Бермуда)',
-        'en_BS' => 'англисӣ (Багам)',
-        'en_BW' => 'англисӣ (Ботсвана)',
-        'en_BZ' => 'англисӣ (Белиз)',
-        'en_CA' => 'англисӣ (Канада)',
-        'en_CC' => 'англисӣ (Ҷазираҳои Кокос [Килинг])',
-        'en_CH' => 'англисӣ (Швейтсария)',
-        'en_CK' => 'англисӣ (Ҷазираҳои Кук)',
-        'en_CM' => 'англисӣ (Камерун)',
-        'en_CX' => 'англисӣ (Ҷазираи Крисмас)',
-        'en_CY' => 'англисӣ (Кипр)',
-        'en_DE' => 'англисӣ (Германия)',
-        'en_DK' => 'англисӣ (Дания)',
-        'en_DM' => 'англисӣ (Доминика)',
-        'en_ER' => 'англисӣ (Эритрея)',
-        'en_FI' => 'англисӣ (Финляндия)',
-        'en_FJ' => 'англисӣ (Фиҷи)',
-        'en_FK' => 'англисӣ (Ҷазираҳои Фолкленд)',
-        'en_FM' => 'англисӣ (Штатҳои Федеративии Микронезия)',
-        'en_GB' => 'англисӣ (Шоҳигарии Муттаҳида)',
-        'en_GD' => 'англисӣ (Гренада)',
-        'en_GG' => 'англисӣ (Гернси)',
-        'en_GH' => 'англисӣ (Гана)',
-        'en_GI' => 'англисӣ (Гибралтар)',
-        'en_GM' => 'англисӣ (Гамбия)',
-        'en_GU' => 'англисӣ (Гуам)',
-        'en_GY' => 'англисӣ (Гайана)',
-        'en_HK' => 'англисӣ (Ҳонконг [МММ])',
-        'en_IE' => 'англисӣ (Ирландия)',
-        'en_IL' => 'англисӣ (Исроил)',
-        'en_IM' => 'англисӣ (Ҷазираи Мэн)',
-        'en_IN' => 'англисӣ (Ҳиндустон)',
-        'en_IO' => 'англисӣ (Қаламрави Британия дар уқёнуси Ҳинд)',
-        'en_JE' => 'англисӣ (Ҷерси)',
-        'en_JM' => 'англисӣ (Ямайка)',
-        'en_KE' => 'англисӣ (Кения)',
-        'en_KI' => 'англисӣ (Кирибати)',
-        'en_KN' => 'англисӣ (Сент-Китс ва Невис)',
-        'en_KY' => 'англисӣ (Ҷазираҳои Кайман)',
-        'en_LC' => 'англисӣ (Сент-Люсия)',
-        'en_LR' => 'англисӣ (Либерия)',
-        'en_LS' => 'англисӣ (Лесото)',
-        'en_MG' => 'англисӣ (Мадагаскар)',
-        'en_MH' => 'англисӣ (Ҷазираҳои Маршалл)',
-        'en_MO' => 'англисӣ (Макао [МММ])',
-        'en_MP' => 'англисӣ (Ҷазираҳои Марианаи Шимолӣ)',
-        'en_MS' => 'англисӣ (Монтсеррат)',
-        'en_MT' => 'англисӣ (Малта)',
-        'en_MU' => 'англисӣ (Маврикий)',
-        'en_MV' => 'англисӣ (Малдив)',
-        'en_MW' => 'англисӣ (Малави)',
-        'en_MY' => 'англисӣ (Малайзия)',
-        'en_NA' => 'англисӣ (Намибия)',
-        'en_NF' => 'англисӣ (Ҷазираи Норфолк)',
-        'en_NG' => 'англисӣ (Нигерия)',
-        'en_NL' => 'англисӣ (Нидерландия)',
-        'en_NR' => 'англисӣ (Науру)',
-        'en_NU' => 'англисӣ (Ниуэ)',
-        'en_NZ' => 'англисӣ (Зеландияи Нав)',
-        'en_PG' => 'англисӣ (Папуа Гвинеяи Нав)',
-        'en_PH' => 'англисӣ (Филиппин)',
-        'en_PK' => 'англисӣ (Покистон)',
-        'en_PN' => 'англисӣ (Ҷазираҳои Питкейрн)',
-        'en_PR' => 'англисӣ (Пуэрто-Рико)',
-        'en_PW' => 'англисӣ (Палау)',
-        'en_RW' => 'англисӣ (Руанда)',
-        'en_SB' => 'англисӣ (Ҷазираҳои Соломон)',
-        'en_SC' => 'англисӣ (Сейшел)',
-        'en_SD' => 'англисӣ (Судон)',
-        'en_SE' => 'англисӣ (Шветсия)',
-        'en_SG' => 'англисӣ (Сингапур)',
-        'en_SH' => 'англисӣ (Сент Елена)',
-        'en_SI' => 'англисӣ (Словения)',
-        'en_SL' => 'англисӣ (Сиерра-Леоне)',
-        'en_SS' => 'англисӣ (Судони Ҷанубӣ)',
-        'en_SX' => 'англисӣ (Синт-Маартен)',
-        'en_SZ' => 'англисӣ (Свазиленд)',
-        'en_TC' => 'англисӣ (Ҷазираҳои Теркс ва Кайкос)',
-        'en_TK' => 'англисӣ (Токелау)',
-        'en_TO' => 'англисӣ (Тонга)',
-        'en_TT' => 'англисӣ (Тринидад ва Тобаго)',
-        'en_TV' => 'англисӣ (Тувалу)',
-        'en_TZ' => 'англисӣ (Танзания)',
-        'en_UG' => 'англисӣ (Уганда)',
-        'en_UM' => 'англисӣ (Ҷазираҳои Хурди Дурдасти ИМА)',
-        'en_US' => 'англисӣ (Иёлоти Муттаҳида)',
-        'en_VC' => 'англисӣ (Сент-Винсент ва Гренадина)',
-        'en_VG' => 'англисӣ (Ҷазираҳои Виргини Британия)',
-        'en_VI' => 'англисӣ (Ҷазираҳои Виргини ИМА)',
-        'en_VU' => 'англисӣ (Вануату)',
-        'en_WS' => 'англисӣ (Самоа)',
-        'en_ZA' => 'англисӣ (Африкаи Ҷанубӣ)',
-        'en_ZM' => 'англисӣ (Замбия)',
-        'en_ZW' => 'англисӣ (Зимбабве)',
+        'en' => 'Англисӣ',
+        'en_AE' => 'Англисӣ (Аморатҳои Муттаҳидаи Араб)',
+        'en_AG' => 'Англисӣ (Антигуа ва Барбуда)',
+        'en_AI' => 'Англисӣ (Ангилия)',
+        'en_AS' => 'Англисӣ (Самоаи Америка)',
+        'en_AT' => 'Англисӣ (Австрия)',
+        'en_AU' => 'Англисӣ (Австралия)',
+        'en_BB' => 'Англисӣ (Барбадос)',
+        'en_BE' => 'Англисӣ (Белгия)',
+        'en_BI' => 'Англисӣ (Бурунди)',
+        'en_BM' => 'Англисӣ (Бермуда)',
+        'en_BS' => 'Англисӣ (Багам)',
+        'en_BW' => 'Англисӣ (Ботсвана)',
+        'en_BZ' => 'Англисӣ (Белиз)',
+        'en_CA' => 'Англисӣ (Канада)',
+        'en_CC' => 'Англисӣ (Ҷазираҳои Кокос [Килинг])',
+        'en_CH' => 'Англисӣ (Швейтсария)',
+        'en_CK' => 'Англисӣ (Ҷазираҳои Кук)',
+        'en_CM' => 'Англисӣ (Камерун)',
+        'en_CX' => 'Англисӣ (Ҷазираи Крисмас)',
+        'en_CY' => 'Англисӣ (Кипр)',
+        'en_DE' => 'Англисӣ (Германия)',
+        'en_DK' => 'Англисӣ (Дания)',
+        'en_DM' => 'Англисӣ (Доминика)',
+        'en_ER' => 'Англисӣ (Эритрея)',
+        'en_FI' => 'Англисӣ (Финляндия)',
+        'en_FJ' => 'Англисӣ (Фиҷи)',
+        'en_FK' => 'Англисӣ (Ҷазираҳои Фолкленд)',
+        'en_FM' => 'Англисӣ (Штатҳои Федеративии Микронезия)',
+        'en_GB' => 'Англисӣ (Шоҳигарии Муттаҳида)',
+        'en_GD' => 'Англисӣ (Гренада)',
+        'en_GG' => 'Англисӣ (Гернси)',
+        'en_GH' => 'Англисӣ (Гана)',
+        'en_GI' => 'Англисӣ (Гибралтар)',
+        'en_GM' => 'Англисӣ (Гамбия)',
+        'en_GU' => 'Англисӣ (Гуам)',
+        'en_GY' => 'Англисӣ (Гайана)',
+        'en_HK' => 'Англисӣ (Ҳонконг [МММ])',
+        'en_IE' => 'Англисӣ (Ирландия)',
+        'en_IL' => 'Англисӣ (Исроил)',
+        'en_IM' => 'Англисӣ (Ҷазираи Мэн)',
+        'en_IN' => 'Англисӣ (Ҳиндустон)',
+        'en_IO' => 'Англисӣ (Қаламрави Британия дар уқёнуси Ҳинд)',
+        'en_JE' => 'Англисӣ (Ҷерси)',
+        'en_JM' => 'Англисӣ (Ямайка)',
+        'en_KE' => 'Англисӣ (Кения)',
+        'en_KI' => 'Англисӣ (Кирибати)',
+        'en_KN' => 'Англисӣ (Сент-Китс ва Невис)',
+        'en_KY' => 'Англисӣ (Ҷазираҳои Кайман)',
+        'en_LC' => 'Англисӣ (Сент-Люсия)',
+        'en_LR' => 'Англисӣ (Либерия)',
+        'en_LS' => 'Англисӣ (Лесото)',
+        'en_MG' => 'Англисӣ (Мадагаскар)',
+        'en_MH' => 'Англисӣ (Ҷазираҳои Маршалл)',
+        'en_MO' => 'Англисӣ (Макао [МММ])',
+        'en_MP' => 'Англисӣ (Ҷазираҳои Марианаи Шимолӣ)',
+        'en_MS' => 'Англисӣ (Монтсеррат)',
+        'en_MT' => 'Англисӣ (Малта)',
+        'en_MU' => 'Англисӣ (Маврикий)',
+        'en_MV' => 'Англисӣ (Малдив)',
+        'en_MW' => 'Англисӣ (Малави)',
+        'en_MY' => 'Англисӣ (Малайзия)',
+        'en_NA' => 'Англисӣ (Намибия)',
+        'en_NF' => 'Англисӣ (Ҷазираи Норфолк)',
+        'en_NG' => 'Англисӣ (Нигерия)',
+        'en_NL' => 'Англисӣ (Нидерландия)',
+        'en_NR' => 'Англисӣ (Науру)',
+        'en_NU' => 'Англисӣ (Ниуэ)',
+        'en_NZ' => 'Англисӣ (Зеландияи Нав)',
+        'en_PG' => 'Англисӣ (Папуа Гвинеяи Нав)',
+        'en_PH' => 'Англисӣ (Филиппин)',
+        'en_PK' => 'Англисӣ (Покистон)',
+        'en_PN' => 'Англисӣ (Ҷазираҳои Питкейрн)',
+        'en_PR' => 'Англисӣ (Пуэрто-Рико)',
+        'en_PW' => 'Англисӣ (Палау)',
+        'en_RW' => 'Англисӣ (Руанда)',
+        'en_SB' => 'Англисӣ (Ҷазираҳои Соломон)',
+        'en_SC' => 'Англисӣ (Сейшел)',
+        'en_SD' => 'Англисӣ (Судон)',
+        'en_SE' => 'Англисӣ (Шветсия)',
+        'en_SG' => 'Англисӣ (Сингапур)',
+        'en_SH' => 'Англисӣ (Сент Елена)',
+        'en_SI' => 'Англисӣ (Словения)',
+        'en_SL' => 'Англисӣ (Сиерра-Леоне)',
+        'en_SS' => 'Англисӣ (Судони Ҷанубӣ)',
+        'en_SX' => 'Англисӣ (Синт-Маартен)',
+        'en_SZ' => 'Англисӣ (Свазиленд)',
+        'en_TC' => 'Англисӣ (Ҷазираҳои Теркс ва Кайкос)',
+        'en_TK' => 'Англисӣ (Токелау)',
+        'en_TO' => 'Англисӣ (Тонга)',
+        'en_TT' => 'Англисӣ (Тринидад ва Тобаго)',
+        'en_TV' => 'Англисӣ (Тувалу)',
+        'en_TZ' => 'Англисӣ (Танзания)',
+        'en_UG' => 'Англисӣ (Уганда)',
+        'en_UM' => 'Англисӣ (Ҷазираҳои Хурди Дурдасти ИМА)',
+        'en_US' => 'Англисӣ (Иёлоти Муттаҳида)',
+        'en_VC' => 'Англисӣ (Сент-Винсент ва Гренадина)',
+        'en_VG' => 'Англисӣ (Ҷазираҳои Виргини Британия)',
+        'en_VI' => 'Англисӣ (Ҷазираҳои Виргини ИМА)',
+        'en_VU' => 'Англисӣ (Вануату)',
+        'en_WS' => 'Англисӣ (Самоа)',
+        'en_ZA' => 'Англисӣ (Африкаи Ҷанубӣ)',
+        'en_ZM' => 'Англисӣ (Замбия)',
+        'en_ZW' => 'Англисӣ (Зимбабве)',
         'eo' => 'эсперанто',
         'es' => 'испанӣ',
         'es_AR' => 'испанӣ (Аргентина)',
@@ -443,6 +443,7 @@ return [
         'sd' => 'синдӣ',
         'sd_Arab' => 'синдӣ (Арабӣ)',
         'sd_Arab_PK' => 'синдӣ (Арабӣ, Покистон)',
+        'sd_IN' => 'синдӣ (Ҳиндустон)',
         'sd_PK' => 'синдӣ (Покистон)',
         'se' => 'самии шимолӣ',
         'se_FI' => 'самии шимолӣ (Финляндия)',
