@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'เชเชน (รัสเซีย)',
         'cs' => 'เช็ก',
         'cs_CZ' => 'เช็ก (เช็ก)',
+        'cv' => 'ชูวัช',
+        'cv_RU' => 'ชูวัช (รัสเซีย)',
         'cy' => 'เวลส์',
         'cy_GB' => 'เวลส์ (สหราชอาณาจักร)',
         'da' => 'เดนมาร์ก',
@@ -239,6 +241,19 @@ return [
         'fa_AF' => 'เปอร์เซีย (อัฟกานิสถาน)',
         'fa_IR' => 'เปอร์เซีย (อิหร่าน)',
         'ff' => 'ฟูลาห์',
+        'ff_Adlm' => 'ฟูลาห์ (อัดลัม)',
+        'ff_Adlm_BF' => 'ฟูลาห์ (อัดลัม, บูร์กินาฟาโซ)',
+        'ff_Adlm_CM' => 'ฟูลาห์ (อัดลัม, แคเมอรูน)',
+        'ff_Adlm_GH' => 'ฟูลาห์ (อัดลัม, กานา)',
+        'ff_Adlm_GM' => 'ฟูลาห์ (อัดลัม, แกมเบีย)',
+        'ff_Adlm_GN' => 'ฟูลาห์ (อัดลัม, กินี)',
+        'ff_Adlm_GW' => 'ฟูลาห์ (อัดลัม, กินี-บิสเซา)',
+        'ff_Adlm_LR' => 'ฟูลาห์ (อัดลัม, ไลบีเรีย)',
+        'ff_Adlm_MR' => 'ฟูลาห์ (อัดลัม, มอริเตเนีย)',
+        'ff_Adlm_NE' => 'ฟูลาห์ (อัดลัม, ไนเจอร์)',
+        'ff_Adlm_NG' => 'ฟูลาห์ (อัดลัม, ไนจีเรีย)',
+        'ff_Adlm_SL' => 'ฟูลาห์ (อัดลัม, เซียร์ราลีโอน)',
+        'ff_Adlm_SN' => 'ฟูลาห์ (อัดลัม, เซเนกัล)',
         'ff_CM' => 'ฟูลาห์ (แคเมอรูน)',
         'ff_GN' => 'ฟูลาห์ (กินี)',
         'ff_Latn' => 'ฟูลาห์ (ละติน)',
@@ -504,6 +519,7 @@ return [
         'sd_Arab_PK' => 'สินธิ (อาหรับ, ปากีสถาน)',
         'sd_Deva' => 'สินธิ (เทวนาครี)',
         'sd_Deva_IN' => 'สินธิ (เทวนาครี, อินเดีย)',
+        'sd_IN' => 'สินธิ (อินเดีย)',
         'sd_PK' => 'สินธิ (ปากีสถาน)',
         'se' => 'ซามิเหนือ',
         'se_FI' => 'ซามิเหนือ (ฟินแลนด์)',
