@@ -71,6 +71,8 @@ return [
         'ce_RU' => 'ቸቸንይና (ሩስያ)',
         'cs' => 'ቸክኛ',
         'cs_CZ' => 'ቸክኛ (ቸክያ)',
+        'cv' => 'ቹቫሽኛ',
+        'cv_RU' => 'ቹቫሽኛ (ሩስያ)',
         'cy' => 'ዌልስኛ',
         'cy_GB' => 'ዌልስኛ (ብሪጣንያ)',
         'da' => 'ዳኒሽ',
@@ -149,10 +151,11 @@ return [
         'en_MG' => 'እንግሊዝኛ (ማዳጋስካር)',
         'en_MH' => 'እንግሊዝኛ (ደሴታት ማርሻል)',
         'en_MO' => 'እንግሊዝኛ (ፍሉይ ምምሕዳራዊ ዞባ ማካው [ቻይና])',
-        'en_MP' => 'እንግሊዝኛ (ደሴታት ሰሜናዊ ማርያና)',
+        'en_MP' => 'እንግሊዝኛ (ሰሜናዊ ደሴታት ማርያና)',
         'en_MS' => 'እንግሊዝኛ (ሞንትሰራት)',
         'en_MT' => 'እንግሊዝኛ (ማልታ)',
         'en_MU' => 'እንግሊዝኛ (ማውሪሸስ)',
+        'en_MV' => 'እንግሊዝኛ (ማልዲቭስ)',
         'en_MW' => 'እንግሊዝኛ (ማላዊ)',
         'en_MY' => 'እንግሊዝኛ (ማለዥያ)',
         'en_NA' => 'እንግሊዝኛ (ናሚብያ)',
@@ -290,7 +293,7 @@ return [
         'fr_MU' => 'ፈረንሳይኛ (ማውሪሸስ)',
         'fr_NC' => 'ፈረንሳይኛ (ኒው ካለዶንያ)',
         'fr_NE' => 'ፈረንሳይኛ (ኒጀር)',
-        'fr_PF' => 'ፈረንሳይኛ (ፈረንሳይ ፖሊነዥያ)',
+        'fr_PF' => 'ፈረንሳይኛ (ፈረንሳዊት ፖሊነዥያ)',
         'fr_PM' => 'ፈረንሳይኛ (ቅዱስ ፕየርን ሚከሎንን)',
         'fr_RE' => 'ፈረንሳይኛ (ርዩንየን)',
         'fr_RW' => 'ፈረንሳይኛ (ርዋንዳ)',
@@ -324,6 +327,8 @@ return [
         'he_IL' => 'እብራይስጢ (እስራኤል)',
         'hi' => 'ሂንዲ',
         'hi_IN' => 'ሂንዲ (ህንዲ)',
+        'hi_Latn' => 'ሂንዲ (ላቲን)',
+        'hi_Latn_IN' => 'ሂንዲ (ላቲን፣ ህንዲ)',
         'hr' => 'ክሮኤሽያን',
         'hr_BA' => 'ክሮኤሽያን (ቦዝንያን ሄርዘጎቪናን)',
         'hr_HR' => 'ክሮኤሽያን (ክሮኤሽያ)',
@@ -414,8 +419,8 @@ return [
         'nb' => 'ኖርወያዊ ቦክማል',
         'nb_NO' => 'ኖርወያዊ ቦክማል (ኖርወይ)',
         'nb_SJ' => 'ኖርወያዊ ቦክማል (ስቫልባርድን ጃን ማየንን)',
-        'nd' => 'ሰሜን ንደበለ',
-        'nd_ZW' => 'ሰሜን ንደበለ (ዚምባብዌ)',
+        'nd' => 'ሰሜን ኤንደበለ',
+        'nd_ZW' => 'ሰሜን ኤንደበለ (ዚምባብዌ)',
         'ne' => 'ኔፓሊ',
         'ne_IN' => 'ኔፓሊ (ህንዲ)',
         'ne_NP' => 'ኔፓሊ (ኔፓል)',
@@ -482,7 +487,10 @@ return [
         'rw_RW' => 'ኪንያርዋንዳ (ርዋንዳ)',
         'sa' => 'ሳንስክሪት',
         'sa_IN' => 'ሳንስክሪት (ህንዲ)',
+        'sc' => 'ሳርዲንኛ',
+        'sc_IT' => 'ሳርዲንኛ (ኢጣልያ)',
         'sd' => 'ሲንድሂ',
+        'sd_IN' => 'ሲንድሂ (ህንዲ)',
         'sd_PK' => 'ሲንድሂ (ፓኪስታን)',
         'se' => 'ሰሜናዊ ሳሚ',
         'se_FI' => 'ሰሜናዊ ሳሚ (ፊንላንድ)',
@@ -508,14 +516,14 @@ return [
         'sq' => 'ኣልባንኛ',
         'sq_AL' => 'ኣልባንኛ (ኣልባንያ)',
         'sq_MK' => 'ኣልባንኛ (ሰሜን መቄዶንያ)',
-        'sr' => 'ሰርብኛ',
-        'sr_BA' => 'ሰርብኛ (ቦዝንያን ሄርዘጎቪናን)',
-        'sr_Latn' => 'ሰርብኛ (ላቲን)',
-        'sr_Latn_BA' => 'ሰርብኛ (ላቲን፣ ቦዝንያን ሄርዘጎቪናን)',
-        'sr_Latn_ME' => 'ሰርብኛ (ላቲን፣ ሞንተኔግሮ)',
-        'sr_Latn_RS' => 'ሰርብኛ (ላቲን፣ ሰርብያ)',
-        'sr_ME' => 'ሰርብኛ (ሞንተኔግሮ)',
-        'sr_RS' => 'ሰርብኛ (ሰርብያ)',
+        'sr' => 'ቃንቃ ሰርቢያ',
+        'sr_BA' => 'ቃንቃ ሰርቢያ (ቦዝንያን ሄርዘጎቪናን)',
+        'sr_Latn' => 'ቃንቃ ሰርቢያ (ላቲን)',
+        'sr_Latn_BA' => 'ቃንቃ ሰርቢያ (ላቲን፣ ቦዝንያን ሄርዘጎቪናን)',
+        'sr_Latn_ME' => 'ቃንቃ ሰርቢያ (ላቲን፣ ሞንተኔግሮ)',
+        'sr_Latn_RS' => 'ቃንቃ ሰርቢያ (ላቲን፣ ሰርብያ)',
+        'sr_ME' => 'ቃንቃ ሰርቢያ (ሞንተኔግሮ)',
+        'sr_RS' => 'ቃንቃ ሰርቢያ (ሰርብያ)',
         'su' => 'ሱንዳንኛ',
         'su_ID' => 'ሱንዳንኛ (ኢንዶነዥያ)',
         'su_Latn' => 'ሱንዳንኛ (ላቲን)',
