@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'çeçen dili (Russiýa)',
         'cs' => 'çeh dili',
         'cs_CZ' => 'çeh dili (Çehiýa)',
+        'cv' => 'çuwaş dili',
+        'cv_RU' => 'çuwaş dili (Russiýa)',
         'cy' => 'walliý dili',
         'cy_GB' => 'walliý dili (Birleşen Patyşalyk)',
         'da' => 'daniýa dili',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'iňlis dili (Monserrat)',
         'en_MT' => 'iňlis dili (Malta)',
         'en_MU' => 'iňlis dili (Mawrikiý)',
+        'en_MV' => 'iňlis dili (Maldiwler)',
         'en_MW' => 'iňlis dili (Malawi)',
         'en_MY' => 'iňlis dili (Malaýziýa)',
         'en_NA' => 'iňlis dili (Namibiýa)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'pars dili (Owganystan)',
         'fa_IR' => 'pars dili (Eýran)',
         'ff' => 'fula dili',
+        'ff_Adlm' => 'fula dili (Adlam)',
+        'ff_Adlm_BF' => 'fula dili (Adlam, Burkina-Faso)',
+        'ff_Adlm_CM' => 'fula dili (Adlam, Kamerun)',
+        'ff_Adlm_GH' => 'fula dili (Adlam, Gana)',
+        'ff_Adlm_GM' => 'fula dili (Adlam, Gambiýa)',
+        'ff_Adlm_GN' => 'fula dili (Adlam, Gwineýa)',
+        'ff_Adlm_GW' => 'fula dili (Adlam, Gwineýa-Bisau)',
+        'ff_Adlm_LR' => 'fula dili (Adlam, Liberiýa)',
+        'ff_Adlm_MR' => 'fula dili (Adlam, Mawritaniýa)',
+        'ff_Adlm_NE' => 'fula dili (Adlam, Niger)',
+        'ff_Adlm_NG' => 'fula dili (Adlam, Nigeriýa)',
+        'ff_Adlm_SL' => 'fula dili (Adlam, Sýerra-Leone)',
+        'ff_Adlm_SN' => 'fula dili (Adlam, Senegal)',
         'ff_CM' => 'fula dili (Kamerun)',
         'ff_GN' => 'fula dili (Gwineýa)',
         'ff_Latn' => 'fula dili (Latyn elipbiýi)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'ýewreý dili (Ysraýyl)',
         'hi' => 'hindi dili',
         'hi_IN' => 'hindi dili (Hindistan)',
+        'hi_Latn' => 'hindi dili (Latyn elipbiýi)',
+        'hi_Latn_IN' => 'hindi dili (Latyn elipbiýi, Hindistan)',
         'hr' => 'horwat dili',
         'hr_BA' => 'horwat dili (Bosniýa we Gersegowina)',
         'hr_HR' => 'horwat dili (Horwatiýa)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kaşmiri dili',
         'ks_Arab' => 'kaşmiri dili (Arap elipbiýi)',
         'ks_Arab_IN' => 'kaşmiri dili (Arap elipbiýi, Hindistan)',
+        'ks_Deva' => 'kaşmiri dili (Dewanagari elipbiýi)',
+        'ks_Deva_IN' => 'kaşmiri dili (Dewanagari elipbiýi, Hindistan)',
         'ks_IN' => 'kaşmiri dili (Hindistan)',
         'ku' => 'kürt dili',
         'ku_TR' => 'kürt dili (Türkiýe)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi dili (Arap elipbiýi, Pakistan)',
         'sd_Deva' => 'sindhi dili (Dewanagari elipbiýi)',
         'sd_Deva_IN' => 'sindhi dili (Dewanagari elipbiýi, Hindistan)',
+        'sd_IN' => 'sindhi dili (Hindistan)',
         'sd_PK' => 'sindhi dili (Pakistan)',
         'se' => 'demirgazyk saam dili',
         'se_FI' => 'demirgazyk saam dili (Finlýandiýa)',
