@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Çeçence (Rusya)',
         'cs' => 'Çekçe',
         'cs_CZ' => 'Çekçe (Çekya)',
+        'cv' => 'Çuvaşça',
+        'cv_RU' => 'Çuvaşça (Rusya)',
         'cy' => 'Galce',
         'cy_GB' => 'Galce (Birleşik Krallık)',
         'da' => 'Danca',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'İngilizce (Montserrat)',
         'en_MT' => 'İngilizce (Malta)',
         'en_MU' => 'İngilizce (Mauritius)',
+        'en_MV' => 'İngilizce (Maldivler)',
         'en_MW' => 'İngilizce (Malavi)',
         'en_MY' => 'İngilizce (Malezya)',
         'en_NA' => 'İngilizce (Namibya)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'Farsça (Afganistan)',
         'fa_IR' => 'Farsça (İran)',
         'ff' => 'Fula dili',
+        'ff_Adlm' => 'Fula dili (Adlam)',
+        'ff_Adlm_BF' => 'Fula dili (Adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'Fula dili (Adlam, Kamerun)',
+        'ff_Adlm_GH' => 'Fula dili (Adlam, Gana)',
+        'ff_Adlm_GM' => 'Fula dili (Adlam, Gambiya)',
+        'ff_Adlm_GN' => 'Fula dili (Adlam, Gine)',
+        'ff_Adlm_GW' => 'Fula dili (Adlam, Gine-Bissau)',
+        'ff_Adlm_LR' => 'Fula dili (Adlam, Liberya)',
+        'ff_Adlm_MR' => 'Fula dili (Adlam, Moritanya)',
+        'ff_Adlm_NE' => 'Fula dili (Adlam, Nijer)',
+        'ff_Adlm_NG' => 'Fula dili (Adlam, Nijerya)',
+        'ff_Adlm_SL' => 'Fula dili (Adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'Fula dili (Adlam, Senegal)',
         'ff_CM' => 'Fula dili (Kamerun)',
         'ff_GN' => 'Fula dili (Gine)',
         'ff_Latn' => 'Fula dili (Latin)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'İbranice (İsrail)',
         'hi' => 'Hintçe',
         'hi_IN' => 'Hintçe (Hindistan)',
+        'hi_Latn' => 'Hintçe (Latin)',
+        'hi_Latn_IN' => 'Hintçe (Latin, Hindistan)',
         'hr' => 'Hırvatça',
         'hr_BA' => 'Hırvatça (Bosna-Hersek)',
         'hr_HR' => 'Hırvatça (Hırvatistan)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'Keşmir dili',
         'ks_Arab' => 'Keşmir dili (Arap)',
         'ks_Arab_IN' => 'Keşmir dili (Arap, Hindistan)',
+        'ks_Deva' => 'Keşmir dili (Devanagari)',
+        'ks_Deva_IN' => 'Keşmir dili (Devanagari, Hindistan)',
         'ks_IN' => 'Keşmir dili (Hindistan)',
         'ku' => 'Kürtçe',
         'ku_TR' => 'Kürtçe (Türkiye)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Sindhi dili (Arap, Pakistan)',
         'sd_Deva' => 'Sindhi dili (Devanagari)',
         'sd_Deva_IN' => 'Sindhi dili (Devanagari, Hindistan)',
+        'sd_IN' => 'Sindhi dili (Hindistan)',
         'sd_PK' => 'Sindhi dili (Pakistan)',
         'se' => 'Kuzey Laponcası',
         'se_FI' => 'Kuzey Laponcası (Finlandiya)',
