@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'چېچىنچە (رۇسىيە)',
         'cs' => 'چېخچە',
         'cs_CZ' => 'چېخچە (چېخ جۇمھۇرىيىتى)',
+        'cv' => 'چۇۋاشچە',
+        'cv_RU' => 'چۇۋاشچە (رۇسىيە)',
         'cy' => 'ۋېلشچە',
         'cy_GB' => 'ۋېلشچە (بىرلەشمە پادىشاھلىق)',
         'da' => 'دانىشچە',
@@ -504,6 +506,7 @@ return [
         'sd_Arab_PK' => 'سىندىچە (ئەرەب، پاكىستان)',
         'sd_Deva' => 'سىندىچە (دېۋاناگارى)',
         'sd_Deva_IN' => 'سىندىچە (دېۋاناگارى، ھىندىستان)',
+        'sd_IN' => 'سىندىچە (ھىندىستان)',
         'sd_PK' => 'سىندىچە (پاكىستان)',
         'se' => 'شىمالىي سامىچە',
         'se_FI' => 'شىمالىي سامىچە (فىنلاندىيە)',
