@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'чеченська (Росія)',
         'cs' => 'чеська',
         'cs_CZ' => 'чеська (Чехія)',
+        'cv' => 'чуваська',
+        'cv_RU' => 'чуваська (Росія)',
         'cy' => 'валлійська',
         'cy_GB' => 'валлійська (Велика Британія)',
         'da' => 'данська',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'англійська (Монтсеррат)',
         'en_MT' => 'англійська (Мальта)',
         'en_MU' => 'англійська (Маврикій)',
+        'en_MV' => 'англійська (Мальдіви)',
         'en_MW' => 'англійська (Малаві)',
         'en_MY' => 'англійська (Малайзія)',
         'en_NA' => 'англійська (Намібія)',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'іврит (Ізраїль)',
         'hi' => 'гінді',
         'hi_IN' => 'гінді (Індія)',
+        'hi_Latn' => 'гінді (латиниця)',
+        'hi_Latn_IN' => 'гінді (латиниця, Індія)',
         'hr' => 'хорватська',
         'hr_BA' => 'хорватська (Боснія і Герцеговина)',
         'hr_HR' => 'хорватська (Хорватія)',
@@ -385,6 +390,8 @@ return [
         'ks' => 'кашмірська',
         'ks_Arab' => 'кашмірська (арабиця)',
         'ks_Arab_IN' => 'кашмірська (арабиця, Індія)',
+        'ks_Deva' => 'кашмірська (деванагарі)',
+        'ks_Deva_IN' => 'кашмірська (деванагарі, Індія)',
         'ks_IN' => 'кашмірська (Індія)',
         'ku' => 'курдська',
         'ku_TR' => 'курдська (Туреччина)',
@@ -482,7 +489,7 @@ return [
         'pt_MZ' => 'португальська (Мозамбік)',
         'pt_PT' => 'португальська (Португалія)',
         'pt_ST' => 'португальська (Сан-Томе і Принсіпі)',
-        'pt_TL' => 'португальська (Тімор-Лешті)',
+        'pt_TL' => 'португальська (Тимор-Лешті)',
         'qu' => 'кечуа',
         'qu_BO' => 'кечуа (Болівія)',
         'qu_EC' => 'кечуа (Еквадор)',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'синдхі (арабиця, Пакистан)',
         'sd_Deva' => 'синдхі (деванагарі)',
         'sd_Deva_IN' => 'синдхі (деванагарі, Індія)',
+        'sd_IN' => 'синдхі (Індія)',
         'sd_PK' => 'синдхі (Пакистан)',
         'se' => 'північносаамська',
         'se_FI' => 'північносаамська (Фінляндія)',
