@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'چیچن (روس)',
         'cs' => 'چیک',
         'cs_CZ' => 'چیک (چیکیا)',
+        'cv' => 'چوواش',
+        'cv_RU' => 'چوواش (روس)',
         'cy' => 'ویلش',
         'cy_GB' => 'ویلش (سلطنت متحدہ)',
         'da' => 'ڈینش',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'انگریزی (مونٹسیراٹ)',
         'en_MT' => 'انگریزی (مالٹا)',
         'en_MU' => 'انگریزی (ماریشس)',
+        'en_MV' => 'انگریزی (مالدیپ)',
         'en_MW' => 'انگریزی (ملاوی)',
         'en_MY' => 'انگریزی (ملائشیا)',
         'en_NA' => 'انگریزی (نامیبیا)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'فارسی (افغانستان)',
         'fa_IR' => 'فارسی (ایران)',
         'ff' => 'فولہ',
+        'ff_Adlm' => 'فولہ (ایڈلم)',
+        'ff_Adlm_BF' => 'فولہ (ایڈلم،برکینا فاسو)',
+        'ff_Adlm_CM' => 'فولہ (ایڈلم،کیمرون)',
+        'ff_Adlm_GH' => 'فولہ (ایڈلم،گھانا)',
+        'ff_Adlm_GM' => 'فولہ (ایڈلم،گیمبیا)',
+        'ff_Adlm_GN' => 'فولہ (ایڈلم،گنی)',
+        'ff_Adlm_GW' => 'فولہ (ایڈلم،گنی بساؤ)',
+        'ff_Adlm_LR' => 'فولہ (ایڈلم،لائبیریا)',
+        'ff_Adlm_MR' => 'فولہ (ایڈلم،موریطانیہ)',
+        'ff_Adlm_NE' => 'فولہ (ایڈلم،نائجر)',
+        'ff_Adlm_NG' => 'فولہ (ایڈلم،نائجیریا)',
+        'ff_Adlm_SL' => 'فولہ (ایڈلم،سیرالیون)',
+        'ff_Adlm_SN' => 'فولہ (ایڈلم،سینیگل)',
         'ff_CM' => 'فولہ (کیمرون)',
         'ff_GN' => 'فولہ (گنی)',
         'ff_Latn' => 'فولہ (لاطینی)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'عبرانی (اسرائیل)',
         'hi' => 'ہندی',
         'hi_IN' => 'ہندی (بھارت)',
+        'hi_Latn' => 'ہندی (لاطینی)',
+        'hi_Latn_IN' => 'ہندی (لاطینی،بھارت)',
         'hr' => 'کراتی',
         'hr_BA' => 'کراتی (بوسنیا اور ہرزیگووینا)',
         'hr_HR' => 'کراتی (کروشیا)',
@@ -372,9 +390,11 @@ return [
         'ks' => 'کشمیری',
         'ks_Arab' => 'کشمیری (عربی)',
         'ks_Arab_IN' => 'کشمیری (عربی،بھارت)',
+        'ks_Deva' => 'کشمیری (دیوناگری)',
+        'ks_Deva_IN' => 'کشمیری (دیوناگری،بھارت)',
         'ks_IN' => 'کشمیری (بھارت)',
         'ku' => 'کردش',
-        'ku_TR' => 'کردش (ترکی)',
+        'ku_TR' => 'کردش (ترکیہ)',
         'kw' => 'کورنش',
         'kw_GB' => 'کورنش (سلطنت متحدہ)',
         'ky' => 'کرغیزی',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'سندھی (عربی،پاکستان)',
         'sd_Deva' => 'سندھی (دیوناگری)',
         'sd_Deva_IN' => 'سندھی (دیوناگری،بھارت)',
+        'sd_IN' => 'سندھی (بھارت)',
         'sd_PK' => 'سندھی (پاکستان)',
         'se' => 'شمالی سامی',
         'se_FI' => 'شمالی سامی (فن لینڈ)',
@@ -571,7 +592,7 @@ return [
         'to_TO' => 'ٹونگن (ٹونگا)',
         'tr' => 'ترکی',
         'tr_CY' => 'ترکی (قبرص)',
-        'tr_TR' => 'ترکی (ترکی)',
+        'tr_TR' => 'ترکی (ترکیہ)',
         'tt' => 'تاتار',
         'tt_RU' => 'تاتار (روس)',
         'ug' => 'یوئگہر',
