@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'chechen (Rossiya)',
         'cs' => 'chex',
         'cs_CZ' => 'chex (Chexiya)',
+        'cv' => 'chuvash',
+        'cv_RU' => 'chuvash (Rossiya)',
         'cy' => 'valliy',
         'cy_GB' => 'valliy (Buyuk Britaniya)',
         'da' => 'dan',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'inglizcha (Montserrat)',
         'en_MT' => 'inglizcha (Malta)',
         'en_MU' => 'inglizcha (Mavrikiy)',
+        'en_MV' => 'inglizcha (Maldiv orollari)',
         'en_MW' => 'inglizcha (Malavi)',
         'en_MY' => 'inglizcha (Malayziya)',
         'en_NA' => 'inglizcha (Namibiya)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'fors (Afgʻoniston)',
         'fa_IR' => 'fors (Eron)',
         'ff' => 'fula',
+        'ff_Adlm' => 'fula (adlam)',
+        'ff_Adlm_BF' => 'fula (adlam, Burkina-Faso)',
+        'ff_Adlm_CM' => 'fula (adlam, Kamerun)',
+        'ff_Adlm_GH' => 'fula (adlam, Gana)',
+        'ff_Adlm_GM' => 'fula (adlam, Gambiya)',
+        'ff_Adlm_GN' => 'fula (adlam, Gvineya)',
+        'ff_Adlm_GW' => 'fula (adlam, Gvineya-Bisau)',
+        'ff_Adlm_LR' => 'fula (adlam, Liberiya)',
+        'ff_Adlm_MR' => 'fula (adlam, Mavritaniya)',
+        'ff_Adlm_NE' => 'fula (adlam, Niger)',
+        'ff_Adlm_NG' => 'fula (adlam, Nigeriya)',
+        'ff_Adlm_SL' => 'fula (adlam, Syerra-Leone)',
+        'ff_Adlm_SN' => 'fula (adlam, Senegal)',
         'ff_CM' => 'fula (Kamerun)',
         'ff_GN' => 'fula (Gvineya)',
         'ff_Latn' => 'fula (lotin)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'ivrit (Isroil)',
         'hi' => 'hind',
         'hi_IN' => 'hind (Hindiston)',
+        'hi_Latn' => 'hind (lotin)',
+        'hi_Latn_IN' => 'hind (lotin, Hindiston)',
         'hr' => 'xorvat',
         'hr_BA' => 'xorvat (Bosniya va Gertsegovina)',
         'hr_HR' => 'xorvat (Xorvatiya)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'kashmircha',
         'ks_Arab' => 'kashmircha (arab)',
         'ks_Arab_IN' => 'kashmircha (arab, Hindiston)',
+        'ks_Deva' => 'kashmircha (devanagari)',
+        'ks_Deva_IN' => 'kashmircha (devanagari, Hindiston)',
         'ks_IN' => 'kashmircha (Hindiston)',
         'ku' => 'kurdcha',
         'ku_TR' => 'kurdcha (Turkiya)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'sindhi (arab, Pokiston)',
         'sd_Deva' => 'sindhi (devanagari)',
         'sd_Deva_IN' => 'sindhi (devanagari, Hindiston)',
+        'sd_IN' => 'sindhi (Hindiston)',
         'sd_PK' => 'sindhi (Pokiston)',
         'se' => 'shimoliy saam',
         'se_FI' => 'shimoliy saam (Finlandiya)',
@@ -600,15 +621,15 @@ return [
         'zh' => 'xitoy',
         'zh_CN' => 'xitoy (Xitoy)',
         'zh_HK' => 'xitoy (Gonkong [Xitoy MMH])',
-        'zh_Hans' => 'xitoy (soddalashgan xitoy)',
-        'zh_Hans_CN' => 'xitoy (soddalashgan xitoy, Xitoy)',
-        'zh_Hans_HK' => 'xitoy (soddalashgan xitoy, Gonkong [Xitoy MMH])',
-        'zh_Hans_MO' => 'xitoy (soddalashgan xitoy, Makao [Xitoy MMH])',
-        'zh_Hans_SG' => 'xitoy (soddalashgan xitoy, Singapur)',
-        'zh_Hant' => 'xitoy (an’anaviy xitoy)',
-        'zh_Hant_HK' => 'xitoy (an’anaviy xitoy, Gonkong [Xitoy MMH])',
-        'zh_Hant_MO' => 'xitoy (an’anaviy xitoy, Makao [Xitoy MMH])',
-        'zh_Hant_TW' => 'xitoy (an’anaviy xitoy, Tayvan)',
+        'zh_Hans' => 'xitoy (soddalashgan)',
+        'zh_Hans_CN' => 'xitoy (soddalashgan, Xitoy)',
+        'zh_Hans_HK' => 'xitoy (soddalashgan, Gonkong [Xitoy MMH])',
+        'zh_Hans_MO' => 'xitoy (soddalashgan, Makao [Xitoy MMH])',
+        'zh_Hans_SG' => 'xitoy (soddalashgan, Singapur)',
+        'zh_Hant' => 'xitoy (anʼanaviy)',
+        'zh_Hant_HK' => 'xitoy (anʼanaviy, Gonkong [Xitoy MMH])',
+        'zh_Hant_MO' => 'xitoy (anʼanaviy, Makao [Xitoy MMH])',
+        'zh_Hant_TW' => 'xitoy (anʼanaviy, Tayvan)',
         'zh_MO' => 'xitoy (Makao [Xitoy MMH])',
         'zh_SG' => 'xitoy (Singapur)',
         'zh_TW' => 'xitoy (Tayvan)',
