@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Tiếng Chechen (Nga)',
         'cs' => 'Tiếng Séc',
         'cs_CZ' => 'Tiếng Séc (Séc)',
+        'cv' => 'Tiếng Chuvash',
+        'cv_RU' => 'Tiếng Chuvash (Nga)',
         'cy' => 'Tiếng Wales',
         'cy_GB' => 'Tiếng Wales (Vương quốc Anh)',
         'da' => 'Tiếng Đan Mạch',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'Tiếng Anh (Montserrat)',
         'en_MT' => 'Tiếng Anh (Malta)',
         'en_MU' => 'Tiếng Anh (Mauritius)',
+        'en_MV' => 'Tiếng Anh (Maldives)',
         'en_MW' => 'Tiếng Anh (Malawi)',
         'en_MY' => 'Tiếng Anh (Malaysia)',
         'en_NA' => 'Tiếng Anh (Namibia)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'Tiếng Ba Tư (Afghanistan)',
         'fa_IR' => 'Tiếng Ba Tư (Iran)',
         'ff' => 'Tiếng Fulah',
+        'ff_Adlm' => 'Tiếng Fulah (Chữ Adlam)',
+        'ff_Adlm_BF' => 'Tiếng Fulah (Chữ Adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'Tiếng Fulah (Chữ Adlam, Cameroon)',
+        'ff_Adlm_GH' => 'Tiếng Fulah (Chữ Adlam, Ghana)',
+        'ff_Adlm_GM' => 'Tiếng Fulah (Chữ Adlam, Gambia)',
+        'ff_Adlm_GN' => 'Tiếng Fulah (Chữ Adlam, Guinea)',
+        'ff_Adlm_GW' => 'Tiếng Fulah (Chữ Adlam, Guinea-Bissau)',
+        'ff_Adlm_LR' => 'Tiếng Fulah (Chữ Adlam, Liberia)',
+        'ff_Adlm_MR' => 'Tiếng Fulah (Chữ Adlam, Mauritania)',
+        'ff_Adlm_NE' => 'Tiếng Fulah (Chữ Adlam, Niger)',
+        'ff_Adlm_NG' => 'Tiếng Fulah (Chữ Adlam, Nigeria)',
+        'ff_Adlm_SL' => 'Tiếng Fulah (Chữ Adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'Tiếng Fulah (Chữ Adlam, Senegal)',
         'ff_CM' => 'Tiếng Fulah (Cameroon)',
         'ff_GN' => 'Tiếng Fulah (Guinea)',
         'ff_Latn' => 'Tiếng Fulah (Chữ La tinh)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'Tiếng Do Thái (Israel)',
         'hi' => 'Tiếng Hindi',
         'hi_IN' => 'Tiếng Hindi (Ấn Độ)',
+        'hi_Latn' => 'Tiếng Hindi (Chữ La tinh)',
+        'hi_Latn_IN' => 'Tiếng Hindi (Chữ La tinh, Ấn Độ)',
         'hr' => 'Tiếng Croatia',
         'hr_BA' => 'Tiếng Croatia (Bosnia và Herzegovina)',
         'hr_HR' => 'Tiếng Croatia (Croatia)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'Tiếng Kashmir',
         'ks_Arab' => 'Tiếng Kashmir (Chữ Ả Rập)',
         'ks_Arab_IN' => 'Tiếng Kashmir (Chữ Ả Rập, Ấn Độ)',
+        'ks_Deva' => 'Tiếng Kashmir (Chữ Devanagari)',
+        'ks_Deva_IN' => 'Tiếng Kashmir (Chữ Devanagari, Ấn Độ)',
         'ks_IN' => 'Tiếng Kashmir (Ấn Độ)',
         'ku' => 'Tiếng Kurd',
         'ku_TR' => 'Tiếng Kurd (Thổ Nhĩ Kỳ)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Tiếng Sindhi (Chữ Ả Rập, Pakistan)',
         'sd_Deva' => 'Tiếng Sindhi (Chữ Devanagari)',
         'sd_Deva_IN' => 'Tiếng Sindhi (Chữ Devanagari, Ấn Độ)',
+        'sd_IN' => 'Tiếng Sindhi (Ấn Độ)',
         'sd_PK' => 'Tiếng Sindhi (Pakistan)',
         'se' => 'Tiếng Sami Miền Bắc',
         'se_FI' => 'Tiếng Sami Miền Bắc (Phần Lan)',
