@@ -121,6 +121,7 @@ return [
         'en_GM' => 'Àngale (Gàmbi)',
         'en_GU' => 'Àngale (Guwam)',
         'en_GY' => 'Àngale (Giyaan)',
+        'en_HK' => 'Àngale (Ooŋ Koŋ)',
         'en_IE' => 'Àngale (Irlànd)',
         'en_IL' => 'Àngale (Israyel)',
         'en_IM' => 'Àngale (Dunu Maan)',
@@ -137,10 +138,12 @@ return [
         'en_LS' => 'Àngale (Lesoto)',
         'en_MG' => 'Àngale (Madagaskaar)',
         'en_MH' => 'Àngale (Duni Marsaal)',
+        'en_MO' => 'Àngale (Makaawo)',
         'en_MP' => 'Àngale (Duni Mariyaan Noor)',
         'en_MS' => 'Àngale (Mooseraa)',
         'en_MT' => 'Àngale (Malt)',
         'en_MU' => 'Àngale (Moriis)',
+        'en_MV' => 'Àngale (Maldiiw)',
         'en_MW' => 'Àngale (Malawi)',
         'en_MY' => 'Àngale (Malesi)',
         'en_NA' => 'Àngale (Namibi)',
@@ -249,7 +252,9 @@ return [
         'fr_BJ' => 'Farañse (Benee)',
         'fr_BL' => 'Farañse (Saŋ Bartalemi)',
         'fr_CA' => 'Farañse (Kanadaa)',
+        'fr_CD' => 'Farañse (Kongo [R K D])',
         'fr_CF' => 'Farañse (Repiblik Sàntar Afrik)',
+        'fr_CG' => 'Farañse (Réewum Kongo)',
         'fr_CH' => 'Farañse (Siwis)',
         'fr_CI' => 'Farañse (Kodiwaar)',
         'fr_CM' => 'Farañse (Kamerun)',
@@ -304,6 +309,8 @@ return [
         'he_IL' => 'Ebrë (Israyel)',
         'hi' => 'Endo',
         'hi_IN' => 'Endo (End)',
+        'hi_Latn' => 'Endo (Latin)',
+        'hi_Latn_IN' => 'Endo (Latin, End)',
         'hr' => 'Krowat',
         'hr_BA' => 'Krowat (Bosni Ersegowin)',
         'hr_HR' => 'Krowat (Korowasi)',
@@ -406,6 +413,7 @@ return [
         'pt_GQ' => 'Purtugees (Gine Ekuwatoriyal)',
         'pt_GW' => 'Purtugees (Gine-Bisaawóo)',
         'pt_LU' => 'Purtugees (Liksàmbur)',
+        'pt_MO' => 'Purtugees (Makaawo)',
         'pt_MZ' => 'Purtugees (Mosàmbig)',
         'pt_PT' => 'Purtugees (Portigaal)',
         'pt_ST' => 'Purtugees (Sawo Tome ak Pirinsipe)',
@@ -433,6 +441,7 @@ return [
         'sd' => 'Sindi',
         'sd_Arab' => 'Sindi (Araab)',
         'sd_Arab_PK' => 'Sindi (Araab, Pakistaŋ)',
+        'sd_IN' => 'Sindi (End)',
         'sd_PK' => 'Sindi (Pakistaŋ)',
         'se' => 'Penku Sami',
         'se_FI' => 'Penku Sami (Finlànd)',
@@ -517,11 +526,17 @@ return [
         'yo_NG' => 'Yoruba (Niseriya)',
         'zh' => 'Sinuwaa',
         'zh_CN' => 'Sinuwaa (Siin)',
+        'zh_HK' => 'Sinuwaa (Ooŋ Koŋ)',
         'zh_Hans' => 'Sinuwaa (Buñ woyofal)',
         'zh_Hans_CN' => 'Sinuwaa (Buñ woyofal, Siin)',
+        'zh_Hans_HK' => 'Sinuwaa (Buñ woyofal, Ooŋ Koŋ)',
+        'zh_Hans_MO' => 'Sinuwaa (Buñ woyofal, Makaawo)',
         'zh_Hans_SG' => 'Sinuwaa (Buñ woyofal, Singapuur)',
         'zh_Hant' => 'Sinuwaa (Cosaan)',
+        'zh_Hant_HK' => 'Sinuwaa (Cosaan, Ooŋ Koŋ)',
+        'zh_Hant_MO' => 'Sinuwaa (Cosaan, Makaawo)',
         'zh_Hant_TW' => 'Sinuwaa (Cosaan, Taywan)',
+        'zh_MO' => 'Sinuwaa (Makaawo)',
         'zh_SG' => 'Sinuwaa (Singapuur)',
         'zh_TW' => 'Sinuwaa (Taywan)',
     ],
