@@ -42,8 +42,8 @@ return [
         'as_IN' => '阿薩姆文（印度）',
         'az' => '亞塞拜然文',
         'az_AZ' => '亞塞拜然文（亞塞拜然）',
-        'az_Cyrl' => '亞塞拜然文（斯拉夫文）',
-        'az_Cyrl_AZ' => '亞塞拜然文（斯拉夫文，亞塞拜然）',
+        'az_Cyrl' => '亞塞拜然文（西里爾文字）',
+        'az_Cyrl_AZ' => '亞塞拜然文（西里爾文字，亞塞拜然）',
         'az_Latn' => '亞塞拜然文（拉丁文）',
         'az_Latn_AZ' => '亞塞拜然文（拉丁文，亞塞拜然）',
         'be' => '白俄羅斯文',
@@ -62,8 +62,8 @@ return [
         'br_FR' => '布列塔尼文（法國）',
         'bs' => '波士尼亞文',
         'bs_BA' => '波士尼亞文（波士尼亞與赫塞哥維納）',
-        'bs_Cyrl' => '波士尼亞文（斯拉夫文）',
-        'bs_Cyrl_BA' => '波士尼亞文（斯拉夫文，波士尼亞與赫塞哥維納）',
+        'bs_Cyrl' => '波士尼亞文（西里爾文字）',
+        'bs_Cyrl_BA' => '波士尼亞文（西里爾文字，波士尼亞與赫塞哥維納）',
         'bs_Latn' => '波士尼亞文（拉丁文）',
         'bs_Latn_BA' => '波士尼亞文（拉丁文，波士尼亞與赫塞哥維納）',
         'ca' => '加泰蘭文',
@@ -75,6 +75,8 @@ return [
         'ce_RU' => '車臣文（俄羅斯）',
         'cs' => '捷克文',
         'cs_CZ' => '捷克文（捷克）',
+        'cv' => '楚瓦什文',
+        'cv_RU' => '楚瓦什文（俄羅斯）',
         'cy' => '威爾斯文',
         'cy_GB' => '威爾斯文（英國）',
         'da' => '丹麥文',
@@ -157,6 +159,7 @@ return [
         'en_MS' => '英文（蒙哲臘）',
         'en_MT' => '英文（馬爾他）',
         'en_MU' => '英文（模里西斯）',
+        'en_MV' => '英文（馬爾地夫）',
         'en_MW' => '英文（馬拉威）',
         'en_MY' => '英文（馬來西亞）',
         'en_NA' => '英文（納米比亞）',
@@ -341,6 +344,8 @@ return [
         'he_IL' => '希伯來文（以色列）',
         'hi' => '印地文',
         'hi_IN' => '印地文（印度）',
+        'hi_Latn' => '印地文（拉丁文）',
+        'hi_Latn_IN' => '印地文（拉丁文，印度）',
         'hr' => '克羅埃西亞文',
         'hr_BA' => '克羅埃西亞文（波士尼亞與赫塞哥維納）',
         'hr_HR' => '克羅埃西亞文（克羅埃西亞）',
@@ -383,8 +388,10 @@ return [
         'ko_KP' => '韓文（北韓）',
         'ko_KR' => '韓文（南韓）',
         'ks' => '喀什米爾文',
-        'ks_Arab' => '喀什米爾文（阿拉伯文）',
-        'ks_Arab_IN' => '喀什米爾文（阿拉伯文，印度）',
+        'ks_Arab' => '喀什米爾文（阿拉伯字母）',
+        'ks_Arab_IN' => '喀什米爾文（阿拉伯字母，印度）',
+        'ks_Deva' => '喀什米爾文（天城文）',
+        'ks_Deva_IN' => '喀什米爾文（天城文，印度）',
         'ks_IN' => '喀什米爾文（印度）',
         'ku' => '庫德文',
         'ku_TR' => '庫德文（土耳其）',
@@ -459,8 +466,8 @@ return [
         'os_GE' => '奧塞提文（喬治亞）',
         'os_RU' => '奧塞提文（俄羅斯）',
         'pa' => '旁遮普文',
-        'pa_Arab' => '旁遮普文（阿拉伯文）',
-        'pa_Arab_PK' => '旁遮普文（阿拉伯文，巴基斯坦）',
+        'pa_Arab' => '旁遮普文（阿拉伯字母）',
+        'pa_Arab_PK' => '旁遮普文（阿拉伯字母，巴基斯坦）',
         'pa_Guru' => '旁遮普文（古魯穆奇文）',
         'pa_Guru_IN' => '旁遮普文（古魯穆奇文，印度）',
         'pa_IN' => '旁遮普文（印度）',
@@ -508,10 +515,11 @@ return [
         'sc' => '撒丁文',
         'sc_IT' => '撒丁文（義大利）',
         'sd' => '信德文',
-        'sd_Arab' => '信德文（阿拉伯文）',
-        'sd_Arab_PK' => '信德文（阿拉伯文，巴基斯坦）',
+        'sd_Arab' => '信德文（阿拉伯字母）',
+        'sd_Arab_PK' => '信德文（阿拉伯字母，巴基斯坦）',
         'sd_Deva' => '信德文（天城文）',
         'sd_Deva_IN' => '信德文（天城文，印度）',
+        'sd_IN' => '信德文（印度）',
         'sd_PK' => '信德文（巴基斯坦）',
         'se' => '北薩米文',
         'se_FI' => '北薩米文（芬蘭）',
@@ -539,10 +547,10 @@ return [
         'sq_MK' => '阿爾巴尼亞文（北馬其頓）',
         'sr' => '塞爾維亞文',
         'sr_BA' => '塞爾維亞文（波士尼亞與赫塞哥維納）',
-        'sr_Cyrl' => '塞爾維亞文（斯拉夫文）',
-        'sr_Cyrl_BA' => '塞爾維亞文（斯拉夫文，波士尼亞與赫塞哥維納）',
-        'sr_Cyrl_ME' => '塞爾維亞文（斯拉夫文，蒙特內哥羅）',
-        'sr_Cyrl_RS' => '塞爾維亞文（斯拉夫文，塞爾維亞）',
+        'sr_Cyrl' => '塞爾維亞文（西里爾文字）',
+        'sr_Cyrl_BA' => '塞爾維亞文（西里爾文字，波士尼亞與赫塞哥維納）',
+        'sr_Cyrl_ME' => '塞爾維亞文（西里爾文字，蒙特內哥羅）',
+        'sr_Cyrl_RS' => '塞爾維亞文（西里爾文字，塞爾維亞）',
         'sr_Latn' => '塞爾維亞文（拉丁文）',
         'sr_Latn_BA' => '塞爾維亞文（拉丁文，波士尼亞與赫塞哥維納）',
         'sr_Latn_ME' => '塞爾維亞文（拉丁文，蒙特內哥羅）',
@@ -596,10 +604,10 @@ return [
         'ur_PK' => '烏都文（巴基斯坦）',
         'uz' => '烏茲別克文',
         'uz_AF' => '烏茲別克文（阿富汗）',
-        'uz_Arab' => '烏茲別克文（阿拉伯文）',
-        'uz_Arab_AF' => '烏茲別克文（阿拉伯文，阿富汗）',
-        'uz_Cyrl' => '烏茲別克文（斯拉夫文）',
-        'uz_Cyrl_UZ' => '烏茲別克文（斯拉夫文，烏茲別克）',
+        'uz_Arab' => '烏茲別克文（阿拉伯字母）',
+        'uz_Arab_AF' => '烏茲別克文（阿拉伯字母，阿富汗）',
+        'uz_Cyrl' => '烏茲別克文（西里爾文字）',
+        'uz_Cyrl_UZ' => '烏茲別克文（西里爾文字，烏茲別克）',
         'uz_Latn' => '烏茲別克文（拉丁文）',
         'uz_Latn_UZ' => '烏茲別克文（拉丁文，烏茲別克）',
         'uz_UZ' => '烏茲別克文（烏茲別克）',
