@@ -226,7 +226,7 @@ return [
         'TM' => '투르크메니스탄',
         'TN' => '튀니지',
         'TO' => '통가',
-        'TR' => '터키',
+        'TR' => '튀르키예',
         'TT' => '트리니다드 토바고',
         'TV' => '투발루',
         'TW' => '대만',
