@@ -2,11 +2,16 @@
 
 return [
     'Names' => [
+        'Adlm' => 'Adlam',
         'Arab' => 'Larabci',
+        'Aran' => 'Rubutun Nastaliq',
         'Armn' => 'Armeniyawa',
         'Beng' => 'Bangla',
         'Bopo' => 'Bopomofo',
         'Brai' => 'Rubutun Makafi',
+        'Cakm' => 'Chakma',
+        'Cans' => 'Haɗaɗɗun Gaɓoɓin ʼYan Asali na Kanada',
+        'Cher' => 'Cherokee',
         'Cyrl' => 'Cyrillic',
         'Deva' => 'Devanagari',
         'Ethi' => 'Ethiopic',
@@ -31,14 +36,23 @@ return [
         'Latn' => 'Latin',
         'Mlym' => 'Yaren Malayalam',
         'Mong' => 'Na kasar Mongolia',
+        'Mtei' => 'Meitei Mayek',
         'Mymr' => 'Ƙasar Myanmar',
+        'Nkoo' => 'N’Ko',
+        'Olck' => 'Ol Chiki',
         'Orya' => 'Yaren Odia',
+        'Rohg' => 'Hanifi',
         'Sinh' => 'Yaren Sinhala',
+        'Sund' => 'Sudananci',
+        'Syrc' => 'Siriyanci',
         'Taml' => 'Yaren Tamil',
         'Telu' => 'Yaren Telugu',
+        'Tfng' => 'Tifinagh',
         'Thaa' => 'Yaren Thaana',
         'Thai' => 'Thai',
         'Tibt' => 'Yaren Tibet',
+        'Vaii' => 'Vai',
+        'Yiii' => 'Yi',
         'Zmth' => 'Alamar Lissafi',
         'Zsye' => 'Alama ta hoto',
         'Zsym' => 'Alamomi',
