@@ -2,11 +2,16 @@
 
 return [
     'Names' => [
+        'Adlm' => 'Adlam',
         'Arab' => 'Arabic',
+        'Aran' => 'Nastaliq',
         'Armn' => 'Armenian',
         'Beng' => 'Bangla',
         'Bopo' => 'Bopomofo',
         'Brai' => 'Braille',
+        'Cakm' => 'Chakma',
+        'Cans' => 'Unified Canadian Aboriginal Syllabics',
+        'Cher' => 'Cherokee',
         'Cyrl' => 'Cyrillic',
         'Deva' => 'Devanagari',
         'Ethi' => 'Ethiopic',
@@ -32,14 +37,23 @@ return [
         'Latn' => 'Latin',
         'Mlym' => 'Malayalam',
         'Mong' => 'Mongolian',
+        'Mtei' => 'Meitei Mayek',
         'Mymr' => 'Myanmar',
+        'Nkoo' => 'N’Ko',
+        'Olck' => 'Ol Chiki',
         'Orya' => 'Odia',
+        'Rohg' => 'Hanifi',
         'Sinh' => 'Sinhala',
+        'Sund' => 'Sundanese',
+        'Syrc' => 'Syriac',
         'Taml' => 'Tamil',
         'Telu' => 'Telugu',
+        'Tfng' => 'Tifinagh',
         'Thaa' => 'Thaana',
         'Thai' => 'Thai',
         'Tibt' => 'Tibetan',
+        'Vaii' => 'Vai',
+        'Yiii' => 'Yi',
         'Zmth' => 'Mathematical Notation',
         'Zsye' => 'Emoji',
         'Zsym' => 'Mga Simbolo',
