@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'የፈረንሳይ ጉያና ሰዓት (ካይንኤ)',
         'America/Cayman' => 'ምስራቃዊ ሰዓት አቆጣጠር (ካይማን)',
         'America/Chicago' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ቺካጎ)',
-        'America/Chihuahua' => 'የሜክሲኮ ፓሲፊክ ሰዓት አቆጣጠር (ቺሁዋውአ)',
+        'America/Chihuahua' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ቺሁዋውአ)',
+        'America/Ciudad_Juarez' => 'የተራራ የሰዓት አቆጣጠር (ሳዮዳድ ሁዋሬዝ)',
         'America/Coral_Harbour' => 'ምስራቃዊ ሰዓት አቆጣጠር (አቲኮካን)',
         'America/Cordoba' => 'የአርጀንቲና የሰዓት አቆጣጠር (ኮርዶባ)',
         'America/Costa_Rica' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ኮስታሪካ)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'የአትላንቲክ የሰዓት አቆጣጠር (ሞንክቶን)',
         'America/Monterrey' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ሞንተርሬይ)',
         'America/Montevideo' => 'የኡራጓይ ሰዓት (ሞንቴቪድዮ)',
-        'America/Montreal' => 'ካናዳ ጊዜ (Montreal)',
         'America/Montserrat' => 'የአትላንቲክ የሰዓት አቆጣጠር (ሞንትሴራት)',
         'America/Nassau' => 'ምስራቃዊ ሰዓት አቆጣጠር (ናሳው)',
         'America/New_York' => 'ምስራቃዊ ሰዓት አቆጣጠር (ኒውዮርክ)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ቤኡላህ, ሰሜን ዳኮታ)',
         'America/North_Dakota/Center' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (መካከለኛ, ሰሜን ዳኮታ)',
         'America/North_Dakota/New_Salem' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (አዲስ ሳሌም, ሰሜን ዳኮታ)',
-        'America/Ojinaga' => 'የተራራ የሰዓት አቆጣጠር (ኦዪናጋ)',
+        'America/Ojinaga' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ኦዪናጋ)',
         'America/Panama' => 'ምስራቃዊ ሰዓት አቆጣጠር (ፓናማ)',
         'America/Pangnirtung' => 'ምስራቃዊ ሰዓት አቆጣጠር (ፓንግኒርተንግ)',
         'America/Paramaribo' => 'የሱሪናም ሰዓት (ፓራማሪቦ)',
