@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'توقيت غويانا الفرنسية (كايين)',
         'America/Cayman' => 'التوقيت الشرقي لأمريكا الشمالية (كايمان)',
         'America/Chicago' => 'التوقيت المركزي لأمريكا الشمالية (شيكاغو)',
-        'America/Chihuahua' => 'توقيت المحيط الهادي للمكسيك (تشيواوا)',
+        'America/Chihuahua' => 'التوقيت المركزي لأمريكا الشمالية (تشيواوا)',
+        'America/Ciudad_Juarez' => 'التوقيت الجبلي لأمريكا الشمالية (سيوداد خواريز)',
         'America/Coral_Harbour' => 'التوقيت الشرقي لأمريكا الشمالية (كورال هاربر)',
         'America/Cordoba' => 'توقيت الأرجنتين (كوردوبا)',
         'America/Costa_Rica' => 'التوقيت المركزي لأمريكا الشمالية (كوستاريكا)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'توقيت الأطلسي (وينكتون)',
         'America/Monterrey' => 'التوقيت المركزي لأمريكا الشمالية (مونتيري)',
         'America/Montevideo' => 'توقيت أوروغواي (مونتفيديو)',
-        'America/Montreal' => 'توقيت كندا (Montreal)',
         'America/Montserrat' => 'توقيت الأطلسي (مونتسيرات)',
         'America/Nassau' => 'التوقيت الشرقي لأمريكا الشمالية (ناسو)',
         'America/New_York' => 'التوقيت الشرقي لأمريكا الشمالية (نيويورك)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'التوقيت المركزي لأمريكا الشمالية (بيولا، داكوتا الشمالية)',
         'America/North_Dakota/Center' => 'التوقيت المركزي لأمريكا الشمالية (سنتر)',
         'America/North_Dakota/New_Salem' => 'التوقيت المركزي لأمريكا الشمالية (نيو ساليم)',
-        'America/Ojinaga' => 'التوقيت الجبلي لأمريكا الشمالية (أوجيناجا)',
+        'America/Ojinaga' => 'التوقيت المركزي لأمريكا الشمالية (أوجيناجا)',
         'America/Panama' => 'التوقيت الشرقي لأمريكا الشمالية (بنما)',
         'America/Pangnirtung' => 'التوقيت الشرقي لأمريكا الشمالية (بانجينتينج)',
         'America/Paramaribo' => 'توقيت سورينام (باراماريبو)',
