@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'ফ্ৰান্স গয়ানাৰ সময় (কেয়েন)',
         'America/Cayman' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (কেইমেন)',
         'America/Chicago' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (চিকাগো)',
-        'America/Chihuahua' => 'মেক্সিকোৰ প্ৰশান্ত সময় (চিহুআহুৱা)',
+        'America/Chihuahua' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (চিহুআহুৱা)',
+        'America/Ciudad_Juarez' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (চিউডে‘ড জৰেজ)',
         'America/Coral_Harbour' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (আটিকোকান)',
         'America/Cordoba' => 'আৰ্জেণ্টিনাৰ সময় (কোৰ্ডোবা)',
         'America/Costa_Rica' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (কোষ্টা ৰিকা)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'আটলাণ্টিক সময় (মন্‌কটন)',
         'America/Monterrey' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (মণ্টেৰেৰী)',
         'America/Montevideo' => 'উৰুগুৱেৰ সময় (মণ্টেভিডিঅ’)',
-        'America/Montreal' => 'কানাডা সময় (Montreal)',
         'America/Montserrat' => 'আটলাণ্টিক সময় (মণ্টছেৰাট)',
         'America/Nassau' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (নাছাউ)',
         'America/New_York' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (নিউ ইয়ৰ্ক)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (বেউলাহ, উত্তৰ ডাকোটা)',
         'America/North_Dakota/Center' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (চেণ্টাৰ, উত্তৰ ডাকোটা)',
         'America/North_Dakota/New_Salem' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (নিউ ছালেম, উত্তৰ ডাকোটা)',
-        'America/Ojinaga' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (অ’জিনাগা)',
+        'America/Ojinaga' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (অ’জিনাগা)',
         'America/Panama' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (পানামা)',
         'America/Pangnirtung' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (পাংনিৰ্টুংগ)',
         'America/Paramaribo' => 'ছুৰিনামৰ সময় (পাৰামাৰিবো)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'গ্ৰীণউইচ মান সময় (গোৰেনচি)',
         'Europe/Helsinki' => 'প্ৰাচ্য ইউৰোপীয় সময় (হেলছিংকি)',
         'Europe/Isle_of_Man' => 'গ্ৰীণউইচ মান সময় (আইল অফ মেন)',
-        'Europe/Istanbul' => 'তুৰ্কি সময় (ইস্তানবুল)',
+        'Europe/Istanbul' => 'তুৰ্কিয়ে সময় (ইস্তানবুল)',
         'Europe/Jersey' => 'গ্ৰীণউইচ মান সময় (জাৰ্চি)',
         'Europe/Kaliningrad' => 'প্ৰাচ্য ইউৰোপীয় সময় (কালিনিনগ্ৰাড)',
         'Europe/Kiev' => 'প্ৰাচ্য ইউৰোপীয় সময় (কিভ)',
