@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Fransız Qvianası Vaxtı (Kayen)',
         'America/Cayman' => 'Şimali Şərqi Amerika Vaxtı (Kayman)',
         'America/Chicago' => 'Şimali Mərkəzi Amerika Vaxtı (Çikaqo)',
-        'America/Chihuahua' => 'Meksika Sakit Okean Vaxtı (Çihuahua)',
+        'America/Chihuahua' => 'Şimali Mərkəzi Amerika Vaxtı (Çihuahua)',
+        'America/Ciudad_Juarez' => 'Şimali Dağlıq Amerika Vaxtı (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Şimali Şərqi Amerika Vaxtı (Atikokan)',
         'America/Cordoba' => 'Argentina Vaxtı (Kordoba)',
         'America/Costa_Rica' => 'Şimali Mərkəzi Amerika Vaxtı (Kosta Rika)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Atlantik Vaxt (Monkton)',
         'America/Monterrey' => 'Şimali Mərkəzi Amerika Vaxtı (Monterey)',
         'America/Montevideo' => 'Uruqvay Vaxtı (Montevideo)',
-        'America/Montreal' => 'Kanada Vaxtı (Montreal)',
         'America/Montserrat' => 'Atlantik Vaxt (Monserat)',
         'America/Nassau' => 'Şimali Şərqi Amerika Vaxtı (Nassau)',
         'America/New_York' => 'Şimali Şərqi Amerika Vaxtı (Nyu York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Şimali Mərkəzi Amerika Vaxtı (Beulah, Şimali Dakota)',
         'America/North_Dakota/Center' => 'Şimali Mərkəzi Amerika Vaxtı (Mərkəz, Şimal Dakota)',
         'America/North_Dakota/New_Salem' => 'Şimali Mərkəzi Amerika Vaxtı (Nyu Salem)',
-        'America/Ojinaga' => 'Şimali Dağlıq Amerika Vaxtı (Ocinaqa)',
+        'America/Ojinaga' => 'Şimali Mərkəzi Amerika Vaxtı (Ocinaqa)',
         'America/Panama' => 'Şimali Şərqi Amerika Vaxtı (Panama)',
         'America/Pangnirtung' => 'Şimali Şərqi Amerika Vaxtı (Panqnirtanq)',
         'America/Paramaribo' => 'Surinam Vaxtı (Paramaribo)',
