@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Френска Гвиана (Кайен)',
         'America/Cayman' => 'Северноамериканско източно време (Кайманови острови)',
         'America/Chicago' => 'Северноамериканско централно време (Чикаго)',
-        'America/Chihuahua' => 'Мексиканско тихоокеанско време (Чиуауа)',
+        'America/Chihuahua' => 'Северноамериканско централно време (Чиуауа)',
+        'America/Ciudad_Juarez' => 'Северноамериканско планинско време (Сиудад Хуарес)',
         'America/Coral_Harbour' => 'Северноамериканско източно време (Атикокан)',
         'America/Cordoba' => 'Аржентинско време (Кордоба)',
         'America/Costa_Rica' => 'Северноамериканско централно време (Коста Рика)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Северноамериканско атлантическо време (Монктон)',
         'America/Monterrey' => 'Северноамериканско централно време (Монтерей)',
         'America/Montevideo' => 'Уругвайско време (Монтевидео)',
-        'America/Montreal' => 'Канада (Montreal)',
         'America/Montserrat' => 'Северноамериканско атлантическо време (Монтсерат)',
         'America/Nassau' => 'Северноамериканско източно време (Насау)',
         'America/New_York' => 'Северноамериканско източно време (Ню Йорк)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Северноамериканско централно време (Бюла)',
         'America/North_Dakota/Center' => 'Северноамериканско централно време (Сентър)',
         'America/North_Dakota/New_Salem' => 'Северноамериканско централно време (Ню Сейлъм)',
-        'America/Ojinaga' => 'Северноамериканско планинско време (Охинага)',
+        'America/Ojinaga' => 'Северноамериканско централно време (Охинага)',
         'America/Panama' => 'Северноамериканско източно време (Панама)',
         'America/Pangnirtung' => 'Северноамериканско източно време (Пангниртунг)',
         'America/Paramaribo' => 'Суринамско време (Парамарибо)',
