@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'eur an Atlantel (Aruba)',
         'America/Asuncion' => 'eur Paraguay (Asunción)',
         'America/Bahia' => 'eur Brasília (Bahia)',
-        'America/Bahia_Banderas' => 'eur ar Cʼhreiz (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'eur ar Cʼhreiz (Bahía de Banderas)',
         'America/Barbados' => 'eur an Atlantel (Barbados)',
         'America/Belem' => 'eur Brasília (Belém)',
         'America/Belize' => 'eur ar Cʼhreiz (Belize)',
@@ -80,13 +80,14 @@ return [
         'America/Buenos_Aires' => 'eur Arcʼhantina (Buenos Aires)',
         'America/Cambridge_Bay' => 'eur ar Menezioù (Cambridge Bay)',
         'America/Campo_Grande' => 'eur an Amazon (Campo Grande)',
-        'America/Cancun' => 'eur ar Reter (Cancun)',
+        'America/Cancun' => 'eur ar Reter (Cancún)',
         'America/Caracas' => 'eur Venezuela (Caracas)',
         'America/Catamarca' => 'eur Arcʼhantina (Catamarca)',
         'America/Cayenne' => 'eur Gwiana cʼhall (Cayenne)',
         'America/Cayman' => 'eur ar Reter (Cayman)',
         'America/Chicago' => 'eur ar Cʼhreiz (Chicago)',
-        'America/Chihuahua' => 'eur an Habask mecʼhikan (Chihuahua)',
+        'America/Chihuahua' => 'eur ar Cʼhreiz (Chihuahua)',
+        'America/Ciudad_Juarez' => 'eur ar Menezioù (Ciudad Juárez)',
         'America/Coral_Harbour' => 'eur ar Reter (Atikokan)',
         'America/Cordoba' => 'eur Arcʼhantina (Cordoba)',
         'America/Costa_Rica' => 'eur ar Cʼhreiz (Costa Rica)',
@@ -145,14 +146,13 @@ return [
         'America/Mazatlan' => 'eur an Habask mecʼhikan (Mazatlan)',
         'America/Mendoza' => 'eur Arcʼhantina (Mendoza)',
         'America/Menominee' => 'eur ar Cʼhreiz (Menominee)',
-        'America/Merida' => 'eur ar Cʼhreiz (Merida)',
+        'America/Merida' => 'eur ar Cʼhreiz (Mérida)',
         'America/Metlakatla' => 'eur Alaska (Metlakatla)',
         'America/Mexico_City' => 'eur ar Cʼhreiz (Kêr Vecʼhiko)',
         'America/Miquelon' => 'eur Sant-Pêr-ha-Mikelon',
         'America/Moncton' => 'eur an Atlantel (Moncton)',
         'America/Monterrey' => 'eur ar Cʼhreiz (Monterrey)',
         'America/Montevideo' => 'eur Uruguay (Montevideo)',
-        'America/Montreal' => 'eur Kanada (Montreal)',
         'America/Montserrat' => 'eur an Atlantel (Montserrat)',
         'America/Nassau' => 'eur ar Reter (Nassau)',
         'America/New_York' => 'eur ar Reter (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'eur ar Cʼhreiz (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'eur ar Cʼhreiz (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'eur ar Cʼhreiz (New Salem, North Dakota)',
-        'America/Ojinaga' => 'eur ar Menezioù (Ojinaga)',
+        'America/Ojinaga' => 'eur ar Cʼhreiz (Ojinaga)',
         'America/Panama' => 'eur ar Reter (Panamá)',
         'America/Pangnirtung' => 'eur ar Reter (Pangnirtung)',
         'America/Paramaribo' => 'eur Surinam (Paramaribo)',
