@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Francuskogvajansko vrijeme (Cayenne)',
         'America/Cayman' => 'Sjevernoameričko istočno vrijeme (Kajman)',
         'America/Chicago' => 'Sjevernoameričko centralno vrijeme (Chicago)',
-        'America/Chihuahua' => 'Meksičko pacifičko vrijeme (Chihuahua)',
+        'America/Chihuahua' => 'Sjevernoameričko centralno vrijeme (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Sjevernoameričko planinsko vrijeme (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Sjevernoameričko istočno vrijeme (Atikokan)',
         'America/Cordoba' => 'Argentinsko vrijeme (Cordoba)',
         'America/Costa_Rica' => 'Sjevernoameričko centralno vrijeme (Kostarika)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Sjevernoameričko atlantsko vrijeme (Moncton)',
         'America/Monterrey' => 'Sjevernoameričko centralno vrijeme (Monterrey)',
         'America/Montevideo' => 'Urugvajsko vrijeme (Montevideo)',
-        'America/Montreal' => 'Kanada (Montreal)',
         'America/Montserrat' => 'Sjevernoameričko atlantsko vrijeme (Montserrat)',
         'America/Nassau' => 'Sjevernoameričko istočno vrijeme (Nassau)',
         'America/New_York' => 'Sjevernoameričko istočno vrijeme (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Sjevernoameričko centralno vrijeme (Beulah, Sjeverna Dakota)',
         'America/North_Dakota/Center' => 'Sjevernoameričko centralno vrijeme (Center, Sjeverna Dakota)',
         'America/North_Dakota/New_Salem' => 'Sjevernoameričko centralno vrijeme (New Salem, Sjeverna Dakota)',
-        'America/Ojinaga' => 'Sjevernoameričko planinsko vrijeme (Ojinaga)',
+        'America/Ojinaga' => 'Sjevernoameričko centralno vrijeme (Ojinaga)',
         'America/Panama' => 'Sjevernoameričko istočno vrijeme (Panama)',
         'America/Pangnirtung' => 'Sjevernoameričko istočno vrijeme (Pangnirtung)',
         'America/Paramaribo' => 'Surinamsko vrijeme (Paramaribo)',
