@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Француска Гвајана вријеме (Кајен)',
         'America/Cayman' => 'Источно вријеме (Кајманска острва)',
         'America/Chicago' => 'Централно вријеме (Чикаго)',
-        'America/Chihuahua' => 'Мексичко пацифичко вријеме (Чивава)',
+        'America/Chihuahua' => 'Централно вријеме (Чивава)',
+        'America/Ciudad_Juarez' => 'Планинско вријеме (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Источно вријеме (Атикокан)',
         'America/Cordoba' => 'Аргентина вријеме (Кордоба)',
         'America/Costa_Rica' => 'Централно вријеме (Костарика)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Атланско вријеме (Монктон)',
         'America/Monterrey' => 'Централно вријеме (Монтереј)',
         'America/Montevideo' => 'Уругвај вријеме (Монтевидео)',
-        'America/Montreal' => 'Време: Канада (Montreal)',
         'America/Montserrat' => 'Атланско вријеме (Монтсерат)',
         'America/Nassau' => 'Источно вријеме (Насау)',
         'America/New_York' => 'Источно вријеме (Њујорк)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Централно вријеме (Бијула, Северна Дакота)',
         'America/North_Dakota/Center' => 'Централно вријеме (Центар, Северна Дакота)',
         'America/North_Dakota/New_Salem' => 'Централно вријеме (Нови Салем, Северна Дакота)',
-        'America/Ojinaga' => 'Планинско вријеме (Охинага)',
+        'America/Ojinaga' => 'Централно вријеме (Охинага)',
         'America/Panama' => 'Источно вријеме (Панама)',
         'America/Pangnirtung' => 'Источно вријеме (Пангниртунг)',
         'America/Paramaribo' => 'Суринам вријеме (Парамарибо)',
