@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Hora de la Guaiana Francesa (Caiena)',
         'America/Cayman' => 'Hora oriental d’Amèrica del Nord (Caiman)',
         'America/Chicago' => 'Hora central d’Amèrica del Nord (Chicago)',
-        'America/Chihuahua' => 'Hora del Pacífic de Mèxic (Chihuahua)',
+        'America/Chihuahua' => 'Hora central d’Amèrica del Nord (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Hora de muntanya d’Amèrica del Nord (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Hora oriental d’Amèrica del Nord (Atikokan)',
         'America/Cordoba' => 'Hora de l’Argentina (Córdoba)',
         'America/Costa_Rica' => 'Hora central d’Amèrica del Nord (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Hora de l’Atlàntic (Moncton)',
         'America/Monterrey' => 'Hora central d’Amèrica del Nord (Monterrey)',
         'America/Montevideo' => 'Hora de l’Uruguai (Montevideo)',
-        'America/Montreal' => 'Hora de: Canadà (Montreal)',
         'America/Montserrat' => 'Hora de l’Atlàntic (Montserrat)',
         'America/Nassau' => 'Hora oriental d’Amèrica del Nord (Nassau)',
         'America/New_York' => 'Hora oriental d’Amèrica del Nord (Nova York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Hora central d’Amèrica del Nord (Beulah, Dakota del Nord)',
         'America/North_Dakota/Center' => 'Hora central d’Amèrica del Nord (Center, Dakota del Nord)',
         'America/North_Dakota/New_Salem' => 'Hora central d’Amèrica del Nord (New Salem, Dakota del Nord)',
-        'America/Ojinaga' => 'Hora de muntanya d’Amèrica del Nord (Ojinaga)',
+        'America/Ojinaga' => 'Hora central d’Amèrica del Nord (Ojinaga)',
         'America/Panama' => 'Hora oriental d’Amèrica del Nord (Panamà)',
         'America/Pangnirtung' => 'Hora oriental d’Amèrica del Nord (Pangnirtung)',
         'America/Paramaribo' => 'Hora de Surinam (Paramaribo)',
