@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'francouzskoguyanský čas (Cayenne)',
         'America/Cayman' => 'severoamerický východní čas (Kajmanské ostrovy)',
         'America/Chicago' => 'severoamerický centrální čas (Chicago)',
-        'America/Chihuahua' => 'mexický pacifický čas (Chihuahua)',
+        'America/Chihuahua' => 'severoamerický centrální čas (Chihuahua)',
+        'America/Ciudad_Juarez' => 'severoamerický horský čas (Ciudad Juárez)',
         'America/Coral_Harbour' => 'severoamerický východní čas (Atikokan)',
         'America/Cordoba' => 'argentinský čas (Córdoba)',
         'America/Costa_Rica' => 'severoamerický centrální čas (Kostarika)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'atlantický čas (Moncton)',
         'America/Monterrey' => 'severoamerický centrální čas (Monterrey)',
         'America/Montevideo' => 'uruguayský čas (Montevideo)',
-        'America/Montreal' => 'časové pásmo Kanada (Montreal)',
         'America/Montserrat' => 'atlantický čas (Montserrat)',
         'America/Nassau' => 'severoamerický východní čas (Nassau)',
         'America/New_York' => 'severoamerický východní čas (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'severoamerický centrální čas (Beulah, Severní Dakota)',
         'America/North_Dakota/Center' => 'severoamerický centrální čas (Center, Severní Dakota)',
         'America/North_Dakota/New_Salem' => 'severoamerický centrální čas (New Salem, Severní Dakota)',
-        'America/Ojinaga' => 'severoamerický horský čas (Ojinaga)',
+        'America/Ojinaga' => 'severoamerický centrální čas (Ojinaga)',
         'America/Panama' => 'severoamerický východní čas (Panama)',
         'America/Pangnirtung' => 'severoamerický východní čas (Pangnirtung)',
         'America/Paramaribo' => 'surinamský čas (Paramaribo)',
