@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Франци Гвиана вӑхӑчӗ (Кайенна)',
         'America/Cayman' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Кайман утравӗсем)',
         'America/Chicago' => 'Тӗп Америка вӑхӑчӗ (Чикаго)',
-        'America/Chihuahua' => 'Мексика Лӑпкӑ океан вӑхӑчӗ (Чиуауа)',
+        'America/Chihuahua' => 'Тӗп Америка вӑхӑчӗ (Чиуауа)',
+        'America/Ciudad_Juarez' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Корал-Харбор)',
         'America/Cordoba' => 'Аргентина вӑхӑчӗ (Кордова)',
         'America/Costa_Rica' => 'Тӗп Америка вӑхӑчӗ (Коста-Рика)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Атлантика вӑхӑчӗ (Монктон)',
         'America/Monterrey' => 'Тӗп Америка вӑхӑчӗ (Монтеррей)',
         'America/Montevideo' => 'Уругвай вӑхӑчӗ (Монтевидео)',
-        'America/Montreal' => 'Канада (Montreal)',
         'America/Montserrat' => 'Атлантика вӑхӑчӗ (Монтсеррат)',
         'America/Nassau' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Нассау)',
         'America/New_York' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Нью-Йорк)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Тӗп Америка вӑхӑчӗ (Бойла, Ҫурҫӗр Дакота)',
         'America/North_Dakota/Center' => 'Тӗп Америка вӑхӑчӗ (Центр, Ҫурҫӗр Дакота)',
         'America/North_Dakota/New_Salem' => 'Тӗп Америка вӑхӑчӗ (Нью-Сейлем, Ҫурҫӗр Дакота)',
-        'America/Ojinaga' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Охинага)',
+        'America/Ojinaga' => 'Тӗп Америка вӑхӑчӗ (Охинага)',
         'America/Panama' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Панама)',
         'America/Pangnirtung' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Пангниртанг)',
         'America/Paramaribo' => 'Суринам вӑхӑчӗ (Парамарибо)',
