@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Fransk Guyana-tid (Cayenne)',
         'America/Cayman' => 'Eastern-tid (Caymanøerne)',
         'America/Chicago' => 'Central-tid (Chicago)',
-        'America/Chihuahua' => 'Mexicansk Pacific-tid (Chihuahua)',
+        'America/Chihuahua' => 'Central-tid (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Mountain-tid (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Eastern-tid (Atikokan)',
         'America/Cordoba' => 'Argentisk tid (Cordoba)',
         'America/Costa_Rica' => 'Central-tid (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Atlantic-tid (Moncton)',
         'America/Monterrey' => 'Central-tid (Monterrey)',
         'America/Montevideo' => 'Uruguayansk tid (Montevideo)',
-        'America/Montreal' => 'Canada (Montreal)',
         'America/Montserrat' => 'Atlantic-tid (Montserrat)',
         'America/Nassau' => 'Eastern-tid (Nassau)',
         'America/New_York' => 'Eastern-tid (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Central-tid (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Central-tid (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Central-tid (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Mountain-tid (Ojinaga)',
+        'America/Ojinaga' => 'Central-tid (Ojinaga)',
         'America/Panama' => 'Eastern-tid (Panama)',
         'America/Pangnirtung' => 'Eastern-tid (Pangnirtung)',
         'America/Paramaribo' => 'Surinam-tid (Paramaribo)',
