@@ -67,12 +67,12 @@ return [
         'America/Argentina/Tucuman' => 'Argentinische Zeit (Tucuman)',
         'America/Argentina/Ushuaia' => 'Argentinische Zeit (Ushuaia)',
         'America/Aruba' => 'Atlantik-Zeit (Aruba)',
-        'America/Asuncion' => 'Paraguayanische Zeit (Asunción)',
+        'America/Asuncion' => 'Paraguayische Zeit (Asunción)',
         'America/Bahia' => 'Brasília-Zeit (Bahia)',
-        'America/Bahia_Banderas' => 'Nordamerikanische Inlandzeit (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'Nordamerikanische Zentralzeit (Bahia Banderas)',
         'America/Barbados' => 'Atlantik-Zeit (Barbados)',
         'America/Belem' => 'Brasília-Zeit (Belem)',
-        'America/Belize' => 'Nordamerikanische Inlandzeit (Belize)',
+        'America/Belize' => 'Nordamerikanische Zentralzeit (Belize)',
         'America/Blanc-Sablon' => 'Atlantik-Zeit (Blanc-Sablon)',
         'America/Boa_Vista' => 'Amazonas-Zeit (Boa Vista)',
         'America/Bogota' => 'Kolumbianische Zeit (Bogotá)',
@@ -85,11 +85,12 @@ return [
         'America/Catamarca' => 'Argentinische Zeit (Catamarca)',
         'America/Cayenne' => 'Französisch-Guayana-Zeit (Cayenne)',
         'America/Cayman' => 'Nordamerikanische Ostküstenzeit (Kaimaninseln)',
-        'America/Chicago' => 'Nordamerikanische Inlandzeit (Chicago)',
-        'America/Chihuahua' => 'Mexiko Pazifikzone-Zeit (Chihuahua)',
+        'America/Chicago' => 'Nordamerikanische Zentralzeit (Chicago)',
+        'America/Chihuahua' => 'Nordamerikanische Zentralzeit (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Rocky-Mountain-Zeit (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Nordamerikanische Ostküstenzeit (Atikokan)',
         'America/Cordoba' => 'Argentinische Zeit (Córdoba)',
-        'America/Costa_Rica' => 'Nordamerikanische Inlandzeit (Costa Rica)',
+        'America/Costa_Rica' => 'Nordamerikanische Zentralzeit (Costa Rica)',
         'America/Creston' => 'Rocky-Mountain-Zeit (Creston)',
         'America/Cuiaba' => 'Amazonas-Zeit (Cuiaba)',
         'America/Curacao' => 'Atlantik-Zeit (Curaçao)',
@@ -101,7 +102,7 @@ return [
         'America/Dominica' => 'Atlantik-Zeit (Dominica)',
         'America/Edmonton' => 'Rocky-Mountain-Zeit (Edmonton)',
         'America/Eirunepe' => 'Acre-Zeit (Eirunepe)',
-        'America/El_Salvador' => 'Nordamerikanische Inlandzeit (El Salvador)',
+        'America/El_Salvador' => 'Nordamerikanische Zentralzeit (El Salvador)',
         'America/Fort_Nelson' => 'Rocky-Mountain-Zeit (Fort Nelson)',
         'America/Fortaleza' => 'Brasília-Zeit (Fortaleza)',
         'America/Glace_Bay' => 'Atlantik-Zeit (Glace Bay)',
@@ -110,16 +111,16 @@ return [
         'America/Grand_Turk' => 'Nordamerikanische Ostküstenzeit (Grand Turk)',
         'America/Grenada' => 'Atlantik-Zeit (Grenada)',
         'America/Guadeloupe' => 'Atlantik-Zeit (Guadeloupe)',
-        'America/Guatemala' => 'Nordamerikanische Inlandzeit (Guatemala)',
+        'America/Guatemala' => 'Nordamerikanische Zentralzeit (Guatemala)',
         'America/Guayaquil' => 'Ecuadorianische Zeit (Guayaquil)',
         'America/Guyana' => 'Guyana-Zeit',
         'America/Halifax' => 'Atlantik-Zeit (Halifax)',
         'America/Havana' => 'Kubanische Zeit (Havanna)',
-        'America/Hermosillo' => 'Mexiko Pazifikzone-Zeit (Hermosillo)',
-        'America/Indiana/Knox' => 'Nordamerikanische Inlandzeit (Knox, Indiana)',
+        'America/Hermosillo' => 'Mexikanische Pazifikzeit (Hermosillo)',
+        'America/Indiana/Knox' => 'Nordamerikanische Zentralzeit (Knox, Indiana)',
         'America/Indiana/Marengo' => 'Nordamerikanische Ostküstenzeit (Marengo, Indiana)',
         'America/Indiana/Petersburg' => 'Nordamerikanische Ostküstenzeit (Petersburg, Indiana)',
-        'America/Indiana/Tell_City' => 'Nordamerikanische Inlandzeit (Tell City, Indiana)',
+        'America/Indiana/Tell_City' => 'Nordamerikanische Zentralzeit (Tell City, Indiana)',
         'America/Indiana/Vevay' => 'Nordamerikanische Ostküstenzeit (Vevay, Indiana)',
         'America/Indiana/Vincennes' => 'Nordamerikanische Ostküstenzeit (Vincennes, Indiana)',
         'America/Indiana/Winamac' => 'Nordamerikanische Ostküstenzeit (Winamac, Indiana)',
@@ -137,32 +138,31 @@ return [
         'America/Louisville' => 'Nordamerikanische Ostküstenzeit (Louisville)',
         'America/Lower_Princes' => 'Atlantik-Zeit (Lower Prince’s Quarter)',
         'America/Maceio' => 'Brasília-Zeit (Maceio)',
-        'America/Managua' => 'Nordamerikanische Inlandzeit (Managua)',
+        'America/Managua' => 'Nordamerikanische Zentralzeit (Managua)',
         'America/Manaus' => 'Amazonas-Zeit (Manaus)',
         'America/Marigot' => 'Atlantik-Zeit (Marigot)',
         'America/Martinique' => 'Atlantik-Zeit (Martinique)',
-        'America/Matamoros' => 'Nordamerikanische Inlandzeit (Matamoros)',
-        'America/Mazatlan' => 'Mexiko Pazifikzone-Zeit (Mazatlan)',
+        'America/Matamoros' => 'Nordamerikanische Zentralzeit (Matamoros)',
+        'America/Mazatlan' => 'Mexikanische Pazifikzeit (Mazatlan)',
         'America/Mendoza' => 'Argentinische Zeit (Mendoza)',
-        'America/Menominee' => 'Nordamerikanische Inlandzeit (Menominee)',
-        'America/Merida' => 'Nordamerikanische Inlandzeit (Merida)',
+        'America/Menominee' => 'Nordamerikanische Zentralzeit (Menominee)',
+        'America/Merida' => 'Nordamerikanische Zentralzeit (Merida)',
         'America/Metlakatla' => 'Alaska-Zeit (Metlakatla)',
-        'America/Mexico_City' => 'Nordamerikanische Inlandzeit (Mexiko-Stadt)',
+        'America/Mexico_City' => 'Nordamerikanische Zentralzeit (Mexiko-Stadt)',
         'America/Miquelon' => 'St.-Pierre-und-Miquelon-Zeit',
         'America/Moncton' => 'Atlantik-Zeit (Moncton)',
-        'America/Monterrey' => 'Nordamerikanische Inlandzeit (Monterrey)',
-        'America/Montevideo' => 'Uruguayanische Zeit (Montevideo)',
-        'America/Montreal' => 'Kanada Zeit (Montreal)',
+        'America/Monterrey' => 'Nordamerikanische Zentralzeit (Monterrey)',
+        'America/Montevideo' => 'Uruguayische Zeit (Montevideo)',
         'America/Montserrat' => 'Atlantik-Zeit (Montserrat)',
         'America/Nassau' => 'Nordamerikanische Ostküstenzeit (Nassau)',
         'America/New_York' => 'Nordamerikanische Ostküstenzeit (New York)',
         'America/Nipigon' => 'Nordamerikanische Ostküstenzeit (Nipigon)',
         'America/Nome' => 'Alaska-Zeit (Nome)',
         'America/Noronha' => 'Fernando-de-Noronha-Zeit',
-        'America/North_Dakota/Beulah' => 'Nordamerikanische Inlandzeit (Beulah, North Dakota)',
-        'America/North_Dakota/Center' => 'Nordamerikanische Inlandzeit (Center, North Dakota)',
-        'America/North_Dakota/New_Salem' => 'Nordamerikanische Inlandzeit (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Rocky-Mountain-Zeit (Ojinaga)',
+        'America/North_Dakota/Beulah' => 'Nordamerikanische Zentralzeit (Beulah, North Dakota)',
+        'America/North_Dakota/Center' => 'Nordamerikanische Zentralzeit (Center, North Dakota)',
+        'America/North_Dakota/New_Salem' => 'Nordamerikanische Zentralzeit (New Salem, North Dakota)',
+        'America/Ojinaga' => 'Nordamerikanische Zentralzeit (Ojinaga)',
         'America/Panama' => 'Nordamerikanische Ostküstenzeit (Panama)',
         'America/Pangnirtung' => 'Nordamerikanische Ostküstenzeit (Pangnirtung)',
         'America/Paramaribo' => 'Suriname-Zeit (Paramaribo)',
@@ -172,13 +172,13 @@ return [
         'America/Porto_Velho' => 'Amazonas-Zeit (Porto Velho)',
         'America/Puerto_Rico' => 'Atlantik-Zeit (Puerto Rico)',
         'America/Punta_Arenas' => 'Chilenische Zeit (Punta Arenas)',
-        'America/Rainy_River' => 'Nordamerikanische Inlandzeit (Rainy River)',
-        'America/Rankin_Inlet' => 'Nordamerikanische Inlandzeit (Rankin Inlet)',
+        'America/Rainy_River' => 'Nordamerikanische Zentralzeit (Rainy River)',
+        'America/Rankin_Inlet' => 'Nordamerikanische Zentralzeit (Rankin Inlet)',
         'America/Recife' => 'Brasília-Zeit (Recife)',
-        'America/Regina' => 'Nordamerikanische Inlandzeit (Regina)',
-        'America/Resolute' => 'Nordamerikanische Inlandzeit (Resolute)',
+        'America/Regina' => 'Nordamerikanische Zentralzeit (Regina)',
+        'America/Resolute' => 'Nordamerikanische Zentralzeit (Resolute)',
         'America/Rio_Branco' => 'Acre-Zeit (Rio Branco)',
-        'America/Santa_Isabel' => 'Mexiko Nordwestliche Zone-Zeit (Santa Isabel)',
+        'America/Santa_Isabel' => 'Nordwestmexiko-Zeit (Santa Isabel)',
         'America/Santarem' => 'Brasília-Zeit (Santarem)',
         'America/Santiago' => 'Chilenische Zeit (Santiago)',
         'America/Santo_Domingo' => 'Atlantik-Zeit (Santo Domingo)',
@@ -191,8 +191,8 @@ return [
         'America/St_Lucia' => 'Atlantik-Zeit (St. Lucia)',
         'America/St_Thomas' => 'Atlantik-Zeit (St. Thomas)',
         'America/St_Vincent' => 'Atlantik-Zeit (St. Vincent)',
-        'America/Swift_Current' => 'Nordamerikanische Inlandzeit (Swift Current)',
-        'America/Tegucigalpa' => 'Nordamerikanische Inlandzeit (Tegucigalpa)',
+        'America/Swift_Current' => 'Nordamerikanische Zentralzeit (Swift Current)',
+        'America/Tegucigalpa' => 'Nordamerikanische Zentralzeit (Tegucigalpa)',
         'America/Thule' => 'Atlantik-Zeit (Thule)',
         'America/Thunder_Bay' => 'Nordamerikanische Ostküstenzeit (Thunder Bay)',
         'America/Tijuana' => 'Nordamerikanische Westküstenzeit (Tijuana)',
@@ -200,7 +200,7 @@ return [
         'America/Tortola' => 'Atlantik-Zeit (Tortola)',
         'America/Vancouver' => 'Nordamerikanische Westküstenzeit (Vancouver)',
         'America/Whitehorse' => 'Yukon-Zeit (Whitehorse)',
-        'America/Winnipeg' => 'Nordamerikanische Inlandzeit (Winnipeg)',
+        'America/Winnipeg' => 'Nordamerikanische Zentralzeit (Winnipeg)',
         'America/Yakutat' => 'Alaska-Zeit (Yakutat)',
         'America/Yellowknife' => 'Rocky-Mountain-Zeit (Yellowknife)',
         'Antarctica/Casey' => 'Casey-Zeit',
@@ -227,7 +227,7 @@ return [
         'Asia/Bahrain' => 'Arabische Zeit (Bahrain)',
         'Asia/Baku' => 'Aserbaidschanische Zeit (Baku)',
         'Asia/Bangkok' => 'Indochina-Zeit (Bangkok)',
-        'Asia/Barnaul' => 'Russland Zeit (Barnaul)',
+        'Asia/Barnaul' => 'Russland (Ortszeit) (Barnaul)',
         'Asia/Beirut' => 'Osteuropäische Zeit (Beirut)',
         'Asia/Bishkek' => 'Kirgisistan-Zeit (Bischkek)',
         'Asia/Brunei' => 'Brunei-Darussalam-Zeit',
@@ -245,7 +245,7 @@ return [
         'Asia/Hebron' => 'Osteuropäische Zeit (Hebron)',
         'Asia/Hong_Kong' => 'Hongkong-Zeit',
         'Asia/Hovd' => 'Chowd-Zeit',
-        'Asia/Irkutsk' => 'Irkutsk-Zeit',
+        'Asia/Irkutsk' => 'Irkutsker Zeit',
         'Asia/Jakarta' => 'Westindonesische Zeit (Jakarta)',
         'Asia/Jayapura' => 'Ostindonesische Zeit (Jayapura)',
         'Asia/Jerusalem' => 'Israelische Zeit (Jerusalem)',
@@ -254,7 +254,7 @@ return [
         'Asia/Karachi' => 'Pakistanische Zeit (Karatschi)',
         'Asia/Katmandu' => 'Nepalesische Zeit (Kathmandu)',
         'Asia/Khandyga' => 'Jakutsker Zeit (Chandyga)',
-        'Asia/Krasnoyarsk' => 'Krasnojarsk-Zeit',
+        'Asia/Krasnoyarsk' => 'Krasnojarsker Zeit',
         'Asia/Kuala_Lumpur' => 'Malaysische Zeit (Kuala Lumpur)',
         'Asia/Kuching' => 'Malaysische Zeit (Kuching)',
         'Asia/Kuwait' => 'Arabische Zeit (Kuwait)',
@@ -264,8 +264,8 @@ return [
         'Asia/Manila' => 'Philippinische Zeit (Manila)',
         'Asia/Muscat' => 'Golf-Zeit (Maskat)',
         'Asia/Nicosia' => 'Osteuropäische Zeit (Nikosia)',
-        'Asia/Novokuznetsk' => 'Krasnojarsk-Zeit (Nowokuznetsk)',
-        'Asia/Novosibirsk' => 'Nowosibirsk-Zeit',
+        'Asia/Novokuznetsk' => 'Krasnojarsker Zeit (Nowokuznetsk)',
+        'Asia/Novosibirsk' => 'Nowosibirsker Zeit',
         'Asia/Omsk' => 'Omsker Zeit',
         'Asia/Oral' => 'Westkasachische Zeit (Oral)',
         'Asia/Phnom_Penh' => 'Indochina-Zeit (Phnom Penh)',
@@ -289,14 +289,14 @@ return [
         'Asia/Tehran' => 'Iranische Zeit (Teheran)',
         'Asia/Thimphu' => 'Bhutan-Zeit (Thimphu)',
         'Asia/Tokyo' => 'Japanische Zeit (Tokio)',
-        'Asia/Tomsk' => 'Russland Zeit (Tomsk)',
+        'Asia/Tomsk' => 'Russland (Ortszeit) (Tomsk)',
         'Asia/Ulaanbaatar' => 'Ulaanbaatar-Zeit',
-        'Asia/Urumqi' => 'China Zeit (Ürümqi)',
-        'Asia/Ust-Nera' => 'Wladiwostok-Zeit (Ust-Nera)',
+        'Asia/Urumqi' => 'China (Ortszeit) (Ürümqi)',
+        'Asia/Ust-Nera' => 'Wladiwostoker Zeit (Ust-Nera)',
         'Asia/Vientiane' => 'Indochina-Zeit (Vientiane)',
-        'Asia/Vladivostok' => 'Wladiwostok-Zeit',
+        'Asia/Vladivostok' => 'Wladiwostoker Zeit',
         'Asia/Yakutsk' => 'Jakutsker Zeit',
-        'Asia/Yekaterinburg' => 'Jekaterinburg-Zeit',
+        'Asia/Yekaterinburg' => 'Jekaterinburger Zeit',
         'Asia/Yerevan' => 'Armenische Zeit (Eriwan)',
         'Atlantic/Azores' => 'Azoren-Zeit',
         'Atlantic/Bermuda' => 'Atlantik-Zeit (Bermuda)',
@@ -320,7 +320,7 @@ return [
         'Australia/Melbourne' => 'Ostaustralische Zeit (Melbourne)',
         'Australia/Perth' => 'Westaustralische Zeit (Perth)',
         'Australia/Sydney' => 'Ostaustralische Zeit (Sydney)',
-        'CST6CDT' => 'Nordamerikanische Inlandzeit',
+        'CST6CDT' => 'Nordamerikanische Zentralzeit',
         'EST5EDT' => 'Nordamerikanische Ostküstenzeit',
         'Etc/GMT' => 'Mittlere Greenwich-Zeit',
         'Etc/UTC' => 'Koordinierte Weltzeit',
@@ -335,18 +335,18 @@ return [
         'Europe/Bucharest' => 'Osteuropäische Zeit (Bukarest)',
         'Europe/Budapest' => 'Mitteleuropäische Zeit (Budapest)',
         'Europe/Busingen' => 'Mitteleuropäische Zeit (Büsingen)',
-        'Europe/Chisinau' => 'Osteuropäische Zeit (Kischinau)',
+        'Europe/Chisinau' => 'Osteuropäische Zeit (Chisinau)',
         'Europe/Copenhagen' => 'Mitteleuropäische Zeit (Kopenhagen)',
         'Europe/Dublin' => 'Mittlere Greenwich-Zeit (Dublin)',
         'Europe/Gibraltar' => 'Mitteleuropäische Zeit (Gibraltar)',
         'Europe/Guernsey' => 'Mittlere Greenwich-Zeit (Guernsey)',
         'Europe/Helsinki' => 'Osteuropäische Zeit (Helsinki)',
         'Europe/Isle_of_Man' => 'Mittlere Greenwich-Zeit (Isle of Man)',
-        'Europe/Istanbul' => 'Türkei Zeit (Istanbul)',
+        'Europe/Istanbul' => 'Türkei (Ortszeit) (Istanbul)',
         'Europe/Jersey' => 'Mittlere Greenwich-Zeit (Jersey)',
         'Europe/Kaliningrad' => 'Osteuropäische Zeit (Kaliningrad)',
         'Europe/Kiev' => 'Osteuropäische Zeit (Kiew)',
-        'Europe/Kirov' => 'Russland Zeit (Kirow)',
+        'Europe/Kirov' => 'Russland (Ortszeit) (Kirow)',
         'Europe/Lisbon' => 'Westeuropäische Zeit (Lissabon)',
         'Europe/Ljubljana' => 'Mitteleuropäische Zeit (Ljubljana)',
         'Europe/London' => 'Mittlere Greenwich-Zeit (London)',
@@ -379,10 +379,10 @@ return [
         'Europe/Vatican' => 'Mitteleuropäische Zeit (Vatikan)',
         'Europe/Vienna' => 'Mitteleuropäische Zeit (Wien)',
         'Europe/Vilnius' => 'Osteuropäische Zeit (Vilnius)',
-        'Europe/Volgograd' => 'Wolgograd-Zeit',
+        'Europe/Volgograd' => 'Wolgograder Zeit',
         'Europe/Warsaw' => 'Mitteleuropäische Zeit (Warschau)',
         'Europe/Zagreb' => 'Mitteleuropäische Zeit (Zagreb)',
-        'Europe/Zaporozhye' => 'Osteuropäische Zeit (Saporischja)',
+        'Europe/Zaporozhye' => 'Osteuropäische Zeit (Saporischschja)',
         'Europe/Zurich' => 'Mitteleuropäische Zeit (Zürich)',
         'Indian/Antananarivo' => 'Ostafrikanische Zeit (Antananarivo)',
         'Indian/Chagos' => 'Indischer-Ozean-Zeit (Chagos)',
@@ -432,7 +432,7 @@ return [
         'Pacific/Saipan' => 'Chamorro-Zeit (Saipan)',
         'Pacific/Tahiti' => 'Tahiti-Zeit',
         'Pacific/Tarawa' => 'Gilbert-Inseln-Zeit (Tarawa)',
-        'Pacific/Tongatapu' => 'Tonganische Zeit (Tongatapu)',
+        'Pacific/Tongatapu' => 'Tongaische Zeit (Tongatapu)',
         'Pacific/Truk' => 'Chuuk-Zeit',
         'Pacific/Wake' => 'Wake-Insel-Zeit',
         'Pacific/Wallis' => 'Wallis-und-Futuna-Zeit',
