@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'ཨེཊ་ལེན་ཊིཀ་ཆུ་ཚོད། (Aruba་)',
         'America/Asuncion' => 'པ་ར་གུ་ཝའི་ཆུ་ཚོད། (Asuncion་)',
         'America/Bahia' => 'བྲ་ཛི་ལི་ཡ་ཆུ་ཚོད། (Bahia་)',
-        'America/Bahia_Banderas' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (Bahia Banderas་)',
+        'America/Bahia_Banderas' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (Bahía de Banderas་)',
         'America/Barbados' => 'ཨེཊ་ལེན་ཊིཀ་ཆུ་ཚོད། (བྷར་བེ་ཌོས་)',
         'America/Belem' => 'བྲ་ཛི་ལི་ཡ་ཆུ་ཚོད། (Belem་)',
         'America/Belize' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (བྷེ་ལིཛ་)',
@@ -80,13 +80,14 @@ return [
         'America/Buenos_Aires' => 'ཨར་ཇེན་ཊི་ན་ཆུ་ཚོད། (Buenos Aires་)',
         'America/Cambridge_Bay' => 'བྱང་ཨ་མི་རི་ཀ་མའུ་ཊེན་ཆུ་ཚོད། (ཀེམ་བིརིདཆ་ བའེ་)',
         'America/Campo_Grande' => 'ཨེ་མ་ཛཱོན་ཆུ་ཚོད། (Campo Grande་)',
-        'America/Cancun' => 'བྱང་ཨ་མི་རི་ཀ་ཤར་ཕྱོགས་ཆུ་ཚོད། (Cancun་)',
+        'America/Cancun' => 'བྱང་ཨ་མི་རི་ཀ་ཤར་ཕྱོགས་ཆུ་ཚོད། (Cancún་)',
         'America/Caracas' => 'བེ་ནི་ཛུ་ཝེ་ལ་ཆུ་ཚོད། (Caracas་)',
         'America/Catamarca' => 'ཨར་ཇེན་ཊི་ན་ཆུ་ཚོད། (Catamarca་)',
         'America/Cayenne' => 'ཕིརེནཅ་གི་ཡ་ན་ཆུ་ཚོད། (Cayenne་)',
         'America/Cayman' => 'བྱང་ཨ་མི་རི་ཀ་ཤར་ཕྱོགས་ཆུ་ཚོད། (Cayman་)',
         'America/Chicago' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (ཅི་ཀཱ་གོ་)',
-        'America/Chihuahua' => 'མེཀ་སི་ཀོ་ཆུ་ཚོད།། (Chihuahua་)',
+        'America/Chihuahua' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (Chihuahua་)',
+        'America/Ciudad_Juarez' => 'བྱང་ཨ་མི་རི་ཀ་མའུ་ཊེན་ཆུ་ཚོད། (Ciudad Juárez་)',
         'America/Coral_Harbour' => 'བྱང་ཨ་མི་རི་ཀ་ཤར་ཕྱོགས་ཆུ་ཚོད། (ཨ་ཏི་ཀོ་ཀཱན་)',
         'America/Cordoba' => 'ཨར་ཇེན་ཊི་ན་ཆུ་ཚོད། (Cordoba་)',
         'America/Costa_Rica' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (ཀོས་ཊ་རི་ཀ་)',
@@ -145,14 +146,13 @@ return [
         'America/Mazatlan' => 'མེཀ་སི་ཀོ་ཆུ་ཚོད།། (Mazatlan་)',
         'America/Mendoza' => 'ཨར་ཇེན་ཊི་ན་ཆུ་ཚོད། (Mendoza་)',
         'America/Menominee' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (Menominee་)',
-        'America/Merida' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (Merida་)',
+        'America/Merida' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (Mérida་)',
         'America/Metlakatla' => 'ཨ་ལསི་ཀ་ཆུ་ཚོད། (Metlakatla་)',
         'America/Mexico_City' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (མེཀ་སི་ཀོ་ སི་ཊི་)',
         'America/Miquelon' => 'པའི་རི་དང་མི་ཀི་ལཱོན་ཆུ་ཚོད། (Miquelon་)',
         'America/Moncton' => 'ཨེཊ་ལེན་ཊིཀ་ཆུ་ཚོད། (མཱོངཀ་ཊོན་)',
         'America/Monterrey' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (Monterrey་)',
         'America/Montevideo' => 'ཡུ་རུ་གུ་ཝཱའི་ཆུ་ཚོད། (Montevideo་)',
-        'America/Montreal' => 'ཀེ་ན་ཌ་ཆུ་ཚོད།། (Montreal་)',
         'America/Montserrat' => 'ཨེཊ་ལེན་ཊིཀ་ཆུ་ཚོད། (Montserrat་)',
         'America/Nassau' => 'བྱང་ཨ་མི་རི་ཀ་ཤར་ཕྱོགས་ཆུ་ཚོད། (Nassau་)',
         'America/New_York' => 'བྱང་ཨ་མི་རི་ཀ་ཤར་ཕྱོགས་ཆུ་ཚོད། (New York་)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (Beulah, North Dakota་)',
         'America/North_Dakota/Center' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (Center, North Dakota་)',
         'America/North_Dakota/New_Salem' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (New Salem, North Dakota་)',
-        'America/Ojinaga' => 'བྱང་ཨ་མི་རི་ཀ་མའུ་ཊེན་ཆུ་ཚོད། (Ojinaga་)',
+        'America/Ojinaga' => 'བྱང་ཨ་མི་རི་ཀ་དབུས་ཕྱོགས་ཆུ་ཚོད། (Ojinaga་)',
         'America/Panama' => 'བྱང་ཨ་མི་རི་ཀ་ཤར་ཕྱོགས་ཆུ་ཚོད། (པ་ན་མ་)',
         'America/Pangnirtung' => 'བྱང་ཨ་མི་རི་ཀ་ཤར་ཕྱོགས་ཆུ་ཚོད། (པེང་ནིར་ཏུང་)',
         'America/Paramaribo' => 'སུ་རི་ནཱམ་ཆུ་ཚོད། (Paramaribo་)',
