@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'French Guiana gaƒoƒo me (Cayenne)',
         'America/Cayman' => 'Eastern America gaƒoƒo me (Cayman)',
         'America/Chicago' => 'Titina America gaƒoƒome (Chicago)',
-        'America/Chihuahua' => 'Mexican Pacific gaƒoƒo me (Chihuahua)',
+        'America/Chihuahua' => 'Titina America gaƒoƒome (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Mountain gaƒoƒo me (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Eastern America gaƒoƒo me (Atikokan)',
         'America/Cordoba' => 'Argentina gaƒoƒo me (Cordoba)',
         'America/Costa_Rica' => 'Titina America gaƒoƒome (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Atlantic gaƒoƒome (Moncton)',
         'America/Monterrey' => 'Titina America gaƒoƒome (Monterrey)',
         'America/Montevideo' => 'Uruguay gaƒoƒo me (Montevideo)',
-        'America/Montreal' => 'Canada nutome gaƒoƒo me (Montreal)',
         'America/Montserrat' => 'Atlantic gaƒoƒome (Montserrat)',
         'America/Nassau' => 'Eastern America gaƒoƒo me (Nassau)',
         'America/New_York' => 'Eastern America gaƒoƒo me (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Titina America gaƒoƒome (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Titina America gaƒoƒome (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Titina America gaƒoƒome (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Mountain gaƒoƒo me (Ojinaga)',
+        'America/Ojinaga' => 'Titina America gaƒoƒome (Ojinaga)',
         'America/Panama' => 'Eastern America gaƒoƒo me (Panama)',
         'America/Pangnirtung' => 'Eastern America gaƒoƒo me (Pangnirtung)',
         'America/Paramaribo' => 'Suriname gaƒoƒome (Paramaribo)',
