@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => '[Ώρα Γαλλικής Γουιάνας (Καγιέν)]',
         'America/Cayman' => '[Ανατολική ώρα Βόρειας Αμερικής (Κέιμαν)]',
         'America/Chicago' => '[Κεντρική ώρα Βόρειας Αμερικής (Σικάγο)]',
-        'America/Chihuahua' => '[Ώρα Ειρηνικού Μεξικού (Τσιουάουα)]',
+        'America/Chihuahua' => '[Κεντρική ώρα Βόρειας Αμερικής (Τσιουάουα)]',
+        'America/Ciudad_Juarez' => '[Ορεινή ώρα Βόρειας Αμερικής (Σιουδάδ Χουάρες)]',
         'America/Coral_Harbour' => '[Ανατολική ώρα Βόρειας Αμερικής (Ατικόκαν)]',
         'America/Cordoba' => '[Ώρα Αργεντινής (Κόρδοβα)]',
         'America/Costa_Rica' => '[Κεντρική ώρα Βόρειας Αμερικής (Κόστα Ρίκα)]',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => '[Ώρα Ατλαντικού (Μόνκτον)]',
         'America/Monterrey' => '[Κεντρική ώρα Βόρειας Αμερικής (Μοντερέι)]',
         'America/Montevideo' => '[Ώρα Ουρουγουάης (Μοντεβιδέο)]',
-        'America/Montreal' => '[Ώρα (Καναδάς) (Montreal)]',
         'America/Montserrat' => '[Ώρα Ατλαντικού (Μονσεράτ)]',
         'America/Nassau' => '[Ανατολική ώρα Βόρειας Αμερικής (Νασάου)]',
         'America/New_York' => '[Ανατολική ώρα Βόρειας Αμερικής (Νέα Υόρκη)]',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => '[Κεντρική ώρα Βόρειας Αμερικής (Μπέουλα, Βόρεια Ντακότα)]',
         'America/North_Dakota/Center' => '[Κεντρική ώρα Βόρειας Αμερικής (Σέντερ, Βόρεια Ντακότα)]',
         'America/North_Dakota/New_Salem' => '[Κεντρική ώρα Βόρειας Αμερικής (Νιου Σέιλεμ, Βόρεια Ντακότα)]',
-        'America/Ojinaga' => '[Ορεινή ώρα Βόρειας Αμερικής (Οχινάγκα)]',
+        'America/Ojinaga' => '[Κεντρική ώρα Βόρειας Αμερικής (Οχινάγκα)]',
         'America/Panama' => '[Ανατολική ώρα Βόρειας Αμερικής (Παναμάς)]',
         'America/Pangnirtung' => '[Ανατολική ώρα Βόρειας Αμερικής (Πανγκνίρτουνγκ)]',
         'America/Paramaribo' => '[Ώρα Σουρινάμ (Παραμαρίμπο)]',
