@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'Atlantic Time (Aruba)',
         'America/Asuncion' => 'Paraguay Time (Asunción)',
         'America/Bahia' => 'Brasilia Time (Bahia)',
-        'America/Bahia_Banderas' => 'Central Time (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'Central Time (Bahía de Banderas)',
         'America/Barbados' => 'Atlantic Time (Barbados)',
         'America/Belem' => 'Brasilia Time (Belem)',
         'America/Belize' => 'Central Time (Belize)',
@@ -80,13 +80,14 @@ return [
         'America/Buenos_Aires' => 'Argentina Time (Buenos Aires)',
         'America/Cambridge_Bay' => 'Mountain Time (Cambridge Bay)',
         'America/Campo_Grande' => 'Amazon Time (Campo Grande)',
-        'America/Cancun' => 'Eastern Time (Cancun)',
+        'America/Cancun' => 'Eastern Time (Cancún)',
         'America/Caracas' => 'Venezuela Time (Caracas)',
         'America/Catamarca' => 'Argentina Time (Catamarca)',
         'America/Cayenne' => 'French Guiana Time (Cayenne)',
         'America/Cayman' => 'Eastern Time (Cayman)',
         'America/Chicago' => 'Central Time (Chicago)',
-        'America/Chihuahua' => 'Mexican Pacific Time (Chihuahua)',
+        'America/Chihuahua' => 'Central Time (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Mountain Time (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Eastern Time (Atikokan)',
         'America/Cordoba' => 'Argentina Time (Cordoba)',
         'America/Costa_Rica' => 'Central Time (Costa Rica)',
@@ -145,14 +146,13 @@ return [
         'America/Mazatlan' => 'Mexican Pacific Time (Mazatlan)',
         'America/Mendoza' => 'Argentina Time (Mendoza)',
         'America/Menominee' => 'Central Time (Menominee)',
-        'America/Merida' => 'Central Time (Merida)',
+        'America/Merida' => 'Central Time (Mérida)',
         'America/Metlakatla' => 'Alaska Time (Metlakatla)',
         'America/Mexico_City' => 'Central Time (Mexico City)',
         'America/Miquelon' => 'St. Pierre & Miquelon Time',
         'America/Moncton' => 'Atlantic Time (Moncton)',
         'America/Monterrey' => 'Central Time (Monterrey)',
         'America/Montevideo' => 'Uruguay Time (Montevideo)',
-        'America/Montreal' => 'Canada Time (Montreal)',
         'America/Montserrat' => 'Atlantic Time (Montserrat)',
         'America/Nassau' => 'Eastern Time (Nassau)',
         'America/New_York' => 'Eastern Time (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Central Time (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Central Time (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Central Time (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Mountain Time (Ojinaga)',
+        'America/Ojinaga' => 'Central Time (Ojinaga)',
         'America/Panama' => 'Eastern Time (Panama)',
         'America/Pangnirtung' => 'Eastern Time (Pangnirtung)',
         'America/Paramaribo' => 'Suriname Time (Paramaribo)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'Greenwich Mean Time (Guernsey)',
         'Europe/Helsinki' => 'Eastern European Time (Helsinki)',
         'Europe/Isle_of_Man' => 'Greenwich Mean Time (Isle of Man)',
-        'Europe/Istanbul' => 'Turkey Time (Istanbul)',
+        'Europe/Istanbul' => 'Türkiye Time (Istanbul)',
         'Europe/Jersey' => 'Greenwich Mean Time (Jersey)',
         'Europe/Kaliningrad' => 'Eastern European Time (Kaliningrad)',
         'Europe/Kiev' => 'Eastern European Time (Kyiv)',
