@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'وقت گویان فرانسه (کاین)',
         'America/Cayman' => 'وقت شرق امریکا (کیمن)',
         'America/Chicago' => 'وقت مرکز امریکا (شیکاگو)',
-        'America/Chihuahua' => 'وقت شرق مکزیک (چیواوا)',
+        'America/Chihuahua' => 'وقت مرکز امریکا (چیواوا)',
+        'America/Ciudad_Juarez' => 'وقت کوهستانی امریکا (سیوداد خوارز)',
         'America/Coral_Harbour' => 'وقت شرق امریکا (اتکوکان)',
         'America/Cordoba' => 'وقت آرژانتین (کوردووا)',
         'America/Costa_Rica' => 'وقت مرکز امریکا (کاستاریکا)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'وقت آتلانتیک (مانکتون)',
         'America/Monterrey' => 'وقت مرکز امریکا (مونتری)',
         'America/Montevideo' => 'وقت اروگوئه (مونته‌ویدئو)',
-        'America/Montreal' => 'وقت کانادا (Montreal)',
         'America/Montserrat' => 'وقت آتلانتیک (مونتسرات)',
         'America/Nassau' => 'وقت شرق امریکا (ناسائو)',
         'America/New_York' => 'وقت شرق امریکا (نیویورک)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'وقت مرکز امریکا (بیولا، داکوتای شمالی)',
         'America/North_Dakota/Center' => 'وقت مرکز امریکا (سنتر، داکوتای شمالی)',
         'America/North_Dakota/New_Salem' => 'وقت مرکز امریکا (نیوسالم، داکوتای شمالی)',
-        'America/Ojinaga' => 'وقت کوهستانی امریکا (اخیناگا)',
+        'America/Ojinaga' => 'وقت مرکز امریکا (اخیناگا)',
         'America/Panama' => 'وقت شرق امریکا (پاناما)',
         'America/Pangnirtung' => 'وقت شرق امریکا (پانگنیرتونگ)',
         'America/Paramaribo' => 'وقت سورینام (پاراماریبو)',
