@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Ranskan Guayanan aika (Cayenne)',
         'America/Cayman' => 'Yhdysvaltain itäinen aika (Cayman)',
         'America/Chicago' => 'Yhdysvaltain keskinen aika (Chicago)',
-        'America/Chihuahua' => 'Meksikon Tyynenmeren aika (Chihuahua)',
+        'America/Chihuahua' => 'Yhdysvaltain keskinen aika (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Kalliovuorten aika (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Yhdysvaltain itäinen aika (Atikokan)',
         'America/Cordoba' => 'Argentiinan aika (Córdoba)',
         'America/Costa_Rica' => 'Yhdysvaltain keskinen aika (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Kanadan Atlantin aika (Moncton)',
         'America/Monterrey' => 'Yhdysvaltain keskinen aika (Monterrey)',
         'America/Montevideo' => 'Uruguayn aika (Montevideo)',
-        'America/Montreal' => 'aikavyöhyke: Kanada (Montreal)',
         'America/Montserrat' => 'Kanadan Atlantin aika (Montserrat)',
         'America/Nassau' => 'Yhdysvaltain itäinen aika (Nassau)',
         'America/New_York' => 'Yhdysvaltain itäinen aika (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Yhdysvaltain keskinen aika (Beulah, Pohjois-Dakota)',
         'America/North_Dakota/Center' => 'Yhdysvaltain keskinen aika (Center, Pohjois-Dakota)',
         'America/North_Dakota/New_Salem' => 'Yhdysvaltain keskinen aika (New Salem, Pohjois-Dakota)',
-        'America/Ojinaga' => 'Kalliovuorten aika (Ojinaga)',
+        'America/Ojinaga' => 'Yhdysvaltain keskinen aika (Ojinaga)',
         'America/Panama' => 'Yhdysvaltain itäinen aika (Panama)',
         'America/Pangnirtung' => 'Yhdysvaltain itäinen aika (Pangnirtung)',
         'America/Paramaribo' => 'Surinamen aika (Paramaribo)',
