@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Franska Gujana tíð (Cayenne)',
         'America/Cayman' => 'Eastern tíð (Cayman)',
         'America/Chicago' => 'Central tíð (Chicago)',
-        'America/Chihuahua' => 'Mexican Pacific tíð (Chihuahua)',
+        'America/Chihuahua' => 'Central tíð (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Mountain tíð (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Eastern tíð (Atikokan)',
         'America/Cordoba' => 'Argentina tíð (Cordoba)',
         'America/Costa_Rica' => 'Central tíð (Kosta Rika)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Atlantic tíð (Moncton)',
         'America/Monterrey' => 'Central tíð (Monterrey)',
         'America/Montevideo' => 'Uruguai tíð (Montevideo)',
-        'America/Montreal' => 'Kanada tíð (Montreal)',
         'America/Montserrat' => 'Atlantic tíð (Montserrat)',
         'America/Nassau' => 'Eastern tíð (Nassau)',
         'America/New_York' => 'Eastern tíð (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Central tíð (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Central tíð (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Central tíð (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Mountain tíð (Ojinaga)',
+        'America/Ojinaga' => 'Central tíð (Ojinaga)',
         'America/Panama' => 'Eastern tíð (Panama)',
         'America/Pangnirtung' => 'Eastern tíð (Pangnirtung)',
         'America/Paramaribo' => 'Surinam tíð (Paramaribo)',
