@@ -54,7 +54,7 @@ return [
         'Africa/Tripoli' => 'heure d’Europe de l’Est (Tripoli (Libye))',
         'Africa/Tunis' => 'heure d’Europe centrale (Tunis)',
         'Africa/Windhoek' => 'heure normale d’Afrique centrale (Windhoek)',
-        'America/Adak' => 'heure d’Hawaii - Aléoutiennes (Adak)',
+        'America/Adak' => 'heure d’Hawaï - Aléoutiennes (Adak)',
         'America/Anchorage' => 'heure de l’Alaska (Anchorage)',
         'America/Anguilla' => 'heure de l’Atlantique (Anguilla)',
         'America/Antigua' => 'heure de l’Atlantique (Antigua)',
@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'heure de la Guyane française (Cayenne)',
         'America/Cayman' => 'heure de l’Est nord-américain (Caïmans)',
         'America/Chicago' => 'heure du centre nord-américain (Chicago)',
-        'America/Chihuahua' => 'heure du Pacifique mexicain (Chihuahua)',
+        'America/Chihuahua' => 'heure du centre nord-américain (Chihuahua)',
+        'America/Ciudad_Juarez' => 'heure des Rocheuses (Ciudad Juárez)',
         'America/Coral_Harbour' => 'heure de l’Est nord-américain (Atikokan)',
         'America/Cordoba' => 'heure de l’Argentine (Córdoba)',
         'America/Costa_Rica' => 'heure du centre nord-américain (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'heure de l’Atlantique (Moncton)',
         'America/Monterrey' => 'heure du centre nord-américain (Monterrey)',
         'America/Montevideo' => 'heure de l’Uruguay (Montevideo)',
-        'America/Montreal' => 'heure : Canada (Montreal)',
         'America/Montserrat' => 'heure de l’Atlantique (Montserrat)',
         'America/Nassau' => 'heure de l’Est nord-américain (Nassau)',
         'America/New_York' => 'heure de l’Est nord-américain (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'heure du centre nord-américain (Beulah (Dakota du Nord))',
         'America/North_Dakota/Center' => 'heure du centre nord-américain (Center (Dakota du Nord))',
         'America/North_Dakota/New_Salem' => 'heure du centre nord-américain (New Salem (Dakota du Nord))',
-        'America/Ojinaga' => 'heure des Rocheuses (Ojinaga)',
+        'America/Ojinaga' => 'heure du centre nord-américain (Ojinaga)',
         'America/Panama' => 'heure de l’Est nord-américain (Panama)',
         'America/Pangnirtung' => 'heure de l’Est nord-américain (Pangnirtung)',
         'America/Paramaribo' => 'heure du Suriname (Paramaribo)',
@@ -192,7 +192,7 @@ return [
         'America/St_Thomas' => 'heure de l’Atlantique (Saint-Thomas)',
         'America/St_Vincent' => 'heure de l’Atlantique (Saint-Vincent)',
         'America/Swift_Current' => 'heure du centre nord-américain (Swift Current)',
-        'America/Tegucigalpa' => 'heure du centre nord-américain (Tégucigalpa)',
+        'America/Tegucigalpa' => 'heure du centre nord-américain (Tegucigalpa)',
         'America/Thule' => 'heure de l’Atlantique (Thulé)',
         'America/Thunder_Bay' => 'heure de l’Est nord-américain (Thunder Bay)',
         'America/Tijuana' => 'heure du Pacifique nord-américain (Tijuana)',
@@ -230,7 +230,7 @@ return [
         'Asia/Barnaul' => 'heure : Russie (Barnaul)',
         'Asia/Beirut' => 'heure d’Europe de l’Est (Beyrouth)',
         'Asia/Bishkek' => 'heure du Kirghizistan (Bichkek)',
-        'Asia/Brunei' => 'heure du Brunéi (Brunei)',
+        'Asia/Brunei' => 'heure du Brunei',
         'Asia/Calcutta' => 'heure de l’Inde (Calcutta)',
         'Asia/Chita' => 'heure de Iakoutsk (Tchita)',
         'Asia/Choibalsan' => 'heure d’Oulan-Bator (Tchoïbalsan)',
@@ -411,8 +411,8 @@ return [
         'Pacific/Gambier' => 'heure des îles Gambier',
         'Pacific/Guadalcanal' => 'heure des îles Salomon (Guadalcanal)',
         'Pacific/Guam' => 'heure des Chamorro (Guam)',
-        'Pacific/Honolulu' => 'heure d’Hawaii - Aléoutiennes (Honolulu)',
-        'Pacific/Johnston' => 'heure d’Hawaii - Aléoutiennes (Johnston)',
+        'Pacific/Honolulu' => 'heure d’Hawaï - Aléoutiennes (Honolulu)',
+        'Pacific/Johnston' => 'heure d’Hawaï - Aléoutiennes (Johnston)',
         'Pacific/Kiritimati' => 'heure des îles de la Ligne (Kiritimati)',
         'Pacific/Kosrae' => 'heure de Kosrae',
         'Pacific/Kwajalein' => 'heure des îles Marshall (Kwajalein)',
@@ -420,11 +420,11 @@ return [
         'Pacific/Marquesas' => 'heure des îles Marquises',
         'Pacific/Midway' => 'heure des Samoa (Midway)',
         'Pacific/Nauru' => 'heure de Nauru',
-        'Pacific/Niue' => 'heure de Nioué (Niue)',
+        'Pacific/Niue' => 'heure de Niue',
         'Pacific/Norfolk' => 'heure de l’île Norfolk',
         'Pacific/Noumea' => 'heure de la Nouvelle-Calédonie (Nouméa)',
         'Pacific/Pago_Pago' => 'heure des Samoa (Pago Pago)',
-        'Pacific/Palau' => 'heure des Palaos (Palau)',
+        'Pacific/Palau' => 'heure des Palaos',
         'Pacific/Pitcairn' => 'heure des îles Pitcairn',
         'Pacific/Ponape' => 'heure de l’île de Pohnpei',
         'Pacific/Port_Moresby' => 'heure de la Papouasie-Nouvelle-Guinée (Port Moresby)',
