@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Am Ghuáin na Fraince (Cayenne)',
         'America/Cayman' => 'Am Oirthearach Mheiriceá Thuaidh (Cayman)',
         'America/Chicago' => 'Am Lárnach Mheiriceá Thuaidh (Chicago)',
-        'America/Chihuahua' => 'Am Meicsiceach an Aigéin Chiúin (Chihuahua)',
+        'America/Chihuahua' => 'Am Lárnach Mheiriceá Thuaidh (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Am Sléibhte Mheiriceá Thuaidh (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Am Oirthearach Mheiriceá Thuaidh (Atikokan)',
         'America/Cordoba' => 'Am na hAirgintíne (Córdoba)',
         'America/Costa_Rica' => 'Am Lárnach Mheiriceá Thuaidh (Cósta Ríce)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Am an Atlantaigh (Moncton)',
         'America/Monterrey' => 'Am Lárnach Mheiriceá Thuaidh (Monterrey)',
         'America/Montevideo' => 'Am Uragua (Montevideo)',
-        'America/Montreal' => 'Ceanada (Montreal)',
         'America/Montserrat' => 'Am an Atlantaigh (Montsarat)',
         'America/Nassau' => 'Am Oirthearach Mheiriceá Thuaidh (Nassau)',
         'America/New_York' => 'Am Oirthearach Mheiriceá Thuaidh (Nua-Eabhrac)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Am Lárnach Mheiriceá Thuaidh (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Am Lárnach Mheiriceá Thuaidh (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Am Lárnach Mheiriceá Thuaidh (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Am Sléibhte Mheiriceá Thuaidh (Ojinaga)',
+        'America/Ojinaga' => 'Am Lárnach Mheiriceá Thuaidh (Ojinaga)',
         'America/Panama' => 'Am Oirthearach Mheiriceá Thuaidh (Panama)',
         'America/Pangnirtung' => 'Am Oirthearach Mheiriceá Thuaidh (Pangnirtung)',
         'America/Paramaribo' => 'Am Shuranam (Paramaribo)',
