@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'ફ્રેંચ ગયાના સમય (કાયેને)',
         'America/Cayman' => 'ઉત્તર અમેરિકન પૂર્વી સમય (કેમેન)',
         'America/Chicago' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (શિકાગો)',
-        'America/Chihuahua' => 'મેક્સિકન પેસિફિક સમય (ચિહુઆહુઆ)',
+        'America/Chihuahua' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (ચિહુઆહુઆ)',
+        'America/Ciudad_Juarez' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (સિયુદાદ હુઆરેઝ)',
         'America/Coral_Harbour' => 'ઉત્તર અમેરિકન પૂર્વી સમય (એટિકોકેન)',
         'America/Cordoba' => 'આર્જેન્ટીના સમય (કોર્ડોબા)',
         'America/Costa_Rica' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (કોસ્ટા રિકા)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'એટલાન્ટિક સમય (મોન્કટન)',
         'America/Monterrey' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (મોન્તોરે)',
         'America/Montevideo' => 'ઉરુગ્વે સમય (મૉંટેવિડિઓ)',
-        'America/Montreal' => 'કેનેડા સમય (Montreal)',
         'America/Montserrat' => 'એટલાન્ટિક સમય (મોંટસેરાત)',
         'America/Nassau' => 'ઉત્તર અમેરિકન પૂર્વી સમય (નાસાઉ)',
         'America/New_York' => 'ઉત્તર અમેરિકન પૂર્વી સમય (ન્યૂયોર્ક)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (બિયુલાહ, ઉત્તર ડેકોટા)',
         'America/North_Dakota/Center' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (સેન્ટર, ઉત્તર ડેકોટા)',
         'America/North_Dakota/New_Salem' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (ન્યુ સેલમ, ઉત્તર ડેકોટા)',
-        'America/Ojinaga' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (ઓજિનાગા)',
+        'America/Ojinaga' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (ઓજિનાગા)',
         'America/Panama' => 'ઉત્તર અમેરિકન પૂર્વી સમય (પનામા)',
         'America/Pangnirtung' => 'ઉત્તર અમેરિકન પૂર્વી સમય (પેંગનિરતુંગ)',
         'America/Paramaribo' => 'સુરીનામ સમય (પેરામેરિબો)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'ગ્રીનવિચ મધ્યમ સમય (ગર્નઝી)',
         'Europe/Helsinki' => 'પૂર્વી યુરોપિયન સમય (હેલસિંકી)',
         'Europe/Isle_of_Man' => 'ગ્રીનવિચ મધ્યમ સમય (આઇલ ઑફ મેન)',
-        'Europe/Istanbul' => 'તુર્કી સમય (ઇસ્તાંબુલ)',
+        'Europe/Istanbul' => 'તુર્કિયે સમય (ઇસ્તાંબુલ)',
         'Europe/Jersey' => 'ગ્રીનવિચ મધ્યમ સમય (જર્સી)',
         'Europe/Kaliningrad' => 'પૂર્વી યુરોપિયન સમય (કલિનિન્ગ્રેડ)',
         'Europe/Kiev' => 'પૂર્વી યુરોપિયન સમય (કૈવ)',
