@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Aruba)',
         'America/Asuncion' => 'Lokacin Paraguay (Asuncion)',
         'America/Bahia' => 'Lokacin Brasillia (Bahia)',
-        'America/Bahia_Banderas' => 'Lokaci dake Amurika arewa ta tsakiyar (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'Lokaci dake Amurika arewa ta tsakiyar (Bahía de Banderas)',
         'America/Barbados' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Barbados)',
         'America/Belem' => 'Lokacin Brasillia (Belem)',
         'America/Belize' => 'Lokaci dake Amurika arewa ta tsakiyar (Belize)',
@@ -80,13 +80,14 @@ return [
         'America/Buenos_Aires' => 'Lokacin Argentina (Buenos Aires)',
         'America/Cambridge_Bay' => 'Lokacin Tsauni na Arewacin Amurka (Cambridge Bay)',
         'America/Campo_Grande' => 'Lokacin Amazon (Campo Grande)',
-        'America/Cancun' => 'Lokacin Gabas dake Arewacin Amurikaa (Cancun)',
+        'America/Cancun' => 'Lokacin Gabas dake Arewacin Amurikaa (Cancún)',
         'America/Caracas' => 'Lokacin Venezuela (Caracas)',
         'America/Catamarca' => 'Lokacin Argentina (Catamarca)',
         'America/Cayenne' => 'Lokacin French Guiana (Cayenne)',
         'America/Cayman' => 'Lokacin Gabas dake Arewacin Amurikaa (Cayman)',
         'America/Chicago' => 'Lokaci dake Amurika arewa ta tsakiyar (Chicago)',
-        'America/Chihuahua' => 'Lokacin Mekziko Pacific (Chihuahua)',
+        'America/Chihuahua' => 'Lokaci dake Amurika arewa ta tsakiyar (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Lokacin Tsauni na Arewacin Amurka (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Lokacin Gabas dake Arewacin Amurikaa (Atikokan)',
         'America/Cordoba' => 'Lokacin Argentina (Cordoba)',
         'America/Costa_Rica' => 'Lokaci dake Amurika arewa ta tsakiyar (Costa Rica)',
@@ -145,14 +146,13 @@ return [
         'America/Mazatlan' => 'Lokacin Mekziko Pacific (Mazatlan)',
         'America/Mendoza' => 'Lokacin Argentina (Mendoza)',
         'America/Menominee' => 'Lokaci dake Amurika arewa ta tsakiyar (Menominee)',
-        'America/Merida' => 'Lokaci dake Amurika arewa ta tsakiyar (Merida)',
+        'America/Merida' => 'Lokaci dake Amurika arewa ta tsakiyar (Mérida)',
         'America/Metlakatla' => 'Lokacin Alaska (Metlakatla)',
         'America/Mexico_City' => 'Lokaci dake Amurika arewa ta tsakiyar (Mexico City)',
         'America/Miquelon' => 'Lokacin St. Pierre da Miquelon',
         'America/Moncton' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Moncton)',
         'America/Monterrey' => 'Lokaci dake Amurika arewa ta tsakiyar (Monterrey)',
         'America/Montevideo' => 'Lokacin Uruguay (Montevideo)',
-        'America/Montreal' => 'Kanada Lokaci (Montreal)',
         'America/Montserrat' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Montserrat)',
         'America/Nassau' => 'Lokacin Gabas dake Arewacin Amurikaa (Nassau)',
         'America/New_York' => 'Lokacin Gabas dake Arewacin Amurikaa (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Lokaci dake Amurika arewa ta tsakiyar (Beulah, Arewacin Dakota)',
         'America/North_Dakota/Center' => 'Lokaci dake Amurika arewa ta tsakiyar (Center, Arewacin Dakota)',
         'America/North_Dakota/New_Salem' => 'Lokaci dake Amurika arewa ta tsakiyar (New Salem, Arewacin Dakota)',
-        'America/Ojinaga' => 'Lokacin Tsauni na Arewacin Amurka (Ojinaga)',
+        'America/Ojinaga' => 'Lokaci dake Amurika arewa ta tsakiyar (Ojinaga)',
         'America/Panama' => 'Lokacin Gabas dake Arewacin Amurikaa (Panama)',
         'America/Pangnirtung' => 'Lokacin Gabas dake Arewacin Amurikaa (Pangnirtung)',
         'America/Paramaribo' => 'Lokacin Suriname (Paramaribo)',
@@ -345,7 +345,7 @@ return [
         'Europe/Istanbul' => 'Turkiyya Lokaci (Istanbul)',
         'Europe/Jersey' => 'Lokacin Greenwhich a London (Jersey)',
         'Europe/Kaliningrad' => 'Lokaci a turai gabas (Kaliningrad)',
-        'Europe/Kiev' => 'Lokaci a turai gabas (Kiev)',
+        'Europe/Kiev' => 'Lokaci a turai gabas (Kyiv)',
         'Europe/Kirov' => 'Rasha Lokaci (Kirov)',
         'Europe/Lisbon' => 'Lokaci ta yammacin turai (Lisbon)',
         'Europe/Ljubljana' => 'Tsakiyar a lokaci turai (Ljubljana)',
