@@ -32,7 +32,7 @@ return [
         'Africa/Khartoum' => 'שעון מרכז אפריקה (חרטום)',
         'Africa/Kigali' => 'שעון מרכז אפריקה (קיגלי)',
         'Africa/Kinshasa' => 'שעון מערב אפריקה (קינשסה)',
-        'Africa/Lagos' => 'שעון מערב אפריקה (לגוס)',
+        'Africa/Lagos' => 'שעון מערב אפריקה (לאגוס)',
         'Africa/Libreville' => 'שעון מערב אפריקה (ליברוויל)',
         'Africa/Lome' => 'שעון גריניץ׳‏ (לומה)',
         'Africa/Luanda' => 'שעון מערב אפריקה (לואנדה)',
@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'שעון גיאנה הצרפתית (קאיין)',
         'America/Cayman' => 'שעון החוף המזרחי (קיימן)',
         'America/Chicago' => 'שעון מרכז ארה״ב (שיקגו)',
-        'America/Chihuahua' => 'שעון מערב מקסיקו (צ׳יוואווה)',
+        'America/Chihuahua' => 'שעון מרכז ארה״ב (צ׳יוואווה)',
+        'America/Ciudad_Juarez' => 'שעון אזור ההרים בארה״ב (סיודד חוארס)',
         'America/Coral_Harbour' => 'שעון החוף המזרחי (אטיקוקן)',
         'America/Cordoba' => 'שעון ארגנטינה (קורדובה)',
         'America/Costa_Rica' => 'שעון מרכז ארה״ב (קוסטה ריקה)',
@@ -152,17 +153,16 @@ return [
         'America/Moncton' => 'שעון האוקיינוס האטלנטי (מונקטון)',
         'America/Monterrey' => 'שעון מרכז ארה״ב (מונטריי)',
         'America/Montevideo' => 'שעון אורוגוואי (מונטווידאו)',
-        'America/Montreal' => 'שעון קנדה (Montreal)',
         'America/Montserrat' => 'שעון האוקיינוס האטלנטי (מונסראט)',
         'America/Nassau' => 'שעון החוף המזרחי (נסאו)',
         'America/New_York' => 'שעון החוף המזרחי (ניו יורק)',
         'America/Nipigon' => 'שעון החוף המזרחי (ניפיגון)',
         'America/Nome' => 'שעון אלסקה (נום)',
         'America/Noronha' => 'שעון פרננדו די נורוניה',
-        'America/North_Dakota/Beulah' => 'שעון מרכז ארה״ב (ביולה, צפון דקוטה)',
-        'America/North_Dakota/Center' => 'שעון מרכז ארה״ב (סנטר, צפון דקוטה)',
-        'America/North_Dakota/New_Salem' => 'שעון מרכז ארה״ב (ניו סיילם, צפון דקוטה)',
-        'America/Ojinaga' => 'שעון אזור ההרים בארה״ב (אוג׳ינאגה)',
+        'America/North_Dakota/Beulah' => 'שעון מרכז ארה״ב (ביולה, דקוטה הצפונית)',
+        'America/North_Dakota/Center' => 'שעון מרכז ארה״ב (סנטר, דקוטה הצפונית)',
+        'America/North_Dakota/New_Salem' => 'שעון מרכז ארה״ב (ניו סיילם, דקוטה הצפונית)',
+        'America/Ojinaga' => 'שעון מרכז ארה״ב (אוג׳ינאגה)',
         'America/Panama' => 'שעון החוף המזרחי (פנמה)',
         'America/Pangnirtung' => 'שעון החוף המזרחי (פנגנירטונג)',
         'America/Paramaribo' => 'שעון סורינאם (פרמריבו)',
@@ -203,7 +203,7 @@ return [
         'America/Winnipeg' => 'שעון מרכז ארה״ב (וויניפג)',
         'America/Yakutat' => 'שעון אלסקה (יקוטאט)',
         'America/Yellowknife' => 'שעון אזור ההרים בארה״ב (ילונייף)',
-        'Antarctica/Casey' => 'שעון אנטארקטיקה (קאסיי)',
+        'Antarctica/Casey' => 'שעון אנטארקטיקה (קייסי)',
         'Antarctica/Davis' => 'שעון דיוויס',
         'Antarctica/DumontDUrville' => 'שעון דומון ד׳אורוויל',
         'Antarctica/Macquarie' => 'שעון מזרח אוסטרליה (מקווארי)',
