@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'फ़्रेंच गुयाना समय (कायेन)',
         'America/Cayman' => 'उत्तरी अमेरिकी पूर्वी समय (कैमेन)',
         'America/Chicago' => 'उत्तरी अमेरिकी केंद्रीय समय (शिकागो)',
-        'America/Chihuahua' => 'मेक्सिकन प्रशांत समय (चिहुआहुआ)',
+        'America/Chihuahua' => 'उत्तरी अमेरिकी केंद्रीय समय (चिहुआहुआ)',
+        'America/Ciudad_Juarez' => 'उत्तरी अमेरिकी माउंटेन समय (स्युदाद ह्वारेज़)',
         'America/Coral_Harbour' => 'उत्तरी अमेरिकी पूर्वी समय (अटिकोकान)',
         'America/Cordoba' => 'अर्जेंटीना समय (कोर्डोबा)',
         'America/Costa_Rica' => 'उत्तरी अमेरिकी केंद्रीय समय (कोस्टा रिका)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'अटलांटिक समय (मोंकटन)',
         'America/Monterrey' => 'उत्तरी अमेरिकी केंद्रीय समय (मोंटेरेरी)',
         'America/Montevideo' => 'उरुग्वे समय (मोंटेवीडियो)',
-        'America/Montreal' => 'कनाडा समय (Montreal)',
         'America/Montserrat' => 'अटलांटिक समय (मोंटसेरात)',
         'America/Nassau' => 'उत्तरी अमेरिकी पूर्वी समय (नासाउ)',
         'America/New_York' => 'उत्तरी अमेरिकी पूर्वी समय (न्यूयॉर्क)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'उत्तरी अमेरिकी केंद्रीय समय (ब्यूला, उत्तरी डकोटा)',
         'America/North_Dakota/Center' => 'उत्तरी अमेरिकी केंद्रीय समय (मध्य, उत्तरी दाकोता)',
         'America/North_Dakota/New_Salem' => 'उत्तरी अमेरिकी केंद्रीय समय (न्यू सालेम, उत्तरी डकोटा)',
-        'America/Ojinaga' => 'उत्तरी अमेरिकी माउंटेन समय (ओखाजीनागा)',
+        'America/Ojinaga' => 'उत्तरी अमेरिकी केंद्रीय समय (ओखाजीनागा)',
         'America/Panama' => 'उत्तरी अमेरिकी पूर्वी समय (पनामा)',
         'America/Pangnirtung' => 'उत्तरी अमेरिकी पूर्वी समय (पांगनिर्टंग)',
         'America/Paramaribo' => 'सूरीनाम समय (पारामारिबो)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'ग्रीनविच मीन टाइम (गर्नसी)',
         'Europe/Helsinki' => 'पूर्वी यूरोपीय समय (हेलसिंकी)',
         'Europe/Isle_of_Man' => 'ग्रीनविच मीन टाइम (आइल ऑफ़ मैन)',
-        'Europe/Istanbul' => 'तुर्की समय (इस्तांबुल)',
+        'Europe/Istanbul' => 'तुर्किये समय (इस्तांबुल)',
         'Europe/Jersey' => 'ग्रीनविच मीन टाइम (जर्सी)',
         'Europe/Kaliningrad' => 'पूर्वी यूरोपीय समय (कालीनिनग्राड)',
         'Europe/Kiev' => 'पूर्वी यूरोपीय समय (कीव)',
