@@ -58,7 +58,7 @@ return [
         'America/Anchorage' => 'aljaško vrijeme (Anchorage)',
         'America/Anguilla' => 'atlantsko vrijeme (Angvila)',
         'America/Antigua' => 'atlantsko vrijeme (Antigua)',
-        'America/Araguaina' => 'brazilijsko vrijeme (Araguaina)',
+        'America/Araguaina' => 'brazilsko vrijeme (Araguaina)',
         'America/Argentina/La_Rioja' => 'argentinsko vrijeme (La Rioja)',
         'America/Argentina/Rio_Gallegos' => 'argentinsko vrijeme (Rio Gallegos)',
         'America/Argentina/Salta' => 'argentinsko vrijeme (Salta)',
@@ -68,10 +68,10 @@ return [
         'America/Argentina/Ushuaia' => 'argentinsko vrijeme (Ushuaia)',
         'America/Aruba' => 'atlantsko vrijeme (Aruba)',
         'America/Asuncion' => 'paragvajsko vrijeme (Asunción)',
-        'America/Bahia' => 'brazilijsko vrijeme (Bahia)',
+        'America/Bahia' => 'brazilsko vrijeme (Bahia)',
         'America/Bahia_Banderas' => 'središnje vrijeme (Bahia Banderas)',
         'America/Barbados' => 'atlantsko vrijeme (Barbados)',
-        'America/Belem' => 'brazilijsko vrijeme (Belem)',
+        'America/Belem' => 'brazilsko vrijeme (Belem)',
         'America/Belize' => 'središnje vrijeme (Belize)',
         'America/Blanc-Sablon' => 'atlantsko vrijeme (Blanc-Sablon)',
         'America/Boa_Vista' => 'amazonsko vrijeme (Boa Vista)',
@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'vrijeme Francuske Gijane (Cayenne)',
         'America/Cayman' => 'istočno vrijeme (Cayman)',
         'America/Chicago' => 'središnje vrijeme (Chicago)',
-        'America/Chihuahua' => 'meksičko pacifičko vrijeme (Chihuahua)',
+        'America/Chihuahua' => 'središnje vrijeme (Chihuahua)',
+        'America/Ciudad_Juarez' => 'planinsko vrijeme (Ciudad Juárez)',
         'America/Coral_Harbour' => 'istočno vrijeme (Atikokan)',
         'America/Cordoba' => 'argentinsko vrijeme (Cordoba)',
         'America/Costa_Rica' => 'središnje vrijeme (Kostarika)',
@@ -103,7 +104,7 @@ return [
         'America/Eirunepe' => 'Acre vrijeme (Eirunepe)',
         'America/El_Salvador' => 'središnje vrijeme (Salvador)',
         'America/Fort_Nelson' => 'planinsko vrijeme (Fort Nelson)',
-        'America/Fortaleza' => 'brazilijsko vrijeme (Fortaleza)',
+        'America/Fortaleza' => 'brazilsko vrijeme (Fortaleza)',
         'America/Glace_Bay' => 'atlantsko vrijeme (Glace Bay)',
         'America/Godthab' => 'zapadnogrenlandsko vrijeme (Nuuk)',
         'America/Goose_Bay' => 'atlantsko vrijeme (Goose Bay)',
@@ -136,7 +137,7 @@ return [
         'America/Los_Angeles' => 'pacifičko vrijeme (Los Angeles)',
         'America/Louisville' => 'istočno vrijeme (Louisville)',
         'America/Lower_Princes' => 'atlantsko vrijeme (Lower Prince’s Quarter)',
-        'America/Maceio' => 'brazilijsko vrijeme (Maceio)',
+        'America/Maceio' => 'brazilsko vrijeme (Maceio)',
         'America/Managua' => 'središnje vrijeme (Managua)',
         'America/Manaus' => 'amazonsko vrijeme (Manaus)',
         'America/Marigot' => 'atlantsko vrijeme (Marigot)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'atlantsko vrijeme (Moncton)',
         'America/Monterrey' => 'središnje vrijeme (Monterrey)',
         'America/Montevideo' => 'urugvajsko vrijeme (Montevideo)',
-        'America/Montreal' => 'Kanada (Montreal)',
         'America/Montserrat' => 'atlantsko vrijeme (Montserrat)',
         'America/Nassau' => 'istočno vrijeme (Nassau)',
         'America/New_York' => 'istočno vrijeme (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'središnje vrijeme (Beulah, Sjeverna Dakota)',
         'America/North_Dakota/Center' => 'središnje vrijeme (Center, Sjeverna Dakota)',
         'America/North_Dakota/New_Salem' => 'središnje vrijeme (New Salem, Sjeverna Dakota)',
-        'America/Ojinaga' => 'planinsko vrijeme (Ojinaga)',
+        'America/Ojinaga' => 'središnje vrijeme (Ojinaga)',
         'America/Panama' => 'istočno vrijeme (Panama)',
         'America/Pangnirtung' => 'istočno vrijeme (Pangnirtung)',
         'America/Paramaribo' => 'surinamsko vrijeme (Paramaribo)',
@@ -174,15 +174,15 @@ return [
         'America/Punta_Arenas' => 'čileansko vrijeme (Punta Arenas)',
         'America/Rainy_River' => 'središnje vrijeme (Rainy River)',
         'America/Rankin_Inlet' => 'središnje vrijeme (Rankin Inlet)',
-        'America/Recife' => 'brazilijsko vrijeme (Recife)',
+        'America/Recife' => 'brazilsko vrijeme (Recife)',
         'America/Regina' => 'središnje vrijeme (Regina)',
         'America/Resolute' => 'središnje vrijeme (Resolute)',
         'America/Rio_Branco' => 'Acre vrijeme (Rio Branco)',
         'America/Santa_Isabel' => 'sjeverozapadno meksičko vrijeme (Santa Isabel)',
-        'America/Santarem' => 'brazilijsko vrijeme (Santarem)',
+        'America/Santarem' => 'brazilsko vrijeme (Santarem)',
         'America/Santiago' => 'čileansko vrijeme (Santiago)',
         'America/Santo_Domingo' => 'atlantsko vrijeme (Santo Domingo)',
-        'America/Sao_Paulo' => 'brazilijsko vrijeme (Sao Paulo)',
+        'America/Sao_Paulo' => 'brazilsko vrijeme (Sao Paulo)',
         'America/Scoresbysund' => 'istočnogrenlandsko vrijeme (Ittoqqortoormiit)',
         'America/Sitka' => 'aljaško vrijeme (Sitka)',
         'America/St_Barthelemy' => 'atlantsko vrijeme (Saint Barthélemy)',
