@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Ֆրանսիական Գվիանայի ժամանակ (Կայեն)',
         'America/Cayman' => 'Արևելյան Ամերիկայի ժամանակ (Կայման կղզիներ)',
         'America/Chicago' => 'Կենտրոնական Ամերիկայի ժամանակ (Չիկագո)',
-        'America/Chihuahua' => 'Մեքսիկայի խաղաղօվկիանոսյան ժամանակ (Չիուաուա)',
+        'America/Chihuahua' => 'Կենտրոնական Ամերիկայի ժամանակ (Չիուաուա)',
+        'America/Ciudad_Juarez' => 'Լեռնային ժամանակ (ԱՄՆ) (Սյուդադ Խուարես)',
         'America/Coral_Harbour' => 'Արևելյան Ամերիկայի ժամանակ (Ատիկոկան)',
         'America/Cordoba' => 'Արգենտինայի ժամանակ (Կորդովա)',
         'America/Costa_Rica' => 'Կենտրոնական Ամերիկայի ժամանակ (Կոստա Ռիկա)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Ատլանտյան ժամանակ (Մոնկտոն)',
         'America/Monterrey' => 'Կենտրոնական Ամերիկայի ժամանակ (Մոնտեռեյ)',
         'America/Montevideo' => 'Ուրուգվայի ժամանակ (Մոնտեվիդեո)',
-        'America/Montreal' => 'Կանադա (Montreal)',
         'America/Montserrat' => 'Ատլանտյան ժամանակ (Մոնսեռատ)',
         'America/Nassau' => 'Արևելյան Ամերիկայի ժամանակ (Նասաու)',
         'America/New_York' => 'Արևելյան Ամերիկայի ժամանակ (Նյու Յորք)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Կենտրոնական Ամերիկայի ժամանակ (Բոյլա, Հյուսիսային Դակոտա)',
         'America/North_Dakota/Center' => 'Կենտրոնական Ամերիկայի ժամանակ (Հյուսիսային Դակոտա - Կենտրոն)',
         'America/North_Dakota/New_Salem' => 'Կենտրոնական Ամերիկայի ժամանակ (Նյու Սալեմ, Հյուսիսային Դակոտա)',
-        'America/Ojinaga' => 'Լեռնային ժամանակ (ԱՄՆ) (Օխինագա)',
+        'America/Ojinaga' => 'Կենտրոնական Ամերիկայի ժամանակ (Օխինագա)',
         'America/Panama' => 'Արևելյան Ամերիկայի ժամանակ (Պանամա)',
         'America/Pangnirtung' => 'Արևելյան Ամերիկայի ժամանակ (Պանգնիրտանգ)',
         'America/Paramaribo' => 'Սուրինամի ժամանակ (Պարամարիբո)',
