@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'hora de Guyana francese (Cayenne)',
         'America/Cayman' => 'hora del est (Caiman)',
         'America/Chicago' => 'hora central (Chicago)',
-        'America/Chihuahua' => 'hora del Pacifico mexican (Chihuahua)',
+        'America/Chihuahua' => 'hora central (Chihuahua)',
+        'America/Ciudad_Juarez' => 'hora del montanias (Ciudad Juárez)',
         'America/Coral_Harbour' => 'hora del est (Atikokan)',
         'America/Cordoba' => 'hora de Argentina (Cordoba)',
         'America/Costa_Rica' => 'hora central (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'hora atlantic (Moncton)',
         'America/Monterrey' => 'hora central (Monterrey)',
         'America/Montevideo' => 'hora de Uruguay (Montevideo)',
-        'America/Montreal' => 'hora de Canada (Montreal)',
         'America/Montserrat' => 'hora atlantic (Montserrat)',
         'America/Nassau' => 'hora del est (Nassau)',
         'America/New_York' => 'hora del est (Nove York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'hora central (Beulah, Dakota del Nord)',
         'America/North_Dakota/Center' => 'hora central (Center, Dakota del Nord)',
         'America/North_Dakota/New_Salem' => 'hora central (New Salem, Dakota del Nord)',
-        'America/Ojinaga' => 'hora del montanias (Ojinaga)',
+        'America/Ojinaga' => 'hora central (Ojinaga)',
         'America/Panama' => 'hora del est (Panama)',
         'America/Pangnirtung' => 'hora del est (Pangnirtung)',
         'America/Paramaribo' => 'hora de Suriname (Paramaribo)',
