@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'Oge Mpaghara Atlantic (Aruba)',
         'America/Asuncion' => 'Oge Paraguay (Asuncion)',
         'America/Bahia' => 'Oge Brasilia (Bahia)',
-        'America/Bahia_Banderas' => 'Oge Mpaghara Etiti (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'Oge Mpaghara Etiti (Bahía de Banderas)',
         'America/Barbados' => 'Oge Mpaghara Atlantic (Barbados)',
         'America/Belem' => 'Oge Brasilia (Belem)',
         'America/Belize' => 'Oge Mpaghara Etiti (Belize)',
@@ -80,13 +80,14 @@ return [
         'America/Buenos_Aires' => 'Oge Argentina (Buenos Aires)',
         'America/Cambridge_Bay' => 'Oge Mpaghara Ugwu (Cambridge Bay)',
         'America/Campo_Grande' => 'Oge Amazon (Campo Grande)',
-        'America/Cancun' => 'Oge Mpaghara Ọwụwa Anyanwụ (Cancun)',
+        'America/Cancun' => 'Oge Mpaghara Ọwụwa Anyanwụ (Cancún)',
         'America/Caracas' => 'Oge Venezuela (Caracas)',
         'America/Catamarca' => 'Oge Argentina (Catamarca)',
         'America/Cayenne' => 'Oge French Guiana (Cayenne)',
         'America/Cayman' => 'Oge Mpaghara Ọwụwa Anyanwụ (Cayman)',
         'America/Chicago' => 'Oge Mpaghara Etiti (Chicago)',
-        'America/Chihuahua' => 'Oge Mexican Pacific (Chihuahua)',
+        'America/Chihuahua' => 'Oge Mpaghara Etiti (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Oge Mpaghara Ugwu (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Oge Mpaghara Ọwụwa Anyanwụ (Atikokan)',
         'America/Cordoba' => 'Oge Argentina (Cordoba)',
         'America/Costa_Rica' => 'Oge Mpaghara Etiti (Costa Rica)',
@@ -145,14 +146,13 @@ return [
         'America/Mazatlan' => 'Oge Mexican Pacific (Mazatlan)',
         'America/Mendoza' => 'Oge Argentina (Mendoza)',
         'America/Menominee' => 'Oge Mpaghara Etiti (Menominee)',
-        'America/Merida' => 'Oge Mpaghara Etiti (Merida)',
+        'America/Merida' => 'Oge Mpaghara Etiti (Mérida)',
         'America/Metlakatla' => 'Oge Alaska (Metlakatla)',
         'America/Mexico_City' => 'Oge Mpaghara Etiti (Mexico City)',
         'America/Miquelon' => 'Oge St. Pierre & Miquelon',
         'America/Moncton' => 'Oge Mpaghara Atlantic (Moncton)',
         'America/Monterrey' => 'Oge Mpaghara Etiti (Monterrey)',
         'America/Montevideo' => 'Oge Uruguay (Montevideo)',
-        'America/Montreal' => 'Oge Kanada (Montreal)',
         'America/Montserrat' => 'Oge Mpaghara Atlantic (Montserrat)',
         'America/Nassau' => 'Oge Mpaghara Ọwụwa Anyanwụ (Nassau)',
         'America/New_York' => 'Oge Mpaghara Ọwụwa Anyanwụ (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Oge Mpaghara Etiti (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Oge Mpaghara Etiti (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Oge Mpaghara Etiti (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Oge Mpaghara Ugwu (Ojinaga)',
+        'America/Ojinaga' => 'Oge Mpaghara Etiti (Ojinaga)',
         'America/Panama' => 'Oge Mpaghara Ọwụwa Anyanwụ (Panama)',
         'America/Pangnirtung' => 'Oge Mpaghara Ọwụwa Anyanwụ (Pangnirtung)',
         'America/Paramaribo' => 'Oge Suriname (Paramaribo)',
@@ -345,7 +345,7 @@ return [
         'Europe/Istanbul' => 'Oge Turkey (Istanbul)',
         'Europe/Jersey' => 'Oge Mpaghara Greemwich Mean (Jersey)',
         'Europe/Kaliningrad' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Kaliningrad)',
-        'Europe/Kiev' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Kiev)',
+        'Europe/Kiev' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Kyiv)',
         'Europe/Kirov' => 'Oge Rụssịa (Kirov)',
         'Europe/Lisbon' => 'Oge Mpaghara Ọdịda Anyanwụ Europe (Lisbon)',
         'Europe/Ljubljana' => 'Oge Mpaghara Etiti Europe (Ljubljana)',
