@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Tími í Frönsku Gvæjana (Cayenne)',
         'America/Cayman' => 'Tími í austurhluta Bandaríkjanna og Kanada (Cayman-eyjar)',
         'America/Chicago' => 'Tími í miðhluta Bandaríkjanna og Kanada (Chicago)',
-        'America/Chihuahua' => 'Kyrrahafstími í Mexíkó (Chihuahua)',
+        'America/Chihuahua' => 'Tími í miðhluta Bandaríkjanna og Kanada (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Tími í Klettafjöllum (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Tími í austurhluta Bandaríkjanna og Kanada (Atikokan)',
         'America/Cordoba' => 'Argentínutími (Cordoba)',
         'America/Costa_Rica' => 'Tími í miðhluta Bandaríkjanna og Kanada (Kostaríka)',
@@ -94,7 +95,7 @@ return [
         'America/Cuiaba' => 'Amasóntími (Cuiaba)',
         'America/Curacao' => 'Tími á Atlantshafssvæðinu (Curacao)',
         'America/Danmarkshavn' => 'Greenwich-staðaltími (Danmarkshavn)',
-        'America/Dawson' => 'Kanada (Dawson)',
+        'America/Dawson' => 'Tími í Júkon (Dawson)',
         'America/Dawson_Creek' => 'Tími í Klettafjöllum (Dawson Creek)',
         'America/Denver' => 'Tími í Klettafjöllum (Denver)',
         'America/Detroit' => 'Tími í austurhluta Bandaríkjanna og Kanada (Detroit)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Tími á Atlantshafssvæðinu (Moncton)',
         'America/Monterrey' => 'Tími í miðhluta Bandaríkjanna og Kanada (Monterrey)',
         'America/Montevideo' => 'Úrúgvætími (Montevideo)',
-        'America/Montreal' => 'Kanada (Montreal)',
         'America/Montserrat' => 'Tími á Atlantshafssvæðinu (Montserrat)',
         'America/Nassau' => 'Tími í austurhluta Bandaríkjanna og Kanada (Nassau)',
         'America/New_York' => 'Tími í austurhluta Bandaríkjanna og Kanada (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Tími í miðhluta Bandaríkjanna og Kanada (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Tími í miðhluta Bandaríkjanna og Kanada (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Tími í miðhluta Bandaríkjanna og Kanada (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Tími í Klettafjöllum (Ojinaga)',
+        'America/Ojinaga' => 'Tími í miðhluta Bandaríkjanna og Kanada (Ojinaga)',
         'America/Panama' => 'Tími í austurhluta Bandaríkjanna og Kanada (Panama)',
         'America/Pangnirtung' => 'Tími í austurhluta Bandaríkjanna og Kanada (Pangnirtung)',
         'America/Paramaribo' => 'Súrinamtími (Paramaribo)',
@@ -199,7 +199,7 @@ return [
         'America/Toronto' => 'Tími í austurhluta Bandaríkjanna og Kanada (Toronto)',
         'America/Tortola' => 'Tími á Atlantshafssvæðinu (Tortóla)',
         'America/Vancouver' => 'Tími á Kyrrahafssvæðinu (Vancouver)',
-        'America/Whitehorse' => 'Kanada (Whitehorse)',
+        'America/Whitehorse' => 'Tími í Júkon (Whitehorse)',
         'America/Winnipeg' => 'Tími í miðhluta Bandaríkjanna og Kanada (Winnipeg)',
         'America/Yakutat' => 'Tími í Alaska (Yakutat)',
         'America/Yellowknife' => 'Tími í Klettafjöllum (Yellowknife)',
@@ -232,12 +232,12 @@ return [
         'Asia/Bishkek' => 'Kirgistan-tími (Bishkek)',
         'Asia/Brunei' => 'Brúneitími',
         'Asia/Calcutta' => 'Indlandstími (Kalkútta)',
-        'Asia/Chita' => 'Tíminn í Yakutsk (Chita)',
+        'Asia/Chita' => 'Tími í Yakutsk (Chita)',
         'Asia/Choibalsan' => 'Tími í Úlan Bator (Choibalsan)',
         'Asia/Colombo' => 'Indlandstími (Kólombó)',
         'Asia/Damascus' => 'Austur-Evróputími (Damaskus)',
         'Asia/Dhaka' => 'Bangladess-tími (Dakka)',
-        'Asia/Dili' => 'Tíminn á Tímor-Leste (Dili)',
+        'Asia/Dili' => 'Tími á Tímor-Leste (Dili)',
         'Asia/Dubai' => 'Staðaltími við Persaflóa (Dubai)',
         'Asia/Dushanbe' => 'Tadsjíkistan-tími (Dushanbe)',
         'Asia/Famagusta' => 'Austur-Evróputími (Famagusta)',
@@ -253,7 +253,7 @@ return [
         'Asia/Kamchatka' => 'Tími í Petropavlovsk-Kamchatski (Kamtsjatka)',
         'Asia/Karachi' => 'Pakistantími (Karachi)',
         'Asia/Katmandu' => 'Nepaltími (Katmandú)',
-        'Asia/Khandyga' => 'Tíminn í Yakutsk (Khandyga)',
+        'Asia/Khandyga' => 'Tími í Yakutsk (Khandyga)',
         'Asia/Krasnoyarsk' => 'Tími í Krasnoyarsk',
         'Asia/Kuala_Lumpur' => 'Malasíutími (Kúala Lúmpúr)',
         'Asia/Kuching' => 'Malasíutími (Kuching)',
@@ -266,7 +266,7 @@ return [
         'Asia/Nicosia' => 'Austur-Evróputími (Níkósía)',
         'Asia/Novokuznetsk' => 'Tími í Krasnoyarsk (Novokuznetsk)',
         'Asia/Novosibirsk' => 'Tími í Novosibirsk',
-        'Asia/Omsk' => 'Tíminn í Omsk',
+        'Asia/Omsk' => 'Tími í Omsk',
         'Asia/Oral' => 'Tími í Vestur-Kasakstan (Oral)',
         'Asia/Phnom_Penh' => 'Indókínatími (Phnom Penh)',
         'Asia/Pontianak' => 'Vestur-Indónesíutími (Pontianak)',
@@ -295,7 +295,7 @@ return [
         'Asia/Ust-Nera' => 'Tími í Vladivostok (Ust-Nera)',
         'Asia/Vientiane' => 'Indókínatími (Vientiane)',
         'Asia/Vladivostok' => 'Tími í Vladivostok',
-        'Asia/Yakutsk' => 'Tíminn í Yakutsk',
+        'Asia/Yakutsk' => 'Tími í Yakutsk',
         'Asia/Yekaterinburg' => 'Tími í Yekaterinburg',
         'Asia/Yerevan' => 'Armeníutími (Yerevan)',
         'Atlantic/Azores' => 'Asóreyjatími (Azoreyjar)',
@@ -405,7 +405,7 @@ return [
         'Pacific/Efate' => 'Vanúatú-tími (Efate)',
         'Pacific/Enderbury' => 'Fönixeyjatími (Enderbury)',
         'Pacific/Fakaofo' => 'Tókelá-tími (Fakaofo)',
-        'Pacific/Fiji' => 'Fídjíeyjatími (Fidjí)',
+        'Pacific/Fiji' => 'Fídjíeyjatími',
         'Pacific/Funafuti' => 'Túvalútími (Funafuti)',
         'Pacific/Galapagos' => 'Galapagos-tími',
         'Pacific/Gambier' => 'Gambier-tími',
