@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Ora della Guiana francese (Caienna)',
         'America/Cayman' => 'Ora orientale USA (Cayman)',
         'America/Chicago' => 'Ora centrale USA (Chicago)',
-        'America/Chihuahua' => 'Ora del Pacifico (Messico) (Chihuahua)',
+        'America/Chihuahua' => 'Ora centrale USA (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Ora Montagne Rocciose USA (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Ora orientale USA (Atikokan)',
         'America/Cordoba' => 'Ora dell’Argentina (Cordoba)',
         'America/Costa_Rica' => 'Ora centrale USA (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Ora dell’Atlantico (Moncton)',
         'America/Monterrey' => 'Ora centrale USA (Monterrey)',
         'America/Montevideo' => 'Ora dell’Uruguay (Montevideo)',
-        'America/Montreal' => 'Ora Canada (Montreal)',
         'America/Montserrat' => 'Ora dell’Atlantico (Montserrat)',
         'America/Nassau' => 'Ora orientale USA (Nassau)',
         'America/New_York' => 'Ora orientale USA (New York)',
@@ -162,8 +162,8 @@ return [
         'America/North_Dakota/Beulah' => 'Ora centrale USA (Beulah, Dakota del nord)',
         'America/North_Dakota/Center' => 'Ora centrale USA (Center, Dakota del nord)',
         'America/North_Dakota/New_Salem' => 'Ora centrale USA (New Salem, Dakota del nord)',
-        'America/Ojinaga' => 'Ora Montagne Rocciose USA (Ojinaga)',
-        'America/Panama' => 'Ora orientale USA (Panamá)',
+        'America/Ojinaga' => 'Ora centrale USA (Ojinaga)',
+        'America/Panama' => 'Ora orientale USA (Panama)',
         'America/Pangnirtung' => 'Ora orientale USA (Pangnirtung)',
         'America/Paramaribo' => 'Ora del Suriname (Paramaribo)',
         'America/Phoenix' => 'Ora Montagne Rocciose USA (Phoenix)',
@@ -290,7 +290,7 @@ return [
         'Asia/Thimphu' => 'Ora del Bhutan (Thimphu)',
         'Asia/Tokyo' => 'Ora del Giappone (Tokyo)',
         'Asia/Tomsk' => 'Ora Russia (Tomsk)',
-        'Asia/Ulaanbaatar' => 'Ora di Ulan Bator (Ulaanbaatar)',
+        'Asia/Ulaanbaatar' => 'Ora di Ulan Bator',
         'Asia/Urumqi' => 'Ora Cina (Urumqi)',
         'Asia/Ust-Nera' => 'Ora di Vladivostok (Ust’-Nera)',
         'Asia/Vientiane' => 'Ora dell’Indocina (Vientiane)',
@@ -386,7 +386,7 @@ return [
         'Europe/Zurich' => 'Ora dell’Europa centrale (Zurigo)',
         'Indian/Antananarivo' => 'Ora dell’Africa orientale (Antananarivo)',
         'Indian/Chagos' => 'Ora dell’Oceano Indiano (Chagos)',
-        'Indian/Christmas' => 'Ora dell’Isola Christmas (Natale)',
+        'Indian/Christmas' => 'Ora dell’Isola Christmas',
         'Indian/Cocos' => 'Ora delle Isole Cocos',
         'Indian/Comoro' => 'Ora dell’Africa orientale (Comore)',
         'Indian/Kerguelen' => 'Ora delle Terre australi e antartiche francesi (Kerguelen)',
