@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => '仏領ギアナ時間（カイエンヌ）',
         'America/Cayman' => 'アメリカ東部時間（ケイマン）',
         'America/Chicago' => 'アメリカ中部時間（シカゴ）',
-        'America/Chihuahua' => 'メキシコ太平洋時間（チワワ）',
+        'America/Chihuahua' => 'アメリカ中部時間（チワワ）',
+        'America/Ciudad_Juarez' => 'アメリカ山地時間（シウダー・フアレス）',
         'America/Coral_Harbour' => 'アメリカ東部時間（アティコカン）',
         'America/Cordoba' => 'アルゼンチン時間（コルドバ）',
         'America/Costa_Rica' => 'アメリカ中部時間（コスタリカ）',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => '大西洋時間（モンクトン）',
         'America/Monterrey' => 'アメリカ中部時間（モンテレイ）',
         'America/Montevideo' => 'ウルグアイ時間（モンテビデオ）',
-        'America/Montreal' => 'カナダ時間（Montreal）',
         'America/Montserrat' => '大西洋時間（モントセラト）',
         'America/Nassau' => 'アメリカ東部時間（ナッソー）',
         'America/New_York' => 'アメリカ東部時間（ニューヨーク）',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'アメリカ中部時間（ノースダコタ州ビューラー）',
         'America/North_Dakota/Center' => 'アメリカ中部時間（ノースダコタ州センター）',
         'America/North_Dakota/New_Salem' => 'アメリカ中部時間（ノースダコタ州ニューセーラム）',
-        'America/Ojinaga' => 'アメリカ山地時間（オヒナガ）',
+        'America/Ojinaga' => 'アメリカ中部時間（オヒナガ）',
         'America/Panama' => 'アメリカ東部時間（パナマ）',
         'America/Pangnirtung' => 'アメリカ東部時間（パンナータング）',
         'America/Paramaribo' => 'スリナム時間（パラマリボ）',
