@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Wektu Guiana Prancis (Kayenne)',
         'America/Cayman' => 'Wektu sisih Wetan (Caiman)',
         'America/Chicago' => 'Wektu Tengah (Chicago)',
-        'America/Chihuahua' => 'Wektu Pasifik Meksiko (Chihuahua)',
+        'America/Chihuahua' => 'Wektu Tengah (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Wektu Giri (Ciudad Juáres)',
         'America/Coral_Harbour' => 'Wektu sisih Wetan (Atikokan)',
         'America/Cordoba' => 'Wektu Argentina (Kordoba)',
         'America/Costa_Rica' => 'Wektu Tengah (Kosta Rika)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Wektu Atlantik (Moncton)',
         'America/Monterrey' => 'Wektu Tengah (Monterrey)',
         'America/Montevideo' => 'Wektu Uruguay (Montevideo)',
-        'America/Montreal' => 'Wektu Kanada (Montreal)',
         'America/Montserrat' => 'Wektu Atlantik (Montserrat)',
         'America/Nassau' => 'Wektu sisih Wetan (Nassau)',
         'America/New_York' => 'Wektu sisih Wetan (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Wektu Tengah (Beulah [Dakota Lor])',
         'America/North_Dakota/Center' => 'Wektu Tengah (Tengah [Dakota Lor])',
         'America/North_Dakota/New_Salem' => 'Wektu Tengah (Salem Anyar [Dakota Lor])',
-        'America/Ojinaga' => 'Wektu Giri (Ojinaga)',
+        'America/Ojinaga' => 'Wektu Tengah (Ojinaga)',
         'America/Panama' => 'Wektu sisih Wetan (Panama)',
         'America/Pangnirtung' => 'Wektu sisih Wetan (Pangnirtung)',
         'America/Paramaribo' => 'Wektu Suriname (Paramaribo)',
