@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'საფრანგეთის გვიანის დრო (კაიენა)',
         'America/Cayman' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (კაიმანი)',
         'America/Chicago' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ჩიკაგო)',
-        'America/Chihuahua' => 'მექსიკის წყნარი ოკეანის დრო (ჩიჰუაჰუა)',
+        'America/Chihuahua' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ჩიჰუაჰუა)',
+        'America/Ciudad_Juarez' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (სიუდად-ხუარესი)',
         'America/Coral_Harbour' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ატიკოკანი)',
         'America/Cordoba' => 'არგენტინის დრო (კორდობა)',
         'America/Costa_Rica' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (კოსტა-რიკა)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'ატლანტიკის ოკეანის დრო (მონქტონი)',
         'America/Monterrey' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (მონტერეი)',
         'America/Montevideo' => 'ურუგვაის დრო (მონტევიდეო)',
-        'America/Montreal' => 'დრო: კანადა (Montreal)',
         'America/Montserrat' => 'ატლანტიკის ოკეანის დრო (მონსერატი)',
         'America/Nassau' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ნასაუ)',
         'America/New_York' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ნიუ-იორკი)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ბიულა, ჩრდილოეთი დაკოტა)',
         'America/North_Dakota/Center' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ცენტრი, ჩრდილოეთი დაკოტა)',
         'America/North_Dakota/New_Salem' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ნიუ-სალემი, ჩრდილოეთი დაკოტა)',
-        'America/Ojinaga' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (ოხინაგა)',
+        'America/Ojinaga' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ოხინაგა)',
         'America/Panama' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (პანამა)',
         'America/Pangnirtung' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (პანგნირტუნგი)',
         'America/Paramaribo' => 'სურინამის დრო (პარამარიბო)',
