@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Француз Гвианасы уақыты (Кайенна)',
         'America/Cayman' => 'Солтүстік Америка шығыс уақыты (Кайман аралдары)',
         'America/Chicago' => 'Солтүстік Америка орталық уақыты (Чикаго)',
-        'America/Chihuahua' => 'Мексика Тынық мұхит уақыты (Чиуауа)',
+        'America/Chihuahua' => 'Солтүстік Америка орталық уақыты (Чиуауа)',
+        'America/Ciudad_Juarez' => 'Солтүстік Америка тау уақыты (Сьюдад-Хуарес)',
         'America/Coral_Harbour' => 'Солтүстік Америка шығыс уақыты (Атикокан)',
         'America/Cordoba' => 'Аргентина уақыты (Кордова)',
         'America/Costa_Rica' => 'Солтүстік Америка орталық уақыты (Коста-Рика)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Атлантика уақыты (Монктон)',
         'America/Monterrey' => 'Солтүстік Америка орталық уақыты (Монтеррей)',
         'America/Montevideo' => 'Уругвай уақыты (Монтевидео)',
-        'America/Montreal' => 'Канада уақыты (Montreal)',
         'America/Montserrat' => 'Атлантика уақыты (Монтсеррат)',
         'America/Nassau' => 'Солтүстік Америка шығыс уақыты (Нассау)',
         'America/New_York' => 'Солтүстік Америка шығыс уақыты (Нью-Йорк)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Солтүстік Америка орталық уақыты (Бойла, Солтүстік Дакота)',
         'America/North_Dakota/Center' => 'Солтүстік Америка орталық уақыты (Сентер, Солтүстік Дакота)',
         'America/North_Dakota/New_Salem' => 'Солтүстік Америка орталық уақыты (Нью Сейлем, Солтүстік Дакота)',
-        'America/Ojinaga' => 'Солтүстік Америка тау уақыты (Охинага)',
+        'America/Ojinaga' => 'Солтүстік Америка орталық уақыты (Охинага)',
         'America/Panama' => 'Солтүстік Америка шығыс уақыты (Панама)',
         'America/Pangnirtung' => 'Солтүстік Америка шығыс уақыты (Пангниртанг)',
         'America/Paramaribo' => 'Суринам уақыты (Парамарибо)',
