@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'ម៉ោង​នៅ​ហ្គីយ៉ាន​បារាំង (កាយ៉េន)',
         'America/Cayman' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (កៃមែន)',
         'America/Chicago' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ស៊ីកាហ្គោ)',
-        'America/Chihuahua' => 'ម៉ោង​នៅ​ប៉ាស៊ីហ្វិក​ម៉ិកស៊ិក (ជីហួហួ)',
+        'America/Chihuahua' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ជីហួហួ)',
+        'America/Ciudad_Juarez' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (ស៊ីអ៊ូដាដ ហ៊ូអារ៉េស)',
         'America/Coral_Harbour' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (អាទីកូកាន)',
         'America/Cordoba' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (កូដូបា)',
         'America/Costa_Rica' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (កូស្តារីកា)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ម៉ុងតុន)',
         'America/Monterrey' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ម៉ុនតេរ៉េ)',
         'America/Montevideo' => 'ម៉ោង​នៅ​អ៊ុយរូហ្គាយ (ម៉ុងតេវីដេអូ)',
-        'America/Montreal' => 'ម៉ោង​នៅ​ កាណាដា (Montreal)',
         'America/Montserrat' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ម៉ុងស៊ែរ៉ាត​)',
         'America/Nassau' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ណាស្សូ)',
         'America/New_York' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ញូវយ៉ក)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ប៊ឺឡា ដាកូតា​ខាងជើង)',
         'America/North_Dakota/Center' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (សិនធឺ ដាកូតា​ខាង​ជើង)',
         'America/North_Dakota/New_Salem' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ញូវ​សាឡឹម ដាកូតា​ខាង​ជើង)',
-        'America/Ojinaga' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (អូជីណាហ្កា)',
+        'America/Ojinaga' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (អូជីណាហ្កា)',
         'America/Panama' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ប៉ាណាម៉ា)',
         'America/Pangnirtung' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ប៉ាងនីទុង)',
         'America/Paramaribo' => 'ម៉ោង​នៅ​សូរីណាម (ប៉ារ៉ាម៉ារីបូ)',
