@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => '프랑스령 가이아나 시간(카옌)',
         'America/Cayman' => '미 동부 시간(케이맨)',
         'America/Chicago' => '미 중부 시간(시카고)',
-        'America/Chihuahua' => '멕시코 태평양 시간(치와와)',
+        'America/Chihuahua' => '미 중부 시간(치와와)',
+        'America/Ciudad_Juarez' => '미 산지 시간(시우다드후아레스)',
         'America/Coral_Harbour' => '미 동부 시간(코랄하버)',
         'America/Cordoba' => '아르헨티나 시간(코르도바)',
         'America/Costa_Rica' => '미 중부 시간(코스타리카)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => '대서양 시간(몽턴)',
         'America/Monterrey' => '미 중부 시간(몬테레이)',
         'America/Montevideo' => '우루과이 시간(몬테비데오)',
-        'America/Montreal' => '캐나다 시간(Montreal)',
         'America/Montserrat' => '대서양 시간(몬세라트)',
         'America/Nassau' => '미 동부 시간(나소)',
         'America/New_York' => '미 동부 시간(뉴욕)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => '미 중부 시간(노스다코타주, 베라)',
         'America/North_Dakota/Center' => '미 중부 시간(중부, 노스다코타)',
         'America/North_Dakota/New_Salem' => '미 중부 시간(노스다코타주, 뉴살렘)',
-        'America/Ojinaga' => '미 산지 시간(오히나가)',
+        'America/Ojinaga' => '미 중부 시간(오히나가)',
         'America/Panama' => '미 동부 시간(파나마)',
         'America/Pangnirtung' => '미 동부 시간(팡니르퉁)',
         'America/Paramaribo' => '수리남 시간(파라마리보)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => '그리니치 표준시(건지)',
         'Europe/Helsinki' => '동유럽 시간(헬싱키)',
         'Europe/Isle_of_Man' => '그리니치 표준시(맨섬)',
-        'Europe/Istanbul' => '터키 시간(이스탄불)',
+        'Europe/Istanbul' => '튀르키예 시간(이스탄불)',
         'Europe/Jersey' => '그리니치 표준시(저지)',
         'Europe/Kaliningrad' => '동유럽 시간(칼리닌그라드)',
         'Europe/Kiev' => '동유럽 시간(키예프)',
