@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'فرؠنچ گیوٗؠنا ٹایِم (کَیین)',
         'America/Cayman' => 'مشرقی ٹایِم (کیمَن)',
         'America/Chicago' => 'مرکزی ٹایِم (شِکاگو)',
-        'America/Chihuahua' => 'میکسیکن پیسیفک ٹائم (چِہُوا ہُوا)',
+        'America/Chihuahua' => 'مرکزی ٹایِم (چِہُوا ہُوا)',
+        'America/Ciudad_Juarez' => 'ماونٹین ٹایِم (Ciudad Juárez)',
         'America/Coral_Harbour' => 'مشرقی ٹایِم (اٹی کوکنٍ)',
         'America/Cordoba' => 'ارجؠنٹیٖنا ٹایِم (کورڑوبا)',
         'America/Costa_Rica' => 'مرکزی ٹایِم (کوسٹا ریٖکا)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'اؠٹلانٹِک ٹایِم (مونکٹٕن)',
         'America/Monterrey' => 'مرکزی ٹایِم (موٹیری)',
         'America/Montevideo' => 'یوٗرؠگوَے ٹایِم (مونٹیوِڈیو)',
-        'America/Montreal' => 'کینیڈا وَکھ (Montreal)',
         'America/Montserrat' => 'اؠٹلانٹِک ٹایِم (مونژیرات)',
         'America/Nassau' => 'مشرقی ٹایِم (نساؤں)',
         'America/New_York' => 'مشرقی ٹایِم (نِو یارک)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'مرکزی ٹایِم (بیولاہ، شُمالی ڈیکوٹا)',
         'America/North_Dakota/Center' => 'مرکزی ٹایِم (مَرکزی جنوٗبی ڈکوٹا)',
         'America/North_Dakota/New_Salem' => 'مرکزی ٹایِم (نوو سیلٕم، شُمالی ڈیکوٹا)',
-        'America/Ojinaga' => 'ماونٹین ٹایِم (اوجی ناگا)',
+        'America/Ojinaga' => 'مرکزی ٹایِم (اوجی ناگا)',
         'America/Panama' => 'مشرقی ٹایِم (پَناما)',
         'America/Pangnirtung' => 'مشرقی ٹایِم (پَنگنِرٹَنگ)',
         'America/Paramaribo' => 'سُرِنام ٹایِم (پَرامارِبو)',
