@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Француз Гвиана убактысы (Кайен)',
         'America/Cayman' => 'Түндүк Америка, чыгыш убактысы (Кайман)',
         'America/Chicago' => 'Түндүк Америка, борбордук убакыт (Чикаго)',
-        'America/Chihuahua' => 'Мексика, Тынч океан убактысы (Чихуахуа)',
+        'America/Chihuahua' => 'Түндүк Америка, борбордук убакыт (Чихуахуа)',
+        'America/Ciudad_Juarez' => 'Түндүк Америка, тоо убактысы (Сьюдад-Хуарес)',
         'America/Coral_Harbour' => 'Түндүк Америка, чыгыш убактысы (Атикокан)',
         'America/Cordoba' => 'Аргентина убактысы (Кордова)',
         'America/Costa_Rica' => 'Түндүк Америка, борбордук убакыт (Коста-Рика)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Атлантика убактысы (Монктон)',
         'America/Monterrey' => 'Түндүк Америка, борбордук убакыт (Монтерей)',
         'America/Montevideo' => 'Уругвай убактысы (Монтевидео)',
-        'America/Montreal' => 'Канада убактысы (Montreal)',
         'America/Montserrat' => 'Атлантика убактысы (Монсерат)',
         'America/Nassau' => 'Түндүк Америка, чыгыш убактысы (Нассау)',
         'America/New_York' => 'Түндүк Америка, чыгыш убактысы (Нью-Йорк)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Түндүк Америка, борбордук убакыт (Беула, Түндүк Дакота)',
         'America/North_Dakota/Center' => 'Түндүк Америка, борбордук убакыт (Түндүк Дакотанын борбору)',
         'America/North_Dakota/New_Salem' => 'Түндүк Америка, борбордук убакыт (Нью-Салем, Түндүк Дакота)',
-        'America/Ojinaga' => 'Түндүк Америка, тоо убактысы (Охинага)',
+        'America/Ojinaga' => 'Түндүк Америка, борбордук убакыт (Охинага)',
         'America/Panama' => 'Түндүк Америка, чыгыш убактысы (Панама)',
         'America/Pangnirtung' => 'Түндүк Америка, чыгыш убактысы (Пангиртуң)',
         'America/Paramaribo' => 'Суринаме убактысы (Парамарибо)',
