@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'Atlantik-Zäit (Aruba)',
         'America/Asuncion' => 'Paraguayanesch Zäit (Asunción)',
         'America/Bahia' => 'Brasília-Zäit (Bahia)',
-        'America/Bahia_Banderas' => 'Nordamerikanesch Inlandzäit (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'Nordamerikanesch Inlandzäit (Bahía de Banderas)',
         'America/Barbados' => 'Atlantik-Zäit (Barbados)',
         'America/Belem' => 'Brasília-Zäit (Belem)',
         'America/Belize' => 'Nordamerikanesch Inlandzäit (Belize)',
@@ -80,13 +80,14 @@ return [
         'America/Buenos_Aires' => 'Argentinesch Zäit (Buenos Aires)',
         'America/Cambridge_Bay' => 'Rocky-Mountain-Zäit (Cambridge Bay)',
         'America/Campo_Grande' => 'Amazonas-Zäit (Campo Grande)',
-        'America/Cancun' => 'Nordamerikanesch Ostküstenzäit (Cancun)',
+        'America/Cancun' => 'Nordamerikanesch Ostküstenzäit (Cancún)',
         'America/Caracas' => 'Venezuela-Zäit (Caracas)',
         'America/Catamarca' => 'Argentinesch Zäit (Catamarca)',
         'America/Cayenne' => 'Franséisch-Guayane-Zäit (Cayenne)',
         'America/Cayman' => 'Nordamerikanesch Ostküstenzäit (Kaimaninselen)',
         'America/Chicago' => 'Nordamerikanesch Inlandzäit (Chicago)',
-        'America/Chihuahua' => 'Mexikanesch Pazifikzäit (Chihuahua)',
+        'America/Chihuahua' => 'Nordamerikanesch Inlandzäit (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Rocky-Mountain-Zäit (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Nordamerikanesch Ostküstenzäit (Atikokan)',
         'America/Cordoba' => 'Argentinesch Zäit (Cordoba)',
         'America/Costa_Rica' => 'Nordamerikanesch Inlandzäit (Costa Rica)',
@@ -145,14 +146,13 @@ return [
         'America/Mazatlan' => 'Mexikanesch Pazifikzäit (Mazatlan)',
         'America/Mendoza' => 'Argentinesch Zäit (Mendoza)',
         'America/Menominee' => 'Nordamerikanesch Inlandzäit (Menominee)',
-        'America/Merida' => 'Nordamerikanesch Inlandzäit (Merida)',
+        'America/Merida' => 'Nordamerikanesch Inlandzäit (Mérida)',
         'America/Metlakatla' => 'Alaska-Zäit (Metlakatla)',
         'America/Mexico_City' => 'Nordamerikanesch Inlandzäit (Mexiko-Stad)',
         'America/Miquelon' => 'Saint-Pierre-a-Miquelon-Zäit',
         'America/Moncton' => 'Atlantik-Zäit (Moncton)',
         'America/Monterrey' => 'Nordamerikanesch Inlandzäit (Monterrey)',
         'America/Montevideo' => 'Uruguayanesch Zäit (Montevideo)',
-        'America/Montreal' => 'Kanada Zäit (Montreal)',
         'America/Montserrat' => 'Atlantik-Zäit (Montserrat)',
         'America/Nassau' => 'Nordamerikanesch Ostküstenzäit (Nassau)',
         'America/New_York' => 'Nordamerikanesch Ostküstenzäit (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Nordamerikanesch Inlandzäit (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Nordamerikanesch Inlandzäit (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Nordamerikanesch Inlandzäit (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Rocky-Mountain-Zäit (Ojinaga)',
+        'America/Ojinaga' => 'Nordamerikanesch Inlandzäit (Ojinaga)',
         'America/Panama' => 'Nordamerikanesch Ostküstenzäit (Panama)',
         'America/Pangnirtung' => 'Nordamerikanesch Ostküstenzäit (Pangnirtung)',
         'America/Paramaribo' => 'Suriname-Zäit (Paramaribo)',
