@@ -67,7 +67,7 @@ return [
         'America/Aruba' => 'Ngonga ya Aruba (Aruba)',
         'America/Asuncion' => 'Ngonga ya Palagwei (Asuncion)',
         'America/Bahia' => 'Ngonga ya Brezílɛ (Bahia)',
-        'America/Bahia_Banderas' => 'Ngonga ya Meksike (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'Ngonga ya Meksike (Bahía de Banderas)',
         'America/Barbados' => 'Ngonga ya Barɛbadɛ (Barbados)',
         'America/Belem' => 'Ngonga ya Brezílɛ (Belem)',
         'America/Belize' => 'Ngonga ya Belizɛ (Belize)',
@@ -78,13 +78,14 @@ return [
         'America/Buenos_Aires' => 'Ngonga ya Arizantinɛ (Buenos Aires)',
         'America/Cambridge_Bay' => 'Ngonga ya Kanada (Cambridge Bay)',
         'America/Campo_Grande' => 'Ngonga ya Brezílɛ (Campo Grande)',
-        'America/Cancun' => 'Ngonga ya Meksike (Cancun)',
+        'America/Cancun' => 'Ngonga ya Meksike (Cancún)',
         'America/Caracas' => 'Ngonga ya Venézuela (Caracas)',
         'America/Catamarca' => 'Ngonga ya Arizantinɛ (Catamarca)',
         'America/Cayenne' => 'Ngonga ya Giyanɛ ya Falánsɛ (Cayenne)',
         'America/Cayman' => 'Ngonga ya Bisanga bya Kayíma (Cayman)',
         'America/Chicago' => 'Ngonga ya Ameriki (Chicago)',
         'America/Chihuahua' => 'Ngonga ya Meksike (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Ngonga ya Meksike (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Ngonga ya Kanada (Atikokan)',
         'America/Cordoba' => 'Ngonga ya Arizantinɛ (Cordoba)',
         'America/Costa_Rica' => 'Ngonga ya Kositarika (Costa Rica)',
@@ -139,14 +140,13 @@ return [
         'America/Mazatlan' => 'Ngonga ya Meksike (Mazatlan)',
         'America/Mendoza' => 'Ngonga ya Arizantinɛ (Mendoza)',
         'America/Menominee' => 'Ngonga ya Ameriki (Menominee)',
-        'America/Merida' => 'Ngonga ya Meksike (Merida)',
+        'America/Merida' => 'Ngonga ya Meksike (Mérida)',
         'America/Metlakatla' => 'Ngonga ya Ameriki (Metlakatla)',
         'America/Mexico_City' => 'Ngonga ya Meksike (Mexico City)',
         'America/Miquelon' => 'Ngonga ya Sántu pététo mpé Mikelɔ (Miquelon)',
         'America/Moncton' => 'Ngonga ya Kanada (Moncton)',
         'America/Monterrey' => 'Ngonga ya Meksike (Monterrey)',
         'America/Montevideo' => 'Ngonga ya Irigwei (Montevideo)',
-        'America/Montreal' => 'Ngonga ya Kanada (Montreal)',
         'America/Montserrat' => 'Ngonga ya Mɔsera (Montserrat)',
         'America/Nassau' => 'Ngonga ya Bahamasɛ (Nassau)',
         'America/New_York' => 'Ngonga ya Ameriki (New York)',
@@ -328,7 +328,7 @@ return [
         'Europe/Helsinki' => 'Ngonga ya Filandɛ (Helsinki)',
         'Europe/Istanbul' => 'Ngonga ya Tiliki (Istanbul)',
         'Europe/Kaliningrad' => 'Ngonga ya Risí (Kaliningrad)',
-        'Europe/Kiev' => 'Ngonga ya Ikrɛni (Kiev)',
+        'Europe/Kiev' => 'Ngonga ya Ikrɛni (Kyiv)',
         'Europe/Kirov' => 'Ngonga ya Risí (Kirov)',
         'Europe/Lisbon' => 'Ngonga ya Putúlugɛsi (Lisbon)',
         'Europe/Ljubljana' => 'Ngonga ya Siloveni (Ljubljana)',
