@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'ເວ​ລາ​ເຟ​ຣນ​ຊ໌​ເກຍ​ນາ (ຄາເຢນ)',
         'America/Cayman' => 'ເວລາຕາເວັນອອກ (ເຄແມນ)',
         'America/Chicago' => 'ເວລາກາງ (ຊິຄາໂກ)',
-        'America/Chihuahua' => 'ເວລາແປຊິຟິກເມັກຊິກັນ (ຊິວາວາ)',
+        'America/Chihuahua' => 'ເວລາກາງ (ຊິວາວາ)',
+        'America/Ciudad_Juarez' => 'ເວລາແຖບພູເຂົາ (ຊີອູດັດ ຄົວເຣຊ)',
         'America/Coral_Harbour' => 'ເວລາຕາເວັນອອກ (ອາທິໂຄຄານ)',
         'America/Cordoba' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ຄໍໂດບາ)',
         'America/Costa_Rica' => 'ເວລາກາງ (ຄອສຕາຣິກາ)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'ເວລາຂອງອາແລນຕິກ (ມອນຕັນ)',
         'America/Monterrey' => 'ເວລາກາງ (ມອນເຕີເຣຍ)',
         'America/Montevideo' => '​ເວ​ລາ​ອູ​ຣູ​ກວຍ (ມອນເຕວິເດໂອ)',
-        'America/Montreal' => 'ເວລາ ແຄນາດາ (Montreal)',
         'America/Montserrat' => 'ເວລາຂອງອາແລນຕິກ (ມອນເຊີຣັດ)',
         'America/Nassau' => 'ເວລາຕາເວັນອອກ (ແນສຊໍ)',
         'America/New_York' => 'ເວລາຕາເວັນອອກ (ນິວຢອກ)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'ເວລາກາງ (ເບີລາ, ນອດ ດາໂກຕາ)',
         'America/North_Dakota/Center' => 'ເວລາກາງ (ເຊັນເຈີ, ນອດ ດາໂກຕາ)',
         'America/North_Dakota/New_Salem' => 'ເວລາກາງ (ນິວ ຊາເລມ, ນອດ ດາໂກຕາ)',
-        'America/Ojinaga' => 'ເວລາແຖບພູເຂົາ (ໂອຈິນາກາ)',
+        'America/Ojinaga' => 'ເວລາກາງ (ໂອຈິນາກາ)',
         'America/Panama' => 'ເວລາຕາເວັນອອກ (ພານາມາ)',
         'America/Pangnirtung' => 'ເວລາຕາເວັນອອກ (ແພງເນີດທັງ)',
         'America/Paramaribo' => 'ເວ​ລາ​ຊຸ​ຣິ​ນາມ (ພາຣາມາຣິໂບ)',
