@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Prancūzijos Gvianos laikas (Kajenas)',
         'America/Cayman' => 'Šiaurės Amerikos rytų laikas (Kaimanas)',
         'America/Chicago' => 'Šiaurės Amerikos centro laikas (Čikaga)',
-        'America/Chihuahua' => 'Meksikos Ramiojo vandenyno laikas (Čihuahua)',
+        'America/Chihuahua' => 'Šiaurės Amerikos centro laikas (Čihuahua)',
+        'America/Ciudad_Juarez' => 'Šiaurės Amerikos kalnų laikas (Siudad Chuaresas)',
         'America/Coral_Harbour' => 'Šiaurės Amerikos rytų laikas (Atikokanas)',
         'America/Cordoba' => 'Argentinos laikas (Kordoba)',
         'America/Costa_Rica' => 'Šiaurės Amerikos centro laikas (Kosta Rika)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Atlanto laikas (Monktonas)',
         'America/Monterrey' => 'Šiaurės Amerikos centro laikas (Monterėjus)',
         'America/Montevideo' => 'Urugvajaus laikas (Montevidėjas)',
-        'America/Montreal' => 'Laikas: Kanada (Montreal)',
         'America/Montserrat' => 'Atlanto laikas (Montseratas)',
         'America/Nassau' => 'Šiaurės Amerikos rytų laikas (Nasau)',
         'America/New_York' => 'Šiaurės Amerikos rytų laikas (Niujorkas)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Šiaurės Amerikos centro laikas (Bjula, Šiaurės Dakota)',
         'America/North_Dakota/Center' => 'Šiaurės Amerikos centro laikas (Senteris, Šiaurės Dakota)',
         'America/North_Dakota/New_Salem' => 'Šiaurės Amerikos centro laikas (Niu Seilemas, Šiaurės Dakota)',
-        'America/Ojinaga' => 'Šiaurės Amerikos kalnų laikas (Ochinaga)',
+        'America/Ojinaga' => 'Šiaurės Amerikos centro laikas (Ochinaga)',
         'America/Panama' => 'Šiaurės Amerikos rytų laikas (Panama)',
         'America/Pangnirtung' => 'Šiaurės Amerikos rytų laikas (Pangnirtungas)',
         'America/Paramaribo' => 'Surinamo laikas (Paramaribas)',
