@@ -87,72 +87,72 @@ return [
         82 => 'America/Cayman',
         83 => 'America/Chicago',
         84 => 'America/Chihuahua',
-        85 => 'America/Coral_Harbour',
-        86 => 'America/Cordoba',
-        87 => 'America/Costa_Rica',
-        88 => 'America/Creston',
-        89 => 'America/Cuiaba',
-        90 => 'America/Curacao',
-        91 => 'America/Danmarkshavn',
-        92 => 'America/Dawson',
-        93 => 'America/Dawson_Creek',
-        94 => 'America/Denver',
-        95 => 'America/Detroit',
-        96 => 'America/Dominica',
-        97 => 'America/Edmonton',
-        98 => 'America/Eirunepe',
-        99 => 'America/El_Salvador',
-        100 => 'America/Fort_Nelson',
-        101 => 'America/Fortaleza',
-        102 => 'America/Glace_Bay',
-        103 => 'America/Godthab',
-        104 => 'America/Goose_Bay',
-        105 => 'America/Grand_Turk',
-        106 => 'America/Grenada',
-        107 => 'America/Guadeloupe',
-        108 => 'America/Guatemala',
-        109 => 'America/Guayaquil',
-        110 => 'America/Guyana',
-        111 => 'America/Halifax',
-        112 => 'America/Havana',
-        113 => 'America/Hermosillo',
-        114 => 'America/Indiana/Knox',
-        115 => 'America/Indiana/Marengo',
-        116 => 'America/Indiana/Petersburg',
-        117 => 'America/Indiana/Tell_City',
-        118 => 'America/Indiana/Vevay',
-        119 => 'America/Indiana/Vincennes',
-        120 => 'America/Indiana/Winamac',
-        121 => 'America/Indianapolis',
-        122 => 'America/Inuvik',
-        123 => 'America/Iqaluit',
-        124 => 'America/Jamaica',
-        125 => 'America/Jujuy',
-        126 => 'America/Juneau',
-        127 => 'America/Kentucky/Monticello',
-        128 => 'America/Kralendijk',
-        129 => 'America/La_Paz',
-        130 => 'America/Lima',
-        131 => 'America/Los_Angeles',
-        132 => 'America/Louisville',
-        133 => 'America/Lower_Princes',
-        134 => 'America/Maceio',
-        135 => 'America/Managua',
-        136 => 'America/Manaus',
-        137 => 'America/Marigot',
-        138 => 'America/Martinique',
-        139 => 'America/Matamoros',
-        140 => 'America/Mazatlan',
-        141 => 'America/Mendoza',
-        142 => 'America/Menominee',
-        143 => 'America/Merida',
-        144 => 'America/Metlakatla',
-        145 => 'America/Mexico_City',
-        146 => 'America/Miquelon',
-        147 => 'America/Moncton',
-        148 => 'America/Monterrey',
-        149 => 'America/Montevideo',
-        150 => 'America/Montreal',
+        85 => 'America/Ciudad_Juarez',
+        86 => 'America/Coral_Harbour',
+        87 => 'America/Cordoba',
+        88 => 'America/Costa_Rica',
+        89 => 'America/Creston',
+        90 => 'America/Cuiaba',
+        91 => 'America/Curacao',
+        92 => 'America/Danmarkshavn',
+        93 => 'America/Dawson',
+        94 => 'America/Dawson_Creek',
+        95 => 'America/Denver',
+        96 => 'America/Detroit',
+        97 => 'America/Dominica',
+        98 => 'America/Edmonton',
+        99 => 'America/Eirunepe',
+        100 => 'America/El_Salvador',
+        101 => 'America/Fort_Nelson',
+        102 => 'America/Fortaleza',
+        103 => 'America/Glace_Bay',
+        104 => 'America/Godthab',
+        105 => 'America/Goose_Bay',
+        106 => 'America/Grand_Turk',
+        107 => 'America/Grenada',
+        108 => 'America/Guadeloupe',
+        109 => 'America/Guatemala',
+        110 => 'America/Guayaquil',
+        111 => 'America/Guyana',
+        112 => 'America/Halifax',
+        113 => 'America/Havana',
+        114 => 'America/Hermosillo',
+        115 => 'America/Indiana/Knox',
+        116 => 'America/Indiana/Marengo',
+        117 => 'America/Indiana/Petersburg',
+        118 => 'America/Indiana/Tell_City',
+        119 => 'America/Indiana/Vevay',
+        120 => 'America/Indiana/Vincennes',
+        121 => 'America/Indiana/Winamac',
+        122 => 'America/Indianapolis',
+        123 => 'America/Inuvik',
+        124 => 'America/Iqaluit',
+        125 => 'America/Jamaica',
+        126 => 'America/Jujuy',
+        127 => 'America/Juneau',
+        128 => 'America/Kentucky/Monticello',
+        129 => 'America/Kralendijk',
+        130 => 'America/La_Paz',
+        131 => 'America/Lima',
+        132 => 'America/Los_Angeles',
+        133 => 'America/Louisville',
+        134 => 'America/Lower_Princes',
+        135 => 'America/Maceio',
+        136 => 'America/Managua',
+        137 => 'America/Manaus',
+        138 => 'America/Marigot',
+        139 => 'America/Martinique',
+        140 => 'America/Matamoros',
+        141 => 'America/Mazatlan',
+        142 => 'America/Mendoza',
+        143 => 'America/Menominee',
+        144 => 'America/Merida',
+        145 => 'America/Metlakatla',
+        146 => 'America/Mexico_City',
+        147 => 'America/Miquelon',
+        148 => 'America/Moncton',
+        149 => 'America/Monterrey',
+        150 => 'America/Montevideo',
         151 => 'America/Montserrat',
         152 => 'America/Nassau',
         153 => 'America/New_York',
@@ -438,6 +438,7 @@ return [
         433 => 'Pacific/Wallis',
     ],
     'ZoneToCountry' => [
+        '' => 'MX',
         'Africa/Abidjan' => 'CI',
         'Africa/Accra' => 'GH',
         'Africa/Addis_Ababa' => 'ET',
@@ -523,6 +524,7 @@ return [
         'America/Cayman' => 'KY',
         'America/Chicago' => 'US',
         'America/Chihuahua' => 'MX',
+        'America/Ciudad_Juarez' => 'MX',
         'America/Coral_Harbour' => 'CA',
         'America/Cordoba' => 'AR',
         'America/Costa_Rica' => 'CR',
@@ -1432,18 +1434,20 @@ return [
             0 => 'Africa/Blantyre',
         ],
         'MX' => [
-            0 => 'America/Bahia_Banderas',
-            1 => 'America/Cancun',
-            2 => 'America/Chihuahua',
-            3 => 'America/Hermosillo',
-            4 => 'America/Matamoros',
-            5 => 'America/Mazatlan',
-            6 => 'America/Merida',
-            7 => 'America/Mexico_City',
-            8 => 'America/Monterrey',
-            9 => 'America/Ojinaga',
-            10 => 'America/Santa_Isabel',
-            11 => 'America/Tijuana',
+            0 => '',
+            1 => 'America/Bahia_Banderas',
+            2 => 'America/Cancun',
+            3 => 'America/Chihuahua',
+            4 => 'America/Ciudad_Juarez',
+            5 => 'America/Hermosillo',
+            6 => 'America/Matamoros',
+            7 => 'America/Mazatlan',
+            8 => 'America/Merida',
+            9 => 'America/Mexico_City',
+            10 => 'America/Monterrey',
+            11 => 'America/Ojinaga',
+            12 => 'America/Santa_Isabel',
+            13 => 'America/Tijuana',
         ],
         'MY' => [
             0 => 'Asia/Kuala_Lumpur',
