@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'ഫ്രഞ്ച് ഗയാന സമയം (കയീൻ‌)',
         'America/Cayman' => 'വടക്കെ അമേരിക്കൻ കിഴക്കൻ സമയം (കേമാൻ)',
         'America/Chicago' => 'വടക്കെ അമേരിക്കൻ സെൻട്രൽ സമയം (ചിക്കാഗോ)',
-        'America/Chihuahua' => 'മെക്സിക്കൻ പസഫിക് സമയം (ചിഹ്വാഹ)',
+        'America/Chihuahua' => 'വടക്കെ അമേരിക്കൻ സെൻട്രൽ സമയം (ചിഹ്വാഹ)',
+        'America/Ciudad_Juarez' => 'വടക്കെ അമേരിക്കൻ മൌണ്ടൻ സമയം (സിയുഡാഡ് ഹുവാരസ്)',
         'America/Coral_Harbour' => 'വടക്കെ അമേരിക്കൻ കിഴക്കൻ സമയം (ഏറ്റികോക്കൺ)',
         'America/Cordoba' => 'അർജന്റീന സമയം (കോർഡോബ)',
         'America/Costa_Rica' => 'വടക്കെ അമേരിക്കൻ സെൻട്രൽ സമയം (കോസ്റ്റ റിക്ക)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'അറ്റ്‌ലാന്റിക് സമയം (മോംഗ്‌ടൻ)',
         'America/Monterrey' => 'വടക്കെ അമേരിക്കൻ സെൻട്രൽ സമയം (മോണ്ടെറി)',
         'America/Montevideo' => 'ഉറുഗ്വേ സമയം (മൊണ്ടെ‌വീഡിയോ)',
-        'America/Montreal' => 'കാനഡ സമയം (Montreal)',
         'America/Montserrat' => 'അറ്റ്‌ലാന്റിക് സമയം (മൊണ്ടെസരത്ത്)',
         'America/Nassau' => 'വടക്കെ അമേരിക്കൻ കിഴക്കൻ സമയം (നാസൗ)',
         'America/New_York' => 'വടക്കെ അമേരിക്കൻ കിഴക്കൻ സമയം (ന്യൂയോർക്ക്)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'വടക്കെ അമേരിക്കൻ സെൻട്രൽ സമയം (ബ്യൂല, വടക്കൻ ഡെക്കോട്ട)',
         'America/North_Dakota/Center' => 'വടക്കെ അമേരിക്കൻ സെൻട്രൽ സമയം (സെന്റർ, വടക്കൻ ഡെക്കോട്ട)',
         'America/North_Dakota/New_Salem' => 'വടക്കെ അമേരിക്കൻ സെൻട്രൽ സമയം (ന്യൂ സെയ്‌ലം, വടക്കൻ ഡെക്കോട്ട)',
-        'America/Ojinaga' => 'വടക്കെ അമേരിക്കൻ മൌണ്ടൻ സമയം (ഒജിൻഗ)',
+        'America/Ojinaga' => 'വടക്കെ അമേരിക്കൻ സെൻട്രൽ സമയം (ഒജിൻഗ)',
         'America/Panama' => 'വടക്കെ അമേരിക്കൻ കിഴക്കൻ സമയം (പനാമ)',
         'America/Pangnirtung' => 'വടക്കെ അമേരിക്കൻ കിഴക്കൻ സമയം (പാൻഗ്‌നിറ്റംഗ്)',
         'America/Paramaribo' => 'സുരിനെയിം സമയം (പരാമാരിബോ)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ഗേൺസേ)',
         'Europe/Helsinki' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ഹെൽ‌സിങ്കി)',
         'Europe/Isle_of_Man' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ഐൽ‌ ഓഫ് മാൻ‌)',
-        'Europe/Istanbul' => 'തുർക്കി സമയം (ഇസ്താം‌ബുൾ‌)',
+        'Europe/Istanbul' => 'തുർക്കിയെ സമയം (ഇസ്താം‌ബുൾ‌)',
         'Europe/Jersey' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ജേഴ്‌സി)',
         'Europe/Kaliningrad' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (കലിനിൻഗ്രാഡ്)',
         'Europe/Kiev' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (കീവ്)',
