@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'फ्रेंच गयाना वेळ (कायेने)',
         'America/Cayman' => 'पौर्वात्य वेळ (केमन)',
         'America/Chicago' => 'केंद्रीय वेळ (शिकागो)',
-        'America/Chihuahua' => 'मेक्सिको पॅसिफिक वेळ (चिहुआहुआ)',
+        'America/Chihuahua' => 'केंद्रीय वेळ (चिहुआहुआ)',
+        'America/Ciudad_Juarez' => 'पर्वतीय वेळ (सिउदाद हुआरेझ)',
         'America/Coral_Harbour' => 'पौर्वात्य वेळ (अॅटिकोकन)',
         'America/Cordoba' => 'अर्जेंटिना वेळ (कॉर्डोबा)',
         'America/Costa_Rica' => 'केंद्रीय वेळ (कोस्टा रिका)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'अटलांटिक वेळ (माँकटन)',
         'America/Monterrey' => 'केंद्रीय वेळ (मॉन्टेरे)',
         'America/Montevideo' => 'उरुग्वे वेळ (मोन्टेव्हिडियो)',
-        'America/Montreal' => 'कॅनडा वेळ (Montreal)',
         'America/Montserrat' => 'अटलांटिक वेळ (माँन्टसेरात)',
         'America/Nassau' => 'पौर्वात्य वेळ (नसाऊ)',
         'America/New_York' => 'पौर्वात्य वेळ (न्यूयॉर्क)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'केंद्रीय वेळ (ब्युलाह, उत्तर डकोटा)',
         'America/North_Dakota/Center' => 'केंद्रीय वेळ (मध्य, उत्तर डकोटा)',
         'America/North_Dakota/New_Salem' => 'केंद्रीय वेळ (न्यू सालेम, उत्तर डकोटा)',
-        'America/Ojinaga' => 'पर्वतीय वेळ (ओजिनागा)',
+        'America/Ojinaga' => 'केंद्रीय वेळ (ओजिनागा)',
         'America/Panama' => 'पौर्वात्य वेळ (पनामा)',
         'America/Pangnirtung' => 'पौर्वात्य वेळ (पँगनिरतुंग)',
         'America/Paramaribo' => 'सुरिनाम वेळ (पारमरीबो)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'ग्रीनिच प्रमाण वेळ (ग्वेर्नसे)',
         'Europe/Helsinki' => 'पूर्व युरोपियन वेळ (हेलसिंकी)',
         'Europe/Isle_of_Man' => 'ग्रीनिच प्रमाण वेळ (आयल ऑफ मॅन)',
-        'Europe/Istanbul' => 'तुर्की वेळ (इस्तंबूल)',
+        'Europe/Istanbul' => 'तुर्किये वेळ (इस्तंबूल)',
         'Europe/Jersey' => 'ग्रीनिच प्रमाण वेळ (जर्सी)',
         'Europe/Kaliningrad' => 'पूर्व युरोपियन वेळ (कलिनिनग्राड)',
         'Europe/Kiev' => 'पूर्व युरोपियन वेळ (कीव)',
