@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Waktu Guyana Perancis (Cayenne)',
         'America/Cayman' => 'Waktu Timur (Cayman)',
         'America/Chicago' => 'Waktu Pusat (Chicago)',
-        'America/Chihuahua' => 'Waktu Pasifik Mexico (Chihuahua)',
+        'America/Chihuahua' => 'Waktu Pusat (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Waktu Pergunungan (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Waktu Timur (Atikokan)',
         'America/Cordoba' => 'Waktu Argentina (Cordoba)',
         'America/Costa_Rica' => 'Waktu Pusat (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Waktu Atlantik (Moncton)',
         'America/Monterrey' => 'Waktu Pusat (Monterrey)',
         'America/Montevideo' => 'Waktu Uruguay (Montevideo)',
-        'America/Montreal' => 'Waktu Kanada (Montreal)',
         'America/Montserrat' => 'Waktu Atlantik (Montserrat)',
         'America/Nassau' => 'Waktu Timur (Nassau)',
         'America/New_York' => 'Waktu Timur (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Waktu Pusat (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Waktu Pusat (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Waktu Pusat (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Waktu Pergunungan (Ojinaga)',
+        'America/Ojinaga' => 'Waktu Pusat (Ojinaga)',
         'America/Panama' => 'Waktu Timur (Panama)',
         'America/Pangnirtung' => 'Waktu Timur (Pangnirtung)',
         'America/Paramaribo' => 'Waktu Suriname (Paramaribo)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'Waktu Min Greenwich (Guernsey)',
         'Europe/Helsinki' => 'Waktu Eropah Timur (Helsinki)',
         'Europe/Isle_of_Man' => 'Waktu Min Greenwich (Isle of Man)',
-        'Europe/Istanbul' => 'Waktu Turki (Istanbul)',
+        'Europe/Istanbul' => 'Waktu Turkiye (Istanbul)',
         'Europe/Jersey' => 'Waktu Min Greenwich (Jersey)',
         'Europe/Kaliningrad' => 'Waktu Eropah Timur (Kaliningrad)',
         'Europe/Kiev' => 'Waktu Eropah Timur (Kiev)',
