@@ -87,6 +87,7 @@ return [
         'America/Cayman' => 'Ħin ta’ il-Gżejjer Cayman (Cayman)',
         'America/Chicago' => 'Ħin ta’ l-Istati Uniti (Chicago)',
         'America/Chihuahua' => 'Ħin ta’ il-Messiku (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Ħin ta’ il-Messiku (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Ħin ta’ il-Kanada (Atikokan)',
         'America/Cordoba' => 'Ħin ta’ l-Arġentina (Cordoba)',
         'America/Costa_Rica' => 'Ħin ta’ il-Costa Rica (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Ħin ta’ il-Kanada (Moncton)',
         'America/Monterrey' => 'Ħin ta’ il-Messiku (Monterrey)',
         'America/Montevideo' => 'Ħin ta’ l-Urugwaj (Montevideo)',
-        'America/Montreal' => 'Ħin ta’ il-Kanada (Montreal)',
         'America/Montserrat' => 'Ħin ta’ Montserrat (Montserrat)',
         'America/Nassau' => 'Ħin ta’ il-Bahamas (Nassau)',
         'America/New_York' => 'Ħin ta’ l-Istati Uniti (New York)',
