@@ -69,114 +69,114 @@ return [
         'America/Aruba' => 'အတ္တလန်တစ် အချိန် (အာရူးဗာ)',
         'America/Asuncion' => 'ပါရာဂွေး အချိန် (အာဆူစီအွန်း)',
         'America/Bahia' => 'ဘရာဇီး အချိန် (ဘာဟီအာ)',
-        'America/Bahia_Banderas' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ဘာဟီအာ ဘန်ဒရက်စ်)',
+        'America/Bahia_Banderas' => 'အလယ်ပိုင်းအချိန် (ဘာဟီအာ ဘန်ဒရက်စ်)',
         'America/Barbados' => 'အတ္တလန်တစ် အချိန် (ဘာဘေးဒိုးစ်)',
         'America/Belem' => 'ဘရာဇီး အချိန် (ဘီလင်မ်)',
-        'America/Belize' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ဘလိဇ်)',
+        'America/Belize' => 'အလယ်ပိုင်းအချိန် (ဘလိဇ်)',
         'America/Blanc-Sablon' => 'အတ္တလန်တစ် အချိန် (ဘလွန်ခ်-စာဘလွန်)',
         'America/Boa_Vista' => 'အမေဇုံ အချိန် (ဘိုအာဗီစ်တာ)',
         'America/Bogota' => 'ကိုလံဘီယာ အချိန် (ဘိုဂိုတာ)',
-        'America/Boise' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (ဗွိုက်စီ)',
+        'America/Boise' => 'တောင်တန်းအချိန် (ဗွိုက်စီ)',
         'America/Buenos_Aires' => 'အာဂျင်တီးနား အချိန် (ဗျူနိုအေးရိစ်)',
-        'America/Cambridge_Bay' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (ကိန်းဘရစ်ချ် ဘေး)',
+        'America/Cambridge_Bay' => 'တောင်တန်းအချိန် (ကိန်းဘရစ်ချ် ဘေး)',
         'America/Campo_Grande' => 'အမေဇုံ အချိန် (ကိမ်ပို ဂရန်ဒီ)',
-        'America/Cancun' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ကန်ခန်)',
+        'America/Cancun' => 'အရှေ့ပိုင်းအချိန် (ကန်ခန်)',
         'America/Caracas' => 'ဗင်နီဇွဲလား အချိန် (ကာရာကာစ်)',
         'America/Catamarca' => 'အာဂျင်တီးနား အချိန် (ကာတာမာရကာ)',
         'America/Cayenne' => 'ပြင်သစ် ဂီအားနား အချိန် (ကေညင်န်)',
-        'America/Cayman' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ကေမန်)',
-        'America/Chicago' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ချီကာကို)',
-        'America/Chihuahua' => 'မက္ကဆီကန် ပစိဖိတ် အချိန် (ချီဟူအာဟူအာ)',
-        'America/Coral_Harbour' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (အာတီကိုကန်)',
+        'America/Cayman' => 'အရှေ့ပိုင်းအချိန် (ကေမန်)',
+        'America/Chicago' => 'အလယ်ပိုင်းအချိန် (ချီကာကို)',
+        'America/Chihuahua' => 'အလယ်ပိုင်းအချိန် (ချီဟူအာဟူအာ)',
+        'America/Ciudad_Juarez' => 'တောင်တန်းအချိန် (စီယူဒတ်စ် ဟွာရက်စ်)',
+        'America/Coral_Harbour' => 'အရှေ့ပိုင်းအချိန် (အာတီကိုကန်)',
         'America/Cordoba' => 'အာဂျင်တီးနား အချိန် (ကိုဒိုဘာ)',
-        'America/Costa_Rica' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ကို့စတာရီကာ)',
-        'America/Creston' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (ကရစ်စတွန်)',
+        'America/Costa_Rica' => 'အလယ်ပိုင်းအချိန် (ကို့စတာရီကာ)',
+        'America/Creston' => 'တောင်တန်းအချိန် (ကရစ်စတွန်)',
         'America/Cuiaba' => 'အမေဇုံ အချိန် (ကွီရာဘာ)',
         'America/Curacao' => 'အတ္တလန်တစ် အချိန် (ကျူရေးကိုး)',
         'America/Danmarkshavn' => 'ဂရင်းနစ် စံတော်ချိန် (ဒန်မတ်ရှ်ဗာန်)',
         'America/Dawson' => 'ယူကွန်း အချိန် (ဒေါ်ဆန်)',
-        'America/Dawson_Creek' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (ဒေါ်ဆန် ခရိခ်)',
-        'America/Denver' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (ဒင်န်ဗာ)',
-        'America/Detroit' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ဒက်ထရွိုက်)',
+        'America/Dawson_Creek' => 'တောင်တန်းအချိန် (ဒေါ်ဆန် ခရိခ်)',
+        'America/Denver' => 'တောင်တန်းအချိန် (ဒင်န်ဗာ)',
+        'America/Detroit' => 'အရှေ့ပိုင်းအချိန် (ဒက်ထရွိုက်)',
         'America/Dominica' => 'အတ္တလန်တစ် အချိန် (ဒိုမီနီကာ)',
-        'America/Edmonton' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (အက်ဒ်မွန်တန်)',
+        'America/Edmonton' => 'တောင်တန်းအချိန် (အက်ဒ်မွန်တန်)',
         'America/Eirunepe' => 'ဘရာဇီး အချိန် (အီရူနီပီ)',
-        'America/El_Salvador' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (အယ်လ်ဆာဗေဒို)',
-        'America/Fort_Nelson' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (ဖို့တ် နယ်လ်ဆင်)',
+        'America/El_Salvador' => 'အလယ်ပိုင်းအချိန် (အယ်လ်ဆာဗေဒို)',
+        'America/Fort_Nelson' => 'တောင်တန်းအချိန် (ဖို့တ် နယ်လ်ဆင်)',
         'America/Fortaleza' => 'ဘရာဇီး အချိန် (ဖို့တ်တာလီဇာ)',
         'America/Glace_Bay' => 'အတ္တလန်တစ် အချိန် (ဂလဲစ်ဘေး)',
         'America/Godthab' => 'အနောက် ဂရင်းလန်း အချိန် (နုခ်)',
         'America/Goose_Bay' => 'အတ္တလန်တစ် အချိန် (ဂူးစ်ဘေး)',
-        'America/Grand_Turk' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ဂရန်ဒ် တခ်)',
+        'America/Grand_Turk' => 'အရှေ့ပိုင်းအချိန် (ဂရန်ဒ် တခ်)',
         'America/Grenada' => 'အတ္တလန်တစ် အချိန် (ဂရီနေဒါ)',
         'America/Guadeloupe' => 'အတ္တလန်တစ် အချိန် (ဂွါဒီလုပ်)',
-        'America/Guatemala' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ဂွါတီမာလာ)',
+        'America/Guatemala' => 'အလယ်ပိုင်းအချိန် (ဂွါတီမာလာ)',
         'America/Guayaquil' => 'အီကွေဒေါ အချိန် (ဂွါရာကွီးလ်)',
         'America/Guyana' => 'ဂိုင်ယာနာ အချိန်',
         'America/Halifax' => 'အတ္တလန်တစ် အချိန် (ဟလီဖက်စ်)',
         'America/Havana' => 'ကျူးဘား အချိန် (ဟာဗာနာ)',
         'America/Hermosillo' => 'မက္ကဆီကန် ပစိဖိတ် အချိန် (ဟာမိုစ်စီလို)',
-        'America/Indiana/Knox' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (နောက်ခ်စ် အင်ဒီယားနား)',
-        'America/Indiana/Marengo' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (မာရန်ဂို အင်ဒီယားနား)',
-        'America/Indiana/Petersburg' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ပီတာစ်ဘတ်ခ် အင်ဒီယားနား)',
-        'America/Indiana/Tell_City' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (တဲလ်စီးတီး အင်ဒီယားနား)',
-        'America/Indiana/Vevay' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ဗီဗဲ အင်ဒီယားနား)',
-        'America/Indiana/Vincennes' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ဗင်ဆင့်စ် အင်ဒီယားနား)',
-        'America/Indiana/Winamac' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ဝီနာမက်ခ် အင်ဒီယားနား)',
-        'America/Indianapolis' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (အင်ဒီယားနား ပိုလိစ်)',
-        'America/Inuvik' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (အီနုဗီခ်)',
-        'America/Iqaluit' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (အီကာလူအီတ်)',
-        'America/Jamaica' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ဂျမေကာ)',
+        'America/Indiana/Knox' => 'အလယ်ပိုင်းအချိန် (နောက်ခ်စ်၊ အင်ဒီယားနား)',
+        'America/Indiana/Marengo' => 'အရှေ့ပိုင်းအချိန် (မာရန်ဂို၊ အင်ဒီယားနား)',
+        'America/Indiana/Petersburg' => 'အရှေ့ပိုင်းအချိန် (ပီတာစ်ဘတ်ခ်၊ အင်ဒီယားနား)',
+        'America/Indiana/Tell_City' => 'အလယ်ပိုင်းအချိန် (တဲလ်စီးတီး၊ အင်ဒီယားနား)',
+        'America/Indiana/Vevay' => 'အရှေ့ပိုင်းအချိန် (ဗီဗဲ၊ အင်ဒီယားနား)',
+        'America/Indiana/Vincennes' => 'အရှေ့ပိုင်းအချိန် (ဗင်ဆင့်စ်၊ အင်ဒီယားနား)',
+        'America/Indiana/Winamac' => 'အရှေ့ပိုင်းအချိန် (ဝီနာမက်ခ်၊ အင်ဒီယားနား)',
+        'America/Indianapolis' => 'အရှေ့ပိုင်းအချိန် (အင်ဒီယားနား ပိုလိစ်)',
+        'America/Inuvik' => 'တောင်တန်းအချိန် (အီနုဗီခ်)',
+        'America/Iqaluit' => 'အရှေ့ပိုင်းအချိန် (အီကာလူအီတ်)',
+        'America/Jamaica' => 'အရှေ့ပိုင်းအချိန် (ဂျမေကာ)',
         'America/Jujuy' => 'အာဂျင်တီးနား အချိန် (ဂျုဂျေ)',
         'America/Juneau' => 'အလာစကာ အချိန် (ဂျုနိုအော)',
-        'America/Kentucky/Monticello' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (မွန်တီချယ်လို ကင်တပ်ကီ)',
+        'America/Kentucky/Monticello' => 'အရှေ့ပိုင်းအချိန် (မွန်တီချယ်လို၊ ကင်တပ်ကီ)',
         'America/Kralendijk' => 'အတ္တလန်တစ် အချိန် (ခရာလဲန်းဒစ်ချ်)',
         'America/La_Paz' => 'ဘိုလီးဘီးယား အချိန် (လာပါဇ်)',
         'America/Lima' => 'ပီရူး အချိန် (လီမာ)',
-        'America/Los_Angeles' => 'မြောက်အမေရိက ပစိဖိတ်အချိန် (လော့စ်အိန်ဂျယ်လိစ်)',
-        'America/Louisville' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (လူဝီဗီးလ်)',
+        'America/Los_Angeles' => 'ပစိဖိတ်အချိန် (လော့စ်အိန်ဂျယ်လိစ်)',
+        'America/Louisville' => 'အရှေ့ပိုင်းအချိန် (လူဝီဗီးလ်)',
         'America/Lower_Princes' => 'အတ္တလန်တစ် အချိန် (လိုအာပရင့်စ် ကွာတာ)',
         'America/Maceio' => 'ဘရာဇီး အချိန် (မာဆဲသွာ)',
-        'America/Managua' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (မာနာဂွါ)',
+        'America/Managua' => 'အလယ်ပိုင်းအချိန် (မာနာဂွါ)',
         'America/Manaus' => 'အမေဇုံ အချိန် (မာနောက်စ်)',
         'America/Marigot' => 'အတ္တလန်တစ် အချိန် (မာရီဂေါ့)',
         'America/Martinique' => 'အတ္တလန်တစ် အချိန် (မာတီနီဂ်)',
-        'America/Matamoros' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (မာတာမိုရိုစ်)',
+        'America/Matamoros' => 'အလယ်ပိုင်းအချိန် (မာတာမိုရိုစ်)',
         'America/Mazatlan' => 'မက္ကဆီကန် ပစိဖိတ် အချိန် (မာဇတ်လန်)',
         'America/Mendoza' => 'အာဂျင်တီးနား အချိန် (မန်ဒိုဇာ)',
-        'America/Menominee' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (မီနိုမီနီး)',
-        'America/Merida' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (မီရီဒါ)',
+        'America/Menominee' => 'အလယ်ပိုင်းအချိန် (မီနိုမီနီး)',
+        'America/Merida' => 'အလယ်ပိုင်းအချိန် (မီရီဒါ)',
         'America/Metlakatla' => 'အလာစကာ အချိန် (မက်တ်လာကက်လာ)',
-        'America/Mexico_City' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (မက်ကဆီကို စီးတီး)',
+        'America/Mexico_City' => 'အလယ်ပိုင်းအချိန် (မက်ကဆီကို စီးတီး)',
         'America/Miquelon' => 'စိန့်ပီအဲနှင့်မီခွီလွန်အချိန် (မီကွီလွန်)',
         'America/Moncton' => 'အတ္တလန်တစ် အချိန် (မွန်ခ်တွန်)',
-        'America/Monterrey' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (မွန်တဲရေး)',
+        'America/Monterrey' => 'အလယ်ပိုင်းအချိန် (မွန်တဲရေး)',
         'America/Montevideo' => 'ဥရုဂွေး အချိန် (မွန်တီဗီဒီအို)',
-        'America/Montreal' => 'ကနေဒါ အချိန် (Montreal)',
         'America/Montserrat' => 'အတ္တလန်တစ် အချိန် (မွန့်(တ်)ဆေးရတ်)',
-        'America/Nassau' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (နာ့ဆော်)',
-        'America/New_York' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (နယူးယောက်)',
-        'America/Nipigon' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (နီပီဂွန်)',
+        'America/Nassau' => 'အရှေ့ပိုင်းအချိန် (နာ့ဆော်)',
+        'America/New_York' => 'အရှေ့ပိုင်းအချိန် (နယူးယောက်)',
+        'America/Nipigon' => 'အရှေ့ပိုင်းအချိန် (နီပီဂွန်)',
         'America/Nome' => 'အလာစကာ အချိန် (နိုမီ)',
         'America/Noronha' => 'ဖာနန်ဒိုးဒီနိုးရိုးညာ အချိန် (နိုရိုညာ)',
-        'America/North_Dakota/Beulah' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ဗြူလာ၊ မြောက်ဒါကိုတာ)',
-        'America/North_Dakota/Center' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (စင်တာ၊ မြောက်ဒါကိုတာ)',
-        'America/North_Dakota/New_Salem' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (နယူးဆေးလမ်၊ မြောက်ဒါကိုတာ)',
-        'America/Ojinaga' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (အိုခီနဂါ)',
-        'America/Panama' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ပနားမား)',
-        'America/Pangnirtung' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ဖန်ဂ်နသ်တံ)',
+        'America/North_Dakota/Beulah' => 'အလယ်ပိုင်းအချိန် (ဗြူလာ၊ မြောက်ဒါကိုတာ)',
+        'America/North_Dakota/Center' => 'အလယ်ပိုင်းအချိန် (စင်တာ၊ မြောက်ဒါကိုတာ)',
+        'America/North_Dakota/New_Salem' => 'အလယ်ပိုင်းအချိန် (နယူးဆေးလမ်၊ မြောက်ဒါကိုတာ)',
+        'America/Ojinaga' => 'အလယ်ပိုင်းအချိန် (အိုခီနဂါ)',
+        'America/Panama' => 'အရှေ့ပိုင်းအချိန် (ပနားမား)',
+        'America/Pangnirtung' => 'အရှေ့ပိုင်းအချိန် (ဖန်ဂ်နသ်တံ)',
         'America/Paramaribo' => 'စူးရီနာမ်အချိန် (ပါရာမာရီဘို)',
-        'America/Phoenix' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (ဖီးနစ်)',
-        'America/Port-au-Prince' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (ပို့တ်-အို-ပရင့်စ်)',
+        'America/Phoenix' => 'တောင်တန်းအချိန် (ဖီးနစ်)',
+        'America/Port-au-Prince' => 'အရှေ့ပိုင်းအချိန် (ပို့တ်-အို-ပရင့်စ်)',
         'America/Port_of_Spain' => 'အတ္တလန်တစ် အချိန် (ပို့တ် အော့ဖ် စပိန်)',
         'America/Porto_Velho' => 'အမေဇုံ အချိန် (ပို့တ်တို ဗဲလီယို)',
         'America/Puerto_Rico' => 'အတ္တလန်တစ် အချိန် (ပေါ်တိုရီကို)',
         'America/Punta_Arenas' => 'ချီလီ အချိန် (ပွန်တာ အရီနာစ်)',
-        'America/Rainy_River' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ရိမ်းနီး ရီဗာ)',
-        'America/Rankin_Inlet' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ရန်ကင် အင်းလက်)',
+        'America/Rainy_River' => 'အလယ်ပိုင်းအချိန် (ရိမ်းနီး ရီဗာ)',
+        'America/Rankin_Inlet' => 'အလယ်ပိုင်းအချိန် (ရန်ကင် အင်းလက်)',
         'America/Recife' => 'ဘရာဇီး အချိန် (ဟေစီဖီလ်)',
-        'America/Regina' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ရယ်ဂျီနာ)',
-        'America/Resolute' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ရီဆိုလုပ်(တ်))',
+        'America/Regina' => 'အလယ်ပိုင်းအချိန် (ရယ်ဂျီနာ)',
+        'America/Resolute' => 'အလယ်ပိုင်းအချိန် (ရီဆိုလုပ်(တ်))',
         'America/Rio_Branco' => 'ဘရာဇီး အချိန် (ရီယို ဘရန်ကို)',
         'America/Santa_Isabel' => 'အနောက်တောင် မက္ကဆီကို အချိန် (ဆန်တာ အစ္ဇဘဲလ်)',
         'America/Santarem' => 'ဘရာဇီး အချိန် (ဆန်တာရမ်)',
@@ -191,18 +191,18 @@ return [
         'America/St_Lucia' => 'အတ္တလန်တစ် အချိန် (စိန့်လူစီယာ)',
         'America/St_Thomas' => 'အတ္တလန်တစ် အချိန် (စိန့်သောမတ်စ်)',
         'America/St_Vincent' => 'အတ္တလန်တစ် အချိန် (စိန့်ဗင်းဆင့်)',
-        'America/Swift_Current' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (စွတ်ဖ်တ် ကားရင့်)',
-        'America/Tegucigalpa' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (တီဂူစီဂလ်ပါ)',
+        'America/Swift_Current' => 'အလယ်ပိုင်းအချိန် (စွတ်ဖ်တ် ကားရင့်)',
+        'America/Tegucigalpa' => 'အလယ်ပိုင်းအချိန် (တီဂူစီဂလ်ပါ)',
         'America/Thule' => 'အတ္တလန်တစ် အချိန် (သုလီ)',
-        'America/Thunder_Bay' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (သန်းန်ဒါး ဘေး)',
-        'America/Tijuana' => 'မြောက်အမေရိက ပစိဖိတ်အချိန် (တီဂွါနာ)',
-        'America/Toronto' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန် (တိုရန်တို)',
+        'America/Thunder_Bay' => 'အရှေ့ပိုင်းအချိန် (သန်းန်ဒါး ဘေး)',
+        'America/Tijuana' => 'ပစိဖိတ်အချိန် (တီဂွါနာ)',
+        'America/Toronto' => 'အရှေ့ပိုင်းအချိန် (တိုရန်တို)',
         'America/Tortola' => 'အတ္တလန်တစ် အချိန် (တောတိုလာ)',
-        'America/Vancouver' => 'မြောက်အမေရိက ပစိဖိတ်အချိန် (ဗန်ကူးဗား)',
+        'America/Vancouver' => 'ပစိဖိတ်အချိန် (ဗန်ကူးဗား)',
         'America/Whitehorse' => 'ယူကွန်း အချိန် (ဝိုက်(တ်)ဟိုစ်)',
-        'America/Winnipeg' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန် (ဝီနီဗက်ဂ်)',
+        'America/Winnipeg' => 'အလယ်ပိုင်းအချိန် (ဝီနီဗက်ဂ်)',
         'America/Yakutat' => 'အလာစကာ အချိန် (ရာကုတတ်)',
-        'America/Yellowknife' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန် (ရဲလိုနိုက်ဖ်)',
+        'America/Yellowknife' => 'တောင်တန်းအချိန် (ရဲလိုနိုက်ဖ်)',
         'Antarctica/Casey' => 'အန်တာတိက အချိန် (ကေစီ)',
         'Antarctica/Davis' => 'ဒေးဗစ် အချိန်',
         'Antarctica/DumontDUrville' => 'ဒူးမော့တ် ဒါရ်ဗီးလ် အချိန်',
@@ -301,7 +301,7 @@ return [
         'Atlantic/Azores' => 'အေဇိုးရီးစ် အချိန်',
         'Atlantic/Bermuda' => 'အတ္တလန်တစ် အချိန် (ဘာမြူဒါ)',
         'Atlantic/Canary' => 'အနောက်ဥရောပ အချိန် (ကနေရီ)',
-        'Atlantic/Cape_Verde' => 'ကိတ်ပ် ဗာဒီ အချိန်',
+        'Atlantic/Cape_Verde' => 'ကိတ်ဗာဒီ အချိန် (ကိတ်ပ် ဗာဒီ)',
         'Atlantic/Faeroe' => 'အနောက်ဥရောပ အချိန် (ဖါရို)',
         'Atlantic/Madeira' => 'အနောက်ဥရောပ အချိန် (မဒီးရာ)',
         'Atlantic/Reykjavik' => 'ဂရင်းနစ် စံတော်ချိန် (ရေးကီဗစ်ခ်)',
@@ -320,8 +320,8 @@ return [
         'Australia/Melbourne' => 'အရှေ့ဩစတြေးလျ အချိန် (မဲလ်ဘုန်း)',
         'Australia/Perth' => 'အနောက်ဩစတြေးလျ အချိန် (ပါးသ်)',
         'Australia/Sydney' => 'အရှေ့ဩစတြေးလျ အချိန် (ဆစ်ဒနီ)',
-        'CST6CDT' => 'မြောက်အမေရိက အလယ်ပိုင်းအချိန်',
-        'EST5EDT' => 'မြောက်အမေရိက အရှေ့ပိုင်းအချိန်',
+        'CST6CDT' => 'အလယ်ပိုင်းအချိန်',
+        'EST5EDT' => 'အရှေ့ပိုင်းအချိန်',
         'Etc/GMT' => 'ဂရင်းနစ် စံတော်ချိန်',
         'Etc/UTC' => 'ညှိထားသည့် ကမ္ဘာ့ စံတော်ချိန်',
         'Europe/Amsterdam' => 'ဥရောပအလယ်ပိုင်း အချိန် (အမ်စတာဒမ်)',
@@ -392,11 +392,11 @@ return [
         'Indian/Kerguelen' => 'ပြင်သစ်တောင်ပိုင်းနှင့် အန္တာတိတ် အချိန် (ခါဂါလန်)',
         'Indian/Mahe' => 'ဆေးရှဲ အချိန် (မာဟီ)',
         'Indian/Maldives' => 'မော်လဒိုက် အချိန်',
-        'Indian/Mauritius' => 'မောရစ်ရှ် အချိန်',
+        'Indian/Mauritius' => 'မောရစ်ရှ အချိန်',
         'Indian/Mayotte' => 'အရှေ့အာဖရိက အချိန် (မာယိုတဲ)',
         'Indian/Reunion' => 'ရီယူနီယံ အချိန် (ရီယူနီယန်)',
-        'MST7MDT' => 'မြောက်အမေရိက တောင်တန်းဒေသအချိန်',
-        'PST8PDT' => 'မြောက်အမေရိက ပစိဖိတ်အချိန်',
+        'MST7MDT' => 'တောင်တန်းအချိန်',
+        'PST8PDT' => 'ပစိဖိတ်အချိန်',
         'Pacific/Apia' => 'အပီယာ အချိန် (အားပီအား)',
         'Pacific/Auckland' => 'နယူးဇီလန် အချိန် (အော့ကလန်)',
         'Pacific/Bougainville' => 'ပါပူအာနယူးဂီနီ အချိန် (ဘူဂန်ဗီးလီးယား)',
@@ -420,7 +420,7 @@ return [
         'Pacific/Marquesas' => 'မာခေးအပ်စ် အချိန်',
         'Pacific/Midway' => 'ဆမိုအာ အချိန် (မစ်ဒ်ဝေး)',
         'Pacific/Nauru' => 'နာဥူရူ အချိန်',
-        'Pacific/Niue' => 'နီဦးအေ အချိန်',
+        'Pacific/Niue' => 'နီဥူအေ အချိန် (နီဦးအေ)',
         'Pacific/Norfolk' => 'နောဖော့ခ်ကျွန်း အချိန် (နော်ဖော့ခ်)',
         'Pacific/Noumea' => 'နယူးကယ်လီဒိုးနီးယား အချိန် (နူမယ်အာ)',
         'Pacific/Pago_Pago' => 'ဆမိုအာ အချိန် (ပါဂိုပါဂို)',
@@ -428,13 +428,13 @@ return [
         'Pacific/Pitcairn' => 'ပါတ်ကယ်ရင် အချိန်',
         'Pacific/Ponape' => 'ဖိုနာဖဲအ် အချိန်',
         'Pacific/Port_Moresby' => 'ပါပူအာနယူးဂီနီ အချိန် (ဖို့တ် မိုရက်စ်ဘီ)',
-        'Pacific/Rarotonga' => 'ကွတ်ခ်ကျွန်းစု အချိန် (ရာရိုတွန်းဂါ)',
+        'Pacific/Rarotonga' => 'ကွတ်ကျွန်းစု အချိန် (ရာရိုတွန်းဂါ)',
         'Pacific/Saipan' => 'ချာမိုရို အချိန် (ဆိုင်ပန်)',
         'Pacific/Tahiti' => 'တဟီတီ အချိန်',
         'Pacific/Tarawa' => 'ဂီလ်ဘတ်ကျွန်းစု အချိန် (တာရာဝါ)',
         'Pacific/Tongatapu' => 'တွန်ဂါ အချိန် (တွန်ဂါတာပု)',
         'Pacific/Truk' => 'ချုခ် အချိန်',
-        'Pacific/Wake' => 'ဝိတ်ခ်ကျွန်း အချိန် (ဝိက်ခ်)',
+        'Pacific/Wake' => 'ဝိတ်ခ်ကျွန်း အချိန်',
         'Pacific/Wallis' => 'ဝေါလီစ်နှင့် ဖူကျူနာ အချိန်',
     ],
     'Meta' => [
