@@ -44,7 +44,7 @@ return [
         'America/Aruba' => 'tidssone for den nordamerikanske atlanterhavskysten (Aruba)',
         'America/Asuncion' => 'paraguayansk tid (Asuncion)',
         'America/Bahia' => 'tidssone for Brasilia (Bahia)',
-        'America/Bahia_Banderas' => 'tidssone for sentrale Nord-Amerika (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'tidssone for sentrale Nord-Amerika (Bahía de Banderas)',
         'America/Barbados' => 'tidssone for den nordamerikanske atlanterhavskysten (Barbados)',
         'America/Belem' => 'tidssone for Brasilia (Belem)',
         'America/Belize' => 'tidssone for sentrale Nord-Amerika (Belize)',
@@ -55,11 +55,12 @@ return [
         'America/Buenos_Aires' => 'argentinsk tid (Buenos Aires)',
         'America/Cambridge_Bay' => 'tidssone for Rocky Mountains (USA) (Cambridge Bay)',
         'America/Campo_Grande' => 'tidssone for Amazonas (Campo Grande)',
-        'America/Cancun' => 'tidssone for den nordamerikanske austkysten (Cancun)',
+        'America/Cancun' => 'tidssone for den nordamerikanske austkysten (Cancún)',
         'America/Catamarca' => 'argentinsk tid (Catamarca)',
         'America/Cayman' => 'tidssone for den nordamerikanske austkysten (Caymanøyane)',
         'America/Chicago' => 'tidssone for sentrale Nord-Amerika (Chicago)',
-        'America/Chihuahua' => 'tidssone for den meksikanske stillehavskysten (Chihuahua)',
+        'America/Chihuahua' => 'tidssone for sentrale Nord-Amerika (Chihuahua)',
+        'America/Ciudad_Juarez' => 'tidssone for Rocky Mountains (USA) (Ciudad Juárez)',
         'America/Coral_Harbour' => 'tidssone for den nordamerikanske austkysten (Atikokan)',
         'America/Cordoba' => 'argentinsk tid (Cordoba)',
         'America/Costa_Rica' => 'tidssone for sentrale Nord-Amerika (Costa Rica)',
@@ -128,7 +129,7 @@ return [
         'America/North_Dakota/Beulah' => 'tidssone for sentrale Nord-Amerika (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'tidssone for sentrale Nord-Amerika (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'tidssone for sentrale Nord-Amerika (New Salem, North Dakota)',
-        'America/Ojinaga' => 'tidssone for Rocky Mountains (USA) (Ojinaga)',
+        'America/Ojinaga' => 'tidssone for sentrale Nord-Amerika (Ojinaga)',
         'America/Panama' => 'tidssone for den nordamerikanske austkysten (Panama)',
         'America/Pangnirtung' => 'tidssone for den nordamerikanske austkysten (Pangnirtung)',
         'America/Phoenix' => 'tidssone for Rocky Mountains (USA) (Phoenix)',
@@ -264,7 +265,7 @@ return [
         'Europe/Gibraltar' => 'sentraleuropeisk tid (Gibraltar)',
         'Europe/Helsinki' => 'austeuropeisk tid (Helsinki)',
         'Europe/Kaliningrad' => 'austeuropeisk tid (Kaliningrad)',
-        'Europe/Kiev' => 'austeuropeisk tid (Kiev)',
+        'Europe/Kiev' => 'austeuropeisk tid (Kyiv)',
         'Europe/Lisbon' => 'vesteuropeisk tid (Lisbon)',
         'Europe/Ljubljana' => 'sentraleuropeisk tid (Ljubljana)',
         'Europe/Luxembourg' => 'sentraleuropeisk tid (Luxembourg)',
