@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'ਫ੍ਰੈਂਚ ਗੁਏਨਾ ਵੇਲਾ (ਕੇਯੇਨੇ)',
         'America/Cayman' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਕੇਮੈਨ)',
         'America/Chicago' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਸ਼ਿਕਾਗੋ)',
-        'America/Chihuahua' => 'ਮੈਕਸੀਕਨ ਪੈਸਿਫਿਕ ਵੇਲਾ (ਚਿਹੁਆਹੁਆ)',
+        'America/Chihuahua' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਚਿਹੁਆਹੁਆ)',
+        'America/Ciudad_Juarez' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਸਿਉਡਾਡ ਹੁਆਰੇਜ਼)',
         'America/Coral_Harbour' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਐਟੀਕੋਕਨ)',
         'America/Cordoba' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਕੋਰਡੋਬਾ)',
         'America/Costa_Rica' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਕੋਸਟਾ ਰੀਕਾ)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਮੋਂਕਟਨ)',
         'America/Monterrey' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਮੋਨਟੇਰੀ)',
         'America/Montevideo' => 'ਉਰੂਗਵੇ ਵੇਲਾ (ਮੋਂਟੇਵੀਡੀਓ)',
-        'America/Montreal' => 'ਕੈਨੇਡਾ ਵੇਲਾ (Montreal)',
         'America/Montserrat' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਮੋਂਟਸੇਰਾਤ)',
         'America/Nassau' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਨਾਸਾਓ)',
         'America/New_York' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਨਿਊ ਯਾਰਕ)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਬਿਉਲਾ, ਉੱਤਰੀ ਡਕੋਟਾ)',
         'America/North_Dakota/Center' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਸੇਂਟਰ, ਉੱਤਰੀ ਡਕੋਟਾ)',
         'America/North_Dakota/New_Salem' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਨਿਊ ਸਲੇਮ, ਉੱਤਰੀ ਡਕੋਟਾ)',
-        'America/Ojinaga' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਓਜੀਨਾਗਾ)',
+        'America/Ojinaga' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਓਜੀਨਾਗਾ)',
         'America/Panama' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਪਨਾਮਾ)',
         'America/Pangnirtung' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਪੈਂਗਨਿਰਟੰਗ)',
         'America/Paramaribo' => 'ਸੂਰੀਨਾਮ ਵੇਲਾ (ਪੈਰਾਮਰੀਬੋ)',
