@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'czas Gujana Francuska (Kajenna)',
         'America/Cayman' => 'czas wschodnioamerykański (Kajmany)',
         'America/Chicago' => 'czas środkowoamerykański (Chicago)',
-        'America/Chihuahua' => 'Meksyk (czas pacyficzny) (Chihuahua)',
+        'America/Chihuahua' => 'czas środkowoamerykański (Chihuahua)',
+        'America/Ciudad_Juarez' => 'czas górski (Ciudad Juárez)',
         'America/Coral_Harbour' => 'czas wschodnioamerykański (Atikokan)',
         'America/Cordoba' => 'czas Argentyna (Córdoba)',
         'America/Costa_Rica' => 'czas środkowoamerykański (Kostaryka)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'czas atlantycki (Moncton)',
         'America/Monterrey' => 'czas środkowoamerykański (Monterrey)',
         'America/Montevideo' => 'czas Urugwaj (Montevideo)',
-        'America/Montreal' => 'czas: Kanada (Montreal)',
         'America/Montserrat' => 'czas atlantycki (Montserrat)',
         'America/Nassau' => 'czas wschodnioamerykański (Nassau)',
         'America/New_York' => 'czas wschodnioamerykański (Nowy Jork)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'czas środkowoamerykański (Beulah, Dakota Północna)',
         'America/North_Dakota/Center' => 'czas środkowoamerykański (Center, Dakota Północna)',
         'America/North_Dakota/New_Salem' => 'czas środkowoamerykański (New Salem, Dakota Północna)',
-        'America/Ojinaga' => 'czas górski (Ojinaga)',
+        'America/Ojinaga' => 'czas środkowoamerykański (Ojinaga)',
         'America/Panama' => 'czas wschodnioamerykański (Panama)',
         'America/Pangnirtung' => 'czas wschodnioamerykański (Pangnirtung)',
         'America/Paramaribo' => 'czas Surinam (Paramaribo)',
