@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'د فرانسوي ګانا وخت (کیین)',
         'America/Cayman' => 'ختیځ وخت (کیمن)',
         'America/Chicago' => 'مرکزي وخت (شیکاګو)',
-        'America/Chihuahua' => 'مکسیکن پیسفک وخت (چھواھوا)',
+        'America/Chihuahua' => 'مرکزي وخت (چھواھوا)',
+        'America/Ciudad_Juarez' => 'د غره د وخت (سیوداد جیوریز)',
         'America/Coral_Harbour' => 'ختیځ وخت (اتیکوکن)',
         'America/Cordoba' => 'ارجنټاین وخت (کورډوبا)',
         'America/Costa_Rica' => 'مرکزي وخت (کوستاریکا)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'اتلانتیک وخت (مونکټون)',
         'America/Monterrey' => 'مرکزي وخت (منټرري)',
         'America/Montevideo' => 'یوروګوای وخت (مونټ وډیو)',
-        'America/Montreal' => 'د کاناډا په وخت (Montreal)',
         'America/Montserrat' => 'اتلانتیک وخت (مانټیسیرت)',
         'America/Nassau' => 'ختیځ وخت (نیساو)',
         'America/New_York' => 'ختیځ وخت (نیویارک)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'مرکزي وخت (بيولا، شمالي ډاکوټا)',
         'America/North_Dakota/Center' => 'مرکزي وخت (مرکز، شمالي ډاکوټا)',
         'America/North_Dakota/New_Salem' => 'مرکزي وخت (نوی سلیم، شمالي داکوتا)',
-        'America/Ojinaga' => 'د غره د وخت (اوجنګا)',
+        'America/Ojinaga' => 'مرکزي وخت (اوجنګا)',
         'America/Panama' => 'ختیځ وخت (پاناما)',
         'America/Pangnirtung' => 'ختیځ وخت (پينګنرچونګ)',
         'America/Paramaribo' => 'سورینام وخت (پاراماربو)',
@@ -345,7 +345,7 @@ return [
         'Europe/Istanbul' => 'د ترکي په وخت (استنبول)',
         'Europe/Jersey' => 'ګرينويچ معياري وخت (جرسی)',
         'Europe/Kaliningrad' => 'ختيځ اروپايي وخت (کيلنينګراډ)',
-        'Europe/Kiev' => 'ختيځ اروپايي وخت (کیو)',
+        'Europe/Kiev' => 'ختيځ اروپايي وخت (کیف)',
         'Europe/Kirov' => 'د روسیه په وخت (کیروف)',
         'Europe/Lisbon' => 'لوېديځ اروپايي وخت (لیسبون)',
         'Europe/Ljubljana' => 'مرکزي اروپايي وخت (لوبجانا)',
