@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Hora da Guiana Francesa (Caiena)',
         'America/Cayman' => 'Hora oriental norte-americana (Caimão)',
         'America/Chicago' => 'Hora central norte-americana (Chicago)',
-        'America/Chihuahua' => 'Hora do Pacífico Mexicano (Chihuahua)',
+        'America/Chihuahua' => 'Hora central norte-americana (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Hora de montanha norte-americana (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Hora oriental norte-americana (Atikokan)',
         'America/Cordoba' => 'Hora da Argentina (Córdoba)',
         'America/Costa_Rica' => 'Hora central norte-americana (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Hora do Atlântico (Moncton)',
         'America/Monterrey' => 'Hora central norte-americana (Monterrey)',
         'America/Montevideo' => 'Hora do Uruguai (Montevideu)',
-        'America/Montreal' => 'Hora de Canadá (Montreal)',
         'America/Montserrat' => 'Hora do Atlântico (Monserrate)',
         'America/Nassau' => 'Hora oriental norte-americana (Nassau)',
         'America/New_York' => 'Hora oriental norte-americana (Nova Iorque)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Hora central norte-americana (Beulah, Dakota do Norte)',
         'America/North_Dakota/Center' => 'Hora central norte-americana (Center, Dakota do Norte)',
         'America/North_Dakota/New_Salem' => 'Hora central norte-americana (New Salen, Dakota do Norte)',
-        'America/Ojinaga' => 'Hora de montanha norte-americana (Ojinaga)',
+        'America/Ojinaga' => 'Hora central norte-americana (Ojinaga)',
         'America/Panama' => 'Hora oriental norte-americana (Panamá)',
         'America/Pangnirtung' => 'Hora oriental norte-americana (Pangnirtung)',
         'America/Paramaribo' => 'Hora do Suriname (Paramaribo)',
