@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Hora de Guayana Francesa (Cayenne)',
         'America/Cayman' => 'Hora del Este (Cayman)',
         'America/Chicago' => 'Hora Central (Chicago)',
-        'America/Chihuahua' => 'Hora del Pacífico Mexicano (Chihuahua)',
+        'America/Chihuahua' => 'Hora Central (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Hora de la Montaña (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Hora del Este (Atikokan)',
         'America/Cordoba' => 'Hora de Argentina (Cordoba)',
         'America/Costa_Rica' => 'Hora Central (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Hora del Atlántico (Moncton)',
         'America/Monterrey' => 'Hora Central (Monterrey)',
         'America/Montevideo' => 'Hora de Uruguay (Montevideo)',
-        'America/Montreal' => 'Canadá (Montreal)',
         'America/Montserrat' => 'Hora del Atlántico (Montserrat)',
         'America/Nassau' => 'Hora del Este (Nassau)',
         'America/New_York' => 'Hora del Este (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Hora Central (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Hora Central (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Hora Central (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Hora de la Montaña (Ojinaga)',
+        'America/Ojinaga' => 'Hora Central (Ojinaga)',
         'America/Panama' => 'Hora del Este (Panama)',
         'America/Pangnirtung' => 'Hora del Este (Pangnirtung)',
         'America/Paramaribo' => 'Hora de Surinam (Paramaribo)',
