@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'Temp atlantic (Oranjestad)',
         'America/Asuncion' => 'temp: Paraguai (Asunción)',
         'America/Bahia' => 'temp: Brasilia (Bahia)',
-        'America/Bahia_Banderas' => 'Temp central (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'Temp central (Bahía de Banderas)',
         'America/Barbados' => 'Temp atlantic (Barbados)',
         'America/Belem' => 'temp: Brasilia (Belém)',
         'America/Belize' => 'Temp central (Belmopan)',
@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'temp: Guyana Franzosa (Cayenne)',
         'America/Cayman' => 'Temp oriental (Inslas Cayman)',
         'America/Chicago' => 'Temp central (Chicago)',
-        'America/Chihuahua' => 'temp: Mexico (Chihuahua)',
+        'America/Chihuahua' => 'Temp central (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Temp da muntogna (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Temp oriental (Atikokan)',
         'America/Cordoba' => 'temp: Argentinia (Córdoba)',
         'America/Costa_Rica' => 'Temp central (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Temp atlantic (Moncton)',
         'America/Monterrey' => 'Temp central (Monterrey)',
         'America/Montevideo' => 'temp: Uruguay (Montevideo)',
-        'America/Montreal' => 'temp: Canada (Montreal)',
         'America/Montserrat' => 'Temp atlantic (Brades)',
         'America/Nassau' => 'Temp oriental (Nassau)',
         'America/New_York' => 'Temp oriental (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Temp central (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Temp central (North Dakota (Central))',
         'America/North_Dakota/New_Salem' => 'Temp central (North Dakota (New Salem))',
-        'America/Ojinaga' => 'Temp da muntogna (Ojinaga)',
+        'America/Ojinaga' => 'Temp central (Ojinaga)',
         'America/Panama' => 'Temp oriental (Panama)',
         'America/Pangnirtung' => 'Temp oriental (Pangnirtung)',
         'America/Paramaribo' => 'temp: Surinam (Paramaribo)',
