@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Ora din Guyana Franceză (Cayenne)',
         'America/Cayman' => 'Ora orientală nord-americană (Cayman)',
         'America/Chicago' => 'Ora centrală nord-americană (Chicago)',
-        'America/Chihuahua' => 'Ora zonei Pacific mexicane (Chihuahua)',
+        'America/Chihuahua' => 'Ora centrală nord-americană (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Ora zonei montane nord-americane (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Ora orientală nord-americană (Atikokan)',
         'America/Cordoba' => 'Ora Argentinei (Cordoba)',
         'America/Costa_Rica' => 'Ora centrală nord-americană (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Ora zonei Atlantic nord-americane (Moncton)',
         'America/Monterrey' => 'Ora centrală nord-americană (Monterrey)',
         'America/Montevideo' => 'Ora Uruguayului (Montevideo)',
-        'America/Montreal' => 'Ora din Canada (Montreal)',
         'America/Montserrat' => 'Ora zonei Atlantic nord-americane (Montserrat)',
         'America/Nassau' => 'Ora orientală nord-americană (Nassau)',
         'America/New_York' => 'Ora orientală nord-americană (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Ora centrală nord-americană (Beulah, Dakota de Nord)',
         'America/North_Dakota/Center' => 'Ora centrală nord-americană (Center, Dakota de Nord)',
         'America/North_Dakota/New_Salem' => 'Ora centrală nord-americană (New Salem, Dakota de Nord)',
-        'America/Ojinaga' => 'Ora zonei montane nord-americane (Ojinaga)',
+        'America/Ojinaga' => 'Ora centrală nord-americană (Ojinaga)',
         'America/Panama' => 'Ora orientală nord-americană (Panama)',
         'America/Pangnirtung' => 'Ora orientală nord-americană (Pangnirtung)',
         'America/Paramaribo' => 'Ora Surinamului (Paramaribo)',
