@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Французская Гвиана (Кайенна)',
         'America/Cayman' => 'Восточная Америка (Острова Кайман)',
         'America/Chicago' => 'Центральная Америка (Чикаго)',
-        'America/Chihuahua' => 'Тихоокеанское мексиканское время (Чиуауа)',
+        'America/Chihuahua' => 'Центральная Америка (Чиуауа)',
+        'America/Ciudad_Juarez' => 'Горное время (Северная Америка) (Сьюдад-Хуарес)',
         'America/Coral_Harbour' => 'Восточная Америка (Корал-Харбор)',
         'America/Cordoba' => 'Аргентина (Кордова)',
         'America/Costa_Rica' => 'Центральная Америка (Коста-Рика)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Атлантическое время (Монктон)',
         'America/Monterrey' => 'Центральная Америка (Монтеррей)',
         'America/Montevideo' => 'Уругвай (Монтевидео)',
-        'America/Montreal' => 'Канада (Montreal)',
         'America/Montserrat' => 'Атлантическое время (Монтсеррат)',
         'America/Nassau' => 'Восточная Америка (Нассау)',
         'America/New_York' => 'Восточная Америка (Нью-Йорк)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Центральная Америка (Бойла, Северная Дакота)',
         'America/North_Dakota/Center' => 'Центральная Америка (Центр, Северная Дакота)',
         'America/North_Dakota/New_Salem' => 'Центральная Америка (Нью-Сейлем, Северная Дакота)',
-        'America/Ojinaga' => 'Горное время (Северная Америка) (Охинага)',
+        'America/Ojinaga' => 'Центральная Америка (Охинага)',
         'America/Panama' => 'Восточная Америка (Панама)',
         'America/Pangnirtung' => 'Восточная Америка (Пангниртанг)',
         'America/Paramaribo' => 'Суринам (Парамарибо)',
