@@ -29,7 +29,7 @@ return [
         'America/Araguaina' => 'ब्राजील समय: (Araguaina)',
         'America/Aruba' => 'अटलाण्टिक समयः (Aruba)',
         'America/Bahia' => 'ब्राजील समय: (Bahia)',
-        'America/Bahia_Banderas' => 'उत्तर अमेरिका: मध्य समयः (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'उत्तर अमेरिका: मध्य समयः (Bahía de Banderas)',
         'America/Barbados' => 'अटलाण्टिक समयः (Barbados)',
         'America/Belem' => 'ब्राजील समय: (Belem)',
         'America/Belize' => 'उत्तर अमेरिका: मध्य समयः (Belize)',
@@ -38,9 +38,11 @@ return [
         'America/Boise' => 'उत्तर अमेरिका: शैल समयः (Boise)',
         'America/Cambridge_Bay' => 'उत्तर अमेरिका: शैल समयः (Cambridge Bay)',
         'America/Campo_Grande' => 'ब्राजील समय: (Campo Grande)',
-        'America/Cancun' => 'उत्तर अमेरिका: पौर्व समयः (Cancun)',
+        'America/Cancun' => 'उत्तर अमेरिका: पौर्व समयः (Cancún)',
         'America/Cayman' => 'उत्तर अमेरिका: पौर्व समयः (Cayman)',
         'America/Chicago' => 'उत्तर अमेरिका: मध्य समयः (Chicago)',
+        'America/Chihuahua' => 'उत्तर अमेरिका: मध्य समयः (Chihuahua)',
+        'America/Ciudad_Juarez' => 'उत्तर अमेरिका: शैल समयः (Ciudad Juárez)',
         'America/Coral_Harbour' => 'उत्तर अमेरिका: पौर्व समयः (Atikokan)',
         'America/Costa_Rica' => 'उत्तर अमेरिका: मध्य समयः (Costa Rica)',
         'America/Creston' => 'उत्तर अमेरिका: शैल समयः (Creston)',
@@ -87,7 +89,7 @@ return [
         'America/Martinique' => 'अटलाण्टिक समयः (Martinique)',
         'America/Matamoros' => 'उत्तर अमेरिका: मध्य समयः (Matamoros)',
         'America/Menominee' => 'उत्तर अमेरिका: मध्य समयः (Menominee)',
-        'America/Merida' => 'उत्तर अमेरिका: मध्य समयः (Merida)',
+        'America/Merida' => 'उत्तर अमेरिका: मध्य समयः (Mérida)',
         'America/Metlakatla' => 'संयुक्त राज्य: समय: (Metlakatla)',
         'America/Mexico_City' => 'उत्तर अमेरिका: मध्य समयः (Mexico City)',
         'America/Moncton' => 'अटलाण्टिक समयः (Moncton)',
@@ -101,7 +103,7 @@ return [
         'America/North_Dakota/Beulah' => 'उत्तर अमेरिका: मध्य समयः (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'उत्तर अमेरिका: मध्य समयः (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'उत्तर अमेरिका: मध्य समयः (New Salem, North Dakota)',
-        'America/Ojinaga' => 'उत्तर अमेरिका: शैल समयः (Ojinaga)',
+        'America/Ojinaga' => 'उत्तर अमेरिका: मध्य समयः (Ojinaga)',
         'America/Panama' => 'उत्तर अमेरिका: पौर्व समयः (Panama)',
         'America/Pangnirtung' => 'उत्तर अमेरिका: पौर्व समयः (Pangnirtung)',
         'America/Phoenix' => 'उत्तर अमेरिका: शैल समयः (Phoenix)',
