@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'Ora de s’Atlànticu (Aruba)',
         'America/Asuncion' => 'Ora de su Paraguay (Asuncion)',
         'America/Bahia' => 'Ora de Brasìlia (Bahia)',
-        'America/Bahia_Banderas' => 'Ora tzentrale USA (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'Ora tzentrale USA (Bahía de Banderas)',
         'America/Barbados' => 'Ora de s’Atlànticu (Barbados)',
         'America/Belem' => 'Ora de Brasìlia (Belem)',
         'America/Belize' => 'Ora tzentrale USA (Belize)',
@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Ora de sa Guiana Frantzesa (Cayenne)',
         'America/Cayman' => 'Ora orientale USA (Cayman)',
         'America/Chicago' => 'Ora tzentrale USA (Chicago)',
-        'America/Chihuahua' => 'Ora de su Patzìficu (Mèssicu) (Chihuahua)',
+        'America/Chihuahua' => 'Ora tzentrale USA (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Ora Montes Pedrosos USA (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Ora orientale USA (Atikokan)',
         'America/Cordoba' => 'Ora de s’Argentina (Cordoba)',
         'America/Costa_Rica' => 'Ora tzentrale USA (Costa Rica)',
@@ -145,14 +146,13 @@ return [
         'America/Mazatlan' => 'Ora de su Patzìficu (Mèssicu) (Mazatlan)',
         'America/Mendoza' => 'Ora de s’Argentina (Mendoza)',
         'America/Menominee' => 'Ora tzentrale USA (Menominee)',
-        'America/Merida' => 'Ora tzentrale USA (Merida)',
+        'America/Merida' => 'Ora tzentrale USA (Mérida)',
         'America/Metlakatla' => 'Ora de s’Alaska (Metlakatla)',
         'America/Mexico_City' => 'Ora tzentrale USA (Tzitade de su Mèssicu)',
         'America/Miquelon' => 'Ora de Saint-Pierre e Miquelon',
         'America/Moncton' => 'Ora de s’Atlànticu (Moncton)',
         'America/Monterrey' => 'Ora tzentrale USA (Monterrey)',
         'America/Montevideo' => 'Ora de s’Uruguay (Montevideo)',
-        'America/Montreal' => 'Ora Cànada (Montreal)',
         'America/Montserrat' => 'Ora de s’Atlànticu (Montserrat)',
         'America/Nassau' => 'Ora orientale USA (Nassau)',
         'America/New_York' => 'Ora orientale USA (Noa York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Ora tzentrale USA (Beulah, Dakota de su Nord)',
         'America/North_Dakota/Center' => 'Ora tzentrale USA (Center, Dakota de su Nord)',
         'America/North_Dakota/New_Salem' => 'Ora tzentrale USA (New Salem, Dakota de su Nord)',
-        'America/Ojinaga' => 'Ora Montes Pedrosos USA (Ojinaga)',
+        'America/Ojinaga' => 'Ora tzentrale USA (Ojinaga)',
         'America/Panama' => 'Ora orientale USA (Pànama)',
         'America/Pangnirtung' => 'Ora orientale USA (Pangnirtung)',
         'America/Paramaribo' => 'Ora de su Suriname (Paramaribo)',
