@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'فرانسيسي گيانا جو وقت (ڪائين)',
         'America/Cayman' => 'مشرقي وقت (سيامن)',
         'America/Chicago' => 'مرڪزي وقت (شڪاگو)',
-        'America/Chihuahua' => 'ميڪسيڪن پيسيفڪ وقت (چي هوا هوا)',
+        'America/Chihuahua' => 'مرڪزي وقت (چي هوا هوا)',
+        'America/Ciudad_Juarez' => 'پهاڙي وقت (سوڊيڊ جوريز)',
         'America/Coral_Harbour' => 'مشرقي وقت (اٽيڪوڪن)',
         'America/Cordoba' => 'ارجنٽينا جو وقت (ڪارڊوبا)',
         'America/Costa_Rica' => 'مرڪزي وقت (ڪوسٽا ريڪا)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'ايٽلانٽڪ جو وقت (مانڪٽن)',
         'America/Monterrey' => 'مرڪزي وقت (مانٽيري)',
         'America/Montevideo' => 'يوروگائي جو وقت (مونٽي ويڊيو)',
-        'America/Montreal' => 'ڪينيڊا وقت (Montreal)',
         'America/Montserrat' => 'ايٽلانٽڪ جو وقت (مانٽسريٽ)',
         'America/Nassau' => 'مشرقي وقت (ناسائو)',
         'America/New_York' => 'مشرقي وقت (نيويارڪ)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'مرڪزي وقت (بيولاه، اتر ڊڪوٽا)',
         'America/North_Dakota/Center' => 'مرڪزي وقت (سينٽر، اتر ڊڪوٽا)',
         'America/North_Dakota/New_Salem' => 'مرڪزي وقت (نيو سيلم، اتر ڊڪوٽا)',
-        'America/Ojinaga' => 'پهاڙي وقت (اوڪيناگا)',
+        'America/Ojinaga' => 'مرڪزي وقت (اوڪيناگا)',
         'America/Panama' => 'مشرقي وقت (پناما)',
         'America/Pangnirtung' => 'مشرقي وقت (پینگنرٽنگ)',
         'America/Paramaribo' => 'سوري نام جو وقت (پيراميريبو)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'گرين وچ مين ٽائيم (گرنزي)',
         'Europe/Helsinki' => 'مشرقي يورپي وقت (هيلسنڪي)',
         'Europe/Isle_of_Man' => 'گرين وچ مين ٽائيم (آئيزل آف مين)',
-        'Europe/Istanbul' => 'ترڪي وقت (استنبول)',
+        'Europe/Istanbul' => 'ترڪييي وقت (استنبول)',
         'Europe/Jersey' => 'گرين وچ مين ٽائيم (جرسي)',
         'Europe/Kaliningrad' => 'مشرقي يورپي وقت (ڪلينن گراڊ)',
         'Europe/Kiev' => 'مشرقي يورپي وقت (ڪِيو)',
