@@ -34,12 +34,13 @@ return [
         'America/Cancun' => 'ओभरी वक्त (ڪانڪون)',
         'America/Cayman' => 'ओभरी वक्त (سيامن)',
         'America/Chicago' => 'मरकज़ी वक्त (شڪاگو)',
+        'America/Chihuahua' => 'मरकज़ी वक्त (چي هوا هوا)',
+        'America/Ciudad_Juarez' => 'पहाड़ी वक्त (سوڊيڊ جوريز)',
         'America/Coral_Harbour' => 'ओभरी वक्त (اٽيڪوڪن)',
         'America/Costa_Rica' => 'मरकज़ी वक्त (ڪوسٽا ريڪا)',
         'America/Creston' => 'पहाड़ी वक्त (ڪريسٽن)',
         'America/Curacao' => 'अटलांटिक वक्त (ڪيوراسائو)',
         'America/Danmarkshavn' => 'ग्रीनविच मीन वक्तु (ڊينمارڪ شون)',
-        'America/Dawson' => 'ڪينيڊا वक्त (ڊاوسن)',
         'America/Dawson_Creek' => 'पहाड़ी वक्त (ڊاوسن ڪريڪ)',
         'America/Denver' => 'पहाड़ी वक्त (ڊينور)',
         'America/Detroit' => 'ओभरी वक्त (ڊيٽرائيٽ)',
@@ -80,7 +81,6 @@ return [
         'America/Mexico_City' => 'मरकज़ी वक्त (ميڪسيڪو شهر)',
         'America/Moncton' => 'अटलांटिक वक्त (مانڪٽن)',
         'America/Monterrey' => 'मरकज़ी वक्त (مانٽيري)',
-        'America/Montreal' => 'ڪينيڊا वक्त (Montreal)',
         'America/Montserrat' => 'अटलांटिक वक्त (مانٽسريٽ)',
         'America/Nassau' => 'ओभरी वक्त (ناسائو)',
         'America/New_York' => 'ओभरी वक्त (نيويارڪ)',
@@ -88,7 +88,7 @@ return [
         'America/North_Dakota/Beulah' => 'मरकज़ी वक्त (بيولاه، اتر ڊڪوٽا)',
         'America/North_Dakota/Center' => 'मरकज़ी वक्त (سينٽر، اتر ڊڪوٽا)',
         'America/North_Dakota/New_Salem' => 'मरकज़ी वक्त (نيو سيلم، اتر ڊڪوٽا)',
-        'America/Ojinaga' => 'पहाड़ी वक्त (اوڪيناگا)',
+        'America/Ojinaga' => 'मरकज़ी वक्त (اوڪيناگا)',
         'America/Panama' => 'ओभरी वक्त (پناما)',
         'America/Pangnirtung' => 'ओभरी वक्त (پینگنرٽنگ)',
         'America/Phoenix' => 'पहाड़ी वक्त (فونيڪس)',
@@ -114,7 +114,6 @@ return [
         'America/Toronto' => 'ओभरी वक्त (ٽورنٽو)',
         'America/Tortola' => 'अटलांटिक वक्त (ٽورٽولا)',
         'America/Vancouver' => 'पेसिफिक वक्त (وينڪوور)',
-        'America/Whitehorse' => 'ڪينيڊا वक्त (وائيٽ هائوس)',
         'America/Winnipeg' => 'मरकज़ी वक्त (وني پيگ)',
         'America/Yellowknife' => 'पहाड़ी वक्त (ييلو نائيف)',
         'Antarctica/Casey' => 'انٽارڪٽيڪا वक्त (ڪيسي)',
@@ -159,7 +158,7 @@ return [
         'Europe/Guernsey' => 'ग्रीनविच मीन वक्तु (گرنزي)',
         'Europe/Helsinki' => 'ओभरी यूरोपी वक्तु (هيلسنڪي)',
         'Europe/Isle_of_Man' => 'ग्रीनविच मीन वक्तु (آئيزل آف مين)',
-        'Europe/Istanbul' => 'ترڪي वक्त (استنبول)',
+        'Europe/Istanbul' => 'ترڪييي वक्त (استنبول)',
         'Europe/Jersey' => 'ग्रीनविच मीन वक्तु (جرسي)',
         'Europe/Kaliningrad' => 'ओभरी यूरोपी वक्तु (ڪلينن گراڊ)',
         'Europe/Kiev' => 'ओभरी यूरोपी वक्तु (ڪِيو)',
@@ -199,5 +198,6 @@ return [
         'PST8PDT' => 'पेसिफिक वक्त',
     ],
     'Meta' => [
+        'GmtFormat' => 'जीएमटी%s',
     ],
 ];
