@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'Aruba (Aruba áigi)',
         'America/Asuncion' => 'Asuncion (Paraguay áigi)',
         'America/Bahia' => 'Bahia (Brasil áigi)',
-        'America/Bahia_Banderas' => 'Bahia Banderas (Meksiko áigi)',
+        'America/Bahia_Banderas' => 'Bahía de Banderas (Meksiko áigi)',
         'America/Barbados' => 'Barbados (Barbados áigi)',
         'America/Belem' => 'Belem (Brasil áigi)',
         'America/Belize' => 'Belize (Belize áigi)',
@@ -80,13 +80,14 @@ return [
         'America/Buenos_Aires' => 'Buenos Aires (Argentina áigi)',
         'America/Cambridge_Bay' => 'Cambridge Bay (Kanáda áigi)',
         'America/Campo_Grande' => 'Campo Grande (Brasil áigi)',
-        'America/Cancun' => 'Cancun (Meksiko áigi)',
+        'America/Cancun' => 'Cancún (Meksiko áigi)',
         'America/Caracas' => 'Caracas (Venezuela áigi)',
         'America/Catamarca' => 'Catamarca (Argentina áigi)',
         'America/Cayenne' => 'Cayenne (Frankriikka Guayana áigi)',
         'America/Cayman' => 'Cayman (Cayman-sullot áigi)',
         'America/Chicago' => 'Chicago (Amerihká ovttastuvvan stáhtat áigi)',
         'America/Chihuahua' => 'Chihuahua (Meksiko áigi)',
+        'America/Ciudad_Juarez' => 'Ciudad Juárez (Meksiko áigi)',
         'America/Coral_Harbour' => 'Atikokan (Kanáda áigi)',
         'America/Cordoba' => 'Cordoba (Argentina áigi)',
         'America/Costa_Rica' => 'Costa Rica (Costa Rica áigi)',
@@ -151,7 +152,6 @@ return [
         'America/Moncton' => 'Moncton (Kanáda áigi)',
         'America/Monterrey' => 'Monterrey (Meksiko áigi)',
         'America/Montevideo' => 'Montevideo (Uruguay áigi)',
-        'America/Montreal' => 'Montreal (Kanáda áigi)',
         'America/Montserrat' => 'Montserrat (Montserrat áigi)',
         'America/Nassau' => 'Nassau (Bahamas áigi)',
         'America/New_York' => 'New York (Amerihká ovttastuvvan stáhtat áigi)',
