@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'ප්‍රංශ ගයනා වේලාව (කේයෙන්)',
         'America/Cayman' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (කේමන්)',
         'America/Chicago' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (චිකාගෝ)',
-        'America/Chihuahua' => 'මෙක්සිකෝ පැසිෆික් වේලාව (චිහුආහුආ)',
+        'America/Chihuahua' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (චිහුආහුආ)',
+        'America/Ciudad_Juarez' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (සියුඩාඩ් ජුවාරෙස්)',
         'America/Coral_Harbour' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (ඇටිකොකන්)',
         'America/Cordoba' => 'ආර්ජන්ටිනා වේලාව (කොර්දොබා)',
         'America/Costa_Rica' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (කොස්ටරිකා)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'අත්ලාන්තික් වේලාව (මොන්ක්ටන්)',
         'America/Monterrey' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (මොන්ටෙරේ)',
         'America/Montevideo' => 'උරුගුවේ වේලාව (මොන්ටෙවිඩියෝ)',
-        'America/Montreal' => 'කැනඩාව වේලාව (Montreal)',
         'America/Montserrat' => 'අත්ලාන්තික් වේලාව (මොන්ට්සේරාට්)',
         'America/Nassau' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (නස්සෝ)',
         'America/New_York' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (නිව්යෝක්)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (බියුලා, උතුරු ඩකෝටා)',
         'America/North_Dakota/Center' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (මධ්‍යම, උතුරු ඩකෝටා)',
         'America/North_Dakota/New_Salem' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (නව සලෙම්ම, උතුරු ඩකෝටා)',
-        'America/Ojinaga' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (ඔජිනගා)',
+        'America/Ojinaga' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (ඔජිනගා)',
         'America/Panama' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (පැනමා)',
         'America/Pangnirtung' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (පැන්නීටන්)',
         'America/Paramaribo' => 'සුරිනාම වේලාව (පැරාමරිබෝ)',
