@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'francúzskoguyanský čas (Cayenne)',
         'America/Cayman' => 'severoamerický východný čas (Kajmanie ostrovy)',
         'America/Chicago' => 'severoamerický centrálny čas (Chicago)',
-        'America/Chihuahua' => 'mexický tichomorský čas (Chihuahua)',
+        'America/Chihuahua' => 'severoamerický centrálny čas (Chihuahua)',
+        'America/Ciudad_Juarez' => 'severoamerický horský čas (Ciudad Juárez)',
         'America/Coral_Harbour' => 'severoamerický východný čas (Atikokan)',
         'America/Cordoba' => 'argentínsky čas (Córdoba)',
         'America/Costa_Rica' => 'severoamerický centrálny čas (Kostarika)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'atlantický čas (Moncton)',
         'America/Monterrey' => 'severoamerický centrálny čas (Monterrey)',
         'America/Montevideo' => 'uruguajský čas (Montevideo)',
-        'America/Montreal' => 'časové pásmo Kanada (Montreal)',
         'America/Montserrat' => 'atlantický čas (Montserrat)',
         'America/Nassau' => 'severoamerický východný čas (Nassau)',
         'America/New_York' => 'severoamerický východný čas (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'severoamerický centrálny čas (Beulah, Severná Dakota)',
         'America/North_Dakota/Center' => 'severoamerický centrálny čas (Center, Severná Dakota)',
         'America/North_Dakota/New_Salem' => 'severoamerický centrálny čas (New Salem, Severná Dakota)',
-        'America/Ojinaga' => 'severoamerický horský čas (Ojinaga)',
+        'America/Ojinaga' => 'severoamerický centrálny čas (Ojinaga)',
         'America/Panama' => 'severoamerický východný čas (Panama)',
         'America/Pangnirtung' => 'severoamerický východný čas (Pangnirtung)',
         'America/Paramaribo' => 'surinamský čas (Paramaribo)',
