@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Француска Гвајана време (Кајен)',
         'America/Cayman' => 'Северноамеричко источно време (Кајманска Острва)',
         'America/Chicago' => 'Северноамеричко централно време (Чикаго)',
-        'America/Chihuahua' => 'Мексички Пацифик (Чихуахуа)',
+        'America/Chihuahua' => 'Северноамеричко централно време (Чихуахуа)',
+        'America/Ciudad_Juarez' => 'Северноамеричко планинско време (Сиудад Хуарез)',
         'America/Coral_Harbour' => 'Северноамеричко источно време (Корал Харбур)',
         'America/Cordoba' => 'Аргентина време (Кордоба)',
         'America/Costa_Rica' => 'Северноамеричко централно време (Костарика)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Атлантско време (Монктон)',
         'America/Monterrey' => 'Северноамеричко централно време (Монтереј)',
         'America/Montevideo' => 'Уругвај време (Монтевидео)',
-        'America/Montreal' => 'Канада (Montreal)',
         'America/Montserrat' => 'Атлантско време (Монтсерат)',
         'America/Nassau' => 'Северноамеричко источно време (Насау)',
         'America/New_York' => 'Северноамеричко источно време (Њујорк)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Северноамеричко централно време (Бијула, Северна Дакота)',
         'America/North_Dakota/Center' => 'Северноамеричко централно време (Центар, Северна Дакота)',
         'America/North_Dakota/New_Salem' => 'Северноамеричко централно време (Нови Салем, Северна Дакота)',
-        'America/Ojinaga' => 'Северноамеричко планинско време (Охинага)',
+        'America/Ojinaga' => 'Северноамеричко централно време (Охинага)',
         'America/Panama' => 'Северноамеричко источно време (Панама)',
         'America/Pangnirtung' => 'Северноамеричко источно време (Пангниртунг)',
         'America/Paramaribo' => 'Суринам време (Парамарибо)',
