@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Francuska Gvajana vreme (Kajen)',
         'America/Cayman' => 'Severnoameričko istočno vreme (Kajmanska Ostrva)',
         'America/Chicago' => 'Severnoameričko centralno vreme (Čikago)',
-        'America/Chihuahua' => 'Meksički Pacifik (Čihuahua)',
+        'America/Chihuahua' => 'Severnoameričko centralno vreme (Čihuahua)',
+        'America/Ciudad_Juarez' => 'Severnoameričko planinsko vreme (Siudad Huarez)',
         'America/Coral_Harbour' => 'Severnoameričko istočno vreme (Koral Harbur)',
         'America/Cordoba' => 'Argentina vreme (Kordoba)',
         'America/Costa_Rica' => 'Severnoameričko centralno vreme (Kostarika)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Atlantsko vreme (Monkton)',
         'America/Monterrey' => 'Severnoameričko centralno vreme (Monterej)',
         'America/Montevideo' => 'Urugvaj vreme (Montevideo)',
-        'America/Montreal' => 'Kanada (Montreal)',
         'America/Montserrat' => 'Atlantsko vreme (Montserat)',
         'America/Nassau' => 'Severnoameričko istočno vreme (Nasau)',
         'America/New_York' => 'Severnoameričko istočno vreme (Njujork)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Severnoameričko centralno vreme (Bijula, Severna Dakota)',
         'America/North_Dakota/Center' => 'Severnoameričko centralno vreme (Centar, Severna Dakota)',
         'America/North_Dakota/New_Salem' => 'Severnoameričko centralno vreme (Novi Salem, Severna Dakota)',
-        'America/Ojinaga' => 'Severnoameričko planinsko vreme (Ohinaga)',
+        'America/Ojinaga' => 'Severnoameričko centralno vreme (Ohinaga)',
         'America/Panama' => 'Severnoameričko istočno vreme (Panama)',
         'America/Pangnirtung' => 'Severnoameričko istočno vreme (Pangnirtung)',
         'America/Paramaribo' => 'Surinam vreme (Paramaribo)',
