@@ -85,6 +85,8 @@ return [
         'America/Cayenne' => 'Francuska Gvajana vrijeme (Kajen)',
         'America/Cayman' => 'Sjevernoameričko istočno vrijeme (Kajmanska Ostrva)',
         'America/Chicago' => 'Sjevernoameričko centralno vrijeme (Čikago)',
+        'America/Chihuahua' => 'Sjevernoameričko centralno vrijeme (Čihuahua)',
+        'America/Ciudad_Juarez' => 'Sjevernoameričko planinsko vrijeme (Siudad Huarez)',
         'America/Coral_Harbour' => 'Sjevernoameričko istočno vrijeme (Koral Harbur)',
         'America/Cordoba' => 'Argentina vrijeme (Kordoba)',
         'America/Costa_Rica' => 'Sjevernoameričko centralno vrijeme (Kostarika)',
@@ -149,7 +151,7 @@ return [
         'America/North_Dakota/Beulah' => 'Sjevernoameričko centralno vrijeme (Bjula, Sjeverna Dakota)',
         'America/North_Dakota/Center' => 'Sjevernoameričko centralno vrijeme (Centar, Sjeverna Dakota)',
         'America/North_Dakota/New_Salem' => 'Sjevernoameričko centralno vrijeme (Novi Salem, Sjeverna Dakota)',
-        'America/Ojinaga' => 'Sjevernoameričko planinsko vrijeme (Ohinaga)',
+        'America/Ojinaga' => 'Sjevernoameričko centralno vrijeme (Ohinaga)',
         'America/Panama' => 'Sjevernoameričko istočno vrijeme (Panama)',
         'America/Pangnirtung' => 'Sjevernoameričko istočno vrijeme (Pangnirtung)',
         'America/Paramaribo' => 'Surinam vrijeme (Paramaribo)',
