@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Saa za Guiana ya Ufaransa (Cayenne)',
         'America/Cayman' => 'Saa za Mashariki (Cayman)',
         'America/Chicago' => 'Saa za Kati (Chicago)',
-        'America/Chihuahua' => 'Saa za pasifiki za Meksiko (Chihuahua)',
+        'America/Chihuahua' => 'Saa za Kati (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Saa za Mountain (Ciudad Juarez)',
         'America/Coral_Harbour' => 'Saa za Mashariki (Atikokan)',
         'America/Cordoba' => 'Saa za Argentina (Cordoba)',
         'America/Costa_Rica' => 'Saa za Kati (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Saa za Atlantiki (Moncton)',
         'America/Monterrey' => 'Saa za Kati (Monterrey)',
         'America/Montevideo' => 'Saa za Urugwai (Montevideo)',
-        'America/Montreal' => 'Saa za Kanada (Montreal)',
         'America/Montserrat' => 'Saa za Atlantiki (Montserrat)',
         'America/Nassau' => 'Saa za Mashariki (Nassau)',
         'America/New_York' => 'Saa za Mashariki (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Saa za Kati (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Saa za Kati (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Saa za Kati (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Saa za Mountain (Ojinaga)',
+        'America/Ojinaga' => 'Saa za Kati (Ojinaga)',
         'America/Panama' => 'Saa za Mashariki (Panama)',
         'America/Pangnirtung' => 'Saa za Mashariki (Pangnirtung)',
         'America/Paramaribo' => 'Saa za Suriname (Paramaribo)',
