@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'ஃபிரஞ்சு கயானா நேரம் (கெய்ன்)',
         'America/Cayman' => 'கிழக்கத்திய நேரம் (கேமன்)',
         'America/Chicago' => 'மத்திய நேரம் (சிகாகோ)',
-        'America/Chihuahua' => 'மெக்ஸிகன் பசிபிக் நேரம் (சுவாவா)',
+        'America/Chihuahua' => 'மத்திய நேரம் (சுவாவா)',
+        'America/Ciudad_Juarez' => 'மவுன்டைன் நேரம் (சியுடாட் வாரஸ்)',
         'America/Coral_Harbour' => 'கிழக்கத்திய நேரம் (அடிகோகன்)',
         'America/Cordoba' => 'அர்ஜென்டினா நேரம் (கார்டோபா)',
         'America/Costa_Rica' => 'மத்திய நேரம் (கோஸ்டா ரிகா)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'அட்லாண்டிக் நேரம் (மாங்டான்)',
         'America/Monterrey' => 'மத்திய நேரம் (மான்டெர்ரே)',
         'America/Montevideo' => 'உருகுவே நேரம் (மான்டேவீடியோ)',
-        'America/Montreal' => 'கனடா நேரம் (Montreal)',
         'America/Montserrat' => 'அட்லாண்டிக் நேரம் (மான்செரேட்)',
         'America/Nassau' => 'கிழக்கத்திய நேரம் (நசவ்)',
         'America/New_York' => 'கிழக்கத்திய நேரம் (நியூயார்க்)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'மத்திய நேரம் (பெவுலா, வடக்கு டகோட்டா)',
         'America/North_Dakota/Center' => 'மத்திய நேரம் (சென்டர், வடக்கு டகோடா)',
         'America/North_Dakota/New_Salem' => 'மத்திய நேரம் (நியூ சலேம், வடக்கு டகோடா)',
-        'America/Ojinaga' => 'மவுன்டைன் நேரம் (ஒஜினகா)',
+        'America/Ojinaga' => 'மத்திய நேரம் (ஒஜினகா)',
         'America/Panama' => 'கிழக்கத்திய நேரம் (பனாமா)',
         'America/Pangnirtung' => 'கிழக்கத்திய நேரம் (பாங்னிர்துங்)',
         'America/Paramaribo' => 'சுரினாம் நேரம் (பரமரிபோ)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'கிரீன்விச் சராசரி நேரம் (கர்னஸே)',
         'Europe/Helsinki' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (ஹெல்சிங்கி)',
         'Europe/Isle_of_Man' => 'கிரீன்விச் சராசரி நேரம் (ஐல் ஆஃப் மேன்)',
-        'Europe/Istanbul' => 'துருக்கி நேரம் (இஸ்தான்புல்)',
+        'Europe/Istanbul' => 'துருக்கியே நேரம் (இஸ்தான்புல்)',
         'Europe/Jersey' => 'கிரீன்விச் சராசரி நேரம் (ஜெர்சி)',
         'Europe/Kaliningrad' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (கலினின்கிராட்)',
         'Europe/Kiev' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (கீவ்)',
