@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'ఫ్రెంచ్ గయానా సమయం (కయేన్)',
         'America/Cayman' => 'తూర్పు సమయం (కేమాన్)',
         'America/Chicago' => 'మధ్యమ సమయం (చికాగో)',
-        'America/Chihuahua' => 'మెక్సికన్ పసిఫిక్ సమయం (చువావా)',
+        'America/Chihuahua' => 'మధ్యమ సమయం (చువావా)',
+        'America/Ciudad_Juarez' => 'మౌంటెయిన్ సమయం (సియుదాద్ హ్వారెజ్)',
         'America/Coral_Harbour' => 'తూర్పు సమయం (అటికోకన్)',
         'America/Cordoba' => 'అర్జెంటీనా సమయం (కోర్డోబా)',
         'America/Costa_Rica' => 'మధ్యమ సమయం (కోస్టా రికా)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'అట్లాంటిక్ సమయం (మోన్‌క్టోన్)',
         'America/Monterrey' => 'మధ్యమ సమయం (మోంటెర్రే)',
         'America/Montevideo' => 'ఉరుగ్వే సమయం (మోంటెవీడియో)',
-        'America/Montreal' => 'కెనడా సమయం (Montreal)',
         'America/Montserrat' => 'అట్లాంటిక్ సమయం (మాంట్సెరాట్)',
         'America/Nassau' => 'తూర్పు సమయం (నాస్సావ్)',
         'America/New_York' => 'తూర్పు సమయం (న్యూయార్క్)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'మధ్యమ సమయం (బ్యులా, ఉత్తర డకోట)',
         'America/North_Dakota/Center' => 'మధ్యమ సమయం (సెంటర్, ఉత్తర డకోటా)',
         'America/North_Dakota/New_Salem' => 'మధ్యమ సమయం (న్యూ సలేమ్, ఉత్తర డకోట)',
-        'America/Ojinaga' => 'మౌంటెయిన్ సమయం (ఒజినగ)',
+        'America/Ojinaga' => 'మధ్యమ సమయం (ఒజినగ)',
         'America/Panama' => 'తూర్పు సమయం (పనామా)',
         'America/Pangnirtung' => 'తూర్పు సమయం (పాంగ్‌నీర్‌టుంగ్)',
         'America/Paramaribo' => 'సూరినామ్ సమయం (పరామారిబో)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'గ్రీన్‌విచ్ సగటు సమయం (గ్వెర్న్సే)',
         'Europe/Helsinki' => 'తూర్పు యూరోపియన్ సమయం (హెల్సింకి)',
         'Europe/Isle_of_Man' => 'గ్రీన్‌విచ్ సగటు సమయం (ఐల్ ఆఫ్ మేన్)',
-        'Europe/Istanbul' => 'టర్కీ సమయం (ఇస్తాంబుల్)',
+        'Europe/Istanbul' => 'తుర్కియె సమయం (ఇస్తాంబుల్)',
         'Europe/Jersey' => 'గ్రీన్‌విచ్ సగటు సమయం (జెర్సీ)',
         'Europe/Kaliningrad' => 'తూర్పు యూరోపియన్ సమయం (కలినిన్‌గ్రద్)',
         'Europe/Kiev' => 'తూర్పు యూరోపియన్ సమయం (కీవ్)',
