@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'Вақти атлантикӣ (Aruba)',
         'America/Asuncion' => 'Вақти Парагвай (Asuncion)',
         'America/Bahia' => 'Вақти Бразилия (Bahia)',
-        'America/Bahia_Banderas' => 'Вақти марказӣ (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'Вақти марказӣ (Bahía de Banderas)',
         'America/Barbados' => 'Вақти атлантикӣ (Barbados)',
         'America/Belem' => 'Вақти Бразилия (Belem)',
         'America/Belize' => 'Вақти марказӣ (Belize)',
@@ -80,13 +80,14 @@ return [
         'America/Buenos_Aires' => 'Вақти Аргентина (Buenos Aires)',
         'America/Cambridge_Bay' => 'Вақти кӯҳӣ (Cambridge Bay)',
         'America/Campo_Grande' => 'Вақти Бразилия (Campo Grande)',
-        'America/Cancun' => 'Вақти шарқӣ (Cancun)',
+        'America/Cancun' => 'Вақти шарқӣ (Cancún)',
         'America/Caracas' => 'Вақти Венесуэла (Caracas)',
         'America/Catamarca' => 'Вақти Аргентина (Catamarca)',
         'America/Cayenne' => 'Вақти Гвианаи Фаронса (Cayenne)',
         'America/Cayman' => 'Вақти шарқӣ (Cayman)',
         'America/Chicago' => 'Вақти марказӣ (Chicago)',
-        'America/Chihuahua' => 'Вақти Мексика (Chihuahua)',
+        'America/Chihuahua' => 'Вақти марказӣ (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Вақти кӯҳӣ (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Вақти шарқӣ (Atikokan)',
         'America/Cordoba' => 'Вақти Аргентина (Cordoba)',
         'America/Costa_Rica' => 'Вақти марказӣ (Costa Rica)',
@@ -145,14 +146,13 @@ return [
         'America/Mazatlan' => 'Вақти Мексика (Mazatlan)',
         'America/Mendoza' => 'Вақти Аргентина (Mendoza)',
         'America/Menominee' => 'Вақти марказӣ (Menominee)',
-        'America/Merida' => 'Вақти марказӣ (Merida)',
+        'America/Merida' => 'Вақти марказӣ (Mérida)',
         'America/Metlakatla' => 'Вақти Иёлоти Муттаҳида (Metlakatla)',
         'America/Mexico_City' => 'Вақти марказӣ (Mexico City)',
         'America/Miquelon' => 'Вақти Сент-Пер ва Микелон (Miquelon)',
         'America/Moncton' => 'Вақти атлантикӣ (Moncton)',
         'America/Monterrey' => 'Вақти марказӣ (Monterrey)',
         'America/Montevideo' => 'Вақти Уругвай (Montevideo)',
-        'America/Montreal' => 'Вақти Канада (Montreal)',
         'America/Montserrat' => 'Вақти атлантикӣ (Montserrat)',
         'America/Nassau' => 'Вақти шарқӣ (Nassau)',
         'America/New_York' => 'Вақти шарқӣ (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Вақти марказӣ (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Вақти марказӣ (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Вақти марказӣ (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Вақти кӯҳӣ (Ojinaga)',
+        'America/Ojinaga' => 'Вақти марказӣ (Ojinaga)',
         'America/Panama' => 'Вақти шарқӣ (Panama)',
         'America/Pangnirtung' => 'Вақти шарқӣ (Pangnirtung)',
         'America/Paramaribo' => 'Вақти Суринам (Paramaribo)',
