@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'เวลาเฟรนช์เกียนา (กาแยน)',
         'America/Cayman' => 'เวลาทางตะวันออกในอเมริกาเหนือ (เคย์แมน)',
         'America/Chicago' => 'เวลาตอนกลางในอเมริกาเหนือ (ชิคาโก)',
-        'America/Chihuahua' => 'เวลาแปซิฟิกเม็กซิโก (ชีวาวา)',
+        'America/Chihuahua' => 'เวลาตอนกลางในอเมริกาเหนือ (ชีวาวา)',
+        'America/Ciudad_Juarez' => 'เวลาแถบภูเขาในอเมริกาเหนือ (ซิวดัดฮัวเรซ)',
         'America/Coral_Harbour' => 'เวลาทางตะวันออกในอเมริกาเหนือ (คอรัลฮาร์เบอร์)',
         'America/Cordoba' => 'เวลาอาร์เจนตินา (คอร์โดบา)',
         'America/Costa_Rica' => 'เวลาตอนกลางในอเมริกาเหนือ (คอสตาริกา)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'เวลาแอตแลนติก (มองตัน)',
         'America/Monterrey' => 'เวลาตอนกลางในอเมริกาเหนือ (มอนเตร์เรย์)',
         'America/Montevideo' => 'เวลาอุรุกวัย (มอนเตวิเดโอ)',
-        'America/Montreal' => 'เวลาแคนาดา (Montreal)',
         'America/Montserrat' => 'เวลาแอตแลนติก (มอนเซอร์รัต)',
         'America/Nassau' => 'เวลาทางตะวันออกในอเมริกาเหนือ (แนสซอ)',
         'America/New_York' => 'เวลาทางตะวันออกในอเมริกาเหนือ (นิวยอร์ก)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'เวลาตอนกลางในอเมริกาเหนือ (โบลาห์, นอร์ทดาโคตา)',
         'America/North_Dakota/Center' => 'เวลาตอนกลางในอเมริกาเหนือ (เซนเตอร์, นอร์ทดาโคตา)',
         'America/North_Dakota/New_Salem' => 'เวลาตอนกลางในอเมริกาเหนือ (นิวเซเลม, นอร์ทดาโคตา)',
-        'America/Ojinaga' => 'เวลาแถบภูเขาในอเมริกาเหนือ (โอจินากา)',
+        'America/Ojinaga' => 'เวลาตอนกลางในอเมริกาเหนือ (โอจินากา)',
         'America/Panama' => 'เวลาทางตะวันออกในอเมริกาเหนือ (ปานามา)',
         'America/Pangnirtung' => 'เวลาทางตะวันออกในอเมริกาเหนือ (พางนีทัง)',
         'America/Paramaribo' => 'เวลาซูรินาเม (ปารามาริโบ)',
@@ -298,7 +298,7 @@ return [
         'Asia/Yakutsk' => 'เวลายาคุตสค์',
         'Asia/Yekaterinburg' => 'เวลาเยคาเตรินบูร์ก (ยีคาเตอรินเบิร์ก)',
         'Asia/Yerevan' => 'เวลาอาร์เมเนีย (เยเรวาน)',
-        'Atlantic/Azores' => 'เวลาอะโซร์ส (อาซอเรส)',
+        'Atlantic/Azores' => 'เวลาอะโซร์ส',
         'Atlantic/Bermuda' => 'เวลาแอตแลนติก (เบอร์มิวดา)',
         'Atlantic/Canary' => 'เวลายุโรปตะวันตก (คะเนรี)',
         'Atlantic/Cape_Verde' => 'เวลาเคปเวิร์ด',
