@@ -87,6 +87,7 @@ return [
         'America/Cayman' => 'ግዜ ደሴታት ካይማን (ካይማን)',
         'America/Chicago' => 'ግዜ ኣመሪካ (ቺካጎ)',
         'America/Chihuahua' => 'ግዜ ሜክሲኮ (ቺዋዋ)',
+        'America/Ciudad_Juarez' => 'ግዜ ሜክሲኮ (Ciudad Juárez)',
         'America/Coral_Harbour' => 'ግዜ ካናዳ (ኣቲኮካን)',
         'America/Cordoba' => 'ግዜ ኣርጀንቲና (ኮርዶባ)',
         'America/Costa_Rica' => 'ግዜ ኮስታ ሪካ (ኮስታ ሪካ)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'ግዜ ካናዳ (ሞንክተን)',
         'America/Monterrey' => 'ግዜ ሜክሲኮ (ሞንተረይ)',
         'America/Montevideo' => 'ግዜ ኡራጓይ (ሞንተቪደዮ)',
-        'America/Montreal' => 'ግዜ ካናዳ (Montreal)',
         'America/Montserrat' => 'ግዜ ሞንትሰራት (ሞንትሰራት)',
         'America/Nassau' => 'ግዜ ባሃማስ (ናሳው)',
         'America/New_York' => 'ግዜ ኣመሪካ (ኒው ዮርክ)',
