@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Fransuz Gwianasy wagty (Kaýenna)',
         'America/Cayman' => 'Demirgazyk Amerika gündogar wagty (Kaýman adalary)',
         'America/Chicago' => 'Merkezi Amerika (Çikago)',
-        'America/Chihuahua' => 'Meksikan Ýuwaş umman wagty (Çihuahua)',
+        'America/Chihuahua' => 'Merkezi Amerika (Çihuahua)',
+        'America/Ciudad_Juarez' => 'Demirgazyk Amerika dag wagty (Sýudad-Huares)',
         'America/Coral_Harbour' => 'Demirgazyk Amerika gündogar wagty (Atikokan)',
         'America/Cordoba' => 'Argentina wagty (Kordowa)',
         'America/Costa_Rica' => 'Merkezi Amerika (Kosta-Rika)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Atlantik wagty (Monkton)',
         'America/Monterrey' => 'Merkezi Amerika (Monterreý)',
         'America/Montevideo' => 'Urugwaý wagty (Montewideo)',
-        'America/Montreal' => 'Kanada wagty (Montreal)',
         'America/Montserrat' => 'Atlantik wagty (Monserrat)',
         'America/Nassau' => 'Demirgazyk Amerika gündogar wagty (Nassau)',
         'America/New_York' => 'Demirgazyk Amerika gündogar wagty (Nýu-Ýork)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Merkezi Amerika (Boýla, Demirgazyk Dakota)',
         'America/North_Dakota/Center' => 'Merkezi Amerika (Sentr, Demirgazyk Dakota)',
         'America/North_Dakota/New_Salem' => 'Merkezi Amerika (Nýu-Salem, D.g. Dakota)',
-        'America/Ojinaga' => 'Demirgazyk Amerika dag wagty (Ohinaga)',
+        'America/Ojinaga' => 'Merkezi Amerika (Ohinaga)',
         'America/Panama' => 'Demirgazyk Amerika gündogar wagty (Panama)',
         'America/Pangnirtung' => 'Demirgazyk Amerika gündogar wagty (Pangnirtang)',
         'America/Paramaribo' => 'Surinam wagty (Paramaribo)',
@@ -218,7 +218,7 @@ return [
         'Asia/Aden' => 'Arap ýurtlary wagty (Aden)',
         'Asia/Almaty' => 'Gündogar Gazagystan wagty (Almaty)',
         'Asia/Amman' => 'Gündogar Ýewropa wagty (Amman)',
-        'Asia/Anadyr' => 'Russiýa wagty (Anadyr)',
+        'Asia/Anadyr' => 'Anadyr wagty',
         'Asia/Aqtau' => 'Günbatar Gazagystan wagty (Aktau)',
         'Asia/Aqtobe' => 'Günbatar Gazagystan wagty (Aktobe)',
         'Asia/Ashgabat' => 'Türkmenistan wagty (Aşgabat)',
@@ -250,7 +250,7 @@ return [
         'Asia/Jayapura' => 'Gündogar Indoneziýa wagty (Jaýapura)',
         'Asia/Jerusalem' => 'Ysraýyl wagty (Iýerusalim)',
         'Asia/Kabul' => 'Owganystan wagty (Kabul)',
-        'Asia/Kamchatka' => 'Russiýa wagty (Kamçatka)',
+        'Asia/Kamchatka' => 'Petropavlowsk-Kamçatskiý wagty (Kamçatka)',
         'Asia/Karachi' => 'Pakistan wagty (Karaçi)',
         'Asia/Katmandu' => 'Nepal wagty (Katmandu)',
         'Asia/Khandyga' => 'Ýakutsk wagty (Handyga)',
@@ -363,7 +363,7 @@ return [
         'Europe/Prague' => 'Merkezi Ýewropa wagty (Praga)',
         'Europe/Riga' => 'Gündogar Ýewropa wagty (Riga)',
         'Europe/Rome' => 'Merkezi Ýewropa wagty (Rim)',
-        'Europe/Samara' => 'Russiýa wagty (Samara)',
+        'Europe/Samara' => 'Samara wagty',
         'Europe/San_Marino' => 'Merkezi Ýewropa wagty (San-Marino)',
         'Europe/Sarajevo' => 'Merkezi Ýewropa wagty (Saraýewo)',
         'Europe/Saratov' => 'Moskwa wagty (Saratow)',
