@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'houa fakakuiana-fakafalanisē (Cayenne)',
         'America/Cayman' => 'houa fakaʻamelika-tokelau hahake (Cayman)',
         'America/Chicago' => 'houa fakaʻamelika-tokelau loto (Chicago)',
-        'America/Chihuahua' => 'houa fakamekisikou-pasifika (Chihuahua)',
+        'America/Chihuahua' => 'houa fakaʻamelika-tokelau loto (Chihuahua)',
+        'America/Ciudad_Juarez' => 'houa fakaʻamelika-tokelau moʻunga (Ciudad Juárez)',
         'America/Coral_Harbour' => 'houa fakaʻamelika-tokelau hahake (Atikokan)',
         'America/Cordoba' => 'houa fakaʻasenitina (Cordoba)',
         'America/Costa_Rica' => 'houa fakaʻamelika-tokelau loto (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Moncton)',
         'America/Monterrey' => 'houa fakaʻamelika-tokelau loto (Monterrey)',
         'America/Montevideo' => 'houa fakaʻulukuai (Montevideo)',
-        'America/Montreal' => 'Taimi Kānata (Montreal)',
         'America/Montserrat' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Montserrat)',
         'America/Nassau' => 'houa fakaʻamelika-tokelau hahake (Nassau)',
         'America/New_York' => 'houa fakaʻamelika-tokelau hahake (Niu ʻIoke)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'houa fakaʻamelika-tokelau loto (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'houa fakaʻamelika-tokelau loto (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'houa fakaʻamelika-tokelau loto (New Salem, North Dakota)',
-        'America/Ojinaga' => 'houa fakaʻamelika-tokelau moʻunga (Ojinaga)',
+        'America/Ojinaga' => 'houa fakaʻamelika-tokelau loto (Ojinaga)',
         'America/Panama' => 'houa fakaʻamelika-tokelau hahake (Panama)',
         'America/Pangnirtung' => 'houa fakaʻamelika-tokelau hahake (Pangnirtung)',
         'America/Paramaribo' => 'houa fakasuliname (Paramaribo)',
