@@ -68,7 +68,7 @@ return [
         'America/Aruba' => 'Төньяк Америка атлантик вакыты (Aruba)',
         'America/Asuncion' => 'Парагвай вакыты (Asuncion)',
         'America/Bahia' => 'Бразилия вакыты (Bahia)',
-        'America/Bahia_Banderas' => 'Төньяк Америка үзәк вакыты (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'Төньяк Америка үзәк вакыты (Bahía de Banderas)',
         'America/Barbados' => 'Төньяк Америка атлантик вакыты (Barbados)',
         'America/Belem' => 'Бразилия вакыты (Belem)',
         'America/Belize' => 'Төньяк Америка үзәк вакыты (Belize)',
@@ -79,13 +79,14 @@ return [
         'America/Buenos_Aires' => 'Аргентина вакыты (Buenos Aires)',
         'America/Cambridge_Bay' => 'Төньяк Америка тау вакыты (Cambridge Bay)',
         'America/Campo_Grande' => 'Бразилия вакыты (Campo Grande)',
-        'America/Cancun' => 'Төньяк Америка көнчыгыш вакыты (Cancun)',
+        'America/Cancun' => 'Төньяк Америка көнчыгыш вакыты (Cancún)',
         'America/Caracas' => 'Венесуэла вакыты (Caracas)',
         'America/Catamarca' => 'Аргентина вакыты (Catamarca)',
         'America/Cayenne' => 'Француз Гвианасы вакыты (Cayenne)',
         'America/Cayman' => 'Төньяк Америка көнчыгыш вакыты (Cayman)',
         'America/Chicago' => 'Төньяк Америка үзәк вакыты (Chicago)',
-        'America/Chihuahua' => 'Мексика вакыты (Chihuahua)',
+        'America/Chihuahua' => 'Төньяк Америка үзәк вакыты (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Төньяк Америка тау вакыты (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Төньяк Америка көнчыгыш вакыты (Atikokan)',
         'America/Cordoba' => 'Аргентина вакыты (Cordoba)',
         'America/Costa_Rica' => 'Төньяк Америка үзәк вакыты (Costa Rica)',
@@ -99,7 +100,7 @@ return [
         'America/Detroit' => 'Төньяк Америка көнчыгыш вакыты (Detroit)',
         'America/Dominica' => 'Төньяк Америка атлантик вакыты (Dominica)',
         'America/Edmonton' => 'Төньяк Америка тау вакыты (Edmonton)',
-        'America/Eirunepe' => 'Бразилия вакыты (Eirunepe)',
+        'America/Eirunepe' => 'Акр вакыты (Eirunepe)',
         'America/El_Salvador' => 'Төньяк Америка үзәк вакыты (El Salvador)',
         'America/Fort_Nelson' => 'Төньяк Америка тау вакыты (Fort Nelson)',
         'America/Fortaleza' => 'Бразилия вакыты (Fortaleza)',
@@ -144,14 +145,13 @@ return [
         'America/Mazatlan' => 'Мексика вакыты (Mazatlan)',
         'America/Mendoza' => 'Аргентина вакыты (Mendoza)',
         'America/Menominee' => 'Төньяк Америка үзәк вакыты (Menominee)',
-        'America/Merida' => 'Төньяк Америка үзәк вакыты (Merida)',
+        'America/Merida' => 'Төньяк Америка үзәк вакыты (Mérida)',
         'America/Metlakatla' => 'АКШ вакыты (Metlakatla)',
         'America/Mexico_City' => 'Төньяк Америка үзәк вакыты (Mexico City)',
         'America/Miquelon' => 'Сен-Пьер һәм Микелон вакыты (Miquelon)',
         'America/Moncton' => 'Төньяк Америка атлантик вакыты (Moncton)',
         'America/Monterrey' => 'Төньяк Америка үзәк вакыты (Monterrey)',
         'America/Montevideo' => 'Уругвай вакыты (Montevideo)',
-        'America/Montreal' => 'Канада вакыты (Montreal)',
         'America/Montserrat' => 'Төньяк Америка атлантик вакыты (Montserrat)',
         'America/Nassau' => 'Төньяк Америка көнчыгыш вакыты (Nassau)',
         'America/New_York' => 'Төньяк Америка көнчыгыш вакыты (New York)',
@@ -161,7 +161,7 @@ return [
         'America/North_Dakota/Beulah' => 'Төньяк Америка үзәк вакыты (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Төньяк Америка үзәк вакыты (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Төньяк Америка үзәк вакыты (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Төньяк Америка тау вакыты (Ojinaga)',
+        'America/Ojinaga' => 'Төньяк Америка үзәк вакыты (Ojinaga)',
         'America/Panama' => 'Төньяк Америка көнчыгыш вакыты (Panama)',
         'America/Pangnirtung' => 'Төньяк Америка көнчыгыш вакыты (Pangnirtung)',
         'America/Paramaribo' => 'Суринам вакыты (Paramaribo)',
@@ -176,7 +176,7 @@ return [
         'America/Recife' => 'Бразилия вакыты (Recife)',
         'America/Regina' => 'Төньяк Америка үзәк вакыты (Regina)',
         'America/Resolute' => 'Төньяк Америка үзәк вакыты (Resolute)',
-        'America/Rio_Branco' => 'Бразилия вакыты (Rio Branco)',
+        'America/Rio_Branco' => 'Акр вакыты (Rio Branco)',
         'America/Santa_Isabel' => 'Мексика вакыты (Santa Isabel)',
         'America/Santarem' => 'Бразилия вакыты (Santarem)',
         'America/Santiago' => 'Чили вакыты (Santiago)',
@@ -217,7 +217,7 @@ return [
         'Asia/Aden' => 'Йәмән вакыты (Aden)',
         'Asia/Almaty' => 'Казахстан вакыты (Almaty)',
         'Asia/Amman' => 'Көнчыгыш Европа вакыты (Amman)',
-        'Asia/Anadyr' => 'Россия вакыты (Anadyr)',
+        'Asia/Anadyr' => 'Анадырь вакыты (Anadyr)',
         'Asia/Aqtau' => 'Казахстан вакыты (Aqtau)',
         'Asia/Aqtobe' => 'Казахстан вакыты (Aqtobe)',
         'Asia/Ashgabat' => 'Төркмәнстан вакыты (Ashgabat)',
@@ -249,7 +249,7 @@ return [
         'Asia/Jayapura' => 'Индонезия вакыты (Jayapura)',
         'Asia/Jerusalem' => 'Израиль вакыты (Jerusalem)',
         'Asia/Kabul' => 'Әфганстан вакыты (Kabul)',
-        'Asia/Kamchatka' => 'Россия вакыты (Kamchatka)',
+        'Asia/Kamchatka' => 'Петропавловск-Камчатский вакыты (Kamchatka)',
         'Asia/Karachi' => 'Пакистан вакыты (Karachi)',
         'Asia/Katmandu' => 'Непал вакыты (Kathmandu)',
         'Asia/Khandyga' => 'Россия вакыты (Khandyga)',
@@ -360,7 +360,7 @@ return [
         'Europe/Prague' => 'Үзәк Европа вакыты (Prague)',
         'Europe/Riga' => 'Көнчыгыш Европа вакыты (Riga)',
         'Europe/Rome' => 'Үзәк Европа вакыты (Rome)',
-        'Europe/Samara' => 'Россия вакыты (Samara)',
+        'Europe/Samara' => 'Самара вакыты (Samara)',
         'Europe/San_Marino' => 'Үзәк Европа вакыты (San Marino)',
         'Europe/Sarajevo' => 'Үзәк Европа вакыты (Sarajevo)',
         'Europe/Saratov' => 'Россия вакыты (Saratov)',
