@@ -69,7 +69,7 @@ return [
         'America/Aruba' => 'ئاتلانتىك ئوكيان ۋاقتى (Aruba)',
         'America/Asuncion' => 'پاراگۋاي ۋاقتى (ئاسۇنسىيون)',
         'America/Bahia' => 'بىرازىلىيە ۋاقتى (Bahia)',
-        'America/Bahia_Banderas' => 'ئوتتۇرا قىسىم ۋاقتى (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'ئوتتۇرا قىسىم ۋاقتى (Bahía de Banderas)',
         'America/Barbados' => 'ئاتلانتىك ئوكيان ۋاقتى (Barbados)',
         'America/Belem' => 'بىرازىلىيە ۋاقتى (Belem)',
         'America/Belize' => 'ئوتتۇرا قىسىم ۋاقتى (Belize)',
@@ -80,13 +80,14 @@ return [
         'America/Buenos_Aires' => 'ئارگېنتىنا ۋاقتى (Buenos Aires)',
         'America/Cambridge_Bay' => 'تاغ ۋاقتى (Cambridge Bay)',
         'America/Campo_Grande' => 'ئامازون ۋاقتى (Campo Grande)',
-        'America/Cancun' => 'شەرقىي قىسىم ۋاقتى (Cancun)',
+        'America/Cancun' => 'شەرقىي قىسىم ۋاقتى (Cancún)',
         'America/Caracas' => 'ۋېنېزۇئېلا ۋاقتى (Caracas)',
         'America/Catamarca' => 'ئارگېنتىنا ۋاقتى (Catamarca)',
         'America/Cayenne' => 'فىرانسىيەگە قاراشلىق گىۋىيانا ۋاقتى (Cayenne)',
         'America/Cayman' => 'شەرقىي قىسىم ۋاقتى (Cayman)',
         'America/Chicago' => 'ئوتتۇرا قىسىم ۋاقتى (Chicago)',
-        'America/Chihuahua' => 'مېكسىكا تىنچ ئوكيان ۋاقتى (Chihuahua)',
+        'America/Chihuahua' => 'ئوتتۇرا قىسىم ۋاقتى (Chihuahua)',
+        'America/Ciudad_Juarez' => 'تاغ ۋاقتى (Ciudad Juárez)',
         'America/Coral_Harbour' => 'شەرقىي قىسىم ۋاقتى (Atikokan)',
         'America/Cordoba' => 'ئارگېنتىنا ۋاقتى (Cordoba)',
         'America/Costa_Rica' => 'ئوتتۇرا قىسىم ۋاقتى (Costa Rica)',
@@ -145,14 +146,13 @@ return [
         'America/Mazatlan' => 'مېكسىكا تىنچ ئوكيان ۋاقتى (Mazatlan)',
         'America/Mendoza' => 'ئارگېنتىنا ۋاقتى (Mendoza)',
         'America/Menominee' => 'ئوتتۇرا قىسىم ۋاقتى (Menominee)',
-        'America/Merida' => 'ئوتتۇرا قىسىم ۋاقتى (Merida)',
+        'America/Merida' => 'ئوتتۇرا قىسىم ۋاقتى (Mérida)',
         'America/Metlakatla' => 'ئالياسكا ۋاقتى (Metlakatla)',
         'America/Mexico_City' => 'ئوتتۇرا قىسىم ۋاقتى (Mexico City)',
         'America/Miquelon' => 'ساينىت پىئېر ۋە مىكېلون ۋاقتى (Miquelon)',
         'America/Moncton' => 'ئاتلانتىك ئوكيان ۋاقتى (Moncton)',
         'America/Monterrey' => 'ئوتتۇرا قىسىم ۋاقتى (Monterrey)',
         'America/Montevideo' => 'ئۇرۇگۋاي ۋاقتى (Montevideo)',
-        'America/Montreal' => 'كانادا ۋاقتى (Montreal)',
         'America/Montserrat' => 'ئاتلانتىك ئوكيان ۋاقتى (Montserrat)',
         'America/Nassau' => 'شەرقىي قىسىم ۋاقتى (Nassau)',
         'America/New_York' => 'شەرقىي قىسىم ۋاقتى (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'ئوتتۇرا قىسىم ۋاقتى (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'ئوتتۇرا قىسىم ۋاقتى (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'ئوتتۇرا قىسىم ۋاقتى (New Salem, North Dakota)',
-        'America/Ojinaga' => 'تاغ ۋاقتى (Ojinaga)',
+        'America/Ojinaga' => 'ئوتتۇرا قىسىم ۋاقتى (Ojinaga)',
         'America/Panama' => 'شەرقىي قىسىم ۋاقتى (Panama)',
         'America/Pangnirtung' => 'شەرقىي قىسىم ۋاقتى (Pangnirtung)',
         'America/Paramaribo' => 'سۇرىنام ۋاقتى (Paramaribo)',
@@ -344,7 +344,7 @@ return [
         'Europe/Istanbul' => 'تۈركىيە ۋاقتى (Istanbul)',
         'Europe/Jersey' => 'گىرىنۋىچ ۋاقتى (Jersey)',
         'Europe/Kaliningrad' => 'شەرقىي ياۋروپا ۋاقتى (Kaliningrad)',
-        'Europe/Kiev' => 'شەرقىي ياۋروپا ۋاقتى (Kiev)',
+        'Europe/Kiev' => 'شەرقىي ياۋروپا ۋاقتى (Kyiv)',
         'Europe/Kirov' => 'رۇسىيە ۋاقتى (Kirov)',
         'Europe/Lisbon' => 'غەربىي ياۋروپا ۋاقتى (Lisbon)',
         'Europe/Ljubljana' => 'ئوتتۇرا ياۋروپا ۋاقتى (Ljubljana)',
