@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'فرینچ گیانا کا وقت (کائین)',
         'America/Cayman' => 'ایسٹرن ٹائم (کیمین)',
         'America/Chicago' => 'سنٹرل ٹائم (شکاگو)',
-        'America/Chihuahua' => 'میکسیکن پیسفک ٹائم (چیہوآہوآ)',
+        'America/Chihuahua' => 'سنٹرل ٹائم (چیہوآہوآ)',
+        'America/Ciudad_Juarez' => 'ماؤنٹین ٹائم (سیوداد جیوریز)',
         'America/Coral_Harbour' => 'ایسٹرن ٹائم (اٹیکوکن)',
         'America/Cordoba' => 'ارجنٹینا کا وقت (کورڈوبا)',
         'America/Costa_Rica' => 'سنٹرل ٹائم (کوسٹا ریکا)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'اٹلانٹک ٹائم (مونکٹن)',
         'America/Monterrey' => 'سنٹرل ٹائم (مونٹیری)',
         'America/Montevideo' => 'یوروگوئے کا وقت (مونٹی ویڈیو)',
-        'America/Montreal' => 'کینیڈا وقت (Montreal)',
         'America/Montserrat' => 'اٹلانٹک ٹائم (مونٹسیراٹ)',
         'America/Nassau' => 'ایسٹرن ٹائم (نساؤ)',
         'America/New_York' => 'ایسٹرن ٹائم (نیو یارک)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'سنٹرل ٹائم (بیولاہ، شمالی ڈکوٹا)',
         'America/North_Dakota/Center' => 'سنٹرل ٹائم (وسط، شمالی ڈکوٹا)',
         'America/North_Dakota/New_Salem' => 'سنٹرل ٹائم (نیو سلیم، شمالی ڈکوٹا)',
-        'America/Ojinaga' => 'ماؤنٹین ٹائم (اوجیناگا)',
+        'America/Ojinaga' => 'سنٹرل ٹائم (اوجیناگا)',
         'America/Panama' => 'ایسٹرن ٹائم (پنامہ)',
         'America/Pangnirtung' => 'ایسٹرن ٹائم (پینگنِرٹنگ)',
         'America/Paramaribo' => 'سورینام کا وقت (پراماریبو)',
@@ -308,7 +308,7 @@ return [
         'Atlantic/South_Georgia' => 'جنوبی جارجیا ٹائم',
         'Atlantic/St_Helena' => 'گرین وچ کا اصل وقت (سینٹ ہیلینا)',
         'Atlantic/Stanley' => 'فاک لینڈ آئلینڈز کا وقت (اسٹینلے)',
-        'Australia/Adelaide' => 'سنٹرل آسٹریلیا ٹائم (اڈیلائڈ)',
+        'Australia/Adelaide' => 'سنٹرل آسٹریلیا ٹائم (ایڈیلیڈ)',
         'Australia/Brisbane' => 'ایسٹرن آسٹریلیا ٹائم (برسبین)',
         'Australia/Broken_Hill' => 'سنٹرل آسٹریلیا ٹائم (بروکن ہِل)',
         'Australia/Currie' => 'ایسٹرن آسٹریلیا ٹائم (کیوری)',
@@ -342,7 +342,7 @@ return [
         'Europe/Guernsey' => 'گرین وچ کا اصل وقت (گرنزی)',
         'Europe/Helsinki' => 'مشرقی یورپ کا وقت (ہیلسنکی)',
         'Europe/Isle_of_Man' => 'گرین وچ کا اصل وقت (آئل آف مین)',
-        'Europe/Istanbul' => 'ترکی وقت (استنبول)',
+        'Europe/Istanbul' => 'ترکیہ وقت (استنبول)',
         'Europe/Jersey' => 'گرین وچ کا اصل وقت (جرسی)',
         'Europe/Kaliningrad' => 'مشرقی یورپ کا وقت (کالينينغراد)',
         'Europe/Kiev' => 'مشرقی یورپ کا وقت (کیو)',
