@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Fransuz Gvianasi vaqti (Kayenna)',
         'America/Cayman' => 'Sharqiy Amerika vaqti (Kayman orollari)',
         'America/Chicago' => 'Markaziy Amerika vaqti (Chikago)',
-        'America/Chihuahua' => 'Meksika Tinch okeani vaqti (Chihuahua)',
+        'America/Chihuahua' => 'Markaziy Amerika vaqti (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Tog‘ vaqti (AQSH) (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Sharqiy Amerika vaqti (Koral-Xarbor)',
         'America/Cordoba' => 'Argentina vaqti (Kordoba)',
         'America/Costa_Rica' => 'Markaziy Amerika vaqti (Kosta-Rika)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Atlantika vaqti (Monkton)',
         'America/Monterrey' => 'Markaziy Amerika vaqti (Monterrey)',
         'America/Montevideo' => 'Urugvay vaqti (Montevideo)',
-        'America/Montreal' => 'Kanada (Montreal)',
         'America/Montserrat' => 'Atlantika vaqti (Montserrat)',
         'America/Nassau' => 'Sharqiy Amerika vaqti (Nassau)',
         'America/New_York' => 'Sharqiy Amerika vaqti (Nyu-York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Markaziy Amerika vaqti (Boyla, Shimoliy Dakota)',
         'America/North_Dakota/Center' => 'Markaziy Amerika vaqti (Markaz, Shimoliy Dakota)',
         'America/North_Dakota/New_Salem' => 'Markaziy Amerika vaqti (Nyu-Salem, Shimoliy Dakota)',
-        'America/Ojinaga' => 'Tog‘ vaqti (AQSH) (Oxinaga)',
+        'America/Ojinaga' => 'Markaziy Amerika vaqti (Oxinaga)',
         'America/Panama' => 'Sharqiy Amerika vaqti (Panama)',
         'America/Pangnirtung' => 'Sharqiy Amerika vaqti (Pangnirtang)',
         'America/Paramaribo' => 'Surinam vaqti (Paramaribo)',
