@@ -86,6 +86,8 @@ return [
         'America/Cayenne' => 'Француз Гвианаси вақти (Kayenna)',
         'America/Cayman' => 'Шимолий Америка шарқий вақти (Kayman orollari)',
         'America/Chicago' => 'Шимолий Америка (Chikago)',
+        'America/Chihuahua' => 'Шимолий Америка (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Шимолий Америка тоғ вақти (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Шимолий Америка шарқий вақти (Atikokan)',
         'America/Cordoba' => 'Аргентина вақти (Kordoba)',
         'America/Costa_Rica' => 'Шимолий Америка (Kosta-Rika)',
@@ -148,7 +150,6 @@ return [
         'America/Moncton' => 'Атлантика вақти (Monkton)',
         'America/Monterrey' => 'Шимолий Америка (Monterrey)',
         'America/Montevideo' => 'Уругвай вақти (Montevideo)',
-        'America/Montreal' => 'Канада вақти (Montreal)',
         'America/Montserrat' => 'Атлантика вақти (Montserrat)',
         'America/Nassau' => 'Шимолий Америка шарқий вақти (Nassau)',
         'America/New_York' => 'Шимолий Америка шарқий вақти (Nyu-York)',
@@ -158,7 +159,7 @@ return [
         'America/North_Dakota/Beulah' => 'Шимолий Америка (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Шимолий Америка (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Шимолий Америка (New Salem, North Dakota)',
-        'America/Ojinaga' => 'Шимолий Америка тоғ вақти (Oxinaga)',
+        'America/Ojinaga' => 'Шимолий Америка (Oxinaga)',
         'America/Panama' => 'Шимолий Америка шарқий вақти (Panama)',
         'America/Pangnirtung' => 'Шимолий Америка шарқий вақти (Pangnirtang)',
         'America/Paramaribo' => 'Суринам вақти (Paramaribo)',
