@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Giờ Guiana thuộc Pháp (Cayenne)',
         'America/Cayman' => 'Giờ miền Đông (Cayman)',
         'America/Chicago' => 'Giờ miền Trung (Chicago)',
-        'America/Chihuahua' => 'Giờ Thái Bình Dương Mexico (Chihuahua)',
+        'America/Chihuahua' => 'Giờ miền Trung (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Giờ miền núi (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Giờ miền Đông (Atikokan)',
         'America/Cordoba' => 'Giờ Argentina (Cordoba)',
         'America/Costa_Rica' => 'Giờ miền Trung (Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Giờ Đại Tây Dương (Moncton)',
         'America/Monterrey' => 'Giờ miền Trung (Monterrey)',
         'America/Montevideo' => 'Giờ Uruguay (Montevideo)',
-        'America/Montreal' => 'Giờ Canada (Montreal)',
         'America/Montserrat' => 'Giờ Đại Tây Dương (Montserrat)',
         'America/Nassau' => 'Giờ miền Đông (Nassau)',
         'America/New_York' => 'Giờ miền Đông (New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Giờ miền Trung (Beulah, Bắc Dakota)',
         'America/North_Dakota/Center' => 'Giờ miền Trung (Center, Bắc Dakota)',
         'America/North_Dakota/New_Salem' => 'Giờ miền Trung (New Salem, Bắc Dakota)',
-        'America/Ojinaga' => 'Giờ miền núi (Ojinaga)',
+        'America/Ojinaga' => 'Giờ miền Trung (Ojinaga)',
         'America/Panama' => 'Giờ miền Đông (Panama)',
         'America/Pangnirtung' => 'Giờ miền Đông (Pangnirtung)',
         'America/Paramaribo' => 'Giờ Suriname (Paramaribo)',
