@@ -12,6 +12,7 @@ return [
         'Africa/Banjul' => 'GMT (waxtu Greenwich) (Banjul)',
         'Africa/Bissau' => 'GMT (waxtu Greenwich) (Bissau)',
         'Africa/Blantyre' => 'Malawi (Blantyre)',
+        'Africa/Brazzaville' => 'Réewum Kongo (Brazzaville)',
         'Africa/Bujumbura' => 'Burundi (Bujumbura)',
         'Africa/Cairo' => 'EET (waxtu ëroop u penku) (Cairo)',
         'Africa/Casablanca' => 'WET (waxtu ëroop u sowwu-jant (Casablanca)',
@@ -30,10 +31,12 @@ return [
         'Africa/Kampala' => 'Ugànda (Kampala)',
         'Africa/Khartoum' => 'Sudaŋ (Khartoum)',
         'Africa/Kigali' => 'Ruwànda (Kigali)',
+        'Africa/Kinshasa' => 'Kongo (R K D) (Kinshasa)',
         'Africa/Lagos' => 'Niseriya (Lagos)',
         'Africa/Libreville' => 'Gaboŋ (Libreville)',
         'Africa/Lome' => 'GMT (waxtu Greenwich) (Lome)',
         'Africa/Luanda' => 'Àngolaa (Luanda)',
+        'Africa/Lubumbashi' => 'Kongo (R K D) (Lubumbashi)',
         'Africa/Lusaka' => 'Sàmbi (Lusaka)',
         'Africa/Malabo' => 'Gine Ekuwatoriyal (Malabo)',
         'Africa/Maputo' => 'Mosàmbig (Maputo)',
@@ -66,7 +69,7 @@ return [
         'America/Aruba' => 'AT (waxtu atlàntik) (Aruba)',
         'America/Asuncion' => 'Paraguwe (Asuncion)',
         'America/Bahia' => 'Beresil (Bahia)',
-        'America/Bahia_Banderas' => 'CT (waxtu sàntaral) (Bahia Banderas)',
+        'America/Bahia_Banderas' => 'CT (waxtu sàntaral) (Bahía de Banderas)',
         'America/Barbados' => 'AT (waxtu atlàntik) (Barbados)',
         'America/Belem' => 'Beresil (Belem)',
         'America/Belize' => 'CT (waxtu sàntaral) (Belize)',
@@ -77,13 +80,14 @@ return [
         'America/Buenos_Aires' => 'Arsàntin (Buenos Aires)',
         'America/Cambridge_Bay' => 'MT (waxtu tundu) (Cambridge Bay)',
         'America/Campo_Grande' => 'Beresil (Campo Grande)',
-        'America/Cancun' => 'ET waxtu penku (Cancun)',
+        'America/Cancun' => 'ET waxtu penku (Cancún)',
         'America/Caracas' => 'Wenesiyela (Caracas)',
         'America/Catamarca' => 'Arsàntin (Catamarca)',
         'America/Cayenne' => 'Guyaan Farañse (Cayenne)',
         'America/Cayman' => 'ET waxtu penku (Cayman)',
         'America/Chicago' => 'CT (waxtu sàntaral) (Chicago)',
-        'America/Chihuahua' => 'Meksiko (Chihuahua)',
+        'America/Chihuahua' => 'CT (waxtu sàntaral) (Chihuahua)',
+        'America/Ciudad_Juarez' => 'MT (waxtu tundu) (Ciudad Juárez)',
         'America/Coral_Harbour' => 'ET waxtu penku (Atikokan)',
         'America/Cordoba' => 'Arsàntin (Cordoba)',
         'America/Costa_Rica' => 'CT (waxtu sàntaral) (Costa Rica)',
@@ -142,14 +146,13 @@ return [
         'America/Mazatlan' => 'Meksiko (Mazatlan)',
         'America/Mendoza' => 'Arsàntin (Mendoza)',
         'America/Menominee' => 'CT (waxtu sàntaral) (Menominee)',
-        'America/Merida' => 'CT (waxtu sàntaral) (Merida)',
+        'America/Merida' => 'CT (waxtu sàntaral) (Mérida)',
         'America/Metlakatla' => 'Etaa Sini (Metlakatla)',
         'America/Mexico_City' => 'CT (waxtu sàntaral) (Mexico City)',
         'America/Miquelon' => 'Saŋ Peer ak Mikeloŋ (Miquelon)',
         'America/Moncton' => 'AT (waxtu atlàntik) (Moncton)',
         'America/Monterrey' => 'CT (waxtu sàntaral) (Monterrey)',
         'America/Montevideo' => 'Uruge (Montevideo)',
-        'America/Montreal' => 'Kanadaa (Montreal)',
         'America/Montserrat' => 'AT (waxtu atlàntik) (Montserrat)',
         'America/Nassau' => 'ET waxtu penku (Nassau)',
         'America/New_York' => 'ET waxtu penku (New York)',
@@ -159,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'CT (waxtu sàntaral) (Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'CT (waxtu sàntaral) (Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'CT (waxtu sàntaral) (New Salem, North Dakota)',
-        'America/Ojinaga' => 'MT (waxtu tundu) (Ojinaga)',
+        'America/Ojinaga' => 'CT (waxtu sàntaral) (Ojinaga)',
         'America/Panama' => 'ET waxtu penku (Panama)',
         'America/Pangnirtung' => 'ET waxtu penku (Pangnirtung)',
         'America/Paramaribo' => 'Sirinam (Paramaribo)',
@@ -240,6 +243,7 @@ return [
         'Asia/Famagusta' => 'EET (waxtu ëroop u penku) (Famagusta)',
         'Asia/Gaza' => 'EET (waxtu ëroop u penku) (Gaza)',
         'Asia/Hebron' => 'EET (waxtu ëroop u penku) (Hebron)',
+        'Asia/Hong_Kong' => 'Ooŋ Koŋ (Hong Kong)',
         'Asia/Hovd' => 'Mongoli (Hovd)',
         'Asia/Irkutsk' => 'Risi (Irkutsk)',
         'Asia/Jakarta' => 'Indonesi (Jakarta)',
@@ -254,6 +258,7 @@ return [
         'Asia/Kuala_Lumpur' => 'Malesi (Kuala Lumpur)',
         'Asia/Kuching' => 'Malesi (Kuching)',
         'Asia/Kuwait' => 'Kowet (Kuwait)',
+        'Asia/Macau' => 'Makaawo (Macao)',
         'Asia/Magadan' => 'Risi (Magadan)',
         'Asia/Makassar' => 'Indonesi (Makassar)',
         'Asia/Manila' => 'Filipin (Manila)',
@@ -339,7 +344,7 @@ return [
         'Europe/Istanbul' => 'Tirki (Istanbul)',
         'Europe/Jersey' => 'GMT (waxtu Greenwich) (Jersey)',
         'Europe/Kaliningrad' => 'EET (waxtu ëroop u penku) (Kaliningrad)',
-        'Europe/Kiev' => 'EET (waxtu ëroop u penku) (Kiev)',
+        'Europe/Kiev' => 'EET (waxtu ëroop u penku) (Kyiv)',
         'Europe/Kirov' => 'Risi (Kirov)',
         'Europe/Lisbon' => 'WET (waxtu ëroop u sowwu-jant (Lisbon)',
         'Europe/Ljubljana' => 'CTE (waxtu ëroop sàntaraal) (Ljubljana)',
