@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Àkókò Gúyánà Fáránsè (Cayenne)',
         'America/Cayman' => 'Àkókò ìhà ìlà oòrùn (ilú Kayman)',
         'America/Chicago' => 'àkókò àárín gbùngbùn (ìlú Chicago)',
-        'America/Chihuahua' => 'Àkókò Pásífíìkì Mẹ́ṣíkò (ìlú Ṣihuahua)',
+        'America/Chihuahua' => 'àkókò àárín gbùngbùn (ìlú Ṣihuahua)',
+        'America/Ciudad_Juarez' => 'Àkókò òkè (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Àkókò ìhà ìlà oòrùn (ìlú àtikọkàn)',
         'America/Cordoba' => 'Aago Ajẹntìnà (Cordoba)',
         'America/Costa_Rica' => 'àkókò àárín gbùngbùn (ìlú Kosta Ríkà)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Àkókò Àtìláńtíìkì (ìlú Montoni)',
         'America/Monterrey' => 'àkókò àárín gbùngbùn (ìlú Monteri)',
         'America/Montevideo' => 'Aago Uruguay (Montevideo)',
-        'America/Montreal' => 'Ìgbà Kánádà (Montreal)',
         'America/Montserrat' => 'Àkókò Àtìláńtíìkì (ìlú Monseratì)',
         'America/Nassau' => 'Àkókò ìhà ìlà oòrùn (ìlú Nasaò)',
         'America/New_York' => 'Àkókò ìhà ìlà oòrùn (ìlú New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'àkókò àárín gbùngbùn (ìlú Beulà ní North Dakota)',
         'America/North_Dakota/Center' => 'àkókò àárín gbùngbùn (ìlú Senta North Dakota)',
         'America/North_Dakota/New_Salem' => 'àkókò àárín gbùngbùn (ìlú New Salem ni North Dakota)',
-        'America/Ojinaga' => 'Àkókò òkè (ìlú Ojinaga)',
+        'America/Ojinaga' => 'àkókò àárín gbùngbùn (ìlú Ojinaga)',
         'America/Panama' => 'Àkókò ìhà ìlà oòrùn (ìlú Panama)',
         'America/Pangnirtung' => 'Àkókò ìhà ìlà oòrùn (ìlú Panituni)',
         'America/Paramaribo' => 'Àkókò Súrínámù (Paramaribo)',
@@ -238,7 +238,7 @@ return [
         'Asia/Damascus' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Damascus)',
         'Asia/Dhaka' => 'Bangladesh Time (Dhaka)',
         'Asia/Dili' => 'Àkókò Ìlà oorùn Timor (Dili)',
-        'Asia/Dubai' => 'Ìgbà Ẹmirate ti Awọn Arabu (Dubai)',
+        'Asia/Dubai' => 'Gulf Standard Time (Dubai)',
         'Asia/Dushanbe' => 'Tajikistan Time (Dushanbe)',
         'Asia/Famagusta' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Famagusta)',
         'Asia/Gaza' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Gaza)',
@@ -262,7 +262,7 @@ return [
         'Asia/Magadan' => 'Magadan Time',
         'Asia/Makassar' => 'Àkókò Ààrin Gbùngbùn Indonesia (Makassar)',
         'Asia/Manila' => 'Philippine Time (Manila)',
-        'Asia/Muscat' => 'Ìgbà Ọọma (Muscat)',
+        'Asia/Muscat' => 'Gulf Standard Time (Muscat)',
         'Asia/Nicosia' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Nicosia)',
         'Asia/Novokuznetsk' => 'Krasnoyarsk Time (Novokuznetsk)',
         'Asia/Novosibirsk' => 'Novosibirsk Time',
