@@ -32,7 +32,7 @@ return [
         'America/Buenos_Aires' => 'Aago Ajɛntìnà (Buenos Aires)',
         'America/Campo_Grande' => 'Àkókò Amásɔ́nì (Campo Grande)',
         'America/Catamarca' => 'Aago Ajɛntìnà (Catamarca)',
-        'America/Chihuahua' => 'Àkókò Pásífíìkì Mɛ́shíkò (ìlú Shihuahua)',
+        'America/Chihuahua' => 'àkókò àárín gbùngbùn (ìlú Shihuahua)',
         'America/Coral_Harbour' => 'Àkókò ìhà ìlà oòrùn (ìlú àtikɔkàn)',
         'America/Cordoba' => 'Aago Ajɛntìnà (Cordoba)',
         'America/Creston' => 'Àkókò òkè (ìlú Kírɛstɔ́ɔ̀nù)',
@@ -63,11 +63,9 @@ return [
         'Antarctica/Palmer' => 'Àkókò Shílè (Palmer)',
         'Asia/Anadyr' => 'Ìgbà Rɔshia (Anadyr)',
         'Asia/Barnaul' => 'Ìgbà Rɔshia (Barnaul)',
-        'Asia/Dubai' => 'Ìgbà Ɛmirate ti Awɔn Arabu (Dubai)',
         'Asia/Jakarta' => 'Àkókò Ìwɔ̀ oorùn Indonesia (Jakarta)',
         'Asia/Kamchatka' => 'Ìgbà Rɔshia (Kamchatka)',
         'Asia/Macau' => 'Àkókò Sháínà (Macao)',
-        'Asia/Muscat' => 'Ìgbà Ɔɔma (Muscat)',
         'Asia/Pontianak' => 'Àkókò Ìwɔ̀ oorùn Indonesia (Pontianak)',
         'Asia/Shanghai' => 'Àkókò Sháínà (Shanghai)',
         'Asia/Tomsk' => 'Ìgbà Rɔshia (Tomsk)',
