@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => '法属圭亚那标准时间（卡宴）',
         'America/Cayman' => '北美东部时间（开曼）',
         'America/Chicago' => '北美中部时间（芝加哥）',
-        'America/Chihuahua' => '墨西哥太平洋时间（奇瓦瓦）',
+        'America/Chihuahua' => '北美中部时间（奇瓦瓦）',
+        'America/Ciudad_Juarez' => '北美山区时间（华雷斯城）',
         'America/Coral_Harbour' => '北美东部时间（阿蒂科肯）',
         'America/Cordoba' => '阿根廷时间（科尔多瓦）',
         'America/Costa_Rica' => '北美中部时间（哥斯达黎加）',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => '大西洋时间（蒙克顿）',
         'America/Monterrey' => '北美中部时间（蒙特雷）',
         'America/Montevideo' => '乌拉圭时间（蒙得维的亚）',
-        'America/Montreal' => '加拿大时间（Montreal）',
         'America/Montserrat' => '大西洋时间（蒙特塞拉特）',
         'America/Nassau' => '北美东部时间（拿骚）',
         'America/New_York' => '北美东部时间（纽约）',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => '北美中部时间（北达科他州比尤拉）',
         'America/North_Dakota/Center' => '北美中部时间（北达科他州申特）',
         'America/North_Dakota/New_Salem' => '北美中部时间（北达科他州新塞勒姆）',
-        'America/Ojinaga' => '北美山区时间（奥希纳加）',
+        'America/Ojinaga' => '北美中部时间（奥希纳加）',
         'America/Panama' => '北美东部时间（巴拿马）',
         'America/Pangnirtung' => '北美东部时间（旁涅唐）',
         'America/Paramaribo' => '苏里南时间（帕拉马里博）',
@@ -205,11 +205,11 @@ return [
         'America/Yellowknife' => '北美山区时间（耶洛奈夫）',
         'Antarctica/Casey' => '凯西时间（卡塞）',
         'Antarctica/Davis' => '戴维斯时间',
-        'Antarctica/DumontDUrville' => '迪蒙迪尔维尔时间',
+        'Antarctica/DumontDUrville' => '迪蒙·迪维尔时间',
         'Antarctica/Macquarie' => '澳大利亚东部时间（麦格理）',
         'Antarctica/Mawson' => '莫森时间',
         'Antarctica/McMurdo' => '新西兰时间（麦克默多）',
-        'Antarctica/Palmer' => '智利时间（帕默尔）',
+        'Antarctica/Palmer' => '智利时间（帕尔默）',
         'Antarctica/Rothera' => '罗瑟拉时间',
         'Antarctica/Syowa' => '昭和时间',
         'Antarctica/Troll' => '格林尼治标准时间（特罗尔）',
