@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => '法屬圭亞那時間（開雲）',
         'America/Cayman' => '東部時間（開曼群島）',
         'America/Chicago' => '中部時間（芝加哥）',
-        'America/Chihuahua' => '墨西哥太平洋時間（奇華華）',
+        'America/Chihuahua' => '中部時間（奇華華）',
+        'America/Ciudad_Juarez' => '山區時間（華雷斯）',
         'America/Coral_Harbour' => '東部時間（阿蒂科肯）',
         'America/Cordoba' => '阿根廷時間（哥多華）',
         'America/Costa_Rica' => '中部時間（哥斯大黎加）',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => '大西洋時間（蒙克頓）',
         'America/Monterrey' => '中部時間（蒙特瑞）',
         'America/Montevideo' => '烏拉圭時間（蒙特維多）',
-        'America/Montreal' => '加拿大時間（Montreal）',
         'America/Montserrat' => '大西洋時間（蒙哲臘）',
         'America/Nassau' => '東部時間（拿索）',
         'America/New_York' => '東部時間（紐約）',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => '中部時間（北達科他州布由拉）',
         'America/North_Dakota/Center' => '中部時間（北達科他州中心）',
         'America/North_Dakota/New_Salem' => '中部時間（北達科他州紐沙倫）',
-        'America/Ojinaga' => '山區時間（奧希納加）',
+        'America/Ojinaga' => '中部時間（奧希納加）',
         'America/Panama' => '東部時間（巴拿馬）',
         'America/Pangnirtung' => '東部時間（潘尼爾東）',
         'America/Paramaribo' => '蘇利南時間（巴拉馬利波）',
