@@ -86,7 +86,8 @@ return [
         'America/Cayenne' => 'Isikhathi sase-French Guiana (i-Cayenne)',
         'America/Cayman' => 'Isikhathi sase-North American East (i-Cayman)',
         'America/Chicago' => 'Isikhathi sase-North American Central (i-Chicago)',
-        'America/Chihuahua' => 'Isikhathi sase-Mexican Pacific (i-Chihuahua)',
+        'America/Chihuahua' => 'Isikhathi sase-North American Central (i-Chihuahua)',
+        'America/Ciudad_Juarez' => 'Isikhathi sase-North American Mountain (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Isikhathi sase-North American East (i-Atikokan)',
         'America/Cordoba' => 'Isikhathi sase-Argentina (i-Cordoba)',
         'America/Costa_Rica' => 'Isikhathi sase-North American Central (i-Costa Rica)',
@@ -152,7 +153,6 @@ return [
         'America/Moncton' => 'Isikhathi sase-Atlantic (i-Moncton)',
         'America/Monterrey' => 'Isikhathi sase-North American Central (i-Monterrey)',
         'America/Montevideo' => 'Isikhathi sase-Uruguay (i-Montevideo)',
-        'America/Montreal' => 'Isikhathi sase-i-Canada (Montreal)',
         'America/Montserrat' => 'Isikhathi sase-Atlantic (i-Montserrat)',
         'America/Nassau' => 'Isikhathi sase-North American East (i-Nassau)',
         'America/New_York' => 'Isikhathi sase-North American East (i-New York)',
@@ -162,7 +162,7 @@ return [
         'America/North_Dakota/Beulah' => 'Isikhathi sase-North American Central (i-Beulah, North Dakota)',
         'America/North_Dakota/Center' => 'Isikhathi sase-North American Central (i-Center, North Dakota)',
         'America/North_Dakota/New_Salem' => 'Isikhathi sase-North American Central (i-New Salem, North Dakota)',
-        'America/Ojinaga' => 'Isikhathi sase-North American Mountain (i-Ojinaga)',
+        'America/Ojinaga' => 'Isikhathi sase-North American Central (i-Ojinaga)',
         'America/Panama' => 'Isikhathi sase-North American East (i-Panama)',
         'America/Pangnirtung' => 'Isikhathi sase-North American East (i-Pangnirtung)',
         'America/Paramaribo' => 'Isikhathi sase-Suriname (i-Paramaribo)',
