@@ -11,18 +11,18 @@
 
 namespace Symfony\Component\Intl\Tests\Globals\Verification;
 
-use Symfony\Component\Intl\Tests\Globals\AbstractIntlGlobalsTest;
+use Symfony\Component\Intl\Tests\Globals\AbstractIntlGlobalsTestCase;
 use Symfony\Component\Intl\Util\IntlTestHelper;
 
 /**
- * Verifies that {@link AbstractIntlGlobalsTest} matches the behavior of the
+ * Verifies that {@link AbstractIntlGlobalsTestCase} matches the behavior of the
  * intl functions with a specific version of ICU.
  *
  * @author Bernhard Schussek <bschussek@gmail.com>
  *
  * @group legacy
  */
-class IntlGlobalsTest extends AbstractIntlGlobalsTest
+class IntlGlobalsTest extends AbstractIntlGlobalsTestCase
 {
     protected function setUp(): void
     {
