@@ -11,14 +11,14 @@
 
 namespace Symfony\Component\Intl\Tests\NumberFormatter\Verification;
 
-use Symfony\Component\Intl\Tests\NumberFormatter\AbstractNumberFormatterTest;
+use Symfony\Component\Intl\Tests\NumberFormatter\AbstractNumberFormatterTestCase;
 use Symfony\Component\Intl\Util\IntlTestHelper;
 
 /**
  * Note that there are some values written like -2147483647 - 1. This is the lower 32bit int max and is a known
  * behavior of PHP.
  */
-class NumberFormatterTest extends AbstractNumberFormatterTest
+class NumberFormatterTest extends AbstractNumberFormatterTestCase
 {
     protected function setUp(): void
     {
@@ -39,7 +39,7 @@ class NumberFormatterTest extends AbstractNumberFormatterTest
         parent::testGetTextAttribute();
     }
 
-    protected function getNumberFormatter(?string $locale = 'en', string $style = null, string $pattern = null): \NumberFormatter
+    protected static function getNumberFormatter(?string $locale = 'en', string $style = null, string $pattern = null): \NumberFormatter
     {
         return new \NumberFormatter($locale, $style, $pattern);
     }
