@@ -98,6 +98,7 @@ class ScriptsTest extends ResourceBundleTestCase
         'Jurc',
         'Kali',
         'Kana',
+        'Kawi',
         'Khar',
         'Khmr',
         'Khoj',
@@ -137,6 +138,7 @@ class ScriptsTest extends ResourceBundleTestCase
         'Mtei',
         'Mult',
         'Mymr',
+        'Nagm',
         'Nand',
         'Narb',
         'Nbat',
