@@ -108,6 +108,7 @@ class TimezonesTest extends ResourceBundleTestCase
         'America/Cayman',
         'America/Chicago',
         'America/Chihuahua',
+        'America/Ciudad_Juarez',
         'America/Coral_Harbour',
         'America/Cordoba',
         'America/Costa_Rica',
@@ -173,7 +174,6 @@ class TimezonesTest extends ResourceBundleTestCase
         'America/Moncton',
         'America/Monterrey',
         'America/Montevideo',
-        'America/Montreal',
         'America/Montserrat',
         'America/Nassau',
         'America/New_York',
