@@ -137,7 +137,7 @@ class Connection extends AbstractConnection
             }
 
             if (!isset($parent['network_timeout'])) {
-                $options->setDefault('network_timeout', ini_get('default_socket_timeout'));
+                $options->setDefault('network_timeout', \ini_get('default_socket_timeout'));
             }
 
             $options->setDefaults([
@@ -159,7 +159,11 @@ class Connection extends AbstractConnection
             }
         }
 
-        $this->connection = ldap_connect($this->config['connection_string']);
+        if (false === $connection = ldap_connect($this->config['connection_string'])) {
+            throw new LdapException('Invalid connection string: '.$this->config['connection_string']);
+        } else {
+            $this->connection = $connection;
+        }
 
         foreach ($this->config['options'] as $name => $value) {
             if (!\in_array(ConnectionOptions::getOption($name), self::PRECONNECT_OPTIONS, true)) {
@@ -167,10 +171,6 @@ class Connection extends AbstractConnection
             }
         }
 
-        if (false === $this->connection) {
-            throw new LdapException('Could not connect to Ldap server: '.ldap_error($this->connection));
-        }
-
         if ('tls' === $this->config['encryption'] && false === @ldap_start_tls($this->connection)) {
             throw new LdapException('Could not initiate TLS connection: '.ldap_error($this->connection));
         }
