@@ -99,22 +99,27 @@ class DoctrineDbalStoreTest extends AbstractStoreTestCase
     public function testCreatesTableInTransaction(string $platform)
     {
         $conn = $this->createMock(Connection::class);
+
+        $series = [
+            [$this->stringContains('INSERT INTO'), $this->createMock(TableNotFoundException::class)],
+            [$this->matches('create sql stmt'), 1],
+            [$this->stringContains('INSERT INTO'), 1],
+        ];
+
         $conn->expects($this->atLeast(3))
             ->method('executeStatement')
-            ->withConsecutive(
-                [$this->stringContains('INSERT INTO')],
-                [$this->matches('create sql stmt')],
-                [$this->stringContains('INSERT INTO')]
-            )
-            ->will(
-                $this->onConsecutiveCalls(
-                    $this->throwException(
-                        $this->createMock(TableNotFoundException::class)
-                    ),
-                    1,
-                    1
-                )
-            );
+            ->willReturnCallback(function ($sql) use (&$series) {
+                if ([$constraint, $return] = array_shift($series)) {
+                    $constraint->evaluate($sql);
+                }
+
+                if ($return instanceof \Exception) {
+                    throw $return;
+                }
+
+                return $return ?? 1;
+            })
+        ;
 
         $conn->method('isTransactionActive')
             ->willReturn(true);
@@ -145,21 +150,26 @@ class DoctrineDbalStoreTest extends AbstractStoreTestCase
     public function testTableCreationInTransactionNotSupported()
     {
         $conn = $this->createMock(Connection::class);
+
+        $series = [
+            [$this->stringContains('INSERT INTO'), $this->createMock(TableNotFoundException::class)],
+            [$this->stringContains('INSERT INTO'), 1],
+        ];
+
         $conn->expects($this->atLeast(2))
             ->method('executeStatement')
-            ->withConsecutive(
-                [$this->stringContains('INSERT INTO')],
-                [$this->stringContains('INSERT INTO')]
-            )
-            ->will(
-                $this->onConsecutiveCalls(
-                    $this->throwException(
-                        $this->createMock(TableNotFoundException::class)
-                    ),
-                    1,
-                    1
-                )
-            );
+            ->willReturnCallback(function ($sql) use (&$series) {
+                if ([$constraint, $return] = array_shift($series)) {
+                    $constraint->evaluate($sql);
+                }
+
+                if ($return instanceof \Exception) {
+                    throw $return;
+                }
+
+                return $return ?? 1;
+            })
+        ;
 
         $conn->method('isTransactionActive')
             ->willReturn(true);
@@ -181,22 +191,27 @@ class DoctrineDbalStoreTest extends AbstractStoreTestCase
     public function testCreatesTableOutsideTransaction()
     {
         $conn = $this->createMock(Connection::class);
+
+        $series = [
+            [$this->stringContains('INSERT INTO'), $this->createMock(TableNotFoundException::class)],
+            [$this->matches('create sql stmt'), 1],
+            [$this->stringContains('INSERT INTO'), 1],
+        ];
+
         $conn->expects($this->atLeast(3))
             ->method('executeStatement')
-            ->withConsecutive(
-                [$this->stringContains('INSERT INTO')],
-                [$this->matches('create sql stmt')],
-                [$this->stringContains('INSERT INTO')]
-            )
-            ->will(
-                $this->onConsecutiveCalls(
-                    $this->throwException(
-                        $this->createMock(TableNotFoundException::class)
-                    ),
-                    1,
-                    1
-                )
-            );
+            ->willReturnCallback(function ($sql) use (&$series) {
+                if ([$constraint, $return] = array_shift($series)) {
+                    $constraint->evaluate($sql);
+                }
+
+                if ($return instanceof \Exception) {
+                    throw $return;
+                }
+
+                return $return ?? 1;
+            })
+        ;
 
         $conn->method('isTransactionActive')
             ->willReturn(false);
