@@ -19,7 +19,7 @@ use Symfony\Component\Lock\Store\FlockStore;
 /**
  * @author Jérémy Derussé <jeremy@derusse.com>
  */
-class FlockStoreTest extends AbstractStoreTest
+class FlockStoreTest extends AbstractStoreTestCase
 {
     use BlockingStoreTestTrait;
     use SharedLockStoreTestTrait;
