@@ -17,7 +17,7 @@ use Symfony\Component\Lock\Store\InMemoryStore;
 /**
  * @author Jérémy Derussé <jeremy@derusse.com>
  */
-class InMemoryStoreTest extends AbstractStoreTest
+class InMemoryStoreTest extends AbstractStoreTestCase
 {
     use SharedLockStoreTestTrait;
 
