@@ -23,9 +23,10 @@ use Symfony\Component\Lock\Store\MongoDbStore;
  * @author Joe Bennett <joe@assimtech.com>
  *
  * @requires extension mongodb
+ *
  * @group integration
  */
-class MongoDbStoreTest extends AbstractStoreTest
+class MongoDbStoreTest extends AbstractStoreTestCase
 {
     use ExpiringStoreTestTrait;
 
@@ -97,7 +98,7 @@ class MongoDbStoreTest extends AbstractStoreTest
         $this->assertFalse($store->exists($key));
     }
 
-    public function provideConstructorArgs()
+    public static function provideConstructorArgs()
     {
         $client = self::getMongoClient();
         yield [$client, ['database' => 'test', 'collection' => 'lock']];
@@ -138,7 +139,7 @@ class MongoDbStoreTest extends AbstractStoreTest
         new MongoDbStore($mongo, $options);
     }
 
-    public function provideInvalidConstructorArgs()
+    public static function provideInvalidConstructorArgs()
     {
         $client = self::getMongoClient();
         yield [$client, ['collection' => 'lock']];
@@ -165,7 +166,7 @@ class MongoDbStoreTest extends AbstractStoreTest
         $this->assertSame($driverUri, $uri);
     }
 
-    public function provideUriCollectionStripArgs()
+    public static function provideUriCollectionStripArgs()
     {
         yield ['mongodb://localhost/?collection=lock', ['database' => 'test'], 'mongodb://localhost/'];
         yield ['mongodb://localhost/', ['database' => 'test', 'collection' => 'lock'], 'mongodb://localhost/'];
