@@ -19,10 +19,11 @@ use Symfony\Component\Lock\Store\PostgreSqlStore;
  * @author Jérémy Derussé <jeremy@derusse.com>
  *
  * @requires extension pdo_pgsql
+ *
  * @group integration
  * @group legacy
  */
-class PostgreSqlDbalStoreTest extends AbstractStoreTest
+class PostgreSqlDbalStoreTest extends AbstractStoreTestCase
 {
     use BlockingStoreTestTrait;
     use ExpectDeprecationTrait;
