@@ -19,9 +19,10 @@ use Symfony\Component\Lock\Store\RedisStore;
  * @author Jérémy Derussé <jeremy@derusse.com>
  *
  * @requires extension redis
+ *
  * @group integration
  */
-class RedisStoreTest extends AbstractRedisStoreTest
+class RedisStoreTest extends AbstractRedisStoreTestCase
 {
     use SharedLockStoreTestTrait;
 
