@@ -20,7 +20,7 @@ use Symfony\Component\Lock\Store\SemaphoreStore;
  *
  * @requires extension sysvsem
  */
-class SemaphoreStoreTest extends AbstractStoreTest
+class SemaphoreStoreTest extends AbstractStoreTestCase
 {
     use BlockingStoreTestTrait;
     use UnserializableTestTrait;
