@@ -11,16 +11,20 @@
 
 namespace Symfony\Component\Mailer\Bridge\Amazon\Transport;
 
+use Psr\EventDispatcher\EventDispatcherInterface;
 use Psr\Log\LoggerInterface;
 use Symfony\Component\Mailer\Envelope;
 use Symfony\Component\Mailer\Exception\HttpTransportException;
 use Symfony\Component\Mailer\SentMessage;
 use Symfony\Component\Mailer\Transport\AbstractApiTransport;
+use Symfony\Component\Mime\Address;
 use Symfony\Component\Mime\Email;
-use Symfony\Contracts\EventDispatcher\EventDispatcherInterface;
+use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
 use Symfony\Contracts\HttpClient\HttpClientInterface;
 use Symfony\Contracts\HttpClient\ResponseInterface;
 
+trigger_deprecation('symfony/amazon-mailer', '5.1', 'The "%s" class is deprecated, use "%s" instead. The Amazon transport now requires "AsyncAws". Run "composer require async-aws/ses".', SesApiTransport::class, SesApiAsyncAwsTransport::class);
+
 /**
  * @author Kevin Verschaeve
  */
@@ -63,8 +67,15 @@ class SesApiTransport extends AbstractApiTransport
             'body' => $payload = $this->getPayload($email, $envelope),
         ]);
 
-        $result = new \SimpleXMLElement($response->getContent(false));
-        if (200 !== $response->getStatusCode()) {
+        try {
+            $statusCode = $response->getStatusCode();
+            $content = $response->getContent(false);
+        } catch (TransportExceptionInterface $e) {
+            throw new HttpTransportException('Could not reach the remote Amazon server.', $response, 0, $e);
+        }
+
+        $result = new \SimpleXMLElement($content);
+        if (200 !== $statusCode) {
             throw new HttpTransportException('Unable to send an email: '.$result->Error->Message.sprintf(' (code %d).', $result->Error->Code), $response);
         }
 
@@ -88,10 +99,20 @@ class SesApiTransport extends AbstractApiTransport
     private function getPayload(Email $email, Envelope $envelope): array
     {
         if ($email->getAttachments()) {
-            return [
+            $payload = [
                 'Action' => 'SendRawEmail',
                 'RawMessage.Data' => base64_encode($email->toString()),
             ];
+
+            if ($header = $email->getHeaders()->get('X-SES-CONFIGURATION-SET')) {
+                $payload['ConfigurationSetName'] = $header->getBodyAsString();
+            }
+
+            if ($header = $email->getHeaders()->get('X-SES-SOURCE-ARN')) {
+                $payload['FromEmailAddressIdentityArn'] = $header->getBodyAsString();
+            }
+
+            return $payload;
         }
 
         $payload = [
@@ -116,7 +137,28 @@ class SesApiTransport extends AbstractApiTransport
         if ($email->getReplyTo()) {
             $payload['ReplyToAddresses.member'] = $this->stringifyAddresses($email->getReplyTo());
         }
+        if ($header = $email->getHeaders()->get('X-SES-CONFIGURATION-SET')) {
+            $payload['ConfigurationSetName'] = $header->getBodyAsString();
+        }
+        if ($header = $email->getHeaders()->get('X-SES-SOURCE-ARN')) {
+            $payload['FromEmailAddressIdentityArn'] = $header->getBodyAsString();
+        }
 
         return $payload;
     }
+
+    protected function stringifyAddresses(array $addresses): array
+    {
+        return array_map(function (Address $a) {
+            // AWS does not support UTF-8 address
+            if (preg_match('~[\x00-\x08\x10-\x19\x7F-\xFF\r\n]~', $name = $a->getName())) {
+                return sprintf('=?UTF-8?B?%s?= <%s>',
+                    base64_encode($name),
+                    $a->getEncodedAddress()
+                );
+            }
+
+            return $a->toString();
+        }, $addresses);
+    }
 }
