@@ -124,7 +124,10 @@ class MandrillApiTransport extends AbstractApiTransport
             }
 
             if ($header instanceof TagHeader) {
-                $payload['message']['tags'] = explode(',', $header->getValue());
+                $payload['message']['tags'] = array_merge(
+                    $payload['message']['tags'] ?? [],
+                    explode(',', $header->getValue())
+                );
 
                 continue;
             }
@@ -135,7 +138,7 @@ class MandrillApiTransport extends AbstractApiTransport
                 continue;
             }
 
-            $payload['message']['headers'][$name] = $header->getBodyAsString();
+            $payload['message']['headers'][$header->getName()] = $header->getBodyAsString();
         }
 
         return $payload;
