@@ -11,15 +11,17 @@
 
 namespace Symfony\Component\Mailer\Bridge\Mailchimp\Transport;
 
+use Psr\EventDispatcher\EventDispatcherInterface;
 use Psr\Log\LoggerInterface;
 use Symfony\Component\Mailer\Transport\Smtp\EsmtpTransport;
-use Symfony\Contracts\EventDispatcher\EventDispatcherInterface;
 
 /**
  * @author Kevin Verschaeve
  */
 class MandrillSmtpTransport extends EsmtpTransport
 {
+    use MandrillHeadersTrait;
+
     public function __construct(string $username, string $password, EventDispatcherInterface $dispatcher = null, LoggerInterface $logger = null)
     {
         parent::__construct('smtp.mandrillapp.com', 587, false, $dispatcher, $logger);
