@@ -11,6 +11,8 @@
 
 namespace Symfony\Component\Mailer\Bridge\Sendinblue\Tests\Transport;
 
+use Psr\Log\NullLogger;
+use Symfony\Component\HttpClient\MockHttpClient;
 use Symfony\Component\Mailer\Bridge\Sendinblue\Transport\SendinblueApiTransport;
 use Symfony\Component\Mailer\Bridge\Sendinblue\Transport\SendinblueSmtpTransport;
 use Symfony\Component\Mailer\Bridge\Sendinblue\Transport\SendinblueTransportFactory;
@@ -22,10 +24,10 @@ class SendinblueTransportFactoryTest extends TransportFactoryTestCase
 {
     public function getFactory(): TransportFactoryInterface
     {
-        return new SendinblueTransportFactory($this->getDispatcher(), $this->getClient(), $this->getLogger());
+        return new SendinblueTransportFactory(null, new MockHttpClient(), new NullLogger());
     }
 
-    public function supportsProvider(): iterable
+    public static function supportsProvider(): iterable
     {
         yield [
             new Dsn('sendinblue', 'default'),
@@ -48,30 +50,30 @@ class SendinblueTransportFactoryTest extends TransportFactoryTestCase
         ];
     }
 
-    public function createProvider(): iterable
+    public static function createProvider(): iterable
     {
         yield [
             new Dsn('sendinblue', 'default', self::USER, self::PASSWORD),
-            new SendinblueSmtpTransport(self::USER, self::PASSWORD, $this->getDispatcher(), $this->getLogger()),
+            new SendinblueSmtpTransport(self::USER, self::PASSWORD, null, new NullLogger()),
         ];
 
         yield [
             new Dsn('sendinblue+smtp', 'default', self::USER, self::PASSWORD),
-            new SendinblueSmtpTransport(self::USER, self::PASSWORD, $this->getDispatcher(), $this->getLogger()),
+            new SendinblueSmtpTransport(self::USER, self::PASSWORD, null, new NullLogger()),
         ];
 
         yield [
             new Dsn('sendinblue+smtp', 'default', self::USER, self::PASSWORD, 465),
-            new SendinblueSmtpTransport(self::USER, self::PASSWORD, $this->getDispatcher(), $this->getLogger()),
+            new SendinblueSmtpTransport(self::USER, self::PASSWORD, null, new NullLogger()),
         ];
 
         yield [
             new Dsn('sendinblue+api', 'default', self::USER),
-            new SendinblueApiTransport(self::USER, $this->getClient(), $this->getDispatcher(), $this->getLogger()),
+            new SendinblueApiTransport(self::USER, new MockHttpClient(), null, new NullLogger()),
         ];
     }
 
-    public function unsupportedSchemeProvider(): iterable
+    public static function unsupportedSchemeProvider(): iterable
     {
         yield [
             new Dsn('sendinblue+foo', 'default', self::USER, self::PASSWORD),
@@ -79,7 +81,7 @@ class SendinblueTransportFactoryTest extends TransportFactoryTestCase
         ];
     }
 
-    public function incompleteDsnProvider(): iterable
+    public static function incompleteDsnProvider(): iterable
     {
         yield [new Dsn('sendinblue+smtp', 'default', self::USER)];
 
