@@ -100,16 +100,10 @@ class EsmtpTransport extends SmtpTransport
 
     protected function doHeloCommand(): void
     {
-        try {
-            $response = $this->executeCommand(sprintf("EHLO %s\r\n", $this->getLocalDomain()), [250]);
-        } catch (TransportExceptionInterface $e) {
-            parent::doHeloCommand();
-
+        if (!$capabilities = $this->callHeloCommand()) {
             return;
         }
 
-        $capabilities = $this->getCapabilities($response);
-
         /** @var SocketStream $stream */
         $stream = $this->getStream();
         // WARNING: !$stream->isTLS() is right, 100% sure :)
@@ -122,14 +116,7 @@ class EsmtpTransport extends SmtpTransport
                 throw new TransportException('Unable to connect with STARTTLS.');
             }
 
-            try {
-                $response = $this->executeCommand(sprintf("EHLO %s\r\n", $this->getLocalDomain()), [250]);
-                $capabilities = $this->getCapabilities($response);
-            } catch (TransportExceptionInterface $e) {
-                parent::doHeloCommand();
-
-                return;
-            }
+            $capabilities = $this->callHeloCommand();
         }
 
         if (\array_key_exists('AUTH', $capabilities)) {
@@ -137,10 +124,26 @@ class EsmtpTransport extends SmtpTransport
         }
     }
 
-    private function getCapabilities(string $ehloResponse): array
+    private function callHeloCommand(): array
     {
+        try {
+            $response = $this->executeCommand(sprintf("EHLO %s\r\n", $this->getLocalDomain()), [250]);
+        } catch (TransportExceptionInterface $e) {
+            try {
+                parent::doHeloCommand();
+
+                return [];
+            } catch (TransportExceptionInterface $ex) {
+                if (!$ex->getCode()) {
+                    throw $e;
+                }
+
+                throw $ex;
+            }
+        }
+
         $capabilities = [];
-        $lines = explode("\r\n", trim($ehloResponse));
+        $lines = explode("\r\n", trim($response));
         array_shift($lines);
         foreach ($lines as $line) {
             if (preg_match('/^[0-9]{3}[ -]([A-Z0-9-]+)((?:[ =].*)?)$/Di', $line, $matches)) {
@@ -179,7 +182,7 @@ class EsmtpTransport extends SmtpTransport
                 }
 
                 // keep the error message, but tries the other authenticators
-                $errors[$authenticator->getAuthKeyword()] = $e;
+                $errors[$authenticator->getAuthKeyword()] = $e->getMessage();
             }
         }
 
