@@ -272,12 +272,22 @@ class ConnectionTest extends TestCase
         $redis = $this->createMock(\Redis::class);
 
         $redis->expects($this->exactly(3))->method('xreadgroup')
-            ->withConsecutive(
-                ['symfony', 'consumer', ['queue' => '0'], 1, null], // first call for pending messages
-                ['symfony', 'consumer', ['queue' => '0'], 1, null], // second call because of claimed message (redisid-123)
-                ['symfony', 'consumer', ['queue' => '>'], 1, null] // third call because of no result (other consumer claimed message redisid-123)
-            )
-            ->willReturnOnConsecutiveCalls([], [], []);
+            ->willReturnCallback(function (...$args) {
+                static $series = [
+                    // first call for pending messages
+                    [['symfony', 'consumer', ['queue' => '0'], 1, null], []],
+                    // second call because of claimed message (redisid-123)
+                    [['symfony', 'consumer', ['queue' => '0'], 1, null], []],
+                    // third call because of no result (other consumer claimed message redisid-123)
+                    [['symfony', 'consumer', ['queue' => '>'], 1, null], []],
+                ];
+
+                [$expectedArgs, $return] = array_shift($series);
+                $this->assertSame($expectedArgs, $args);
+
+                return $return;
+            })
+        ;
 
         $redis->expects($this->once())->method('xpending')->willReturn([[
             0 => 'redisid-123', // message-id
@@ -298,14 +308,20 @@ class ConnectionTest extends TestCase
         $redis = $this->createMock(\Redis::class);
 
         $redis->expects($this->exactly(2))->method('xreadgroup')
-            ->withConsecutive(
-                ['symfony', 'consumer', ['queue' => '0'], 1, null], // first call for pending messages
-                ['symfony', 'consumer', ['queue' => '0'], 1, null] // second call because of claimed message (redisid-123)
-            )
-            ->willReturnOnConsecutiveCalls(
-                [], // first call returns no result
-                ['queue' => [['message' => '{"body":"1","headers":[]}']]] // second call returns claimed message (redisid-123)
-            );
+            ->willReturnCallback(function (...$args) {
+                static $series = [
+                    // first call for pending messages
+                    [['symfony', 'consumer', ['queue' => '0'], 1, null], []],
+                    // second call because of claimed message (redisid-123)
+                    [['symfony', 'consumer', ['queue' => '0'], 1, null], ['queue' => [['message' => '{"body":"1","headers":[]}']]]],
+                ];
+
+                [$expectedArgs, $return] = array_shift($series);
+                $this->assertSame($expectedArgs, $args);
+
+                return $return;
+            })
+        ;
 
         $redis->expects($this->once())->method('xpending')->willReturn([[
             0 => 'redisid-123', // message-id
