@@ -235,15 +235,20 @@ class MessengerPass implements CompilerPassInterface
 
         if ($type instanceof \ReflectionUnionType) {
             $types = [];
+            $invalidTypes = [];
             foreach ($type->getTypes() as $type) {
                 if (!$type->isBuiltin()) {
                     $types[] = (string) $type;
+                } else {
+                    $invalidTypes[] = (string) $type;
                 }
             }
 
             if ($types) {
                 return $types;
             }
+
+            throw new RuntimeException(sprintf('Invalid handler service "%s": type-hint of argument "$%s" in method "%s::__invoke()" must be a class , "%s" given.', $serviceId, $parameters[0]->getName(), $handlerClass->getName(), implode('|', $invalidTypes)));
         }
 
         if ($type->isBuiltin()) {
