@@ -12,10 +12,8 @@
 namespace Symfony\Component\Messenger\Event;
 
 use Symfony\Component\Messenger\Envelope;
+use Symfony\Component\Messenger\Stamp\StampInterface;
 
-/**
- * @experimental in 4.3
- */
 abstract class AbstractWorkerMessageEvent
 {
     private $envelope;
@@ -39,4 +37,9 @@ abstract class AbstractWorkerMessageEvent
     {
         return $this->receiverName;
     }
+
+    public function addStamps(StampInterface ...$stamps): void
+    {
+        $this->envelope = $this->envelope->with(...$stamps);
+    }
 }
