@@ -53,13 +53,14 @@ class HandleMessageMiddleware implements MiddlewareInterface
         $message = $envelope->getMessage();
 
         $context = [
-            'message' => $message,
             'class' => \get_class($message),
         ];
 
         $exceptions = [];
+        $alreadyHandled = false;
         foreach ($this->handlersLocator->getHandlers($envelope) as $handlerDescriptor) {
             if ($this->messageHasAlreadyBeenHandled($envelope, $handlerDescriptor)) {
+                $alreadyHandled = true;
                 continue;
             }
 
@@ -117,7 +118,7 @@ class HandleMessageMiddleware implements MiddlewareInterface
             }
         }
 
-        if (null === $handler) {
+        if (null === $handler && !$alreadyHandled) {
             if (!$this->allowNoHandlers) {
                 throw new NoHandlerForMessageException(sprintf('No handler for message "%s".', $context['class']));
             }
