@@ -31,7 +31,7 @@ class SendMessageMiddlewareTest extends MiddlewareTestCase
     {
         $message = new DummyMessage('Hey');
         $envelope = new Envelope($message);
-        $sender = $this->getMockBuilder(SenderInterface::class)->getMock();
+        $sender = $this->createMock(SenderInterface::class);
 
         $sendersLocator = $this->createSendersLocator([DummyMessage::class => ['my_sender']], ['my_sender' => $sender]);
         $middleware = new SendMessageMiddleware($sendersLocator);
@@ -49,8 +49,8 @@ class SendMessageMiddlewareTest extends MiddlewareTestCase
     public function testItSendsTheMessageToMultipleSenders()
     {
         $envelope = new Envelope(new DummyMessage('Hey'));
-        $sender = $this->getMockBuilder(SenderInterface::class)->getMock();
-        $sender2 = $this->getMockBuilder(SenderInterface::class)->getMock();
+        $sender = $this->createMock(SenderInterface::class);
+        $sender2 = $this->createMock(SenderInterface::class);
 
         $sendersLocator = $this->createSendersLocator([DummyMessage::class => ['foo', 'bar']], ['foo' => $sender, 'bar' => $sender2]);
         $middleware = new SendMessageMiddleware($sendersLocator);
@@ -86,7 +86,7 @@ class SendMessageMiddlewareTest extends MiddlewareTestCase
     public function testItSendsTheMessageToAssignedSenderWithPreWrappedMessage()
     {
         $envelope = new Envelope(new ChildDummyMessage('Hey'));
-        $sender = $this->getMockBuilder(SenderInterface::class)->getMock();
+        $sender = $this->createMock(SenderInterface::class);
 
         $sendersLocator = $this->createSendersLocator([DummyMessage::class => ['foo_sender']], ['foo_sender' => $sender]);
         $middleware = new SendMessageMiddleware($sendersLocator);
@@ -100,7 +100,7 @@ class SendMessageMiddlewareTest extends MiddlewareTestCase
     {
         $message = new ChildDummyMessage('Hey');
         $envelope = new Envelope($message);
-        $sender = $this->getMockBuilder(SenderInterface::class)->getMock();
+        $sender = $this->createMock(SenderInterface::class);
 
         $sendersLocator = $this->createSendersLocator([DummyMessage::class => ['foo_sender']], ['foo_sender' => $sender]);
         $middleware = new SendMessageMiddleware($sendersLocator);
@@ -114,7 +114,7 @@ class SendMessageMiddlewareTest extends MiddlewareTestCase
     {
         $message = new DummyMessage('Hey');
         $envelope = new Envelope($message);
-        $sender = $this->getMockBuilder(SenderInterface::class)->getMock();
+        $sender = $this->createMock(SenderInterface::class);
 
         $sendersLocator = $this->createSendersLocator([DummyMessageInterface::class => ['foo_sender']], ['foo_sender' => $sender]);
         $middleware = new SendMessageMiddleware($sendersLocator);
@@ -128,7 +128,7 @@ class SendMessageMiddlewareTest extends MiddlewareTestCase
     {
         $message = new DummyMessage('Hey');
         $envelope = new Envelope($message);
-        $sender = $this->getMockBuilder(SenderInterface::class)->getMock();
+        $sender = $this->createMock(SenderInterface::class);
 
         $sendersLocator = $this->createSendersLocator(['*' => ['foo_sender']], ['foo_sender' => $sender]);
         $middleware = new SendMessageMiddleware($sendersLocator);
@@ -152,7 +152,7 @@ class SendMessageMiddlewareTest extends MiddlewareTestCase
     {
         $envelope = (new Envelope(new DummyMessage('Hey')))->with(new ReceivedStamp('transport'));
 
-        $sender = $this->getMockBuilder(SenderInterface::class)->getMock();
+        $sender = $this->createMock(SenderInterface::class);
 
         $sendersLocator = $this->createSendersLocator(['*' => ['foo']], ['foo' => $sender]);
         $middleware = new SendMessageMiddleware($sendersLocator);
@@ -173,8 +173,8 @@ class SendMessageMiddlewareTest extends MiddlewareTestCase
             ->method('dispatch')
             ->with(new SendMessageToTransportsEvent($envelope));
 
-        $sender1 = $this->getMockBuilder(SenderInterface::class)->getMock();
-        $sender2 = $this->getMockBuilder(SenderInterface::class)->getMock();
+        $sender1 = $this->createMock(SenderInterface::class);
+        $sender2 = $this->createMock(SenderInterface::class);
 
         $sendersLocator = $this->createSendersLocator([DummyMessage::class => ['foo', 'bar']], ['foo' => $sender1, 'bar' => $sender2]);
         $middleware = new SendMessageMiddleware($sendersLocator, $dispatcher);
