@@ -26,12 +26,14 @@ class InMemoryTransportFactory implements TransportFactoryInterface, ResetInterf
 
     public function createTransport(string $dsn, array $options, SerializerInterface $serializer): TransportInterface
     {
-        return $this->createdTransports[] = new InMemoryTransport();
+        ['serialize' => $serialize] = $this->parseDsn($dsn);
+
+        return $this->createdTransports[] = new InMemoryTransport($serialize ? $serializer : null);
     }
 
     public function supports(string $dsn, array $options): bool
     {
-        return 0 === strpos($dsn, 'in-memory://');
+        return str_starts_with($dsn, 'in-memory://');
     }
 
     public function reset()
@@ -40,4 +42,16 @@ class InMemoryTransportFactory implements TransportFactoryInterface, ResetInterf
             $transport->reset();
         }
     }
+
+    private function parseDsn(string $dsn): array
+    {
+        $query = [];
+        if ($queryAsString = strstr($dsn, '?')) {
+            parse_str(ltrim($queryAsString, '?'), $query);
+        }
+
+        return [
+            'serialize' => filter_var($query['serialize'] ?? false, \FILTER_VALIDATE_BOOLEAN),
+        ];
+    }
 }
