@@ -11,7 +11,6 @@
 
 namespace Symfony\Component\Notifier\Bridge\Discord;
 
-use Symfony\Component\Notifier\Exception\IncompleteDsnException;
 use Symfony\Component\Notifier\Exception\UnsupportedSchemeException;
 use Symfony\Component\Notifier\Transport\AbstractTransportFactory;
 use Symfony\Component\Notifier\Transport\Dsn;
@@ -19,8 +18,6 @@ use Symfony\Component\Notifier\Transport\TransportInterface;
 
 /**
  * @author Mathieu Piot <math.piot@gmail.com>
- *
- * @experimental in 5.2
  */
 final class DiscordTransportFactory extends AbstractTransportFactory
 {
@@ -36,12 +33,7 @@ final class DiscordTransportFactory extends AbstractTransportFactory
         }
 
         $token = $this->getUser($dsn);
-        $webhookId = $dsn->getOption('webhook_id');
-
-        if (!$webhookId) {
-            throw new IncompleteDsnException('Missing webhook_id.', $dsn->getOriginalDsn());
-        }
-
+        $webhookId = $dsn->getRequiredOption('webhook_id');
         $host = 'default' === $dsn->getHost() ? null : $dsn->getHost();
         $port = $dsn->getPort();
 
