@@ -17,9 +17,9 @@ use Symfony\Component\Notifier\Bridge\Firebase\FirebaseOptions;
 use Symfony\Component\Notifier\Bridge\Firebase\FirebaseTransport;
 use Symfony\Component\Notifier\Exception\TransportException;
 use Symfony\Component\Notifier\Message\ChatMessage;
-use Symfony\Component\Notifier\Message\MessageInterface;
 use Symfony\Component\Notifier\Message\SmsMessage;
 use Symfony\Component\Notifier\Test\TransportTestCase;
+use Symfony\Component\Notifier\Tests\Transport\DummyMessage;
 use Symfony\Component\Notifier\Transport\TransportInterface;
 use Symfony\Contracts\HttpClient\HttpClientInterface;
 use Symfony\Contracts\HttpClient\ResponseInterface;
@@ -32,25 +32,25 @@ final class FirebaseTransportTest extends TransportTestCase
     /**
      * @return FirebaseTransport
      */
-    public function createTransport(HttpClientInterface $client = null): TransportInterface
+    public static function createTransport(HttpClientInterface $client = null): TransportInterface
     {
-        return new FirebaseTransport('username:password', $client ?? $this->createMock(HttpClientInterface::class));
+        return new FirebaseTransport('username:password', $client ?? new MockHttpClient());
     }
 
-    public function toStringProvider(): iterable
+    public static function toStringProvider(): iterable
     {
-        yield ['firebase://fcm.googleapis.com/fcm/send', $this->createTransport()];
+        yield ['firebase://fcm.googleapis.com/fcm/send', self::createTransport()];
     }
 
-    public function supportedMessagesProvider(): iterable
+    public static function supportedMessagesProvider(): iterable
     {
         yield [new ChatMessage('Hello!')];
     }
 
-    public function unsupportedMessagesProvider(): iterable
+    public static function unsupportedMessagesProvider(): iterable
     {
         yield [new SmsMessage('0611223344', 'Hello!')];
-        yield [$this->createMock(MessageInterface::class)];
+        yield [new DummyMessage()];
     }
 
     /**
@@ -65,12 +65,12 @@ final class FirebaseTransportTest extends TransportTestCase
         });
         $options = new class('recipient-id', []) extends FirebaseOptions {};
 
-        $transport = $this->createTransport($client);
+        $transport = self::createTransport($client);
 
         $transport->send(new ChatMessage('Hello!', $options));
     }
 
-    public function sendWithErrorThrowsExceptionProvider(): iterable
+    public static function sendWithErrorThrowsExceptionProvider(): iterable
     {
         yield [new MockResponse(
             json_encode(['results' => [['error' => 'testErrorCode']]]),
