@@ -25,7 +25,7 @@ final class GoogleChatTransportFactoryTest extends TransportFactoryTestCase
         return new GoogleChatTransportFactory();
     }
 
-    public function createProvider(): iterable
+    public static function createProvider(): iterable
     {
         yield [
             'googlechat://chat.googleapis.com/AAAAA_YYYYY',
@@ -38,18 +38,18 @@ final class GoogleChatTransportFactoryTest extends TransportFactoryTestCase
         ];
     }
 
-    public function supportsProvider(): iterable
+    public static function supportsProvider(): iterable
     {
         yield [true, 'googlechat://host/path'];
         yield [false, 'somethingElse://host/path'];
     }
 
-    public function incompleteDsnProvider(): iterable
+    public static function incompleteDsnProvider(): iterable
     {
         yield 'missing credentials' => ['googlechat://chat.googleapis.com/v1/spaces/AAAAA_YYYYY/messages'];
     }
 
-    public function unsupportedSchemeProvider(): iterable
+    public static function unsupportedSchemeProvider(): iterable
     {
         yield ['somethingElse://host/path'];
     }
