@@ -25,7 +25,7 @@ final class SinchTransportFactoryTest extends TransportFactoryTestCase
         return new SinchTransportFactory();
     }
 
-    public function createProvider(): iterable
+    public static function createProvider(): iterable
     {
         yield [
             'sinch://host.test?from=0611223344',
@@ -33,18 +33,18 @@ final class SinchTransportFactoryTest extends TransportFactoryTestCase
         ];
     }
 
-    public function supportsProvider(): iterable
+    public static function supportsProvider(): iterable
     {
         yield [true, 'sinch://accountSid:authToken@default?from=0611223344'];
         yield [false, 'somethingElse://accountSid:authToken@default?from=0611223344'];
     }
 
-    public function missingRequiredOptionProvider(): iterable
+    public static function missingRequiredOptionProvider(): iterable
     {
         yield 'missing option: from' => ['sinch://accountSid:authToken@default'];
     }
 
-    public function unsupportedSchemeProvider(): iterable
+    public static function unsupportedSchemeProvider(): iterable
     {
         yield ['somethingElse://accountSid:authToken@default?from=0611223344'];
         yield ['somethingElse://accountSid:authToken@default']; // missing "from" option
