@@ -16,9 +16,9 @@ use Symfony\Component\Notifier\Bridge\Telegram\TelegramOptions;
 use Symfony\Component\Notifier\Bridge\Telegram\TelegramTransport;
 use Symfony\Component\Notifier\Exception\TransportException;
 use Symfony\Component\Notifier\Message\ChatMessage;
-use Symfony\Component\Notifier\Message\MessageInterface;
 use Symfony\Component\Notifier\Message\SmsMessage;
 use Symfony\Component\Notifier\Test\TransportTestCase;
+use Symfony\Component\Notifier\Tests\Transport\DummyMessage;
 use Symfony\Component\Notifier\Transport\TransportInterface;
 use Symfony\Contracts\HttpClient\HttpClientInterface;
 use Symfony\Contracts\HttpClient\ResponseInterface;
@@ -28,26 +28,26 @@ final class TelegramTransportTest extends TransportTestCase
     /**
      * @return TelegramTransport
      */
-    public function createTransport(HttpClientInterface $client = null, string $channel = null): TransportInterface
+    public static function createTransport(HttpClientInterface $client = null, string $channel = null): TransportInterface
     {
-        return new TelegramTransport('token', $channel, $client ?? $this->createMock(HttpClientInterface::class));
+        return new TelegramTransport('token', $channel, $client ?? new MockHttpClient());
     }
 
-    public function toStringProvider(): iterable
+    public static function toStringProvider(): iterable
     {
-        yield ['telegram://api.telegram.org', $this->createTransport()];
-        yield ['telegram://api.telegram.org?channel=testChannel', $this->createTransport(null, 'testChannel')];
+        yield ['telegram://api.telegram.org', self::createTransport()];
+        yield ['telegram://api.telegram.org?channel=testChannel', self::createTransport(null, 'testChannel')];
     }
 
-    public function supportedMessagesProvider(): iterable
+    public static function supportedMessagesProvider(): iterable
     {
         yield [new ChatMessage('Hello!')];
     }
 
-    public function unsupportedMessagesProvider(): iterable
+    public static function unsupportedMessagesProvider(): iterable
     {
         yield [new SmsMessage('0611223344', 'Hello!')];
-        yield [$this->createMock(MessageInterface::class)];
+        yield [new DummyMessage()];
     }
 
     public function testSendWithErrorResponseThrowsTransportException()
@@ -67,7 +67,7 @@ final class TelegramTransportTest extends TransportTestCase
             return $response;
         });
 
-        $transport = $this->createTransport($client, 'testChannel');
+        $transport = self::createTransport($client, 'testChannel');
 
         $transport->send(new ChatMessage('testMessage'));
     }
@@ -119,7 +119,7 @@ JSON;
             return $response;
         });
 
-        $transport = $this->createTransport($client, 'testChannel');
+        $transport = self::createTransport($client, 'testChannel');
 
         $sentMessage = $transport->send(new ChatMessage('testMessage'));
 
@@ -175,7 +175,7 @@ JSON;
             return $response;
         });
 
-        $transport = $this->createTransport($client, 'defaultChannel');
+        $transport = self::createTransport($client, 'defaultChannel');
 
         $messageOptions = new TelegramOptions();
         $messageOptions->chatId($channelOverride);
@@ -233,7 +233,7 @@ JSON;
             return $response;
         });
 
-        $transport = $this->createTransport($client, 'testChannel');
+        $transport = self::createTransport($client, 'testChannel');
 
         $transport->send(new ChatMessage('I contain special characters _ * [ ] ( ) ~ ` > # + - = | { } . ! to send.'));
     }
