@@ -302,7 +302,7 @@ EOTXT
         $this->assertSame($expectedSuggestions, $tester->complete($input));
     }
 
-    public function provideCompletionSuggestions(): iterable
+    public static function provideCompletionSuggestions(): iterable
     {
         yield 'user_class_empty' => [
             ['p@ssw0rd', ''],
