@@ -55,7 +55,7 @@ class PropertyAccessorTest extends TestCase
         $this->propertyAccessor = new PropertyAccessor();
     }
 
-    public function getPathsWithUnexpectedType()
+    public static function getPathsWithUnexpectedType()
     {
         return [
             ['', 'foobar'],
@@ -69,7 +69,7 @@ class PropertyAccessorTest extends TestCase
         ];
     }
 
-    public function getPathsWithMissingProperty()
+    public static function getPathsWithMissingProperty()
     {
         return [
             [(object) ['firstName' => 'Bernhard'], 'lastName'],
@@ -89,7 +89,7 @@ class PropertyAccessorTest extends TestCase
         ];
     }
 
-    public function getPathsWithMissingIndex()
+    public static function getPathsWithMissingIndex()
     {
         return [
             [['firstName' => 'Bernhard'], '[lastName]'],
@@ -129,6 +129,7 @@ class PropertyAccessorTest extends TestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider getPathsWithMissingProperty
      */
     public function testGetValueReturnsNullIfPropertyNotFoundAndExceptionIsDisabledUsingBooleanArgument($objectOrArray, $path)
@@ -160,6 +161,7 @@ class PropertyAccessorTest extends TestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider getPathsWithMissingIndex
      */
     public function testGetValueThrowsExceptionIfIndexNotFoundAndIndexExceptionsEnabledUsingBooleanArgument($objectOrArray, $path)
@@ -357,6 +359,7 @@ class PropertyAccessorTest extends TestCase
 
     /**
      * @group legacy
+     *
      * @expectedDeprecation Since symfony/property-access 5.2: Passing a boolean as the first argument to "Symfony\Component\PropertyAccess\PropertyAccessor::__construct()" is deprecated. Pass a combination of bitwise flags instead (i.e an integer).
      */
     public function testLegacyGetValueReadsMagicCallIfEnabled()
@@ -476,6 +479,7 @@ class PropertyAccessorTest extends TestCase
 
     /**
      * @group legacy
+     *
      * @expectedDeprecation Since symfony/property-access 5.2: Passing a boolean as the first argument to "Symfony\Component\PropertyAccess\PropertyAccessor::__construct()" is deprecated. Pass a combination of bitwise flags instead (i.e an integer).
      */
     public function testLegacySetValueUpdatesMagicCallIfEnabled()
@@ -564,6 +568,7 @@ class PropertyAccessorTest extends TestCase
 
     /**
      * @group legacy
+     *
      * @expectedDeprecation Since symfony/property-access 5.2: Passing a boolean as the first argument to "Symfony\Component\PropertyAccess\PropertyAccessor::__construct()" is deprecated. Pass a combination of bitwise flags instead (i.e an integer).
      */
     public function testLegacyIsReadableRecognizesMagicCallIfEnabled()
@@ -636,6 +641,7 @@ class PropertyAccessorTest extends TestCase
 
     /**
      * @group legacy
+     *
      * @expectedDeprecation Since symfony/property-access 5.2: Passing a boolean as the first argument to "Symfony\Component\PropertyAccess\PropertyAccessor::__construct()" is deprecated. Pass a combination of bitwise flags instead (i.e an integer).
      */
     public function testLegacyIsWritableRecognizesMagicCallIfEnabled()
@@ -660,7 +666,7 @@ class PropertyAccessorTest extends TestCase
         $this->assertFalse($this->propertyAccessor->isWritable($objectOrArray, $path));
     }
 
-    public function getValidPropertyPaths()
+    public static function getValidPropertyPaths()
     {
         return [
             [['Bernhard', 'Schussek'], '[0]', 'Bernhard'],
@@ -723,7 +729,7 @@ class PropertyAccessorTest extends TestCase
         $this->assertSame('Updated', $obj->publicProperty['foo']['bar']);
     }
 
-    public function getReferenceChainObjectsForSetValue()
+    public static function getReferenceChainObjectsForSetValue()
     {
         return [
             [['a' => ['b' => ['c' => 'old-value']]], '[a][b][c]', 'new-value'],
@@ -744,7 +750,7 @@ class PropertyAccessorTest extends TestCase
         $this->assertEquals($value, $this->propertyAccessor->getValue($object, $path));
     }
 
-    public function getReferenceChainObjectsForIsWritable()
+    public static function getReferenceChainObjectsForIsWritable()
     {
         return [
             [new TestClassIsWritable(['a' => ['b' => 'old-value']]), 'value[a][b]', false],
