@@ -11,6 +11,7 @@
 
 namespace Symfony\Component\PropertyInfo\Util;
 
+use phpDocumentor\Reflection\PseudoTypes\ConstExpression;
 use phpDocumentor\Reflection\PseudoTypes\List_;
 use phpDocumentor\Reflection\Type as DocType;
 use phpDocumentor\Reflection\Types\Array_;
@@ -39,6 +40,11 @@ final class PhpDocTypeHelper
      */
     public function getTypes(DocType $varType): array
     {
+        if ($varType instanceof ConstExpression) {
+            // It's safer to fall back to other extractors here, as resolving const types correctly is not easy at the moment
+            return [];
+        }
+
         $types = [];
         $nullable = false;
 
@@ -64,6 +70,11 @@ final class PhpDocTypeHelper
         for ($typeIndex = 0; $varType->has($typeIndex); ++$typeIndex) {
             $type = $varType->get($typeIndex);
 
+            if ($type instanceof ConstExpression) {
+                // It's safer to fall back to other extractors here, as resolving const types correctly is not easy at the moment
+                return [];
+            }
+
             // If null is present, all types are nullable
             if ($type instanceof Null_) {
                 $nullable = true;
@@ -162,7 +173,7 @@ final class PhpDocTypeHelper
             case 'boolean':
                 return 'bool';
 
-            // real is not part of the PHPDoc standard, so we ignore it
+                // real is not part of the PHPDoc standard, so we ignore it
             case 'double':
                 return 'float';
 
@@ -187,6 +198,6 @@ final class PhpDocTypeHelper
             return ['object', $docType];
         }
 
-        return ['object', substr($docType, 1)]; // substr to strip the namespace's `\`-prefix
+        return ['object', ltrim($docType, '\\')];
     }
 }
