@@ -85,4 +85,31 @@ final class Window implements LimiterStateInterface
 
         return $cyclesRequired * $this->intervalInSeconds;
     }
+
+    public function __serialize(): array
+    {
+        return [
+            $this->id => $this->timer,
+            pack('NN', $this->hitCount, $this->intervalInSeconds) => $this->maxSize,
+        ];
+    }
+
+    public function __unserialize(array $data): void
+    {
+        // BC layer for old objects serialized via __sleep
+        if (5 === \count($data)) {
+            $data = array_values($data);
+            $this->id = $data[0];
+            $this->hitCount = $data[1];
+            $this->intervalInSeconds = $data[2];
+            $this->maxSize = $data[3];
+            $this->timer = $data[4];
+
+            return;
+        }
+
+        [$this->timer, $this->maxSize] = array_values($data);
+        [$this->id, $pack] = array_keys($data);
+        ['a' => $this->hitCount, 'b' => $this->intervalInSeconds] = unpack('Na/Nb', $pack);
+    }
 }
