@@ -130,7 +130,7 @@ class UrlGeneratorTest extends TestCase
         $this->assertSame('http://localhost/app.php/testing'.$expectedQueryString, $url);
     }
 
-    public function valuesProvider(): array
+    public static function valuesProvider(): array
     {
         $stdClass = new \stdClass();
         $stdClass->baz = 'bar';
@@ -862,7 +862,7 @@ class UrlGeneratorTest extends TestCase
         $this->assertSame($expectedPath, UrlGenerator::getRelativePath($sourcePath, $targetPath));
     }
 
-    public function provideRelativePaths()
+    public static function provideRelativePaths()
     {
         return [
             [
@@ -1004,7 +1004,7 @@ class UrlGeneratorTest extends TestCase
         $this->assertSame($expected, $this->getGenerator($routes)->generate('test', ['foo' => 'a/b', 'baz' => 'c/d/e']));
     }
 
-    public function provideLookAroundRequirementsInPath()
+    public static function provideLookAroundRequirementsInPath()
     {
         yield ['/app.php/a/b/b%28ar/c/d/e', '/{foo}/b(ar/{baz}', '.+(?=/b\\(ar/)'];
         yield ['/app.php/a/b/bar/c/d/e', '/{foo}/bar/{baz}', '.+(?!$)'];
