@@ -52,7 +52,7 @@ class YamlFileLoaderTest extends TestCase
         $loader->load($filePath);
     }
 
-    public function getPathsToInvalidFiles()
+    public static function getPathsToInvalidFiles()
     {
         return [
             ['nonvalid.yml'],
@@ -171,7 +171,7 @@ class YamlFileLoaderTest extends TestCase
         $this->assertSame('FrameworkBundle:Template:template', $route->getDefault('_controller'));
     }
 
-    public function provideFilesImportingRoutesWithControllers()
+    public static function provideFilesImportingRoutesWithControllers()
     {
         yield ['import_controller.yml'];
         yield ['import__controller.yml'];
