@@ -32,13 +32,13 @@ class RouteCompilerTest extends TestCase
         $this->assertEquals($tokens, $compiled->getTokens(), $name.' (tokens)');
     }
 
-    public function provideCompileData()
+    public static function provideCompileData()
     {
         return [
             [
                 'Static route',
                 ['/foo'],
-                '/foo', '#^/foo$#sD', [], [
+                '/foo', '{^/foo$}sD', [], [
                     ['text', '/foo'],
                 ],
             ],
@@ -46,7 +46,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with a variable',
                 ['/foo/{bar}'],
-                '/foo', '#^/foo/(?P<bar>[^/]++)$#sD', ['bar'], [
+                '/foo', '{^/foo/(?P<bar>[^/]++)$}sD', ['bar'], [
                     ['variable', '/', '[^/]++', 'bar'],
                     ['text', '/foo'],
                 ],
@@ -55,7 +55,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with a variable that has a default value',
                 ['/foo/{bar}', ['bar' => 'bar']],
-                '/foo', '#^/foo(?:/(?P<bar>[^/]++))?$#sD', ['bar'], [
+                '/foo', '{^/foo(?:/(?P<bar>[^/]++))?$}sD', ['bar'], [
                     ['variable', '/', '[^/]++', 'bar'],
                     ['text', '/foo'],
                 ],
@@ -64,7 +64,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with several variables',
                 ['/foo/{bar}/{foobar}'],
-                '/foo', '#^/foo/(?P<bar>[^/]++)/(?P<foobar>[^/]++)$#sD', ['bar', 'foobar'], [
+                '/foo', '{^/foo/(?P<bar>[^/]++)/(?P<foobar>[^/]++)$}sD', ['bar', 'foobar'], [
                     ['variable', '/', '[^/]++', 'foobar'],
                     ['variable', '/', '[^/]++', 'bar'],
                     ['text', '/foo'],
@@ -74,7 +74,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with several variables that have default values',
                 ['/foo/{bar}/{foobar}', ['bar' => 'bar', 'foobar' => '']],
-                '/foo', '#^/foo(?:/(?P<bar>[^/]++)(?:/(?P<foobar>[^/]++))?)?$#sD', ['bar', 'foobar'], [
+                '/foo', '{^/foo(?:/(?P<bar>[^/]++)(?:/(?P<foobar>[^/]++))?)?$}sD', ['bar', 'foobar'], [
                     ['variable', '/', '[^/]++', 'foobar'],
                     ['variable', '/', '[^/]++', 'bar'],
                     ['text', '/foo'],
@@ -84,7 +84,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with several variables but some of them have no default values',
                 ['/foo/{bar}/{foobar}', ['bar' => 'bar']],
-                '/foo', '#^/foo/(?P<bar>[^/]++)/(?P<foobar>[^/]++)$#sD', ['bar', 'foobar'], [
+                '/foo', '{^/foo/(?P<bar>[^/]++)/(?P<foobar>[^/]++)$}sD', ['bar', 'foobar'], [
                     ['variable', '/', '[^/]++', 'foobar'],
                     ['variable', '/', '[^/]++', 'bar'],
                     ['text', '/foo'],
@@ -94,7 +94,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with an optional variable as the first segment',
                 ['/{bar}', ['bar' => 'bar']],
-                '', '#^/(?P<bar>[^/]++)?$#sD', ['bar'], [
+                '', '{^/(?P<bar>[^/]++)?$}sD', ['bar'], [
                     ['variable', '/', '[^/]++', 'bar'],
                 ],
             ],
@@ -102,7 +102,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with a requirement of 0',
                 ['/{bar}', ['bar' => null], ['bar' => '0']],
-                '', '#^/(?P<bar>0)?$#sD', ['bar'], [
+                '', '{^/(?P<bar>0)?$}sD', ['bar'], [
                     ['variable', '/', '0', 'bar'],
                 ],
             ],
@@ -110,7 +110,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with an optional variable as the first segment with requirements',
                 ['/{bar}', ['bar' => 'bar'], ['bar' => '(foo|bar)']],
-                '', '#^/(?P<bar>(?:foo|bar))?$#sD', ['bar'], [
+                '', '{^/(?P<bar>(?:foo|bar))?$}sD', ['bar'], [
                     ['variable', '/', '(?:foo|bar)', 'bar'],
                 ],
             ],
@@ -118,7 +118,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with only optional variables',
                 ['/{foo}/{bar}', ['foo' => 'foo', 'bar' => 'bar']],
-                '', '#^/(?P<foo>[^/]++)?(?:/(?P<bar>[^/]++))?$#sD', ['foo', 'bar'], [
+                '', '{^/(?P<foo>[^/]++)?(?:/(?P<bar>[^/]++))?$}sD', ['foo', 'bar'], [
                     ['variable', '/', '[^/]++', 'bar'],
                     ['variable', '/', '[^/]++', 'foo'],
                 ],
@@ -127,7 +127,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with a variable in last position',
                 ['/foo-{bar}'],
-                '/foo-', '#^/foo\-(?P<bar>[^/]++)$#sD', ['bar'], [
+                '/foo-', '{^/foo\-(?P<bar>[^/]++)$}sD', ['bar'], [
                     ['variable', '-', '[^/]++', 'bar'],
                     ['text', '/foo'],
                 ],
@@ -136,7 +136,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with nested placeholders',
                 ['/{static{var}static}'],
-                '/{static', '#^/\{static(?P<var>[^/]+)static\}$#sD', ['var'], [
+                '/{static', '{^/\{static(?P<var>[^/]+)static\}$}sD', ['var'], [
                     ['text', 'static}'],
                     ['variable', '', '[^/]+', 'var'],
                     ['text', '/{static'],
@@ -146,7 +146,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route without separator between variables',
                 ['/{w}{x}{y}{z}.{_format}', ['z' => 'default-z', '_format' => 'html'], ['y' => '(y|Y)']],
-                '', '#^/(?P<w>[^/\.]+)(?P<x>[^/\.]+)(?P<y>(?:y|Y))(?:(?P<z>[^/\.]++)(?:\.(?P<_format>[^/]++))?)?$#sD', ['w', 'x', 'y', 'z', '_format'], [
+                '', '{^/(?P<w>[^/\.]+)(?P<x>[^/\.]+)(?P<y>(?:y|Y))(?:(?P<z>[^/\.]++)(?:\.(?P<_format>[^/]++))?)?$}sD', ['w', 'x', 'y', 'z', '_format'], [
                     ['variable', '.', '[^/]++', '_format'],
                     ['variable', '', '[^/\.]++', 'z'],
                     ['variable', '', '(?:y|Y)', 'y'],
@@ -158,7 +158,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with a format',
                 ['/foo/{bar}.{_format}'],
-                '/foo', '#^/foo/(?P<bar>[^/\.]++)\.(?P<_format>[^/]++)$#sD', ['bar', '_format'], [
+                '/foo', '{^/foo/(?P<bar>[^/\.]++)\.(?P<_format>[^/]++)$}sD', ['bar', '_format'], [
                     ['variable', '.', '[^/]++', '_format'],
                     ['variable', '/', '[^/\.]++', 'bar'],
                     ['text', '/foo'],
@@ -168,7 +168,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Static non UTF-8 route',
                 ["/fo\xE9"],
-                "/fo\xE9", "#^/fo\xE9$#sD", [], [
+                "/fo\xE9", "{^/fo\xE9$}sD", [], [
                     ['text', "/fo\xE9"],
                 ],
             ],
@@ -176,7 +176,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with an explicit UTF-8 requirement',
                 ['/{bar}', ['bar' => null], ['bar' => '.'], ['utf8' => true]],
-                '', '#^/(?P<bar>.)?$#sDu', ['bar'], [
+                '', '{^/(?P<bar>.)?$}sDu', ['bar'], [
                     ['variable', '/', '.', 'bar', true],
                 ],
             ],
@@ -199,13 +199,13 @@ class RouteCompilerTest extends TestCase
         $this->assertEquals($tokens, $compiled->getTokens(), $name.' (tokens)');
     }
 
-    public function provideCompileImplicitUtf8Data()
+    public static function provideCompileImplicitUtf8Data()
     {
         return [
             [
                 'Static UTF-8 route',
                 ['/foé'],
-                '/foé', '#^/foé$#sDu', [], [
+                '/foé', '{^/foé$}sDu', [], [
                     ['text', '/foé'],
                 ],
                 'patterns',
@@ -214,7 +214,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with an implicit UTF-8 requirement',
                 ['/{bar}', ['bar' => null], ['bar' => 'é']],
-                '', '#^/(?P<bar>é)?$#sDu', ['bar'], [
+                '', '{^/(?P<bar>é)?$}sDu', ['bar'], [
                     ['variable', '/', 'é', 'bar', true],
                 ],
                 'requirements',
@@ -223,7 +223,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with a UTF-8 class requirement',
                 ['/{bar}', ['bar' => null], ['bar' => '\pM']],
-                '', '#^/(?P<bar>\pM)?$#sDu', ['bar'], [
+                '', '{^/(?P<bar>\pM)?$}sDu', ['bar'], [
                     ['variable', '/', '\pM', 'bar', true],
                 ],
                 'requirements',
@@ -232,7 +232,7 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with a UTF-8 separator',
                 ['/foo/{bar}§{_format}', [], [], ['compiler_class' => Utf8RouteCompiler::class]],
-                '/foo', '#^/foo/(?P<bar>[^/§]++)§(?P<_format>[^/]++)$#sDu', ['bar', '_format'], [
+                '/foo', '{^/foo/(?P<bar>[^/§]++)§(?P<_format>[^/]++)$}sDu', ['bar', '_format'], [
                     ['variable', '§', '[^/]++', '_format', true],
                     ['variable', '/', '[^/§]++', 'bar', true],
                     ['text', '/foo'],
@@ -284,7 +284,7 @@ class RouteCompilerTest extends TestCase
         $route->compile();
     }
 
-    public function getVariableNamesStartingWithADigit()
+    public static function getVariableNamesStartingWithADigit()
     {
         return [
            ['09'],
@@ -312,27 +312,27 @@ class RouteCompilerTest extends TestCase
         $this->assertEquals($hostTokens, $compiled->getHostTokens(), $name.' (host tokens)');
     }
 
-    public function provideCompileWithHostData()
+    public static function provideCompileWithHostData()
     {
         return [
             [
                 'Route with host pattern',
                 ['/hello', [], [], [], 'www.example.com'],
-                '/hello', '#^/hello$#sD', [], [], [
+                '/hello', '{^/hello$}sD', [], [], [
                     ['text', '/hello'],
                 ],
-                '#^www\.example\.com$#sDi', [], [
+                '{^www\.example\.com$}sDi', [], [
                     ['text', 'www.example.com'],
                 ],
             ],
             [
                 'Route with host pattern and some variables',
                 ['/hello/{name}', [], [], [], 'www.example.{tld}'],
-                '/hello', '#^/hello/(?P<name>[^/]++)$#sD', ['tld', 'name'], ['name'], [
+                '/hello', '{^/hello/(?P<name>[^/]++)$}sD', ['tld', 'name'], ['name'], [
                     ['variable', '/', '[^/]++', 'name'],
                     ['text', '/hello'],
                 ],
-                '#^www\.example\.(?P<tld>[^\.]++)$#sDi', ['tld'], [
+                '{^www\.example\.(?P<tld>[^\.]++)$}sDi', ['tld'], [
                     ['variable', '.', '[^\.]++', 'tld'],
                     ['text', 'www.example'],
                 ],
@@ -340,10 +340,10 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with variable at beginning of host',
                 ['/hello', [], [], [], '{locale}.example.{tld}'],
-                '/hello', '#^/hello$#sD', ['locale', 'tld'], [], [
+                '/hello', '{^/hello$}sD', ['locale', 'tld'], [], [
                     ['text', '/hello'],
                 ],
-                '#^(?P<locale>[^\.]++)\.example\.(?P<tld>[^\.]++)$#sDi', ['locale', 'tld'], [
+                '{^(?P<locale>[^\.]++)\.example\.(?P<tld>[^\.]++)$}sDi', ['locale', 'tld'], [
                     ['variable', '.', '[^\.]++', 'tld'],
                     ['text', '.example'],
                     ['variable', '', '[^\.]++', 'locale'],
@@ -352,10 +352,10 @@ class RouteCompilerTest extends TestCase
             [
                 'Route with host variables that has a default value',
                 ['/hello', ['locale' => 'a', 'tld' => 'b'], [], [], '{locale}.example.{tld}'],
-                '/hello', '#^/hello$#sD', ['locale', 'tld'], [], [
+                '/hello', '{^/hello$}sD', ['locale', 'tld'], [], [
                     ['text', '/hello'],
                 ],
-                '#^(?P<locale>[^\.]++)\.example\.(?P<tld>[^\.]++)$#sDi', ['locale', 'tld'], [
+                '{^(?P<locale>[^\.]++)\.example\.(?P<tld>[^\.]++)$}sDi', ['locale', 'tld'], [
                     ['variable', '.', '[^\.]++', 'tld'],
                     ['text', '.example'],
                     ['variable', '', '[^\.]++', 'locale'],
@@ -381,14 +381,14 @@ class RouteCompilerTest extends TestCase
         $this->assertSame($regex, $route->compile()->getRegex());
     }
 
-    public function provideRemoveCapturingGroup()
+    public static function provideRemoveCapturingGroup()
     {
-        yield ['#^/(?P<foo>a(?:b|c)(?:d|e)f)$#sD', 'a(b|c)(d|e)f'];
-        yield ['#^/(?P<foo>a\(b\)c)$#sD', 'a\(b\)c'];
-        yield ['#^/(?P<foo>(?:b))$#sD', '(?:b)'];
-        yield ['#^/(?P<foo>(?(b)b))$#sD', '(?(b)b)'];
-        yield ['#^/(?P<foo>(*F))$#sD', '(*F)'];
-        yield ['#^/(?P<foo>(?:(?:foo)))$#sD', '((foo))'];
+        yield ['{^/(?P<foo>a(?:b|c)(?:d|e)f)$}sD', 'a(b|c)(d|e)f'];
+        yield ['{^/(?P<foo>a\(b\)c)$}sD', 'a\(b\)c'];
+        yield ['{^/(?P<foo>(?:b))$}sD', '(?:b)'];
+        yield ['{^/(?P<foo>(?(b)b))$}sD', '(?(b)b)'];
+        yield ['{^/(?P<foo>(*F))$}sD', '(*F)'];
+        yield ['{^/(?P<foo>(?:(?:foo)))$}sD', '((foo))'];
     }
 }
 
