@@ -17,6 +17,9 @@ use Symfony\Component\ExpressionLanguage\ExpressionLanguage as BaseExpressionLan
 if (!class_exists(BaseExpressionLanguage::class)) {
     throw new \LogicException(sprintf('The "%s" class requires the "ExpressionLanguage" component. Try running "composer require symfony/expression-language".', ExpressionLanguage::class));
 } else {
+    // Help opcache.preload discover always-needed symbols
+    class_exists(ExpressionLanguageProvider::class);
+
     /**
      * Adds some function to the default ExpressionLanguage.
      *
