@@ -21,11 +21,18 @@ use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
  */
 class AuthenticationException extends RuntimeException
 {
+    /** @internal */
+    protected $serialized;
+
     private $token;
 
+    public function __construct(string $message = '', int $code = 0, \Throwable $previous = null)
+    {
+        unset($this->serialized);
+        parent::__construct($message, $code, $previous);
+    }
+
     /**
-     * Get the token.
-     *
      * @return TokenInterface|null
      */
     public function getToken()
@@ -58,25 +65,6 @@ class AuthenticationException extends RuntimeException
         return [$this->token, $this->code, $this->message, $this->file, $this->line];
     }
 
-    /**
-     * {@inheritdoc}
-     *
-     * @final since Symfony 4.3, use __serialize() instead
-     *
-     * @internal since Symfony 4.3, use __serialize() instead
-     */
-    public function serialize()
-    {
-        $serialized = $this->__serialize();
-
-        if (null === $isCalledFromOverridingMethod = \func_num_args() ? func_get_arg(0) : null) {
-            $trace = debug_backtrace(\DEBUG_BACKTRACE_PROVIDE_OBJECT, 2);
-            $isCalledFromOverridingMethod = isset($trace[1]['function'], $trace[1]['object']) && 'serialize' === $trace[1]['function'] && $this === $trace[1]['object'];
-        }
-
-        return $isCalledFromOverridingMethod ? $serialized : serialize($serialized);
-    }
-
     /**
      * Restores the object state from an array given by __serialize().
      *
@@ -98,48 +86,6 @@ class AuthenticationException extends RuntimeException
         [$this->token, $this->code, $this->message, $this->file, $this->line] = $data;
     }
 
-    /**
-     * {@inheritdoc}
-     *
-     * @final since Symfony 4.3, use __unserialize() instead
-     *
-     * @internal since Symfony 4.3, use __unserialize() instead
-     */
-    public function unserialize($serialized)
-    {
-        $this->__unserialize(\is_array($serialized) ? $serialized : unserialize($serialized));
-    }
-
-    /**
-     * @internal
-     */
-    public function __sleep(): array
-    {
-        if (__CLASS__ !== $c = (new \ReflectionMethod($this, 'serialize'))->getDeclaringClass()->name) {
-            @trigger_error(sprintf('Implementing the "%s::serialize()" method is deprecated since Symfony 4.3, implement the __serialize() and __unserialize() methods instead.', $c), \E_USER_DEPRECATED);
-            $this->serialized = $this->serialize();
-        } else {
-            $this->serialized = $this->__serialize();
-        }
-
-        return ['serialized'];
-    }
-
-    /**
-     * @internal
-     */
-    public function __wakeup()
-    {
-        if (__CLASS__ !== $c = (new \ReflectionMethod($this, 'unserialize'))->getDeclaringClass()->name) {
-            @trigger_error(sprintf('Implementing the "%s::unserialize()" method is deprecated since Symfony 4.3, implement the __serialize() and __unserialize() methods instead.', $c), \E_USER_DEPRECATED);
-            $this->unserialize($this->serialized);
-        } else {
-            $this->__unserialize($this->serialized);
-        }
-
-        unset($this->serialized);
-    }
-
     /**
      * Message key to be used by the translation component.
      *
@@ -159,4 +105,23 @@ class AuthenticationException extends RuntimeException
     {
         return [];
     }
+
+    /**
+     * @internal
+     */
+    public function __sleep(): array
+    {
+        $this->serialized = $this->__serialize();
+
+        return ['serialized'];
+    }
+
+    /**
+     * @internal
+     */
+    public function __wakeup(): void
+    {
+        $this->__unserialize($this->serialized);
+        unset($this->serialized);
+    }
 }
