@@ -123,9 +123,15 @@ class LdapBindAuthenticationProviderTest extends TestCase
         $ldap = $this->createMock(LdapInterface::class);
         $ldap
             ->method('bind')
-            ->withConsecutive(
-                ['elsa', 'test1234A$']
-            );
+            ->willReturnCallback(function (...$args) {
+                static $series = [
+                    ['elsa', 'test1234A$'],
+                    ['', 'bar'],
+                ];
+
+                $this->assertSame(array_shift($series), $args);
+            })
+        ;
         $ldap
             ->expects($this->once())
             ->method('escape')
@@ -169,9 +175,15 @@ class LdapBindAuthenticationProviderTest extends TestCase
         $ldap = $this->createMock(LdapInterface::class);
         $ldap
             ->method('bind')
-            ->withConsecutive(
-                ['elsa', 'test1234A$']
-            );
+            ->willReturnCallback(function (...$args) {
+                static $series = [
+                    ['elsa', 'test1234A$'],
+                    ['', 'bar'],
+                ];
+
+                $this->assertSame(array_shift($series), $args);
+            })
+        ;
         $ldap
             ->expects($this->once())
             ->method('escape')
@@ -213,9 +225,15 @@ class LdapBindAuthenticationProviderTest extends TestCase
         $ldap = $this->createMock(LdapInterface::class);
         $ldap
             ->method('bind')
-            ->withConsecutive(
-                ['elsa', 'test1234A$']
-            );
+            ->willReturnCallback(function (...$args) {
+                static $series = [
+                    ['elsa', 'test1234A$'],
+                    ['', 'bar'],
+                ];
+
+                $this->assertSame(array_shift($series), $args);
+            })
+        ;
         $ldap
             ->expects($this->once())
             ->method('query')
