@@ -14,6 +14,7 @@ namespace Symfony\Component\Security\Core\Tests\Authentication\Token\Storage;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorage;
 use Symfony\Component\Security\Core\Authentication\Token\UsernamePasswordToken;
+use Symfony\Component\Security\Core\User\InMemoryUser;
 
 class TokenStorageTest extends TestCase
 {
@@ -21,7 +22,7 @@ class TokenStorageTest extends TestCase
     {
         $tokenStorage = new TokenStorage();
         $this->assertNull($tokenStorage->getToken());
-        $token = new UsernamePasswordToken('username', 'password', 'provider');
+        $token = new UsernamePasswordToken(new InMemoryUser('username', 'password'), 'provider');
         $tokenStorage->setToken($token);
         $this->assertSame($token, $tokenStorage->getToken());
     }
