@@ -13,20 +13,43 @@ namespace Symfony\Component\Security\Core\Tests\Authentication\Token;
 
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Security\Core\Authentication\Token\UsernamePasswordToken;
+use Symfony\Component\Security\Core\User\InMemoryUser;
 
 class UsernamePasswordTokenTest extends TestCase
 {
     public function testConstructor()
+    {
+        $token = new UsernamePasswordToken(new InMemoryUser('foo', 'bar', ['ROLE_FOO']), 'key', ['ROLE_FOO']);
+        $this->assertEquals(['ROLE_FOO'], $token->getRoleNames());
+        $this->assertEquals('key', $token->getFirewallName());
+    }
+
+    /**
+     * @group legacy
+     */
+    public function testLegacyConstructor()
+    {
+        $token = new UsernamePasswordToken('foo', 'bar', 'key', ['ROLE_FOO']);
+        $this->assertEquals(['ROLE_FOO'], $token->getRoleNames());
+        $this->assertEquals('bar', $token->getCredentials());
+        $this->assertEquals('key', $token->getFirewallName());
+    }
+
+    /**
+     * @group legacy
+     */
+    public function testIsAuthenticated()
     {
         $token = new UsernamePasswordToken('foo', 'bar', 'key');
         $this->assertFalse($token->isAuthenticated());
 
         $token = new UsernamePasswordToken('foo', 'bar', 'key', ['ROLE_FOO']);
-        $this->assertEquals(['ROLE_FOO'], $token->getRoleNames());
         $this->assertTrue($token->isAuthenticated());
-        $this->assertEquals('key', $token->getFirewallName());
     }
 
+    /**
+     * @group legacy
+     */
     public function testSetAuthenticatedToTrue()
     {
         $this->expectException(\LogicException::class);
@@ -34,6 +57,9 @@ class UsernamePasswordTokenTest extends TestCase
         $token->setAuthenticated(true);
     }
 
+    /**
+     * @group legacy
+     */
     public function testSetAuthenticatedToFalse()
     {
         $token = new UsernamePasswordToken('foo', 'bar', 'key');
@@ -41,6 +67,9 @@ class UsernamePasswordTokenTest extends TestCase
         $this->assertFalse($token->isAuthenticated());
     }
 
+    /**
+     * @group legacy
+     */
     public function testEraseCredentials()
     {
         $token = new UsernamePasswordToken('foo', 'bar', 'key');
@@ -50,7 +79,7 @@ class UsernamePasswordTokenTest extends TestCase
 
     public function testToString()
     {
-        $token = new UsernamePasswordToken('foo', '', 'foo', ['A', 'B']);
+        $token = new UsernamePasswordToken(new InMemoryUser('foo', '', ['A', 'B']), 'foo', ['A', 'B']);
         $this->assertEquals('UsernamePasswordToken(user="foo", authenticated=true, roles="A, B")', (string) $token);
     }
 }
