@@ -117,7 +117,7 @@ class AuthorizationCheckerTest extends TestCase
         $this->assertSame($decide, $this->authorizationChecker->isGranted('ROLE_FOO'));
     }
 
-    public function isGrantedProvider()
+    public static function isGrantedProvider()
     {
         return [[true], [false]];
     }
