@@ -33,7 +33,7 @@ class AuthenticatedVoterTest extends TestCase
         $this->assertSame($expected, $voter->vote($this->getToken($authenticated), null, $attributes));
     }
 
-    public function getVoteTests()
+    public static function getVoteTests()
     {
         return [
             ['fully', [], VoterInterface::ACCESS_ABSTAIN],
@@ -55,6 +55,7 @@ class AuthenticatedVoterTest extends TestCase
 
     /**
      * @group legacy
+     *
      * @dataProvider getLegacyVoteTests
      */
     public function testLegacyVote($authenticated, $attributes, $expected)
@@ -62,7 +63,7 @@ class AuthenticatedVoterTest extends TestCase
         $this->testVote($authenticated, $attributes, $expected);
     }
 
-    public function getLegacyVoteTests()
+    public static function getLegacyVoteTests()
     {
         return [
             ['anonymously', [], VoterInterface::ACCESS_ABSTAIN],
@@ -93,7 +94,7 @@ class AuthenticatedVoterTest extends TestCase
         $this->assertSame($expected, $voter->supportsAttribute($attribute));
     }
 
-    public function provideAttributes()
+    public static function provideAttributes()
     {
         yield [AuthenticatedVoter::IS_AUTHENTICATED_FULLY, true];
         yield [AuthenticatedVoter::IS_AUTHENTICATED_REMEMBERED, true];
