@@ -14,7 +14,11 @@ namespace Symfony\Component\Security\Core\Tests\Encoder;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Security\Core\Encoder\MessageDigestPasswordEncoder;
 use Symfony\Component\Security\Core\Exception\BadCredentialsException;
+use Symfony\Component\Security\Core\Tests\Encoder\Fixtures\MyMessageDigestPasswordEncoder;
 
+/**
+ * @group legacy
+ */
 class MessageDigestPasswordEncoderTest extends TestCase
 {
     public function testIsPasswordValid()
@@ -57,4 +61,13 @@ class MessageDigestPasswordEncoderTest extends TestCase
 
         $this->assertFalse($encoder->isPasswordValid('encoded', str_repeat('a', 5000), 'salt'));
     }
+
+    public function testCustomEncoder()
+    {
+        $encoder = new MyMessageDigestPasswordEncoder();
+        $encodedPassword = $encoder->encodePassword('p4ssw0rd', 's417');
+
+        $this->assertSame(base64_encode(hash('sha512', '{"password":"p4ssw0rd","salt":"s417"}', true)), $encodedPassword);
+        $this->assertTrue($encoder->isPasswordValid($encodedPassword, 'p4ssw0rd', 's417'));
+    }
 }
