@@ -16,6 +16,8 @@ use Symfony\Component\Security\Core\Encoder\NativePasswordEncoder;
 
 /**
  * @author Elnur Abdurrakhimov <elnur@elnur.pro>
+ *
+ * @group legacy
  */
 class NativePasswordEncoderTest extends TestCase
 {
@@ -39,7 +41,7 @@ class NativePasswordEncoderTest extends TestCase
         $this->assertInstanceOf(NativePasswordEncoder::class, new NativePasswordEncoder(null, null, $cost));
     }
 
-    public function validRangeData()
+    public static function validRangeData()
     {
         $costs = range(4, 31);
         array_walk($costs, function (&$cost) { $cost = [$cost]; });
