@@ -59,7 +59,7 @@ class SecurityTest extends TestCase
         $this->assertSame($expectedUser, $security->getUser());
     }
 
-    public function getUserTests()
+    public static function getUserTests()
     {
         yield [null, null];
 
@@ -70,7 +70,7 @@ class SecurityTest extends TestCase
     /**
      * @group legacy
      */
-    public function getLegacyUserTests()
+    public static function getLegacyUserTests()
     {
         yield ['string_username', null];
 
