@@ -11,13 +11,11 @@
 
 namespace Symfony\Component\Security\Core\User;
 
-use Symfony\Component\Security\Core\Role\Role;
-
 /**
  * Represents the interface that all user classes must implement.
  *
  * This interface is useful because the authentication layer can deal with
- * the object through its lifecycle, using the object to get the encoded
+ * the object through its lifecycle, using the object to get the hashed
  * password (for checking against a submitted password), assigning roles
  * and so on.
  *
@@ -28,6 +26,8 @@ use Symfony\Component\Security\Core\Role\Role;
  *
  * @see UserProviderInterface
  *
+ * @method string getUserIdentifier() returns the identifier for this user (e.g. its username or email address)
+ *
  * @author Fabien Potencier <fabien@symfony.com>
  */
 interface UserInterface
@@ -40,40 +40,37 @@ interface UserInterface
      *         return ['ROLE_USER'];
      *     }
      *
-     * Alternatively, the roles might be stored on a ``roles`` property,
+     * Alternatively, the roles might be stored in a ``roles`` property,
      * and populated in any number of different ways when the user object
      * is created.
      *
-     * @return (Role|string)[] The user roles
+     * @return string[]
      */
     public function getRoles();
 
     /**
      * Returns the password used to authenticate the user.
      *
-     * This should be the encoded password. On authentication, a plain-text
-     * password will be salted, encoded, and then compared to this value.
+     * This should be the hashed password. On authentication, a plain-text
+     * password will be hashed, and then compared to this value.
      *
-     * @return string|null The encoded password if any
+     * This method is deprecated since Symfony 5.3, implement it from {@link PasswordAuthenticatedUserInterface} instead.
+     *
+     * @return string|null
      */
     public function getPassword();
 
     /**
-     * Returns the salt that was originally used to encode the password.
+     * Returns the salt that was originally used to hash the password.
      *
-     * This can return null if the password was not encoded using a salt.
+     * This can return null if the password was not hashed using a salt.
      *
-     * @return string|null The salt
+     * This method is deprecated since Symfony 5.3, implement it from {@link LegacyPasswordAuthenticatedUserInterface} instead.
+     *
+     * @return string|null
      */
     public function getSalt();
 
-    /**
-     * Returns the username used to authenticate the user.
-     *
-     * @return string The username
-     */
-    public function getUsername();
-
     /**
      * Removes sensitive data from the user.
      *
@@ -81,4 +78,11 @@ interface UserInterface
      * the plain-text password is stored on this object.
      */
     public function eraseCredentials();
+
+    /**
+     * @return string
+     *
+     * @deprecated since Symfony 5.3, use getUserIdentifier() instead
+     */
+    public function getUsername();
 }
