@@ -32,6 +32,7 @@ use Symfony\Component\Security\Http\RememberMe\RememberMeServicesInterface;
 /**
  * @author Ryan Weaver <weaverryan@gmail.com>
  * @author Amaury Leroux de Lens <amaury@lerouxdelens.com>
+ *
  * @group legacy
  */
 class GuardAuthenticationListenerTest extends TestCase
@@ -256,7 +257,7 @@ class GuardAuthenticationListenerTest extends TestCase
         $listener($this->event);
     }
 
-    public function exceptionsToHide()
+    public static function exceptionsToHide()
     {
         return [
             [new UserNotFoundException()],
