@@ -14,12 +14,17 @@ namespace Symfony\Component\Security\Http\EntryPoint;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpKernel\HttpKernelInterface;
 use Symfony\Component\Security\Core\Exception\AuthenticationException;
+use Symfony\Component\Security\Http\Authenticator\FormLoginAuthenticator;
 use Symfony\Component\Security\Http\HttpUtils;
 
+trigger_deprecation('symfony/security-http', '5.4', 'The "%s" class is deprecated, use the new security system with "%s" instead.', FormAuthenticationEntryPoint::class, FormLoginAuthenticator::class);
+
 /**
  * FormAuthenticationEntryPoint starts an authentication via a login form.
  *
  * @author Fabien Potencier <fabien@symfony.com>
+ *
+ * @deprecated since Symfony 5.4
  */
 class FormAuthenticationEntryPoint implements AuthenticationEntryPointInterface
 {
@@ -29,9 +34,8 @@ class FormAuthenticationEntryPoint implements AuthenticationEntryPointInterface
     private $httpUtils;
 
     /**
-     * @param HttpUtils $httpUtils  An HttpUtils instance
-     * @param string    $loginPath  The path to the login form
-     * @param bool      $useForward Whether to forward or redirect to the login form
+     * @param string $loginPath  The path to the login form
+     * @param bool   $useForward Whether to forward or redirect to the login form
      */
     public function __construct(HttpKernelInterface $kernel, HttpUtils $httpUtils, string $loginPath, bool $useForward = false)
     {
