@@ -20,16 +20,20 @@ use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
 use Symfony\Component\Security\Core\Exception\AuthenticationException;
 use Symfony\Component\Security\Core\Exception\CookieTheftException;
 use Symfony\Component\Security\Core\Exception\UnsupportedUserException;
-use Symfony\Component\Security\Core\Exception\UsernameNotFoundException;
+use Symfony\Component\Security\Core\Exception\UserNotFoundException;
 use Symfony\Component\Security\Core\User\UserInterface;
 use Symfony\Component\Security\Core\User\UserProviderInterface;
 use Symfony\Component\Security\Http\Logout\LogoutHandlerInterface;
 use Symfony\Component\Security\Http\ParameterBagUtils;
 
+trigger_deprecation('symfony/security-http', '5.4', 'The "%s" class is deprecated, use "%s" instead.', AbstractRememberMeServices::class, AbstractRememberMeHandler::class);
+
 /**
  * Base class implementing the RememberMeServicesInterface.
  *
  * @author Johannes M. Schmitt <schmittjoh@gmail.com>
+ *
+ * @deprecated since Symfony 5.4, use {@see AbstractRememberMeHandler} instead
  */
 abstract class AbstractRememberMeServices implements RememberMeServicesInterface, LogoutHandlerInterface
 {
@@ -40,21 +44,26 @@ abstract class AbstractRememberMeServices implements RememberMeServicesInterface
         'secure' => false,
         'httponly' => true,
         'samesite' => null,
+        'path' => null,
+        'domain' => null,
     ];
-    private $providerKey;
+    private $firewallName;
     private $secret;
     private $userProviders;
 
     /**
      * @throws \InvalidArgumentException
      */
-    public function __construct(array $userProviders, string $secret, string $providerKey, array $options = [], LoggerInterface $logger = null)
+    public function __construct(iterable $userProviders, string $secret, string $firewallName, array $options = [], LoggerInterface $logger = null)
     {
         if (empty($secret)) {
             throw new \InvalidArgumentException('$secret must not be empty.');
         }
-        if (empty($providerKey)) {
-            throw new \InvalidArgumentException('$providerKey must not be empty.');
+        if ('' === $firewallName) {
+            throw new \InvalidArgumentException('$firewallName must not be empty.');
+        }
+        if (!\is_array($userProviders) && !$userProviders instanceof \Countable) {
+            $userProviders = iterator_to_array($userProviders, false);
         }
         if (0 === \count($userProviders)) {
             throw new \InvalidArgumentException('You must provide at least one user provider.');
@@ -62,7 +71,7 @@ abstract class AbstractRememberMeServices implements RememberMeServicesInterface
 
         $this->userProviders = $userProviders;
         $this->secret = $secret;
-        $this->providerKey = $providerKey;
+        $this->firewallName = $firewallName;
         $this->options = array_merge($this->options, $options);
         $this->logger = $logger;
     }
@@ -120,12 +129,12 @@ abstract class AbstractRememberMeServices implements RememberMeServicesInterface
                 $this->logger->info('Remember-me cookie accepted.');
             }
 
-            return new RememberMeToken($user, $this->providerKey, $this->secret);
+            return new RememberMeToken($user, $this->firewallName, $this->secret);
         } catch (CookieTheftException $e) {
             $this->loginFail($request, $e);
 
             throw $e;
-        } catch (UsernameNotFoundException $e) {
+        } catch (UserNotFoundException $e) {
             if (null !== $this->logger) {
                 $this->logger->info('User for remember-me cookie not found.', ['exception' => $e]);
             }
@@ -241,11 +250,9 @@ abstract class AbstractRememberMeServices implements RememberMeServicesInterface
     /**
      * Decodes the raw cookie value.
      *
-     * @param string $rawCookie
-     *
      * @return array
      */
-    protected function decodeCookie($rawCookie)
+    protected function decodeCookie(string $rawCookie)
     {
         return explode(self::COOKIE_DELIMITER, base64_decode($rawCookie));
     }
@@ -260,7 +267,7 @@ abstract class AbstractRememberMeServices implements RememberMeServicesInterface
     protected function encodeCookie(array $cookieParts)
     {
         foreach ($cookieParts as $cookiePart) {
-            if (false !== strpos($cookiePart, self::COOKIE_DELIMITER)) {
+            if (str_contains($cookiePart, self::COOKIE_DELIMITER)) {
                 throw new \InvalidArgumentException(sprintf('$cookieParts should not contain the cookie delimiter "%s".', self::COOKIE_DELIMITER));
             }
         }
