@@ -38,7 +38,7 @@ class DefaultAuthenticationSuccessHandlerTest extends TestCase
         $this->assertSame('http://localhost'.$redirectedUrl, $handler->onAuthenticationSuccess($request, $token)->getTargetUrl());
     }
 
-    public function getRequestRedirections()
+    public function testRequestRedirectionsWithTargetPathInSessions()
     {
         $session = $this->createMock(SessionInterface::class);
         $session->expects($this->once())->method('get')->with('_security.admin.target_path')->willReturn('/admin/dashboard');
@@ -46,6 +46,18 @@ class DefaultAuthenticationSuccessHandlerTest extends TestCase
         $requestWithSession = Request::create('/');
         $requestWithSession->setSession($session);
 
+        $urlGenerator = $this->createMock(UrlGeneratorInterface::class);
+        $urlGenerator->expects($this->any())->method('generate')->willReturn('http://localhost/login');
+        $httpUtils = new HttpUtils($urlGenerator);
+        $token = $this->createMock(TokenInterface::class);
+        $handler = new DefaultAuthenticationSuccessHandler($httpUtils);
+        $handler->setFirewallName('admin');
+
+        $this->assertSame('http://localhost/admin/dashboard', $handler->onAuthenticationSuccess($requestWithSession, $token)->getTargetUrl());
+    }
+
+    public static function getRequestRedirections()
+    {
         return [
             'default' => [
                 Request::create('/'),
@@ -72,11 +84,6 @@ class DefaultAuthenticationSuccessHandlerTest extends TestCase
                 ['target_path_parameter' => '_target_path[value]'],
                 '/dashboard',
             ],
-            'target path in session' => [
-                $requestWithSession,
-                [],
-                '/admin/dashboard',
-            ],
             'target path as referer' => [
                 Request::create('/', 'GET', [], [], [], ['HTTP_REFERER' => 'http://localhost/dashboard']),
                 ['use_referer' => true],
