@@ -119,7 +119,7 @@ class AbstractRememberMeServicesTest extends TestCase
         $this->assertSame($options['httponly'], $cookie->isHttpOnly());
     }
 
-    public function provideOptionsForLogout()
+    public static function provideOptionsForLogout()
     {
         return [
             [['name' => 'foo', 'path' => '/', 'domain' => null, 'secure' => false, 'httponly' => true]],
@@ -259,7 +259,7 @@ class AbstractRememberMeServicesTest extends TestCase
         $service->loginSuccess($request, $response, $token);
     }
 
-    public function getPositiveRememberMeParameterValues()
+    public static function getPositiveRememberMeParameterValues()
     {
         return [
             ['true'],
