@@ -14,6 +14,7 @@ namespace Symfony\Component\Serializer\Tests\Encoder;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Serializer\Encoder\JsonDecode;
 use Symfony\Component\Serializer\Encoder\JsonEncoder;
+use Symfony\Component\Serializer\Exception\UnexpectedValueException;
 
 class JsonDecodeTest extends TestCase
 {
@@ -42,7 +43,7 @@ class JsonDecodeTest extends TestCase
         );
     }
 
-    public function decodeProvider()
+    public static function decodeProvider()
     {
         $stdClass = new \stdClass();
         $stdClass->foo = 'bar';
@@ -60,11 +61,11 @@ class JsonDecodeTest extends TestCase
      */
     public function testDecodeWithException($value)
     {
-        $this->expectException('Symfony\Component\Serializer\Exception\UnexpectedValueException');
+        $this->expectException(UnexpectedValueException::class);
         $this->decode->decode($value, JsonEncoder::FORMAT);
     }
 
-    public function decodeProviderException()
+    public static function decodeProviderException()
     {
         return [
             ["{'foo': 'bar'}"],
