@@ -13,6 +13,7 @@ namespace Symfony\Component\Serializer\Tests\Fixtures\Annotations;
 
 use Symfony\Component\Serializer\Annotation\Groups;
 use Symfony\Component\Serializer\Tests\Fixtures\GroupDummyInterface;
+use Symfony\Component\Serializer\Tests\Fixtures\ChildOfGroupsAnnotationDummy;
 
 /**
  * @author Kévin Dunglas <dunglas@gmail.com>
@@ -27,6 +28,11 @@ class GroupDummy extends GroupDummyParent implements GroupDummyInterface
      * @Groups({"b", "c", "name_converter"})
      */
     protected $bar;
+    /**
+     * @ChildOfGroupsAnnotationDummy
+     */
+    protected $quux;
+
     private $fooBar;
     private $symfony;
 
@@ -78,4 +84,14 @@ class GroupDummy extends GroupDummyParent implements GroupDummyInterface
     {
         return $this->symfony;
     }
+
+    public function getQuux()
+    {
+        return $this->quux;
+    }
+
+    public function setQuux($quux): void
+    {
+        $this->quux = $quux;
+    }
 }
