@@ -28,6 +28,7 @@ final class Php74Full
     /** @var Php74Full[] */
     public array $collection;
     public Php74FullWithConstructor $php74FullWithConstructor;
+    public Php74FullWithTypedConstructor $php74FullWithTypedConstructor;
     public DummyMessageInterface $dummyMessage;
     /** @var TestFoo[] $nestedArray */
     public TestFoo $nestedObject;
@@ -43,6 +44,13 @@ final class Php74FullWithConstructor
     }
 }
 
+final class Php74FullWithTypedConstructor
+{
+    public function __construct(float $something)
+    {
+    }
+}
+
 final class TestFoo
 {
     public int $int;
