@@ -13,6 +13,7 @@ namespace Symfony\Component\Serializer\Tests\Mapping\Factory;
 
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Cache\Adapter\ArrayAdapter;
+use Symfony\Component\Serializer\Exception\InvalidArgumentException;
 use Symfony\Component\Serializer\Mapping\ClassMetadata;
 use Symfony\Component\Serializer\Mapping\Factory\CacheClassMetadataFactory;
 use Symfony\Component\Serializer\Mapping\Factory\ClassMetadataFactoryInterface;
@@ -27,7 +28,7 @@ class CacheMetadataFactoryTest extends TestCase
     {
         $metadata = new ClassMetadata(Dummy::class);
 
-        $decorated = $this->getMockBuilder(ClassMetadataFactoryInterface::class)->getMock();
+        $decorated = $this->createMock(ClassMetadataFactoryInterface::class);
         $decorated
             ->expects($this->once())
             ->method('getMetadataFor')
@@ -43,7 +44,7 @@ class CacheMetadataFactoryTest extends TestCase
 
     public function testHasMetadataFor()
     {
-        $decorated = $this->getMockBuilder(ClassMetadataFactoryInterface::class)->getMock();
+        $decorated = $this->createMock(ClassMetadataFactoryInterface::class);
         $decorated
             ->expects($this->once())
             ->method('hasMetadataFor')
@@ -57,8 +58,8 @@ class CacheMetadataFactoryTest extends TestCase
 
     public function testInvalidClassThrowsException()
     {
-        $this->expectException('Symfony\Component\Serializer\Exception\InvalidArgumentException');
-        $decorated = $this->getMockBuilder(ClassMetadataFactoryInterface::class)->getMock();
+        $this->expectException(InvalidArgumentException::class);
+        $decorated = $this->createMock(ClassMetadataFactoryInterface::class);
         $factory = new CacheClassMetadataFactory($decorated, new ArrayAdapter());
 
         $factory->getMetadataFor('Not\Exist');
@@ -70,7 +71,7 @@ class CacheMetadataFactoryTest extends TestCase
         };
 
         $metadata = new ClassMetadata(\get_class($anonymousObject));
-        $decorated = $this->getMockBuilder(ClassMetadataFactoryInterface::class)->getMock();
+        $decorated = $this->createMock(ClassMetadataFactoryInterface::class);
         $decorated
             ->expects($this->once())
             ->method('getMetadataFor')
