@@ -1,5 +1,14 @@
 <?php
 
+/*
+ * This file is part of the Symfony package.
+ *
+ * (c) Fabien Potencier <fabien@symfony.com>
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
+
 namespace Symfony\Component\String\Tests;
 
 use PHPUnit\Framework\TestCase;
@@ -101,7 +110,7 @@ abstract class AbstractAsciiTestCase extends TestCase
         $this->assertEquals($expected, $actual);
     }
 
-    public function wordwrapProvider()
+    public static function wordwrapProvider()
     {
         return [
             [
@@ -1032,11 +1041,14 @@ abstract class AbstractAsciiTestCase extends TestCase
     {
         return [
             ['', ''],
+            ['xY', 'x_y'],
+            ['xuYo', 'xu_yo'],
             ['symfonyIsGreat', 'symfony_is_great'],
             ['symfony5IsGreat', 'symfony_5_is_great'],
             ['symfonyIsGreat', 'Symfony is great'],
             ['symfonyIsAGreatFramework', 'Symfony is a great framework'],
             ['symfonyIsGREAT', '*Symfony* is GREAT!!'],
+            ['SYMFONY', 'SYMFONY'],
         ];
     }
 
@@ -1054,6 +1066,9 @@ abstract class AbstractAsciiTestCase extends TestCase
     {
         return [
             ['', ''],
+            ['x_y', 'x_y'],
+            ['x_y', 'X_Y'],
+            ['xu_yo', 'xu_yo'],
             ['symfony_is_great', 'symfonyIsGreat'],
             ['symfony5_is_great', 'symfony5IsGreat'],
             ['symfony5is_great', 'symfony5isGreat'],
@@ -1061,6 +1076,7 @@ abstract class AbstractAsciiTestCase extends TestCase
             ['symfony_is_a_great_framework', 'symfonyIsAGreatFramework'],
             ['symfony_is_great', 'symfonyIsGREAT'],
             ['symfony_is_really_great', 'symfonyIsREALLYGreat'],
+            ['symfony', 'SYMFONY'],
         ];
     }
 
