@@ -54,6 +54,7 @@ class EnglishInflectorTest extends TestCase
             ['children', 'child'],
             ['circuses', ['circus', 'circuse', 'circusis']],
             ['cliffs', 'cliff'],
+            ['codes', 'code'],
             ['committee', 'committee'],
             ['crises', ['cris', 'crise', 'crisis']],
             ['criteria', ['criterion', 'criterium']],
@@ -108,6 +109,7 @@ class EnglishInflectorTest extends TestCase
             ['mice', 'mouse'],
             ['moves', 'move'],
             ['movies', 'movie'],
+            ['names', 'name'],
             ['nebulae', 'nebula'],
             ['neuroses', ['neuros', 'neurose', 'neurosis']],
             ['news', 'news'],
