@@ -12,7 +12,6 @@
 namespace Symfony\Component\Templating\Loader;
 
 use Symfony\Component\Templating\Storage\FileStorage;
-use Symfony\Component\Templating\Storage\Storage;
 use Symfony\Component\Templating\TemplateReferenceInterface;
 
 /**
@@ -39,9 +38,7 @@ class CacheLoader extends Loader
     }
 
     /**
-     * Loads a template.
-     *
-     * @return Storage|bool false if the template cannot be loaded, a Storage instance otherwise
+     * {@inheritdoc}
      */
     public function load(TemplateReferenceInterface $template)
     {
@@ -78,13 +75,9 @@ class CacheLoader extends Loader
     }
 
     /**
-     * Returns true if the template is still fresh.
-     *
-     * @param int $time The last modification time of the cached template (timestamp)
-     *
-     * @return bool
+     * {@inheritdoc}
      */
-    public function isFresh(TemplateReferenceInterface $template, $time)
+    public function isFresh(TemplateReferenceInterface $template, int $time)
     {
         return $this->loader->isFresh($template, $time);
     }
