@@ -24,7 +24,7 @@ interface LoaderInterface
     /**
      * Loads a template.
      *
-     * @return Storage|bool false if the template cannot be loaded, a Storage instance otherwise
+     * @return Storage|false
      */
     public function load(TemplateReferenceInterface $template);
 
@@ -35,5 +35,5 @@ interface LoaderInterface
      *
      * @return bool
      */
-    public function isFresh(TemplateReferenceInterface $template, $time);
+    public function isFresh(TemplateReferenceInterface $template, int $time);
 }
