@@ -31,17 +31,17 @@ abstract class Storage
     /**
      * Returns the object string representation.
      *
-     * @return string The template name
+     * @return string
      */
     public function __toString()
     {
-        return (string) $this->template;
+        return $this->template;
     }
 
     /**
      * Returns the content of the template.
      *
-     * @return string The template content
+     * @return string
      */
     abstract public function getContent();
 }
