@@ -38,7 +38,7 @@ class ProjectTemplateLoader4 extends Loader
         return $this->logger;
     }
 
-    public function isFresh(TemplateReferenceInterface $template, $time): bool
+    public function isFresh(TemplateReferenceInterface $template, int $time): bool
     {
         return false;
     }
