@@ -95,8 +95,12 @@ final class CrowdinProvider implements ProviderInterface
         }
 
         foreach ($responses as $response) {
-            if (200 !== $response->getStatusCode()) {
+            if (200 !== $statusCode = $response->getStatusCode()) {
                 $this->logger->error(sprintf('Unable to upload translations to Crowdin: "%s".', $response->getContent(false)));
+
+                if (500 <= $statusCode) {
+                    throw new ProviderException('Unable to upload translations to Crowdin.', $response);
+                }
             }
         }
     }
@@ -135,9 +139,13 @@ final class CrowdinProvider implements ProviderInterface
                 continue;
             }
 
-            if (200 !== $response->getStatusCode()) {
+            if (200 !== $statusCode = $response->getStatusCode()) {
                 $this->logger->error(sprintf('Unable to export file: "%s".', $response->getContent(false)));
 
+                if (500 <= $statusCode) {
+                    throw new ProviderException('Unable to export file.', $response);
+                }
+
                 continue;
             }
 
@@ -146,9 +154,13 @@ final class CrowdinProvider implements ProviderInterface
         }
 
         foreach ($downloads as [$response, $locale, $domain]) {
-            if (200 !== $response->getStatusCode()) {
+            if (200 !== $statusCode = $response->getStatusCode()) {
                 $this->logger->error(sprintf('Unable to download file content: "%s".', $response->getContent(false)));
 
+                if (500 <= $statusCode) {
+                    throw new ProviderException('Unable to download file content.', $response);
+                }
+
                 continue;
             }
 
@@ -192,8 +204,12 @@ final class CrowdinProvider implements ProviderInterface
                 continue;
             }
 
-            if (204 !== $response->getStatusCode()) {
+            if (204 !== $statusCode = $response->getStatusCode()) {
                 $this->logger->warning(sprintf('Unable to delete string: "%s".', $response->getContent(false)));
+
+                if (500 <= $statusCode) {
+                    throw new ProviderException('Unable to delete string.', $response);
+                }
             }
         }
     }
@@ -228,8 +244,8 @@ final class CrowdinProvider implements ProviderInterface
         $storageId = $this->addStorage($domain, $content);
 
         /**
-         * @see https://support.crowdin.com/api/v2/#operation/api.projects.files.getMany (Crowdin API)
-         * @see https://support.crowdin.com/enterprise/api/#operation/api.projects.files.getMany (Crowdin Enterprise API)
+         * @see https://developer.crowdin.com/api/v2/#operation/api.projects.files.getMany (Crowdin API)
+         * @see https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.files.getMany (Crowdin Enterprise API)
          */
         $response = $this->client->request('POST', 'files', [
             'json' => [
@@ -238,9 +254,13 @@ final class CrowdinProvider implements ProviderInterface
             ],
         ]);
 
-        if (201 !== $response->getStatusCode()) {
+        if (201 !== $statusCode = $response->getStatusCode()) {
             $this->logger->error(sprintf('Unable to create a File in Crowdin for domain "%s": "%s".', $domain, $response->getContent(false)));
 
+            if (500 <= $statusCode) {
+                throw new ProviderException(sprintf('Unable to create a File in Crowdin for domain "%s".', $domain), $response);
+            }
+
             return null;
         }
 
@@ -252,8 +272,8 @@ final class CrowdinProvider implements ProviderInterface
         $storageId = $this->addStorage($domain, $content);
 
         /**
-         * @see https://support.crowdin.com/api/v2/#operation/api.projects.files.put (Crowdin API)
-         * @see https://support.crowdin.com/enterprise/api/#operation/api.projects.files.put (Crowdin Enterprise API)
+         * @see https://developer.crowdin.com/api/v2/#operation/api.projects.files.put (Crowdin API)
+         * @see https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.files.put (Crowdin Enterprise API)
          */
         $response = $this->client->request('PUT', 'files/'.$fileId, [
             'json' => [
@@ -261,9 +281,13 @@ final class CrowdinProvider implements ProviderInterface
             ],
         ]);
 
-        if (200 !== $response->getStatusCode()) {
+        if (200 !== $statusCode = $response->getStatusCode()) {
             $this->logger->error(sprintf('Unable to update file in Crowdin for file ID "%d" and domain "%s": "%s".', $fileId, $domain, $response->getContent(false)));
 
+            if (500 <= $statusCode) {
+                throw new ProviderException(sprintf('Unable to update file in Crowdin for file ID "%d" and domain "%s".', $fileId, $domain), $response);
+            }
+
             return null;
         }
 
@@ -275,8 +299,8 @@ final class CrowdinProvider implements ProviderInterface
         $storageId = $this->addStorage($domain, $content);
 
         /*
-         * @see https://support.crowdin.com/api/v2/#operation/api.projects.translations.postOnLanguage (Crowdin API)
-         * @see https://support.crowdin.com/enterprise/api/#operation/api.projects.translations.postOnLanguage (Crowdin Enterprise API)
+         * @see https://developer.crowdin.com/api/v2/#operation/api.projects.translations.postOnLanguage (Crowdin API)
+         * @see https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.translations.postOnLanguage (Crowdin Enterprise API)
          */
         return $this->client->request('POST', 'translations/'.str_replace('_', '-', $locale), [
             'json' => [
@@ -289,8 +313,8 @@ final class CrowdinProvider implements ProviderInterface
     private function exportProjectTranslations(string $languageId, int $fileId): ResponseInterface
     {
         /*
-         * @see https://support.crowdin.com/api/v2/#operation/api.projects.translations.exports.post (Crowdin API)
-         * @see https://support.crowdin.com/enterprise/api/#operation/api.projects.translations.exports.post (Crowdin Enterprise API)
+         * @see https://developer.crowdin.com/api/v2/#operation/api.projects.translations.exports.post (Crowdin API)
+         * @see https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.translations.exports.post (Crowdin Enterprise API)
          */
         return $this->client->request('POST', 'translations/exports', [
             'json' => [
@@ -303,8 +327,8 @@ final class CrowdinProvider implements ProviderInterface
     private function downloadSourceFile(int $fileId): ResponseInterface
     {
         /*
-         * @see https://support.crowdin.com/api/v2/#operation/api.projects.files.download.get (Crowdin API)
-         * @see https://support.crowdin.com/enterprise/api/#operation/api.projects.files.download.get (Crowdin Enterprise API)
+         * @see https://developer.crowdin.com/api/v2/#operation/api.projects.files.download.get (Crowdin API)
+         * @see https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.files.download.get (Crowdin Enterprise API)
          */
         return $this->client->request('GET', sprintf('files/%d/download', $fileId));
     }
@@ -312,8 +336,8 @@ final class CrowdinProvider implements ProviderInterface
     private function listStrings(int $fileId, int $limit, int $offset): array
     {
         /**
-         * @see https://support.crowdin.com/api/v2/#operation/api.projects.strings.getMany (Crowdin API)
-         * @see https://support.crowdin.com/enterprise/api/#operation/api.projects.strings.getMany (Crowdin Enterprise API)
+         * @see https://developer.crowdin.com/api/v2/#operation/api.projects.strings.getMany (Crowdin API)
+         * @see https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.strings.getMany (Crowdin Enterprise API)
          */
         $response = $this->client->request('GET', 'strings', [
             'query' => [
@@ -324,9 +348,7 @@ final class CrowdinProvider implements ProviderInterface
         ]);
 
         if (200 !== $response->getStatusCode()) {
-            $this->logger->error(sprintf('Unable to list strings for file %d: "%s".', $fileId, $response->getContent()));
-
-            return [];
+            throw new ProviderException(sprintf('Unable to list strings for file "%d".', $fileId), $response);
         }
 
         return $response->toArray()['data'];
@@ -335,8 +357,8 @@ final class CrowdinProvider implements ProviderInterface
     private function deleteString(int $stringId): ResponseInterface
     {
         /*
-         * @see https://support.crowdin.com/api/v2/#operation/api.projects.strings.delete (Crowdin API)
-         * @see https://support.crowdin.com/enterprise/api/#operation/api.projects.strings.delete (Crowdin Enterprise API)
+         * @see https://developer.crowdin.com/api/v2/#operation/api.projects.strings.delete (Crowdin API)
+         * @see https://developer.crowdin.com/enterprise/api/v2#operation/api.projects.strings.delete (Crowdin Enterprise API)
          */
         return $this->client->request('DELETE', 'strings/'.$stringId);
     }
@@ -344,8 +366,8 @@ final class CrowdinProvider implements ProviderInterface
     private function addStorage(string $domain, string $content): int
     {
         /**
-         * @see https://support.crowdin.com/api/v2/#operation/api.storages.post (Crowdin API)
-         * @see https://support.crowdin.com/enterprise/api/#operation/api.storages.post (Crowdin Enterprise API)
+         * @see https://developer.crowdin.com/api/v2/#operation/api.storages.post (Crowdin API)
+         * @see https://developer.crowdin.com/enterprise/api/v2/#operation/api.storages.post (Crowdin Enterprise API)
          */
         $response = $this->client->request('POST', '../../storages', [
             'headers' => [
@@ -367,8 +389,8 @@ final class CrowdinProvider implements ProviderInterface
         $result = [];
 
         /**
-         * @see https://support.crowdin.com/api/v2/#operation/api.projects.files.getMany (Crowdin API)
-         * @see https://support.crowdin.com/enterprise/api/#operation/api.projects.files.getMany (Crowdin Enterprise API)
+         * @see https://developer.crowdin.com/api/v2/#operation/api.projects.files.getMany (Crowdin API)
+         * @see https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.files.getMany (Crowdin Enterprise API)
          */
         $response = $this->client->request('GET', 'files');
 
