@@ -20,18 +20,18 @@ use Symfony\Component\Translation\Test\ProviderFactoryTestCase;
 
 class LokaliseProviderFactoryTest extends ProviderFactoryTestCase
 {
-    public function supportsProvider(): iterable
+    public static function supportsProvider(): iterable
     {
         yield [true, 'lokalise://PROJECT_ID:API_KEY@default'];
         yield [false, 'somethingElse://PROJECT_ID:API_KEY@default'];
     }
 
-    public function unsupportedSchemeProvider(): iterable
+    public static function unsupportedSchemeProvider(): iterable
     {
         yield ['somethingElse://PROJECT_ID:API_KEY@default'];
     }
 
-    public function createProvider(): iterable
+    public static function createProvider(): iterable
     {
         yield [
             'lokalise://api.lokalise.com',
@@ -39,7 +39,7 @@ class LokaliseProviderFactoryTest extends ProviderFactoryTestCase
         ];
     }
 
-    public function incompleteDsnProvider(): iterable
+    public static function incompleteDsnProvider(): iterable
     {
         yield ['lokalise://default'];
     }
