@@ -15,10 +15,8 @@ use PHPUnit\Framework\TestCase;
 use Symfony\Component\Translation\Exception\InvalidArgumentException;
 use Symfony\Component\Translation\Exception\NotFoundResourceException;
 use Symfony\Component\Translation\Exception\RuntimeException;
-use Symfony\Component\Translation\Formatter\IntlFormatter;
 use Symfony\Component\Translation\Formatter\IntlFormatterInterface;
 use Symfony\Component\Translation\Formatter\MessageFormatter;
-use Symfony\Component\Translation\Formatter\MessageFormatterInterface;
 use Symfony\Component\Translation\Loader\ArrayLoader;
 use Symfony\Component\Translation\MessageCatalogue;
 use Symfony\Component\Translation\Translator;
@@ -301,7 +299,7 @@ class TranslatorTest extends TestCase
         $this->assertEquals('foobar', $translator->trans('bar'));
     }
 
-    public function getFallbackLocales()
+    public static function getFallbackLocales()
     {
         $locales = [
             ['en', 'en_US'],
@@ -456,7 +454,7 @@ class TranslatorTest extends TestCase
         }, $this, Translator::class))();
     }
 
-    public function getTransFileTests()
+    public static function getTransFileTests()
     {
         return [
             ['csv', 'CsvFileLoader'],
@@ -471,7 +469,7 @@ class TranslatorTest extends TestCase
         ];
     }
 
-    public function getTransTests()
+    public static function getTransTests()
     {
         return [
             ['Symfony est super !', 'Symfony is great!', 'Symfony est super !', [], 'fr', ''],
@@ -481,7 +479,7 @@ class TranslatorTest extends TestCase
         ];
     }
 
-    public function getTransICUTests()
+    public static function getTransICUTests()
     {
         $id = '{apples, plural, =0 {There are no apples} one {There is one apple} other {There are # apples}}';
 
@@ -492,7 +490,7 @@ class TranslatorTest extends TestCase
         ];
     }
 
-    public function getFlattenedTransTests()
+    public static function getFlattenedTransTests()
     {
         $messages = [
             'symfony' => [
@@ -515,7 +513,7 @@ class TranslatorTest extends TestCase
         ];
     }
 
-    public function getInvalidLocalesTests()
+    public static function getInvalidLocalesTests()
     {
         return [
             ['fr FR'],
@@ -532,7 +530,7 @@ class TranslatorTest extends TestCase
         ];
     }
 
-    public function getValidLocalesTests()
+    public static function getValidLocalesTests()
     {
         return [
             [''],
