@@ -33,33 +33,24 @@ class ConstraintViolation implements ConstraintViolationInterface
      * Creates a new constraint violation.
      *
      * @param string|\Stringable $message         The violation message as a string or a stringable object
-     * @param string             $messageTemplate The raw violation message
+     * @param string|null        $messageTemplate The raw violation message
      * @param array              $parameters      The parameters to substitute in the
      *                                            raw violation message
      * @param mixed              $root            The value originally passed to the
      *                                            validator
-     * @param string             $propertyPath    The property path from the root
+     * @param string|null        $propertyPath    The property path from the root
      *                                            value to the invalid value
      * @param mixed              $invalidValue    The invalid value that caused this
      *                                            violation
      * @param int|null           $plural          The number for determining the plural
      *                                            form when translating the message
-     * @param mixed              $code            The error code of the violation
+     * @param string|null        $code            The error code of the violation
      * @param Constraint|null    $constraint      The constraint whose validation
      *                                            caused the violation
      * @param mixed              $cause           The cause of the violation
      */
-    public function __construct($message, ?string $messageTemplate, array $parameters, $root, ?string $propertyPath, $invalidValue, int $plural = null, $code = null, Constraint $constraint = null, $cause = null)
+    public function __construct($message, ?string $messageTemplate, array $parameters, $root, ?string $propertyPath, $invalidValue, int $plural = null, string $code = null, Constraint $constraint = null, $cause = null)
     {
-        if (null === $message) {
-            @trigger_error(sprintf('Passing a null message when instantiating a "%s" is deprecated since Symfony 4.4.', __CLASS__), \E_USER_DEPRECATED);
-            $message = '';
-        }
-
-        if (null !== $code && !\is_string($code)) {
-            @trigger_error(sprintf('Not using a string as the error code in %s() is deprecated since Symfony 4.4. A type-hint will be added in 5.0.', __METHOD__), \E_USER_DEPRECATED);
-        }
-
         if (!\is_string($message) && !(\is_object($message) && method_exists($message, '__toString'))) {
             throw new \TypeError('Constraint violation message should be a string or an object which implements the __toString() method.');
         }
@@ -79,7 +70,7 @@ class ConstraintViolation implements ConstraintViolationInterface
     /**
      * Converts the violation into a string for debugging purposes.
      *
-     * @return string The violation as string
+     * @return string
      */
     public function __toString()
     {
@@ -92,13 +83,12 @@ class ConstraintViolation implements ConstraintViolationInterface
         }
 
         $propertyPath = (string) $this->propertyPath;
-        $code = (string) $this->code;
 
         if ('' !== $propertyPath && '[' !== $propertyPath[0] && '' !== $class) {
             $class .= '.';
         }
 
-        if ('' !== $code) {
+        if (null !== ($code = $this->code) && '' !== $code) {
             $code = ' (code '.$code.')';
         }
 
@@ -110,7 +100,7 @@ class ConstraintViolation implements ConstraintViolationInterface
      */
     public function getMessageTemplate()
     {
-        return $this->messageTemplate;
+        return (string) $this->messageTemplate;
     }
 
     /**
@@ -150,7 +140,7 @@ class ConstraintViolation implements ConstraintViolationInterface
      */
     public function getPropertyPath()
     {
-        return $this->propertyPath;
+        return (string) $this->propertyPath;
     }
 
     /**
@@ -164,7 +154,7 @@ class ConstraintViolation implements ConstraintViolationInterface
     /**
      * Returns the constraint whose validation caused the violation.
      *
-     * @return Constraint|null The constraint or null if it is not known
+     * @return Constraint|null
      */
     public function getConstraint()
     {
