@@ -22,6 +22,7 @@ use Symfony\Component\Validator\Exception\LogicException;
  * @author Miha Vrhovnik <miha.vrhovnik@pagein.si>
  * @author Bernhard Schussek <bschussek@gmail.com>
  */
+#[\Attribute(\Attribute::TARGET_PROPERTY | \Attribute::TARGET_METHOD | \Attribute::IS_REPEATABLE)]
 class Currency extends Constraint
 {
     public const NO_SUCH_CURRENCY_ERROR = '69945ac1-2db4-405f-bec7-d2772f73df52';
@@ -32,13 +33,14 @@ class Currency extends Constraint
 
     public $message = 'This value is not a valid currency.';
 
-    public function __construct($options = null)
+    public function __construct(array $options = null, string $message = null, array $groups = null, $payload = null)
     {
         if (!class_exists(Currencies::class)) {
-            // throw new LogicException('The Intl component is required to use the Currency constraint. Try running "composer require symfony/intl".');
-            @trigger_error(sprintf('Using the "%s" constraint without the "symfony/intl" component installed is deprecated since Symfony 4.2.', __CLASS__), \E_USER_DEPRECATED);
+            throw new LogicException('The Intl component is required to use the Currency constraint. Try running "composer require symfony/intl".');
         }
 
-        parent::__construct($options);
+        parent::__construct($options, $groups, $payload);
+
+        $this->message = $message ?? $this->message;
     }
 }
