@@ -46,7 +46,7 @@ class DateValidator extends ConstraintValidator
             return;
         }
 
-        if (!is_scalar($value) && !(\is_object($value) && method_exists($value, '__toString'))) {
+        if (!\is_scalar($value) && !(\is_object($value) && method_exists($value, '__toString'))) {
             throw new UnexpectedValueException($value, 'string');
         }
 
@@ -62,9 +62,9 @@ class DateValidator extends ConstraintValidator
         }
 
         if (!self::checkDate(
-          $matches['year'] ?? $matches[1],
-          $matches['month'] ?? $matches[2],
-          $matches['day'] ?? $matches[3]
+            $matches['year'] ?? $matches[1],
+            $matches['month'] ?? $matches[2],
+            $matches['day'] ?? $matches[3]
         )) {
             $this->context->buildViolation($constraint->message)
                 ->setParameter('{{ value }}', $this->formatValue($value))
