@@ -17,9 +17,10 @@ namespace Symfony\Component\Validator\Constraints;
  *
  * @author Colin O'Dell <colinodell@gmail.com>
  */
+#[\Attribute(\Attribute::TARGET_PROPERTY | \Attribute::TARGET_METHOD | \Attribute::IS_REPEATABLE)]
 class DivisibleBy extends AbstractComparison
 {
-    const NOT_DIVISIBLE_BY = '6d99d6c3-1464-4ccf-bdc7-14d083cf455c';
+    public const NOT_DIVISIBLE_BY = '6d99d6c3-1464-4ccf-bdc7-14d083cf455c';
 
     protected static $errorNames = [
         self::NOT_DIVISIBLE_BY => 'NOT_DIVISIBLE_BY',
