@@ -27,6 +27,10 @@ class AddAutoMappingConfigurationPass implements CompilerPassInterface
 
     public function __construct(string $validatorBuilderService = 'validator.builder', string $tag = 'validator.auto_mapper')
     {
+        if (0 < \func_num_args()) {
+            trigger_deprecation('symfony/validator', '5.3', 'Configuring "%s" is deprecated.', __CLASS__);
+        }
+
         $this->validatorBuilderService = $validatorBuilderService;
         $this->tag = $tag;
     }
@@ -59,13 +63,8 @@ class AddAutoMappingConfigurationPass implements CompilerPassInterface
         $validatorBuilder = $container->getDefinition($this->validatorBuilderService);
         foreach ($container->findTaggedServiceIds($this->tag) as $id => $tags) {
             $regexp = $this->getRegexp(array_merge($globalNamespaces, $servicesToNamespaces[$id] ?? []));
-            if (null === $regexp) {
-                $container->removeDefinition($id);
-                continue;
-            }
-
-            $container->getDefinition($id)->setArgument('$classValidatorRegexp', $regexp);
             $validatorBuilder->addMethodCall('addLoader', [new Reference($id)]);
+            $container->getDefinition($id)->setArgument('$classValidatorRegexp', $regexp);
         }
 
         $container->getParameterBag()->remove('validator.auto_mapping');
@@ -89,7 +88,7 @@ class AddAutoMappingConfigurationPass implements CompilerPassInterface
             $regex = strtr($regex, ['\\*\\*' => '.*?', '\\*' => '[^\\\\]*?']);
 
             // If this class does not end by a slash, anchor the end
-            if ('\\' !== substr($regex, -1)) {
+            if (!str_ends_with($regex, '\\')) {
                 $regex .= '$';
             }
 
