@@ -230,22 +230,29 @@ class CallbackValidatorTest extends ConstraintValidatorTestCase
     public function testPayloadIsPassedToCallback()
     {
         $object = new \stdClass();
-        $payloadCopy = null;
+        $payloadCopy = 'Replace me!';
+        $callback = function ($object, ExecutionContextInterface $constraint, $payload) use (&$payloadCopy) {
+            $payloadCopy = $payload;
+        };
 
         $constraint = new Callback([
-            'callback' => function ($object, ExecutionContextInterface $constraint, $payload) use (&$payloadCopy) {
-                $payloadCopy = $payload;
-            },
+            'callback' => $callback,
             'payload' => 'Hello world!',
         ]);
         $this->validator->validate($object, $constraint);
         $this->assertEquals('Hello world!', $payloadCopy);
 
-        $payloadCopy = null;
+        if (\PHP_VERSION_ID >= 80000) {
+            $payloadCopy = 'Replace me!';
+            $constraint = eval('return new \Symfony\Component\Validator\Constraints\Callback(callback: $callback, payload: "Hello world!");');
+            $this->validator->validate($object, $constraint);
+            $this->assertEquals('Hello world!', $payloadCopy);
+            $payloadCopy = 'Replace me!';
+        }
+
+        $payloadCopy = 'Replace me!';
         $constraint = new Callback([
-            'callback' => function ($object, ExecutionContextInterface $constraint, $payload) use (&$payloadCopy) {
-                $payloadCopy = $payload;
-            },
+            'callback' => $callback,
         ]);
         $this->validator->validate($object, $constraint);
         $this->assertNull($payloadCopy);
