@@ -91,7 +91,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideConstraintsWithNotFoundMessage(): iterable
+    public static function provideConstraintsWithNotFoundMessage(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'notFoundMessage' => 'myMessage',
@@ -132,7 +132,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideMinWidthConstraints(): iterable
+    public static function provideMinWidthConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'minWidth' => 3,
@@ -160,7 +160,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideMaxWidthConstraints(): iterable
+    public static function provideMaxWidthConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'maxWidth' => 1,
@@ -188,7 +188,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideMinHeightConstraints(): iterable
+    public static function provideMinHeightConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'minHeight' => 3,
@@ -216,7 +216,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideMaxHeightConstraints(): iterable
+    public static function provideMaxHeightConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'maxHeight' => 1,
@@ -246,7 +246,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideMinPixelsConstraints(): iterable
+    public static function provideMinPixelsConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'minPixels' => 5,
@@ -276,7 +276,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideMaxPixelsConstraints(): iterable
+    public static function provideMaxPixelsConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'maxPixels' => 3,
@@ -364,7 +364,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideMinRatioConstraints(): iterable
+    public static function provideMinRatioConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'minRatio' => 2,
@@ -392,7 +392,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideMaxRatioConstraints(): iterable
+    public static function provideMaxRatioConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'maxRatio' => 0.5,
@@ -473,7 +473,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideAllowSquareConstraints(): iterable
+    public static function provideAllowSquareConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'allowSquare' => false,
@@ -501,7 +501,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideAllowLandscapeConstraints(): iterable
+    public static function provideAllowLandscapeConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'allowLandscape' => false,
@@ -529,7 +529,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideAllowPortraitConstraints(): iterable
+    public static function provideAllowPortraitConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'allowPortrait' => false,
@@ -578,7 +578,7 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function provideDetectCorruptedConstraints(): iterable
+    public static function provideDetectCorruptedConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
             'detectCorrupted' => true,
