@@ -26,7 +26,7 @@ class IssnValidatorTest extends ConstraintValidatorTestCase
         return new IssnValidator();
     }
 
-    public function getValidLowerCasedIssn()
+    public static function getValidLowerCasedIssn()
     {
         return [
             ['2162-321x'],
@@ -39,7 +39,7 @@ class IssnValidatorTest extends ConstraintValidatorTestCase
         ];
     }
 
-    public function getValidNonHyphenatedIssn()
+    public static function getValidNonHyphenatedIssn()
     {
         return [
             ['2162321X'],
@@ -52,7 +52,7 @@ class IssnValidatorTest extends ConstraintValidatorTestCase
         ];
     }
 
-    public function getFullValidIssn()
+    public static function getFullValidIssn()
     {
         return [
             ['1550-7416'],
@@ -66,16 +66,16 @@ class IssnValidatorTest extends ConstraintValidatorTestCase
         ];
     }
 
-    public function getValidIssn()
+    public static function getValidIssn()
     {
         return array_merge(
-            $this->getValidLowerCasedIssn(),
-            $this->getValidNonHyphenatedIssn(),
-            $this->getFullValidIssn()
+            self::getValidLowerCasedIssn(),
+            self::getValidNonHyphenatedIssn(),
+            self::getFullValidIssn()
         );
     }
 
-    public function getInvalidIssn()
+    public static function getInvalidIssn()
     {
         return [
             [0, Issn::TOO_SHORT_ERROR],
