@@ -67,6 +67,7 @@ class RegexValidatorTest extends ConstraintValidatorTestCase
 
     /**
      * @requires PHP 8
+     *
      * @dataProvider getValidValuesWithWhitespaces
      */
     public function testValidValuesWithWhitespacesNamed($value)
@@ -77,7 +78,7 @@ class RegexValidatorTest extends ConstraintValidatorTestCase
         $this->assertNoViolation();
     }
 
-    public function getValidValues()
+    public static function getValidValues()
     {
         return [
             [0],
@@ -93,7 +94,7 @@ class RegexValidatorTest extends ConstraintValidatorTestCase
         ];
     }
 
-    public function getValidValuesWithWhitespaces()
+    public static function getValidValuesWithWhitespaces()
     {
         return [
             ["\x207"],
@@ -125,6 +126,7 @@ class RegexValidatorTest extends ConstraintValidatorTestCase
 
     /**
      * @requires PHP 8
+     *
      * @dataProvider getInvalidValues
      */
     public function testInvalidValuesNamed($value)
@@ -139,7 +141,7 @@ class RegexValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function getInvalidValues()
+    public static function getInvalidValues()
     {
         return [
             ['abcd'],
