@@ -37,17 +37,6 @@ class TimeValidatorTest extends ConstraintValidatorTestCase
         $this->assertNoViolation();
     }
 
-    /**
-     * @group legacy
-     * @expectedDeprecation Validating a \DateTimeInterface with "Symfony\Component\Validator\Constraints\Time" is deprecated since version 4.2. Use "Symfony\Component\Validator\Constraints\Type" instead or remove the constraint if the underlying model is already type hinted to \DateTimeInterface.
-     */
-    public function testDateTimeClassIsValid()
-    {
-        $this->validator->validate(new \DateTime(), new Time());
-
-        $this->assertNoViolation();
-    }
-
     public function testExpectsStringCompatibleType()
     {
         $this->expectException(UnexpectedValueException::class);
@@ -64,7 +53,7 @@ class TimeValidatorTest extends ConstraintValidatorTestCase
         $this->assertNoViolation();
     }
 
-    public function getValidTimes()
+    public static function getValidTimes()
     {
         return [
             ['01:02:03'],
@@ -90,7 +79,7 @@ class TimeValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
-    public function getInvalidTimes()
+    public static function getInvalidTimes()
     {
         return [
             ['foobar', Time::INVALID_FORMAT_ERROR],
@@ -102,15 +91,4 @@ class TimeValidatorTest extends ConstraintValidatorTestCase
             ['00:00:60', Time::INVALID_TIME_ERROR],
         ];
     }
-
-    /**
-     * @group legacy
-     * @expectedDeprecation Validating a \DateTimeInterface with "Symfony\Component\Validator\Constraints\Time" is deprecated since version 4.2. Use "Symfony\Component\Validator\Constraints\Type" instead or remove the constraint if the underlying model is already type hinted to \DateTimeInterface.
-     */
-    public function testDateTimeImmutableIsValid()
-    {
-        $this->validator->validate(new \DateTimeImmutable(), new Time());
-
-        $this->assertNoViolation();
-    }
 }
