@@ -14,23 +14,24 @@ namespace Symfony\Component\Validator\Tests\Mapping\Loader;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Validator\Mapping\ClassMetadata;
 use Symfony\Component\Validator\Mapping\Loader\LoaderInterface;
+use Symfony\Component\Validator\Tests\Fixtures\Annotation\Entity;
 use Symfony\Component\Validator\Tests\Fixtures\FilesLoader;
 
 class FilesLoaderTest extends TestCase
 {
     public function testCallsGetFileLoaderInstanceForeachPath()
     {
-        $loader = $this->getFilesLoader($this->getFileLoader());
+        $loader = $this->getFilesLoader($this->createMock(LoaderInterface::class));
         $this->assertEquals(4, $loader->getTimesCalled());
     }
 
     public function testCallsActualFileLoaderForMetadata()
     {
-        $fileLoader = $this->getFileLoader();
+        $fileLoader = $this->createMock(LoaderInterface::class);
         $fileLoader->expects($this->exactly(4))
             ->method('loadClassMetadata');
         $loader = $this->getFilesLoader($fileLoader);
-        $loader->loadClassMetadata(new ClassMetadata('Symfony\Component\Validator\Tests\Fixtures\Entity'));
+        $loader->loadClassMetadata(new ClassMetadata(Entity::class));
     }
 
     public function getFilesLoader(LoaderInterface $loader)
@@ -42,9 +43,4 @@ class FilesLoaderTest extends TestCase
             __DIR__.'/constraint-mapping.txt',
         ], $loader]);
     }
-
-    public function getFileLoader()
-    {
-        return $this->createMock(LoaderInterface::class);
-    }
 }
