@@ -11,7 +11,7 @@
 
 namespace Symfony\Component\Validator\Tests;
 
-use Doctrine\Common\Annotations\CachedReader;
+use Doctrine\Common\Annotations\PsrCachedReader;
 use Doctrine\Common\Annotations\Reader;
 use PHPUnit\Framework\TestCase;
 use Psr\Cache\CacheItemPoolInterface;
@@ -99,7 +99,7 @@ class ValidatorBuilderTest extends TestCase
         $r = new \ReflectionProperty(AnnotationLoader::class, 'reader');
         $r->setAccessible(true);
 
-        $this->assertInstanceOf(CachedReader::class, $r->getValue($loaders[0]));
+        $this->assertInstanceOf(PsrCachedReader::class, $r->getValue($loaders[0]));
     }
 
     public function testEnableAnnotationMappingWithDefaultDoctrineAnnotationReader()
@@ -114,7 +114,7 @@ class ValidatorBuilderTest extends TestCase
         $r = new \ReflectionProperty(AnnotationLoader::class, 'reader');
         $r->setAccessible(true);
 
-        $this->assertInstanceOf(CachedReader::class, $r->getValue($loaders[0]));
+        $this->assertInstanceOf(PsrCachedReader::class, $r->getValue($loaders[0]));
     }
 
     /**
