@@ -32,7 +32,7 @@ class ServerDumpCommandTest extends TestCase
         $this->assertSame($expectedSuggestions, $tester->complete($input));
     }
 
-    public function provideCompletionSuggestions()
+    public static function provideCompletionSuggestions()
     {
         yield 'option --format' => [
             ['--format', ''],
