@@ -20,8 +20,8 @@ use Symfony\Component\Workflow\WorkflowInterface;
  */
 class UndefinedTransitionException extends TransitionException
 {
-    public function __construct($subject, string $transitionName, WorkflowInterface $workflow)
+    public function __construct(object $subject, string $transitionName, WorkflowInterface $workflow, array $context = [])
     {
-        parent::__construct($subject, $transitionName, $workflow, sprintf('Transition "%s" is not defined for workflow "%s".', $transitionName, $workflow->getName()));
+        parent::__construct($subject, $transitionName, $workflow, sprintf('Transition "%s" is not defined for workflow "%s".', $transitionName, $workflow->getName()), $context);
     }
 }
