@@ -12,7 +12,6 @@
 namespace Symfony\Component\Workflow;
 
 use Symfony\Component\Workflow\Exception\InvalidArgumentException;
-use Symfony\Component\Workflow\SupportStrategy\SupportStrategyInterface;
 use Symfony\Component\Workflow\SupportStrategy\WorkflowSupportStrategyInterface;
 
 /**
@@ -23,29 +22,26 @@ class Registry
 {
     private $workflows = [];
 
-    /**
-     * @param SupportStrategyInterface $supportStrategy
-     *
-     * @deprecated since Symfony 4.1, use addWorkflow() instead
-     */
-    public function add(Workflow $workflow, $supportStrategy)
-    {
-        @trigger_error(sprintf('The "%s()" method is deprecated since Symfony 4.1. Use addWorkflow() instead.', __METHOD__), \E_USER_DEPRECATED);
-        $this->workflows[] = [$workflow, $supportStrategy];
-    }
-
     public function addWorkflow(WorkflowInterface $workflow, WorkflowSupportStrategyInterface $supportStrategy)
     {
         $this->workflows[] = [$workflow, $supportStrategy];
     }
 
+    public function has(object $subject, string $workflowName = null): bool
+    {
+        foreach ($this->workflows as [$workflow, $supportStrategy]) {
+            if ($this->supports($workflow, $supportStrategy, $subject, $workflowName)) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
     /**
-     * @param object      $subject
-     * @param string|null $workflowName
-     *
      * @return Workflow
      */
-    public function get($subject, $workflowName = null)
+    public function get(object $subject, string $workflowName = null)
     {
         $matched = [];
 
@@ -56,7 +52,7 @@ class Registry
         }
 
         if (!$matched) {
-            throw new InvalidArgumentException(sprintf('Unable to find a workflow for class "%s".', \get_class($subject)));
+            throw new InvalidArgumentException(sprintf('Unable to find a workflow for class "%s".', get_debug_type($subject)));
         }
 
         if (2 <= \count($matched)) {
@@ -64,18 +60,16 @@ class Registry
                 return $workflow->getName();
             }, $matched);
 
-            throw new InvalidArgumentException(sprintf('Too many workflows (%s) match this subject (%s); set a different name on each and use the second (name) argument of this method.', implode(', ', $names), \get_class($subject)));
+            throw new InvalidArgumentException(sprintf('Too many workflows (%s) match this subject (%s); set a different name on each and use the second (name) argument of this method.', implode(', ', $names), get_debug_type($subject)));
         }
 
         return $matched[0];
     }
 
     /**
-     * @param object $subject
-     *
      * @return Workflow[]
      */
-    public function all($subject): array
+    public function all(object $subject): array
     {
         $matched = [];
         foreach ($this->workflows as [$workflow, $supportStrategy]) {
@@ -87,11 +81,7 @@ class Registry
         return $matched;
     }
 
-    /**
-     * @param WorkflowSupportStrategyInterface $supportStrategy
-     * @param object                           $subject
-     */
-    private function supports(WorkflowInterface $workflow, $supportStrategy, $subject, ?string $workflowName): bool
+    private function supports(WorkflowInterface $workflow, WorkflowSupportStrategyInterface $supportStrategy, object $subject, ?string $workflowName): bool
     {
         if (null !== $workflowName && $workflowName !== $workflow->getName()) {
             return false;
