@@ -11,7 +11,6 @@
 
 namespace Symfony\Component\Workflow;
 
-use Symfony\Component\EventDispatcher\LegacyEventDispatcherProxy;
 use Symfony\Component\Workflow\Event\AnnounceEvent;
 use Symfony\Component\Workflow\Event\CompletedEvent;
 use Symfony\Component\Workflow\Event\EnteredEvent;
@@ -23,7 +22,7 @@ use Symfony\Component\Workflow\Exception\LogicException;
 use Symfony\Component\Workflow\Exception\NotEnabledTransitionException;
 use Symfony\Component\Workflow\Exception\UndefinedTransitionException;
 use Symfony\Component\Workflow\MarkingStore\MarkingStoreInterface;
-use Symfony\Component\Workflow\MarkingStore\MultipleStateMarkingStore;
+use Symfony\Component\Workflow\MarkingStore\MethodMarkingStore;
 use Symfony\Component\Workflow\Metadata\MetadataStoreInterface;
 use Symfony\Contracts\EventDispatcher\EventDispatcherInterface;
 
@@ -31,32 +30,56 @@ use Symfony\Contracts\EventDispatcher\EventDispatcherInterface;
  * @author Fabien Potencier <fabien@symfony.com>
  * @author Grégoire Pineau <lyrixx@lyrixx.info>
  * @author Tobias Nyholm <tobias.nyholm@gmail.com>
+ * @author Carlos Pereira De Amorim <carlos@shauri.fr>
  */
 class Workflow implements WorkflowInterface
 {
+    public const DISABLE_LEAVE_EVENT = 'workflow_disable_leave_event';
+    public const DISABLE_TRANSITION_EVENT = 'workflow_disable_transition_event';
+    public const DISABLE_ENTER_EVENT = 'workflow_disable_enter_event';
+    public const DISABLE_ENTERED_EVENT = 'workflow_disable_entered_event';
+    public const DISABLE_COMPLETED_EVENT = 'workflow_disable_completed_event';
+    public const DISABLE_ANNOUNCE_EVENT = 'workflow_disable_announce_event';
+
+    public const DEFAULT_INITIAL_CONTEXT = ['initial' => true];
+
+    private const DISABLE_EVENTS_MAPPING = [
+        WorkflowEvents::LEAVE => self::DISABLE_LEAVE_EVENT,
+        WorkflowEvents::TRANSITION => self::DISABLE_TRANSITION_EVENT,
+        WorkflowEvents::ENTER => self::DISABLE_ENTER_EVENT,
+        WorkflowEvents::ENTERED => self::DISABLE_ENTERED_EVENT,
+        WorkflowEvents::COMPLETED => self::DISABLE_COMPLETED_EVENT,
+        WorkflowEvents::ANNOUNCE => self::DISABLE_ANNOUNCE_EVENT,
+    ];
+
     private $definition;
     private $markingStore;
     private $dispatcher;
     private $name;
 
-    public function __construct(Definition $definition, MarkingStoreInterface $markingStore = null, EventDispatcherInterface $dispatcher = null, string $name = 'unnamed')
+    /**
+     * When `null` fire all events (the default behaviour).
+     * Setting this to an empty array `[]` means no events are dispatched (except the Guard Event).
+     * Passing an array with WorkflowEvents will allow only those events to be dispatched plus
+     * the Guard Event.
+     *
+     * @var array|string[]|null
+     */
+    private $eventsToDispatch = null;
+
+    public function __construct(Definition $definition, MarkingStoreInterface $markingStore = null, EventDispatcherInterface $dispatcher = null, string $name = 'unnamed', array $eventsToDispatch = null)
     {
         $this->definition = $definition;
-        $this->markingStore = $markingStore ?: new MultipleStateMarkingStore();
-
-        if (null !== $dispatcher && class_exists(LegacyEventDispatcherProxy::class)) {
-            $this->dispatcher = LegacyEventDispatcherProxy::decorate($dispatcher);
-        } else {
-            $this->dispatcher = $dispatcher;
-        }
-
+        $this->markingStore = $markingStore ?? new MethodMarkingStore();
+        $this->dispatcher = $dispatcher;
         $this->name = $name;
+        $this->eventsToDispatch = $eventsToDispatch;
     }
 
     /**
      * {@inheritdoc}
      */
-    public function getMarking($subject)
+    public function getMarking(object $subject, array $context = [])
     {
         $marking = $this->markingStore->getMarking($subject);
 
@@ -76,7 +99,11 @@ class Workflow implements WorkflowInterface
             // update the subject with the new marking
             $this->markingStore->setMarking($subject, $marking);
 
-            $this->entered($subject, null, $marking);
+            if (!$context) {
+                $context = self::DEFAULT_INITIAL_CONTEXT;
+            }
+
+            $this->entered($subject, null, $marking, $context);
         }
 
         // check that the subject has a known place
@@ -98,7 +125,7 @@ class Workflow implements WorkflowInterface
     /**
      * {@inheritdoc}
      */
-    public function can($subject, $transitionName)
+    public function can(object $subject, string $transitionName)
     {
         $transitions = $this->definition->getTransitions();
         $marking = $this->getMarking($subject);
@@ -121,7 +148,7 @@ class Workflow implements WorkflowInterface
     /**
      * {@inheritdoc}
      */
-    public function buildTransitionBlockerList($subject, string $transitionName): TransitionBlockerList
+    public function buildTransitionBlockerList(object $subject, string $transitionName): TransitionBlockerList
     {
         $transitions = $this->definition->getTransitions();
         $marking = $this->getMarking($subject);
@@ -156,14 +183,10 @@ class Workflow implements WorkflowInterface
 
     /**
      * {@inheritdoc}
-     *
-     * @param array $context Some context
      */
-    public function apply($subject, $transitionName/*, array $context = []*/)
+    public function apply(object $subject, string $transitionName, array $context = [])
     {
-        $context = \func_get_args()[2] ?? [];
-
-        $marking = $this->getMarking($subject);
+        $marking = $this->getMarking($subject, $context);
 
         $transitionExist = false;
         $approvedTransitions = [];
@@ -198,36 +221,38 @@ class Workflow implements WorkflowInterface
         }
 
         if (!$transitionExist) {
-            throw new UndefinedTransitionException($subject, $transitionName, $this);
+            throw new UndefinedTransitionException($subject, $transitionName, $this, $context);
         }
 
         if (!$approvedTransitions) {
-            throw new NotEnabledTransitionException($subject, $transitionName, $this, $bestTransitionBlockerList);
+            throw new NotEnabledTransitionException($subject, $transitionName, $this, $bestTransitionBlockerList, $context);
         }
 
         foreach ($approvedTransitions as $transition) {
-            $this->leave($subject, $transition, $marking);
+            $this->leave($subject, $transition, $marking, $context);
 
             $context = $this->transition($subject, $transition, $marking, $context);
 
-            $this->enter($subject, $transition, $marking);
+            $this->enter($subject, $transition, $marking, $context);
 
             $this->markingStore->setMarking($subject, $marking, $context);
 
-            $this->entered($subject, $transition, $marking);
+            $this->entered($subject, $transition, $marking, $context);
 
-            $this->completed($subject, $transition, $marking);
+            $this->completed($subject, $transition, $marking, $context);
 
-            $this->announce($subject, $transition, $marking);
+            $this->announce($subject, $transition, $marking, $context);
         }
 
+        $marking->setContext($context);
+
         return $marking;
     }
 
     /**
      * {@inheritdoc}
      */
-    public function getEnabledTransitions($subject)
+    public function getEnabledTransitions(object $subject)
     {
         $enabledTransitions = [];
         $marking = $this->getMarking($subject);
@@ -242,6 +267,25 @@ class Workflow implements WorkflowInterface
         return $enabledTransitions;
     }
 
+    public function getEnabledTransition(object $subject, string $name): ?Transition
+    {
+        $marking = $this->getMarking($subject);
+
+        foreach ($this->definition->getTransitions() as $transition) {
+            if ($transition->getName() !== $name) {
+                continue;
+            }
+            $transitionBlockerList = $this->buildTransitionBlockerListForTransition($subject, $marking, $transition);
+            if (!$transitionBlockerList->isEmpty()) {
+                continue;
+            }
+
+            return $transition;
+        }
+
+        return null;
+    }
+
     /**
      * {@inheritdoc}
      */
@@ -274,7 +318,7 @@ class Workflow implements WorkflowInterface
         return $this->definition->getMetadataStore();
     }
 
-    private function buildTransitionBlockerListForTransition($subject, Marking $marking, Transition $transition): TransitionBlockerList
+    private function buildTransitionBlockerListForTransition(object $subject, Marking $marking, Transition $transition): TransitionBlockerList
     {
         foreach ($transition->getFroms() as $place) {
             if (!$marking->has($place)) {
@@ -297,7 +341,7 @@ class Workflow implements WorkflowInterface
         return new TransitionBlockerList();
     }
 
-    private function guardTransition($subject, Marking $marking, Transition $transition): ?GuardEvent
+    private function guardTransition(object $subject, Marking $marking, Transition $transition): ?GuardEvent
     {
         if (null === $this->dispatcher) {
             return null;
@@ -312,12 +356,12 @@ class Workflow implements WorkflowInterface
         return $event;
     }
 
-    private function leave($subject, Transition $transition, Marking $marking): void
+    private function leave(object $subject, Transition $transition, Marking $marking, array $context = []): void
     {
         $places = $transition->getFroms();
 
-        if (null !== $this->dispatcher) {
-            $event = new LeaveEvent($subject, $marking, $transition, $this);
+        if ($this->shouldDispatchEvent(WorkflowEvents::LEAVE, $context)) {
+            $event = new LeaveEvent($subject, $marking, $transition, $this, $context);
 
             $this->dispatcher->dispatch($event, WorkflowEvents::LEAVE);
             $this->dispatcher->dispatch($event, sprintf('workflow.%s.leave', $this->name));
@@ -332,14 +376,13 @@ class Workflow implements WorkflowInterface
         }
     }
 
-    private function transition($subject, Transition $transition, Marking $marking, array $context): array
+    private function transition(object $subject, Transition $transition, Marking $marking, array $context): array
     {
-        if (null === $this->dispatcher) {
+        if (!$this->shouldDispatchEvent(WorkflowEvents::TRANSITION, $context)) {
             return $context;
         }
 
-        $event = new TransitionEvent($subject, $marking, $transition, $this);
-        $event->setContext($context);
+        $event = new TransitionEvent($subject, $marking, $transition, $this, $context);
 
         $this->dispatcher->dispatch($event, WorkflowEvents::TRANSITION);
         $this->dispatcher->dispatch($event, sprintf('workflow.%s.transition', $this->name));
@@ -348,12 +391,12 @@ class Workflow implements WorkflowInterface
         return $event->getContext();
     }
 
-    private function enter($subject, Transition $transition, Marking $marking): void
+    private function enter(object $subject, Transition $transition, Marking $marking, array $context): void
     {
         $places = $transition->getTos();
 
-        if (null !== $this->dispatcher) {
-            $event = new EnterEvent($subject, $marking, $transition, $this);
+        if ($this->shouldDispatchEvent(WorkflowEvents::ENTER, $context)) {
+            $event = new EnterEvent($subject, $marking, $transition, $this, $context);
 
             $this->dispatcher->dispatch($event, WorkflowEvents::ENTER);
             $this->dispatcher->dispatch($event, sprintf('workflow.%s.enter', $this->name));
@@ -368,44 +411,42 @@ class Workflow implements WorkflowInterface
         }
     }
 
-    private function entered($subject, Transition $transition = null, Marking $marking): void
+    private function entered(object $subject, ?Transition $transition, Marking $marking, array $context): void
     {
-        if (null === $this->dispatcher) {
+        if (!$this->shouldDispatchEvent(WorkflowEvents::ENTERED, $context)) {
             return;
         }
 
-        $event = new EnteredEvent($subject, $marking, $transition, $this);
+        $event = new EnteredEvent($subject, $marking, $transition, $this, $context);
 
         $this->dispatcher->dispatch($event, WorkflowEvents::ENTERED);
         $this->dispatcher->dispatch($event, sprintf('workflow.%s.entered', $this->name));
 
-        if ($transition) {
-            foreach ($transition->getTos() as $place) {
-                $this->dispatcher->dispatch($event, sprintf('workflow.%s.entered.%s', $this->name, $place));
-            }
+        foreach ($marking->getPlaces() as $placeName => $nbToken) {
+            $this->dispatcher->dispatch($event, sprintf('workflow.%s.entered.%s', $this->name, $placeName));
         }
     }
 
-    private function completed($subject, Transition $transition, Marking $marking): void
+    private function completed(object $subject, Transition $transition, Marking $marking, array $context): void
     {
-        if (null === $this->dispatcher) {
+        if (!$this->shouldDispatchEvent(WorkflowEvents::COMPLETED, $context)) {
             return;
         }
 
-        $event = new CompletedEvent($subject, $marking, $transition, $this);
+        $event = new CompletedEvent($subject, $marking, $transition, $this, $context);
 
         $this->dispatcher->dispatch($event, WorkflowEvents::COMPLETED);
         $this->dispatcher->dispatch($event, sprintf('workflow.%s.completed', $this->name));
         $this->dispatcher->dispatch($event, sprintf('workflow.%s.completed.%s', $this->name, $transition->getName()));
     }
 
-    private function announce($subject, Transition $initialTransition, Marking $marking): void
+    private function announce(object $subject, Transition $initialTransition, Marking $marking, array $context): void
     {
-        if (null === $this->dispatcher) {
+        if (!$this->shouldDispatchEvent(WorkflowEvents::ANNOUNCE, $context)) {
             return;
         }
 
-        $event = new AnnounceEvent($subject, $marking, $initialTransition, $this);
+        $event = new AnnounceEvent($subject, $marking, $initialTransition, $this, $context);
 
         $this->dispatcher->dispatch($event, WorkflowEvents::ANNOUNCE);
         $this->dispatcher->dispatch($event, sprintf('workflow.%s.announce', $this->name));
@@ -414,4 +455,25 @@ class Workflow implements WorkflowInterface
             $this->dispatcher->dispatch($event, sprintf('workflow.%s.announce.%s', $this->name, $transition->getName()));
         }
     }
+
+    private function shouldDispatchEvent(string $eventName, array $context): bool
+    {
+        if (null === $this->dispatcher) {
+            return false;
+        }
+
+        if ($context[self::DISABLE_EVENTS_MAPPING[$eventName]] ?? false) {
+            return false;
+        }
+
+        if (null === $this->eventsToDispatch) {
+            return true;
+        }
+
+        if ([] === $this->eventsToDispatch) {
+            return false;
+        }
+
+        return \in_array($eventName, $this->eventsToDispatch, true);
+    }
 }
