@@ -56,7 +56,7 @@ class InlineTest extends TestCase
         $this->assertSame($value, $actual);
     }
 
-    public function getTestsForParsePhpConstants()
+    public static function getTestsForParsePhpConstants()
     {
         return [
             ['!php/const Symfony\Component\Yaml\Yaml::PARSE_CONSTANT', Yaml::PARSE_CONSTANT],
@@ -195,7 +195,7 @@ class InlineTest extends TestCase
         $this->assertSame($expected, Inline::parse($yaml, 0, $references));
     }
 
-    public function getDataForParseReferences()
+    public static function getDataForParseReferences()
     {
         return [
             'scalar' => ['*var', 'var-value'],
@@ -245,7 +245,7 @@ class InlineTest extends TestCase
         Inline::parse(sprintf('{ foo: %sfoo }', $indicator));
     }
 
-    public function getReservedIndicators()
+    public static function getReservedIndicators()
     {
         return [['@'], ['`']];
     }
@@ -261,7 +261,7 @@ class InlineTest extends TestCase
         Inline::parse(sprintf('{ foo: %sfoo }', $indicator));
     }
 
-    public function getScalarIndicators()
+    public static function getScalarIndicators()
     {
         return [['|'], ['>'], ['%']];
     }
@@ -274,7 +274,7 @@ class InlineTest extends TestCase
         $this->assertSame($expected, Inline::isHash($array));
     }
 
-    public function getDataForIsHash()
+    public static function getDataForIsHash()
     {
         return [
             [[], false],
@@ -284,7 +284,7 @@ class InlineTest extends TestCase
         ];
     }
 
-    public function getTestsForParse()
+    public static function getTestsForParse()
     {
         return [
             ['', ''],
@@ -370,7 +370,7 @@ class InlineTest extends TestCase
         ];
     }
 
-    public function getTestsForParseWithMapObjects()
+    public static function getTestsForParseWithMapObjects()
     {
         return [
             ['', ''],
@@ -451,7 +451,7 @@ class InlineTest extends TestCase
         ];
     }
 
-    public function getTestsForDump()
+    public static function getTestsForDump()
     {
         return [
             ['null', null],
@@ -549,7 +549,7 @@ class InlineTest extends TestCase
         $this->assertSame($timezone, $date->format('O'));
     }
 
-    public function getTimestampTests(): array
+    public static function getTimestampTests(): array
     {
         return [
             'canonical' => ['2001-12-15T02:59:43.1Z', 2001, 12, 15, 2, 59, 43, 100000, '+0000'],
@@ -591,7 +591,7 @@ class InlineTest extends TestCase
         $this->assertSame("!php/const Symfony\Component\Yaml\Tests\Fixtures\FooUnitEnum::BAR", Inline::dump(FooUnitEnum::BAR));
     }
 
-    public function getDateTimeDumpTests()
+    public static function getDateTimeDumpTests()
     {
         $tests = [];
 
@@ -612,7 +612,7 @@ class InlineTest extends TestCase
         $this->assertSame('Hello world', Inline::parse($data));
     }
 
-    public function getBinaryData()
+    public static function getBinaryData()
     {
         return [
             'enclosed with double quotes' => ['!!binary "SGVsbG8gd29ybGQ="'],
@@ -632,7 +632,7 @@ class InlineTest extends TestCase
         Inline::parse($data);
     }
 
-    public function getInvalidBinaryData()
+    public static function getInvalidBinaryData()
     {
         return [
             'length not a multiple of four' => ['!!binary "SGVsbG8d29ybGQ="', '/The normalized base64 encoded data \(data without whitespace characters\) length must be a multiple of four \(\d+ bytes given\)/'],
@@ -674,7 +674,7 @@ class InlineTest extends TestCase
         $this->assertSame($expected, Inline::parse($yaml));
     }
 
-    public function getTestsForNullValues()
+    public static function getTestsForNullValues()
     {
         return [
             'null before closing curly brace' => ['{foo:}', ['foo' => null]],
@@ -697,7 +697,7 @@ class InlineTest extends TestCase
         $this->assertSame($expected, Inline::parse($yaml));
     }
 
-    public function getNotPhpCompatibleMappingKeyData()
+    public static function getNotPhpCompatibleMappingKeyData()
     {
         return [
             'boolean-true' => ['{true: "foo"}', ['true' => 'foo']],
@@ -776,7 +776,7 @@ class InlineTest extends TestCase
         self::assertSame($expected, Inline::parse($yaml));
     }
 
-    public function getTestsForOctalNumbers()
+    public static function getTestsForOctalNumbers()
     {
         return [
             'positive octal number' => [28, '0o34'],
@@ -797,7 +797,7 @@ class InlineTest extends TestCase
         self::assertSame($expected, Inline::parse($yaml));
     }
 
-    public function getTestsForOctalNumbersYaml11Notation()
+    public static function getTestsForOctalNumbersYaml11Notation()
     {
         return [
             'positive octal number' => [28, '034', '0o34'],
@@ -818,7 +818,7 @@ class InlineTest extends TestCase
         $this->assertSame($expected, Inline::parse($value, Yaml::PARSE_OBJECT));
     }
 
-    public function phpObjectTagWithEmptyValueProvider()
+    public static function phpObjectTagWithEmptyValueProvider()
     {
         return [
             [false, '!php/object'],
@@ -842,7 +842,7 @@ class InlineTest extends TestCase
         $this->assertSame($expected, Inline::parse($value, Yaml::PARSE_CONSTANT));
     }
 
-    public function phpConstTagWithEmptyValueProvider()
+    public static function phpConstTagWithEmptyValueProvider()
     {
         return [
             ['', '!php/const'],
@@ -894,7 +894,7 @@ class InlineTest extends TestCase
         Inline::parse($value);
     }
 
-    public function unquotedExclamationMarkThrowsProvider()
+    public static function unquotedExclamationMarkThrowsProvider()
     {
         return [
             ['!'],
@@ -926,7 +926,7 @@ class InlineTest extends TestCase
     }
 
     // This provider should stay consistent with unquotedExclamationMarkThrowsProvider
-    public function quotedExclamationMarkProvider()
+    public static function quotedExclamationMarkProvider()
     {
         return [
             ['!', '"!"'],
@@ -956,7 +956,7 @@ class InlineTest extends TestCase
         $this->assertSame($expected, Inline::parse($yaml));
     }
 
-    public function ideographicSpaceProvider(): array
+    public static function ideographicSpaceProvider(): array
     {
         return [
             ["\u{3000}", '　'],
