@@ -29,7 +29,7 @@ foreach ($_SERVER as $k => $v) {
     }
 }
 
-$json = json_encode($vars, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE);
+$json = json_encode($vars, \JSON_PRETTY_PRINT | \JSON_UNESCAPED_SLASHES | \JSON_UNESCAPED_UNICODE);
 
 switch ($vars['REQUEST_URI']) {
     default:
@@ -63,6 +63,15 @@ switch ($vars['REQUEST_URI']) {
         header('Content-Type: application/json', true, 404);
         break;
 
+    case '/404-gzipped':
+        header('Content-Type: text/plain', true, 404);
+        ob_start('ob_gzhandler');
+        @ob_flush();
+        flush();
+        usleep(300000);
+        echo 'some text';
+        exit;
+
     case '/301':
         if ('Basic Zm9vOmJhcg==' === $vars['HTTP_AUTHORIZATION']) {
             header('Location: http://127.0.0.1:8057/302', true, 301);
@@ -77,6 +86,12 @@ switch ($vars['REQUEST_URI']) {
         header('Location: //?foo=bar', true, 301);
         break;
 
+    case '/301/proxy':
+    case 'http://localhost:8057/301/proxy':
+    case 'http://127.0.0.1:8057/301/proxy':
+        header('Location: http://localhost:8057/', true, 301);
+        break;
+
     case '/302':
         if (!isset($vars['HTTP_AUTHORIZATION'])) {
             header('Location: http://localhost:8057/', true, 302);
@@ -102,7 +117,7 @@ switch ($vars['REQUEST_URI']) {
         break;
 
     case '/post':
-        $output = json_encode($_POST + ['REQUEST_METHOD' => $vars['REQUEST_METHOD']], JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE);
+        $output = json_encode($_POST + ['REQUEST_METHOD' => $vars['REQUEST_METHOD']], \JSON_PRETTY_PRINT | \JSON_UNESCAPED_SLASHES | \JSON_UNESCAPED_UNICODE);
         header('Content-Type: application/json', true);
         header('Content-Length: '.strlen($output));
         echo $output;
@@ -145,6 +160,37 @@ switch ($vars['REQUEST_URI']) {
         header('Content-Encoding: gzip');
         echo str_repeat('-', 1000);
         exit;
+
+    case '/max-duration':
+        ignore_user_abort(false);
+        while (true) {
+            echo '<1>';
+            @ob_flush();
+            flush();
+            usleep(500);
+        }
+        exit;
+
+    case '/json':
+        header('Content-Type: application/json');
+        echo json_encode([
+            'documents' => [
+                ['id' => '/json/1'],
+                ['id' => '/json/2'],
+                ['id' => '/json/3'],
+            ],
+        ]);
+        exit;
+
+    case '/json/1':
+    case '/json/2':
+    case '/json/3':
+        header('Content-Type: application/json');
+        echo json_encode([
+            'title' => $vars['REQUEST_URI'],
+        ]);
+
+        exit;
 }
 
 header('Content-Type: application/json', true);
