@@ -55,8 +55,47 @@ class ServiceSubscriberTraitTest extends TestCase
         $this->assertSame($container, (new TestService())->setContainer($container));
     }
 
+    public function testParentNotCalledIfHasMagicCall()
+    {
+        $container = new class([]) implements ContainerInterface {
+            use ServiceLocatorTrait;
+        };
+        $service = new class() extends ParentWithMagicCall {
+            use ServiceSubscriberTrait;
+        };
+
+        $this->assertNull($service->setContainer($container));
+        $this->assertSame([], $service::getSubscribedServices());
+    }
+
+    public function testParentNotCalledIfNoParent()
+    {
+        $container = new class([]) implements ContainerInterface {
+            use ServiceLocatorTrait;
+        };
+        $service = new class() {
+            use ServiceSubscriberTrait;
+        };
+
+        $this->assertNull($service->setContainer($container));
+        $this->assertSame([], $service::getSubscribedServices());
+    }
+
+    public function testSetContainerCalledFirstOnParent()
+    {
+        $container1 = new class([]) implements ContainerInterface {
+            use ServiceLocatorTrait;
+        };
+        $container2 = clone $container1;
+
+        $testService = new TestService2();
+        $this->assertNull($testService->setContainer($container1));
+        $this->assertSame($container1, $testService->setContainer($container2));
+    }
+
     /**
      * @requires PHP 8
+     *
      * @group legacy
      */
     public function testMethodsWithUnionReturnTypesAreIgnored()
@@ -118,6 +157,38 @@ class ChildTestService extends TestService
     }
 }
 
+class ParentWithMagicCall
+{
+    public function __call($method, $args)
+    {
+        throw new \BadMethodCallException('Should not be called.');
+    }
+
+    public static function __callStatic($method, $args)
+    {
+        throw new \BadMethodCallException('Should not be called.');
+    }
+}
+
 class Service3
 {
 }
+
+class ParentTestService2
+{
+    /** @var ContainerInterface */
+    protected $container;
+
+    public function setContainer(ContainerInterface $container)
+    {
+        $previous = $this->container;
+        $this->container = $container;
+
+        return $previous;
+    }
+}
+
+class TestService2 extends ParentTestService2 implements ServiceSubscriberInterface
+{
+    use ServiceSubscriberTrait;
+}
